<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>PPTX Renderer</title>
  <style>
    * {
      margin: 0;
      padding: 0;
      box-sizing: border-box;
    }
    body {
      background: white;
      overflow: hidden;
    }
    #container {
      width: 100%;
      height: 100vh;
      display: flex;
      justify-content: center;
      align-items: flex-start;
      background: white;
    }
    #pptx-container {
      background: white;
    }
  </style>
  <script type="module" crossorigin>(function(){const e=document.createElement("link").relList;if(e&&e.supports&&e.supports("modulepreload"))return;for(const a of document.querySelectorAll('link[rel="modulepreload"]'))n(a);new MutationObserver(a=>{for(const i of a)if(i.type==="childList")for(const o of i.addedNodes)o.tagName==="LINK"&&o.rel==="modulepreload"&&n(o)}).observe(document,{childList:!0,subtree:!0});function t(a){const i={};return a.integrity&&(i.integrity=a.integrity),a.referrerPolicy&&(i.referrerPolicy=a.referrerPolicy),a.crossOrigin==="use-credentials"?i.credentials="include":a.crossOrigin==="anonymous"?i.credentials="omit":i.credentials="same-origin",i}function n(a){if(a.ep)return;a.ep=!0;const i=t(a);fetch(a.href,i)}})();var V0=function(r,e){return V0=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var a in n)Object.prototype.hasOwnProperty.call(n,a)&&(t[a]=n[a])},V0(r,e)};function Sh(r,e){if(typeof e!="function"&&e!==null)throw new TypeError("Class extends value "+String(e)+" is not a constructor or null");V0(r,e);function t(){this.constructor=r}r.prototype=e===null?Object.create(e):(t.prototype=e.prototype,new t)}var Dt=function(){return Dt=Object.assign||function(e){for(var t,n=1,a=arguments.length;n<a;n++){t=arguments[n];for(var i in t)Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i])}return e},Dt.apply(this,arguments)};function dr(r,e,t,n){function a(i){return i instanceof t?i:new t(function(o){o(i)})}return new(t||(t=Promise))(function(i,o){function s(c){try{u(n.next(c))}catch(h){o(h)}}function l(c){try{u(n.throw(c))}catch(h){o(h)}}function u(c){c.done?i(c.value):a(c.value).then(s,l)}u((n=n.apply(r,e||[])).next())})}function pr(r,e){var t={label:0,sent:function(){if(i[0]&1)throw i[1];return i[1]},trys:[],ops:[]},n,a,i,o=Object.create((typeof Iterator=="function"?Iterator:Object).prototype);return o.next=s(0),o.throw=s(1),o.return=s(2),typeof Symbol=="function"&&(o[Symbol.iterator]=function(){return this}),o;function s(u){return function(c){return l([u,c])}}function l(u){if(n)throw new TypeError("Generator is already executing.");for(;o&&(o=0,u[0]&&(t=0)),t;)try{if(n=1,a&&(i=u[0]&2?a.return:u[0]?a.throw||((i=a.return)&&i.call(a),0):a.next)&&!(i=i.call(a,u[1])).done)return i;switch(a=0,i&&(u=[u[0]&2,i.value]),u[0]){case 0:case 1:i=u;break;case 4:return t.label++,{value:u[1],done:!1};case 5:t.label++,a=u[1],u=[0];continue;case 7:u=t.ops.pop(),t.trys.pop();continue;default:if(i=t.trys,!(i=i.length>0&&i[i.length-1])&&(u[0]===6||u[0]===2)){t=0;continue}if(u[0]===3&&(!i||u[1]>i[0]&&u[1]<i[3])){t.label=u[1];break}if(u[0]===6&&t.label<i[1]){t.label=i[1],i=u;break}if(i&&t.label<i[2]){t.label=i[2],t.ops.push(u);break}i[2]&&t.ops.pop(),t.trys.pop();continue}u=e.call(r,t)}catch(c){u=[6,c],a=0}finally{n=i=0}if(u[0]&5)throw u[1];return{value:u[0]?u[1]:void 0,done:!0}}}function Ic(r,e,t){if(t||arguments.length===2)for(var n=0,a=e.length,i;n<a;n++)(i||!(n in e))&&(i||(i=Array.prototype.slice.call(e,0,n)),i[n]=e[n]);return r.concat(i||Array.prototype.slice.call(e))}var pi=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function JG(r){return r&&r.__esModule&&Object.prototype.hasOwnProperty.call(r,"default")?r.default:r}function Ff(r){throw new Error('Could not dynamically require "'+r+'". Please configure the dynamicRequireTargets or/and ignoreDynamicRequires option of @rollup/plugin-commonjs appropriately for this require call to work.')}var EI={exports:{}};/*!

JSZip v3.10.1 - A JavaScript class for generating and reading zip files
<http://stuartk.com/jszip>

(c) 2009-2016 Stuart Knightley <stuart [at] stuartk.com>
Dual licenced under the MIT license or GPLv3. See https://raw.github.com/Stuk/jszip/main/LICENSE.markdown.

JSZip uses the library pako released under the MIT license :
https://github.com/nodeca/pako/blob/main/LICENSE
*/(function(r,e){(function(t){r.exports=t()})(function(){return function t(n,a,i){function o(u,c){if(!a[u]){if(!n[u]){var h=typeof Ff=="function"&&Ff;if(!c&&h)return h(u,!0);if(s)return s(u,!0);var d=new Error("Cannot find module '"+u+"'");throw d.code="MODULE_NOT_FOUND",d}var v=a[u]={exports:{}};n[u][0].call(v.exports,function(p){var y=n[u][1][p];return o(y||p)},v,v.exports,t,n,a,i)}return a[u].exports}for(var s=typeof Ff=="function"&&Ff,l=0;l<i.length;l++)o(i[l]);return o}({1:[function(t,n,a){var i=t("./utils"),o=t("./support"),s="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";a.encode=function(l){for(var u,c,h,d,v,p,y,_=[],g=0,f=l.length,w=f,x=i.getTypeOf(l)!=="string";g<l.length;)w=f-g,h=x?(u=l[g++],c=g<f?l[g++]:0,g<f?l[g++]:0):(u=l.charCodeAt(g++),c=g<f?l.charCodeAt(g++):0,g<f?l.charCodeAt(g++):0),d=u>>2,v=(3&u)<<4|c>>4,p=1<w?(15&c)<<2|h>>6:64,y=2<w?63&h:64,_.push(s.charAt(d)+s.charAt(v)+s.charAt(p)+s.charAt(y));return _.join("")},a.decode=function(l){var u,c,h,d,v,p,y=0,_=0,g="data:";if(l.substr(0,g.length)===g)throw new Error("Invalid base64 input, it looks like a data url.");var f,w=3*(l=l.replace(/[^A-Za-z0-9+/=]/g,"")).length/4;if(l.charAt(l.length-1)===s.charAt(64)&&w--,l.charAt(l.length-2)===s.charAt(64)&&w--,w%1!=0)throw new Error("Invalid base64 input, bad content length.");for(f=o.uint8array?new Uint8Array(0|w):new Array(0|w);y<l.length;)u=s.indexOf(l.charAt(y++))<<2|(d=s.indexOf(l.charAt(y++)))>>4,c=(15&d)<<4|(v=s.indexOf(l.charAt(y++)))>>2,h=(3&v)<<6|(p=s.indexOf(l.charAt(y++))),f[_++]=u,v!==64&&(f[_++]=c),p!==64&&(f[_++]=h);return f}},{"./support":30,"./utils":32}],2:[function(t,n,a){var i=t("./external"),o=t("./stream/DataWorker"),s=t("./stream/Crc32Probe"),l=t("./stream/DataLengthProbe");function u(c,h,d,v,p){this.compressedSize=c,this.uncompressedSize=h,this.crc32=d,this.compression=v,this.compressedContent=p}u.prototype={getContentWorker:function(){var c=new o(i.Promise.resolve(this.compressedContent)).pipe(this.compression.uncompressWorker()).pipe(new l("data_length")),h=this;return c.on("end",function(){if(this.streamInfo.data_length!==h.uncompressedSize)throw new Error("Bug : uncompressed data size mismatch")}),c},getCompressedWorker:function(){return new o(i.Promise.resolve(this.compressedContent)).withStreamInfo("compressedSize",this.compressedSize).withStreamInfo("uncompressedSize",this.uncompressedSize).withStreamInfo("crc32",this.crc32).withStreamInfo("compression",this.compression)}},u.createWorkerFrom=function(c,h,d){return c.pipe(new s).pipe(new l("uncompressedSize")).pipe(h.compressWorker(d)).pipe(new l("compressedSize")).withStreamInfo("compression",h)},n.exports=u},{"./external":6,"./stream/Crc32Probe":25,"./stream/DataLengthProbe":26,"./stream/DataWorker":27}],3:[function(t,n,a){var i=t("./stream/GenericWorker");a.STORE={magic:"\0\0",compressWorker:function(){return new i("STORE compression")},uncompressWorker:function(){return new i("STORE decompression")}},a.DEFLATE=t("./flate")},{"./flate":7,"./stream/GenericWorker":28}],4:[function(t,n,a){var i=t("./utils"),o=function(){for(var s,l=[],u=0;u<256;u++){s=u;for(var c=0;c<8;c++)s=1&s?3988292384^s>>>1:s>>>1;l[u]=s}return l}();n.exports=function(s,l){return s!==void 0&&s.length?i.getTypeOf(s)!=="string"?function(u,c,h,d){var v=o,p=d+h;u^=-1;for(var y=d;y<p;y++)u=u>>>8^v[255&(u^c[y])];return-1^u}(0|l,s,s.length,0):function(u,c,h,d){var v=o,p=d+h;u^=-1;for(var y=d;y<p;y++)u=u>>>8^v[255&(u^c.charCodeAt(y))];return-1^u}(0|l,s,s.length,0):0}},{"./utils":32}],5:[function(t,n,a){a.base64=!1,a.binary=!1,a.dir=!1,a.createFolders=!0,a.date=null,a.compression=null,a.compressionOptions=null,a.comment=null,a.unixPermissions=null,a.dosPermissions=null},{}],6:[function(t,n,a){var i=null;i=typeof Promise<"u"?Promise:t("lie"),n.exports={Promise:i}},{lie:37}],7:[function(t,n,a){var i=typeof Uint8Array<"u"&&typeof Uint16Array<"u"&&typeof Uint32Array<"u",o=t("pako"),s=t("./utils"),l=t("./stream/GenericWorker"),u=i?"uint8array":"array";function c(h,d){l.call(this,"FlateWorker/"+h),this._pako=null,this._pakoAction=h,this._pakoOptions=d,this.meta={}}a.magic="\b\0",s.inherits(c,l),c.prototype.processChunk=function(h){this.meta=h.meta,this._pako===null&&this._createPako(),this._pako.push(s.transformTo(u,h.data),!1)},c.prototype.flush=function(){l.prototype.flush.call(this),this._pako===null&&this._createPako(),this._pako.push([],!0)},c.prototype.cleanUp=function(){l.prototype.cleanUp.call(this),this._pako=null},c.prototype._createPako=function(){this._pako=new o[this._pakoAction]({raw:!0,level:this._pakoOptions.level||-1});var h=this;this._pako.onData=function(d){h.push({data:d,meta:h.meta})}},a.compressWorker=function(h){return new c("Deflate",h)},a.uncompressWorker=function(){return new c("Inflate",{})}},{"./stream/GenericWorker":28,"./utils":32,pako:38}],8:[function(t,n,a){function i(v,p){var y,_="";for(y=0;y<p;y++)_+=String.fromCharCode(255&v),v>>>=8;return _}function o(v,p,y,_,g,f){var w,x,S=v.file,A=v.compression,T=f!==u.utf8encode,L=s.transformTo("string",f(S.name)),M=s.transformTo("string",u.utf8encode(S.name)),I=S.comment,R=s.transformTo("string",f(I)),P=s.transformTo("string",u.utf8encode(I)),E=M.length!==S.name.length,D=P.length!==I.length,N="",V="",W="",$=S.dir,H=S.date,K={crc32:0,compressedSize:0,uncompressedSize:0};p&&!y||(K.crc32=v.crc32,K.compressedSize=v.compressedSize,K.uncompressedSize=v.uncompressedSize);var U=0;p&&(U|=8),T||!E&&!D||(U|=2048);var j=0,ut=0;$&&(j|=16),g==="UNIX"?(ut=798,j|=function(it,Et){var jt=it;return it||(jt=Et?16893:33204),(65535&jt)<<16}(S.unixPermissions,$)):(ut=20,j|=function(it){return 63&(it||0)}(S.dosPermissions)),w=H.getUTCHours(),w<<=6,w|=H.getUTCMinutes(),w<<=5,w|=H.getUTCSeconds()/2,x=H.getUTCFullYear()-1980,x<<=4,x|=H.getUTCMonth()+1,x<<=5,x|=H.getUTCDate(),E&&(V=i(1,1)+i(c(L),4)+M,N+="up"+i(V.length,2)+V),D&&(W=i(1,1)+i(c(R),4)+P,N+="uc"+i(W.length,2)+W);var ot="";return ot+=`
\0`,ot+=i(U,2),ot+=A.magic,ot+=i(w,2),ot+=i(x,2),ot+=i(K.crc32,4),ot+=i(K.compressedSize,4),ot+=i(K.uncompressedSize,4),ot+=i(L.length,2),ot+=i(N.length,2),{fileRecord:h.LOCAL_FILE_HEADER+ot+L+N,dirRecord:h.CENTRAL_FILE_HEADER+i(ut,2)+ot+i(R.length,2)+"\0\0\0\0"+i(j,4)+i(_,4)+L+N+R}}var s=t("../utils"),l=t("../stream/GenericWorker"),u=t("../utf8"),c=t("../crc32"),h=t("../signature");function d(v,p,y,_){l.call(this,"ZipFileWorker"),this.bytesWritten=0,this.zipComment=p,this.zipPlatform=y,this.encodeFileName=_,this.streamFiles=v,this.accumulate=!1,this.contentBuffer=[],this.dirRecords=[],this.currentSourceOffset=0,this.entriesCount=0,this.currentFile=null,this._sources=[]}s.inherits(d,l),d.prototype.push=function(v){var p=v.meta.percent||0,y=this.entriesCount,_=this._sources.length;this.accumulate?this.contentBuffer.push(v):(this.bytesWritten+=v.data.length,l.prototype.push.call(this,{data:v.data,meta:{currentFile:this.currentFile,percent:y?(p+100*(y-_-1))/y:100}}))},d.prototype.openedSource=function(v){this.currentSourceOffset=this.bytesWritten,this.currentFile=v.file.name;var p=this.streamFiles&&!v.file.dir;if(p){var y=o(v,p,!1,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);this.push({data:y.fileRecord,meta:{percent:0}})}else this.accumulate=!0},d.prototype.closedSource=function(v){this.accumulate=!1;var p=this.streamFiles&&!v.file.dir,y=o(v,p,!0,this.currentSourceOffset,this.zipPlatform,this.encodeFileName);if(this.dirRecords.push(y.dirRecord),p)this.push({data:function(_){return h.DATA_DESCRIPTOR+i(_.crc32,4)+i(_.compressedSize,4)+i(_.uncompressedSize,4)}(v),meta:{percent:100}});else for(this.push({data:y.fileRecord,meta:{percent:0}});this.contentBuffer.length;)this.push(this.contentBuffer.shift());this.currentFile=null},d.prototype.flush=function(){for(var v=this.bytesWritten,p=0;p<this.dirRecords.length;p++)this.push({data:this.dirRecords[p],meta:{percent:100}});var y=this.bytesWritten-v,_=function(g,f,w,x,S){var A=s.transformTo("string",S(x));return h.CENTRAL_DIRECTORY_END+"\0\0\0\0"+i(g,2)+i(g,2)+i(f,4)+i(w,4)+i(A.length,2)+A}(this.dirRecords.length,y,v,this.zipComment,this.encodeFileName);this.push({data:_,meta:{percent:100}})},d.prototype.prepareNextSource=function(){this.previous=this._sources.shift(),this.openedSource(this.previous.streamInfo),this.isPaused?this.previous.pause():this.previous.resume()},d.prototype.registerPrevious=function(v){this._sources.push(v);var p=this;return v.on("data",function(y){p.processChunk(y)}),v.on("end",function(){p.closedSource(p.previous.streamInfo),p._sources.length?p.prepareNextSource():p.end()}),v.on("error",function(y){p.error(y)}),this},d.prototype.resume=function(){return!!l.prototype.resume.call(this)&&(!this.previous&&this._sources.length?(this.prepareNextSource(),!0):this.previous||this._sources.length||this.generatedError?void 0:(this.end(),!0))},d.prototype.error=function(v){var p=this._sources;if(!l.prototype.error.call(this,v))return!1;for(var y=0;y<p.length;y++)try{p[y].error(v)}catch{}return!0},d.prototype.lock=function(){l.prototype.lock.call(this);for(var v=this._sources,p=0;p<v.length;p++)v[p].lock()},n.exports=d},{"../crc32":4,"../signature":23,"../stream/GenericWorker":28,"../utf8":31,"../utils":32}],9:[function(t,n,a){var i=t("../compressions"),o=t("./ZipFileWorker");a.generateWorker=function(s,l,u){var c=new o(l.streamFiles,u,l.platform,l.encodeFileName),h=0;try{s.forEach(function(d,v){h++;var p=function(f,w){var x=f||w,S=i[x];if(!S)throw new Error(x+" is not a valid compression method !");return S}(v.options.compression,l.compression),y=v.options.compressionOptions||l.compressionOptions||{},_=v.dir,g=v.date;v._compressWorker(p,y).withStreamInfo("file",{name:d,dir:_,date:g,comment:v.comment||"",unixPermissions:v.unixPermissions,dosPermissions:v.dosPermissions}).pipe(c)}),c.entriesCount=h}catch(d){c.error(d)}return c}},{"../compressions":3,"./ZipFileWorker":8}],10:[function(t,n,a){function i(){if(!(this instanceof i))return new i;if(arguments.length)throw new Error("The constructor with parameters has been removed in JSZip 3.0, please check the upgrade guide.");this.files=Object.create(null),this.comment=null,this.root="",this.clone=function(){var o=new i;for(var s in this)typeof this[s]!="function"&&(o[s]=this[s]);return o}}(i.prototype=t("./object")).loadAsync=t("./load"),i.support=t("./support"),i.defaults=t("./defaults"),i.version="3.10.1",i.loadAsync=function(o,s){return new i().loadAsync(o,s)},i.external=t("./external"),n.exports=i},{"./defaults":5,"./external":6,"./load":11,"./object":15,"./support":30}],11:[function(t,n,a){var i=t("./utils"),o=t("./external"),s=t("./utf8"),l=t("./zipEntries"),u=t("./stream/Crc32Probe"),c=t("./nodejsUtils");function h(d){return new o.Promise(function(v,p){var y=d.decompressed.getContentWorker().pipe(new u);y.on("error",function(_){p(_)}).on("end",function(){y.streamInfo.crc32!==d.decompressed.crc32?p(new Error("Corrupted zip : CRC32 mismatch")):v()}).resume()})}n.exports=function(d,v){var p=this;return v=i.extend(v||{},{base64:!1,checkCRC32:!1,optimizedBinaryString:!1,createFolders:!1,decodeFileName:s.utf8decode}),c.isNode&&c.isStream(d)?o.Promise.reject(new Error("JSZip can't accept a stream when loading a zip file.")):i.prepareContent("the loaded zip file",d,!0,v.optimizedBinaryString,v.base64).then(function(y){var _=new l(v);return _.load(y),_}).then(function(y){var _=[o.Promise.resolve(y)],g=y.files;if(v.checkCRC32)for(var f=0;f<g.length;f++)_.push(h(g[f]));return o.Promise.all(_)}).then(function(y){for(var _=y.shift(),g=_.files,f=0;f<g.length;f++){var w=g[f],x=w.fileNameStr,S=i.resolve(w.fileNameStr);p.file(S,w.decompressed,{binary:!0,optimizedBinaryString:!0,date:w.date,dir:w.dir,comment:w.fileCommentStr.length?w.fileCommentStr:null,unixPermissions:w.unixPermissions,dosPermissions:w.dosPermissions,createFolders:v.createFolders}),w.dir||(p.file(S).unsafeOriginalName=x)}return _.zipComment.length&&(p.comment=_.zipComment),p})}},{"./external":6,"./nodejsUtils":14,"./stream/Crc32Probe":25,"./utf8":31,"./utils":32,"./zipEntries":33}],12:[function(t,n,a){var i=t("../utils"),o=t("../stream/GenericWorker");function s(l,u){o.call(this,"Nodejs stream input adapter for "+l),this._upstreamEnded=!1,this._bindStream(u)}i.inherits(s,o),s.prototype._bindStream=function(l){var u=this;(this._stream=l).pause(),l.on("data",function(c){u.push({data:c,meta:{percent:0}})}).on("error",function(c){u.isPaused?this.generatedError=c:u.error(c)}).on("end",function(){u.isPaused?u._upstreamEnded=!0:u.end()})},s.prototype.pause=function(){return!!o.prototype.pause.call(this)&&(this._stream.pause(),!0)},s.prototype.resume=function(){return!!o.prototype.resume.call(this)&&(this._upstreamEnded?this.end():this._stream.resume(),!0)},n.exports=s},{"../stream/GenericWorker":28,"../utils":32}],13:[function(t,n,a){var i=t("readable-stream").Readable;function o(s,l,u){i.call(this,l),this._helper=s;var c=this;s.on("data",function(h,d){c.push(h)||c._helper.pause(),u&&u(d)}).on("error",function(h){c.emit("error",h)}).on("end",function(){c.push(null)})}t("../utils").inherits(o,i),o.prototype._read=function(){this._helper.resume()},n.exports=o},{"../utils":32,"readable-stream":16}],14:[function(t,n,a){n.exports={isNode:typeof Buffer<"u",newBufferFrom:function(i,o){if(Buffer.from&&Buffer.from!==Uint8Array.from)return Buffer.from(i,o);if(typeof i=="number")throw new Error('The "data" argument must not be a number');return new Buffer(i,o)},allocBuffer:function(i){if(Buffer.alloc)return Buffer.alloc(i);var o=new Buffer(i);return o.fill(0),o},isBuffer:function(i){return Buffer.isBuffer(i)},isStream:function(i){return i&&typeof i.on=="function"&&typeof i.pause=="function"&&typeof i.resume=="function"}}},{}],15:[function(t,n,a){function i(S,A,T){var L,M=s.getTypeOf(A),I=s.extend(T||{},c);I.date=I.date||new Date,I.compression!==null&&(I.compression=I.compression.toUpperCase()),typeof I.unixPermissions=="string"&&(I.unixPermissions=parseInt(I.unixPermissions,8)),I.unixPermissions&&16384&I.unixPermissions&&(I.dir=!0),I.dosPermissions&&16&I.dosPermissions&&(I.dir=!0),I.dir&&(S=g(S)),I.createFolders&&(L=_(S))&&f.call(this,L,!0);var R=M==="string"&&I.binary===!1&&I.base64===!1;T&&T.binary!==void 0||(I.binary=!R),(A instanceof h&&A.uncompressedSize===0||I.dir||!A||A.length===0)&&(I.base64=!1,I.binary=!0,A="",I.compression="STORE",M="string");var P=null;P=A instanceof h||A instanceof l?A:p.isNode&&p.isStream(A)?new y(S,A):s.prepareContent(S,A,I.binary,I.optimizedBinaryString,I.base64);var E=new d(S,P,I);this.files[S]=E}var o=t("./utf8"),s=t("./utils"),l=t("./stream/GenericWorker"),u=t("./stream/StreamHelper"),c=t("./defaults"),h=t("./compressedObject"),d=t("./zipObject"),v=t("./generate"),p=t("./nodejsUtils"),y=t("./nodejs/NodejsStreamInputAdapter"),_=function(S){S.slice(-1)==="/"&&(S=S.substring(0,S.length-1));var A=S.lastIndexOf("/");return 0<A?S.substring(0,A):""},g=function(S){return S.slice(-1)!=="/"&&(S+="/"),S},f=function(S,A){return A=A!==void 0?A:c.createFolders,S=g(S),this.files[S]||i.call(this,S,null,{dir:!0,createFolders:A}),this.files[S]};function w(S){return Object.prototype.toString.call(S)==="[object RegExp]"}var x={load:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},forEach:function(S){var A,T,L;for(A in this.files)L=this.files[A],(T=A.slice(this.root.length,A.length))&&A.slice(0,this.root.length)===this.root&&S(T,L)},filter:function(S){var A=[];return this.forEach(function(T,L){S(T,L)&&A.push(L)}),A},file:function(S,A,T){if(arguments.length!==1)return S=this.root+S,i.call(this,S,A,T),this;if(w(S)){var L=S;return this.filter(function(I,R){return!R.dir&&L.test(I)})}var M=this.files[this.root+S];return M&&!M.dir?M:null},folder:function(S){if(!S)return this;if(w(S))return this.filter(function(M,I){return I.dir&&S.test(M)});var A=this.root+S,T=f.call(this,A),L=this.clone();return L.root=T.name,L},remove:function(S){S=this.root+S;var A=this.files[S];if(A||(S.slice(-1)!=="/"&&(S+="/"),A=this.files[S]),A&&!A.dir)delete this.files[S];else for(var T=this.filter(function(M,I){return I.name.slice(0,S.length)===S}),L=0;L<T.length;L++)delete this.files[T[L].name];return this},generate:function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},generateInternalStream:function(S){var A,T={};try{if((T=s.extend(S||{},{streamFiles:!1,compression:"STORE",compressionOptions:null,type:"",platform:"DOS",comment:null,mimeType:"application/zip",encodeFileName:o.utf8encode})).type=T.type.toLowerCase(),T.compression=T.compression.toUpperCase(),T.type==="binarystring"&&(T.type="string"),!T.type)throw new Error("No output type specified.");s.checkSupport(T.type),T.platform!=="darwin"&&T.platform!=="freebsd"&&T.platform!=="linux"&&T.platform!=="sunos"||(T.platform="UNIX"),T.platform==="win32"&&(T.platform="DOS");var L=T.comment||this.comment||"";A=v.generateWorker(this,T,L)}catch(M){(A=new l("error")).error(M)}return new u(A,T.type||"string",T.mimeType)},generateAsync:function(S,A){return this.generateInternalStream(S).accumulate(A)},generateNodeStream:function(S,A){return(S=S||{}).type||(S.type="nodebuffer"),this.generateInternalStream(S).toNodejsStream(A)}};n.exports=x},{"./compressedObject":2,"./defaults":5,"./generate":9,"./nodejs/NodejsStreamInputAdapter":12,"./nodejsUtils":14,"./stream/GenericWorker":28,"./stream/StreamHelper":29,"./utf8":31,"./utils":32,"./zipObject":35}],16:[function(t,n,a){n.exports=t("stream")},{stream:void 0}],17:[function(t,n,a){var i=t("./DataReader");function o(s){i.call(this,s);for(var l=0;l<this.data.length;l++)s[l]=255&s[l]}t("../utils").inherits(o,i),o.prototype.byteAt=function(s){return this.data[this.zero+s]},o.prototype.lastIndexOfSignature=function(s){for(var l=s.charCodeAt(0),u=s.charCodeAt(1),c=s.charCodeAt(2),h=s.charCodeAt(3),d=this.length-4;0<=d;--d)if(this.data[d]===l&&this.data[d+1]===u&&this.data[d+2]===c&&this.data[d+3]===h)return d-this.zero;return-1},o.prototype.readAndCheckSignature=function(s){var l=s.charCodeAt(0),u=s.charCodeAt(1),c=s.charCodeAt(2),h=s.charCodeAt(3),d=this.readData(4);return l===d[0]&&u===d[1]&&c===d[2]&&h===d[3]},o.prototype.readData=function(s){if(this.checkOffset(s),s===0)return[];var l=this.data.slice(this.zero+this.index,this.zero+this.index+s);return this.index+=s,l},n.exports=o},{"../utils":32,"./DataReader":18}],18:[function(t,n,a){var i=t("../utils");function o(s){this.data=s,this.length=s.length,this.index=0,this.zero=0}o.prototype={checkOffset:function(s){this.checkIndex(this.index+s)},checkIndex:function(s){if(this.length<this.zero+s||s<0)throw new Error("End of data reached (data length = "+this.length+", asked index = "+s+"). Corrupted zip ?")},setIndex:function(s){this.checkIndex(s),this.index=s},skip:function(s){this.setIndex(this.index+s)},byteAt:function(){},readInt:function(s){var l,u=0;for(this.checkOffset(s),l=this.index+s-1;l>=this.index;l--)u=(u<<8)+this.byteAt(l);return this.index+=s,u},readString:function(s){return i.transformTo("string",this.readData(s))},readData:function(){},lastIndexOfSignature:function(){},readAndCheckSignature:function(){},readDate:function(){var s=this.readInt(4);return new Date(Date.UTC(1980+(s>>25&127),(s>>21&15)-1,s>>16&31,s>>11&31,s>>5&63,(31&s)<<1))}},n.exports=o},{"../utils":32}],19:[function(t,n,a){var i=t("./Uint8ArrayReader");function o(s){i.call(this,s)}t("../utils").inherits(o,i),o.prototype.readData=function(s){this.checkOffset(s);var l=this.data.slice(this.zero+this.index,this.zero+this.index+s);return this.index+=s,l},n.exports=o},{"../utils":32,"./Uint8ArrayReader":21}],20:[function(t,n,a){var i=t("./DataReader");function o(s){i.call(this,s)}t("../utils").inherits(o,i),o.prototype.byteAt=function(s){return this.data.charCodeAt(this.zero+s)},o.prototype.lastIndexOfSignature=function(s){return this.data.lastIndexOf(s)-this.zero},o.prototype.readAndCheckSignature=function(s){return s===this.readData(4)},o.prototype.readData=function(s){this.checkOffset(s);var l=this.data.slice(this.zero+this.index,this.zero+this.index+s);return this.index+=s,l},n.exports=o},{"../utils":32,"./DataReader":18}],21:[function(t,n,a){var i=t("./ArrayReader");function o(s){i.call(this,s)}t("../utils").inherits(o,i),o.prototype.readData=function(s){if(this.checkOffset(s),s===0)return new Uint8Array(0);var l=this.data.subarray(this.zero+this.index,this.zero+this.index+s);return this.index+=s,l},n.exports=o},{"../utils":32,"./ArrayReader":17}],22:[function(t,n,a){var i=t("../utils"),o=t("../support"),s=t("./ArrayReader"),l=t("./StringReader"),u=t("./NodeBufferReader"),c=t("./Uint8ArrayReader");n.exports=function(h){var d=i.getTypeOf(h);return i.checkSupport(d),d!=="string"||o.uint8array?d==="nodebuffer"?new u(h):o.uint8array?new c(i.transformTo("uint8array",h)):new s(i.transformTo("array",h)):new l(h)}},{"../support":30,"../utils":32,"./ArrayReader":17,"./NodeBufferReader":19,"./StringReader":20,"./Uint8ArrayReader":21}],23:[function(t,n,a){a.LOCAL_FILE_HEADER="PK",a.CENTRAL_FILE_HEADER="PK",a.CENTRAL_DIRECTORY_END="PK",a.ZIP64_CENTRAL_DIRECTORY_LOCATOR="PK\x07",a.ZIP64_CENTRAL_DIRECTORY_END="PK",a.DATA_DESCRIPTOR="PK\x07\b"},{}],24:[function(t,n,a){var i=t("./GenericWorker"),o=t("../utils");function s(l){i.call(this,"ConvertWorker to "+l),this.destType=l}o.inherits(s,i),s.prototype.processChunk=function(l){this.push({data:o.transformTo(this.destType,l.data),meta:l.meta})},n.exports=s},{"../utils":32,"./GenericWorker":28}],25:[function(t,n,a){var i=t("./GenericWorker"),o=t("../crc32");function s(){i.call(this,"Crc32Probe"),this.withStreamInfo("crc32",0)}t("../utils").inherits(s,i),s.prototype.processChunk=function(l){this.streamInfo.crc32=o(l.data,this.streamInfo.crc32||0),this.push(l)},n.exports=s},{"../crc32":4,"../utils":32,"./GenericWorker":28}],26:[function(t,n,a){var i=t("../utils"),o=t("./GenericWorker");function s(l){o.call(this,"DataLengthProbe for "+l),this.propName=l,this.withStreamInfo(l,0)}i.inherits(s,o),s.prototype.processChunk=function(l){if(l){var u=this.streamInfo[this.propName]||0;this.streamInfo[this.propName]=u+l.data.length}o.prototype.processChunk.call(this,l)},n.exports=s},{"../utils":32,"./GenericWorker":28}],27:[function(t,n,a){var i=t("../utils"),o=t("./GenericWorker");function s(l){o.call(this,"DataWorker");var u=this;this.dataIsReady=!1,this.index=0,this.max=0,this.data=null,this.type="",this._tickScheduled=!1,l.then(function(c){u.dataIsReady=!0,u.data=c,u.max=c&&c.length||0,u.type=i.getTypeOf(c),u.isPaused||u._tickAndRepeat()},function(c){u.error(c)})}i.inherits(s,o),s.prototype.cleanUp=function(){o.prototype.cleanUp.call(this),this.data=null},s.prototype.resume=function(){return!!o.prototype.resume.call(this)&&(!this._tickScheduled&&this.dataIsReady&&(this._tickScheduled=!0,i.delay(this._tickAndRepeat,[],this)),!0)},s.prototype._tickAndRepeat=function(){this._tickScheduled=!1,this.isPaused||this.isFinished||(this._tick(),this.isFinished||(i.delay(this._tickAndRepeat,[],this),this._tickScheduled=!0))},s.prototype._tick=function(){if(this.isPaused||this.isFinished)return!1;var l=null,u=Math.min(this.max,this.index+16384);if(this.index>=this.max)return this.end();switch(this.type){case"string":l=this.data.substring(this.index,u);break;case"uint8array":l=this.data.subarray(this.index,u);break;case"array":case"nodebuffer":l=this.data.slice(this.index,u)}return this.index=u,this.push({data:l,meta:{percent:this.max?this.index/this.max*100:0}})},n.exports=s},{"../utils":32,"./GenericWorker":28}],28:[function(t,n,a){function i(o){this.name=o||"default",this.streamInfo={},this.generatedError=null,this.extraStreamInfo={},this.isPaused=!0,this.isFinished=!1,this.isLocked=!1,this._listeners={data:[],end:[],error:[]},this.previous=null}i.prototype={push:function(o){this.emit("data",o)},end:function(){if(this.isFinished)return!1;this.flush();try{this.emit("end"),this.cleanUp(),this.isFinished=!0}catch(o){this.emit("error",o)}return!0},error:function(o){return!this.isFinished&&(this.isPaused?this.generatedError=o:(this.isFinished=!0,this.emit("error",o),this.previous&&this.previous.error(o),this.cleanUp()),!0)},on:function(o,s){return this._listeners[o].push(s),this},cleanUp:function(){this.streamInfo=this.generatedError=this.extraStreamInfo=null,this._listeners=[]},emit:function(o,s){if(this._listeners[o])for(var l=0;l<this._listeners[o].length;l++)this._listeners[o][l].call(this,s)},pipe:function(o){return o.registerPrevious(this)},registerPrevious:function(o){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.streamInfo=o.streamInfo,this.mergeStreamInfo(),this.previous=o;var s=this;return o.on("data",function(l){s.processChunk(l)}),o.on("end",function(){s.end()}),o.on("error",function(l){s.error(l)}),this},pause:function(){return!this.isPaused&&!this.isFinished&&(this.isPaused=!0,this.previous&&this.previous.pause(),!0)},resume:function(){if(!this.isPaused||this.isFinished)return!1;var o=this.isPaused=!1;return this.generatedError&&(this.error(this.generatedError),o=!0),this.previous&&this.previous.resume(),!o},flush:function(){},processChunk:function(o){this.push(o)},withStreamInfo:function(o,s){return this.extraStreamInfo[o]=s,this.mergeStreamInfo(),this},mergeStreamInfo:function(){for(var o in this.extraStreamInfo)Object.prototype.hasOwnProperty.call(this.extraStreamInfo,o)&&(this.streamInfo[o]=this.extraStreamInfo[o])},lock:function(){if(this.isLocked)throw new Error("The stream '"+this+"' has already been used.");this.isLocked=!0,this.previous&&this.previous.lock()},toString:function(){var o="Worker "+this.name;return this.previous?this.previous+" -> "+o:o}},n.exports=i},{}],29:[function(t,n,a){var i=t("../utils"),o=t("./ConvertWorker"),s=t("./GenericWorker"),l=t("../base64"),u=t("../support"),c=t("../external"),h=null;if(u.nodestream)try{h=t("../nodejs/NodejsStreamOutputAdapter")}catch{}function d(p,y){return new c.Promise(function(_,g){var f=[],w=p._internalType,x=p._outputType,S=p._mimeType;p.on("data",function(A,T){f.push(A),y&&y(T)}).on("error",function(A){f=[],g(A)}).on("end",function(){try{var A=function(T,L,M){switch(T){case"blob":return i.newBlob(i.transformTo("arraybuffer",L),M);case"base64":return l.encode(L);default:return i.transformTo(T,L)}}(x,function(T,L){var M,I=0,R=null,P=0;for(M=0;M<L.length;M++)P+=L[M].length;switch(T){case"string":return L.join("");case"array":return Array.prototype.concat.apply([],L);case"uint8array":for(R=new Uint8Array(P),M=0;M<L.length;M++)R.set(L[M],I),I+=L[M].length;return R;case"nodebuffer":return Buffer.concat(L);default:throw new Error("concat : unsupported type '"+T+"'")}}(w,f),S);_(A)}catch(T){g(T)}f=[]}).resume()})}function v(p,y,_){var g=y;switch(y){case"blob":case"arraybuffer":g="uint8array";break;case"base64":g="string"}try{this._internalType=g,this._outputType=y,this._mimeType=_,i.checkSupport(g),this._worker=p.pipe(new o(g)),p.lock()}catch(f){this._worker=new s("error"),this._worker.error(f)}}v.prototype={accumulate:function(p){return d(this,p)},on:function(p,y){var _=this;return p==="data"?this._worker.on(p,function(g){y.call(_,g.data,g.meta)}):this._worker.on(p,function(){i.delay(y,arguments,_)}),this},resume:function(){return i.delay(this._worker.resume,[],this._worker),this},pause:function(){return this._worker.pause(),this},toNodejsStream:function(p){if(i.checkSupport("nodestream"),this._outputType!=="nodebuffer")throw new Error(this._outputType+" is not supported by this method");return new h(this,{objectMode:this._outputType!=="nodebuffer"},p)}},n.exports=v},{"../base64":1,"../external":6,"../nodejs/NodejsStreamOutputAdapter":13,"../support":30,"../utils":32,"./ConvertWorker":24,"./GenericWorker":28}],30:[function(t,n,a){if(a.base64=!0,a.array=!0,a.string=!0,a.arraybuffer=typeof ArrayBuffer<"u"&&typeof Uint8Array<"u",a.nodebuffer=typeof Buffer<"u",a.uint8array=typeof Uint8Array<"u",typeof ArrayBuffer>"u")a.blob=!1;else{var i=new ArrayBuffer(0);try{a.blob=new Blob([i],{type:"application/zip"}).size===0}catch{try{var o=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);o.append(i),a.blob=o.getBlob("application/zip").size===0}catch{a.blob=!1}}}try{a.nodestream=!!t("readable-stream").Readable}catch{a.nodestream=!1}},{"readable-stream":16}],31:[function(t,n,a){for(var i=t("./utils"),o=t("./support"),s=t("./nodejsUtils"),l=t("./stream/GenericWorker"),u=new Array(256),c=0;c<256;c++)u[c]=252<=c?6:248<=c?5:240<=c?4:224<=c?3:192<=c?2:1;u[254]=u[254]=1;function h(){l.call(this,"utf-8 decode"),this.leftOver=null}function d(){l.call(this,"utf-8 encode")}a.utf8encode=function(v){return o.nodebuffer?s.newBufferFrom(v,"utf-8"):function(p){var y,_,g,f,w,x=p.length,S=0;for(f=0;f<x;f++)(64512&(_=p.charCodeAt(f)))==55296&&f+1<x&&(64512&(g=p.charCodeAt(f+1)))==56320&&(_=65536+(_-55296<<10)+(g-56320),f++),S+=_<128?1:_<2048?2:_<65536?3:4;for(y=o.uint8array?new Uint8Array(S):new Array(S),f=w=0;w<S;f++)(64512&(_=p.charCodeAt(f)))==55296&&f+1<x&&(64512&(g=p.charCodeAt(f+1)))==56320&&(_=65536+(_-55296<<10)+(g-56320),f++),_<128?y[w++]=_:(_<2048?y[w++]=192|_>>>6:(_<65536?y[w++]=224|_>>>12:(y[w++]=240|_>>>18,y[w++]=128|_>>>12&63),y[w++]=128|_>>>6&63),y[w++]=128|63&_);return y}(v)},a.utf8decode=function(v){return o.nodebuffer?i.transformTo("nodebuffer",v).toString("utf-8"):function(p){var y,_,g,f,w=p.length,x=new Array(2*w);for(y=_=0;y<w;)if((g=p[y++])<128)x[_++]=g;else if(4<(f=u[g]))x[_++]=65533,y+=f-1;else{for(g&=f===2?31:f===3?15:7;1<f&&y<w;)g=g<<6|63&p[y++],f--;1<f?x[_++]=65533:g<65536?x[_++]=g:(g-=65536,x[_++]=55296|g>>10&1023,x[_++]=56320|1023&g)}return x.length!==_&&(x.subarray?x=x.subarray(0,_):x.length=_),i.applyFromCharCode(x)}(v=i.transformTo(o.uint8array?"uint8array":"array",v))},i.inherits(h,l),h.prototype.processChunk=function(v){var p=i.transformTo(o.uint8array?"uint8array":"array",v.data);if(this.leftOver&&this.leftOver.length){if(o.uint8array){var y=p;(p=new Uint8Array(y.length+this.leftOver.length)).set(this.leftOver,0),p.set(y,this.leftOver.length)}else p=this.leftOver.concat(p);this.leftOver=null}var _=function(f,w){var x;for((w=w||f.length)>f.length&&(w=f.length),x=w-1;0<=x&&(192&f[x])==128;)x--;return x<0||x===0?w:x+u[f[x]]>w?x:w}(p),g=p;_!==p.length&&(o.uint8array?(g=p.subarray(0,_),this.leftOver=p.subarray(_,p.length)):(g=p.slice(0,_),this.leftOver=p.slice(_,p.length))),this.push({data:a.utf8decode(g),meta:v.meta})},h.prototype.flush=function(){this.leftOver&&this.leftOver.length&&(this.push({data:a.utf8decode(this.leftOver),meta:{}}),this.leftOver=null)},a.Utf8DecodeWorker=h,i.inherits(d,l),d.prototype.processChunk=function(v){this.push({data:a.utf8encode(v.data),meta:v.meta})},a.Utf8EncodeWorker=d},{"./nodejsUtils":14,"./stream/GenericWorker":28,"./support":30,"./utils":32}],32:[function(t,n,a){var i=t("./support"),o=t("./base64"),s=t("./nodejsUtils"),l=t("./external");function u(y){return y}function c(y,_){for(var g=0;g<y.length;++g)_[g]=255&y.charCodeAt(g);return _}t("setimmediate"),a.newBlob=function(y,_){a.checkSupport("blob");try{return new Blob([y],{type:_})}catch{try{var g=new(self.BlobBuilder||self.WebKitBlobBuilder||self.MozBlobBuilder||self.MSBlobBuilder);return g.append(y),g.getBlob(_)}catch{throw new Error("Bug : can't construct the Blob.")}}};var h={stringifyByChunk:function(y,_,g){var f=[],w=0,x=y.length;if(x<=g)return String.fromCharCode.apply(null,y);for(;w<x;)_==="array"||_==="nodebuffer"?f.push(String.fromCharCode.apply(null,y.slice(w,Math.min(w+g,x)))):f.push(String.fromCharCode.apply(null,y.subarray(w,Math.min(w+g,x)))),w+=g;return f.join("")},stringifyByChar:function(y){for(var _="",g=0;g<y.length;g++)_+=String.fromCharCode(y[g]);return _},applyCanBeUsed:{uint8array:function(){try{return i.uint8array&&String.fromCharCode.apply(null,new Uint8Array(1)).length===1}catch{return!1}}(),nodebuffer:function(){try{return i.nodebuffer&&String.fromCharCode.apply(null,s.allocBuffer(1)).length===1}catch{return!1}}()}};function d(y){var _=65536,g=a.getTypeOf(y),f=!0;if(g==="uint8array"?f=h.applyCanBeUsed.uint8array:g==="nodebuffer"&&(f=h.applyCanBeUsed.nodebuffer),f)for(;1<_;)try{return h.stringifyByChunk(y,g,_)}catch{_=Math.floor(_/2)}return h.stringifyByChar(y)}function v(y,_){for(var g=0;g<y.length;g++)_[g]=y[g];return _}a.applyFromCharCode=d;var p={};p.string={string:u,array:function(y){return c(y,new Array(y.length))},arraybuffer:function(y){return p.string.uint8array(y).buffer},uint8array:function(y){return c(y,new Uint8Array(y.length))},nodebuffer:function(y){return c(y,s.allocBuffer(y.length))}},p.array={string:d,array:u,arraybuffer:function(y){return new Uint8Array(y).buffer},uint8array:function(y){return new Uint8Array(y)},nodebuffer:function(y){return s.newBufferFrom(y)}},p.arraybuffer={string:function(y){return d(new Uint8Array(y))},array:function(y){return v(new Uint8Array(y),new Array(y.byteLength))},arraybuffer:u,uint8array:function(y){return new Uint8Array(y)},nodebuffer:function(y){return s.newBufferFrom(new Uint8Array(y))}},p.uint8array={string:d,array:function(y){return v(y,new Array(y.length))},arraybuffer:function(y){return y.buffer},uint8array:u,nodebuffer:function(y){return s.newBufferFrom(y)}},p.nodebuffer={string:d,array:function(y){return v(y,new Array(y.length))},arraybuffer:function(y){return p.nodebuffer.uint8array(y).buffer},uint8array:function(y){return v(y,new Uint8Array(y.length))},nodebuffer:u},a.transformTo=function(y,_){if(_=_||"",!y)return _;a.checkSupport(y);var g=a.getTypeOf(_);return p[g][y](_)},a.resolve=function(y){for(var _=y.split("/"),g=[],f=0;f<_.length;f++){var w=_[f];w==="."||w===""&&f!==0&&f!==_.length-1||(w===".."?g.pop():g.push(w))}return g.join("/")},a.getTypeOf=function(y){return typeof y=="string"?"string":Object.prototype.toString.call(y)==="[object Array]"?"array":i.nodebuffer&&s.isBuffer(y)?"nodebuffer":i.uint8array&&y instanceof Uint8Array?"uint8array":i.arraybuffer&&y instanceof ArrayBuffer?"arraybuffer":void 0},a.checkSupport=function(y){if(!i[y.toLowerCase()])throw new Error(y+" is not supported by this platform")},a.MAX_VALUE_16BITS=65535,a.MAX_VALUE_32BITS=-1,a.pretty=function(y){var _,g,f="";for(g=0;g<(y||"").length;g++)f+="\\x"+((_=y.charCodeAt(g))<16?"0":"")+_.toString(16).toUpperCase();return f},a.delay=function(y,_,g){setImmediate(function(){y.apply(g||null,_||[])})},a.inherits=function(y,_){function g(){}g.prototype=_.prototype,y.prototype=new g},a.extend=function(){var y,_,g={};for(y=0;y<arguments.length;y++)for(_ in arguments[y])Object.prototype.hasOwnProperty.call(arguments[y],_)&&g[_]===void 0&&(g[_]=arguments[y][_]);return g},a.prepareContent=function(y,_,g,f,w){return l.Promise.resolve(_).then(function(x){return i.blob&&(x instanceof Blob||["[object File]","[object Blob]"].indexOf(Object.prototype.toString.call(x))!==-1)&&typeof FileReader<"u"?new l.Promise(function(S,A){var T=new FileReader;T.onload=function(L){S(L.target.result)},T.onerror=function(L){A(L.target.error)},T.readAsArrayBuffer(x)}):x}).then(function(x){var S=a.getTypeOf(x);return S?(S==="arraybuffer"?x=a.transformTo("uint8array",x):S==="string"&&(w?x=o.decode(x):g&&f!==!0&&(x=function(A){return c(A,i.uint8array?new Uint8Array(A.length):new Array(A.length))}(x))),x):l.Promise.reject(new Error("Can't read the data of '"+y+"'. Is it in a supported JavaScript type (String, Blob, ArrayBuffer, etc) ?"))})}},{"./base64":1,"./external":6,"./nodejsUtils":14,"./support":30,setimmediate:54}],33:[function(t,n,a){var i=t("./reader/readerFor"),o=t("./utils"),s=t("./signature"),l=t("./zipEntry"),u=t("./support");function c(h){this.files=[],this.loadOptions=h}c.prototype={checkSignature:function(h){if(!this.reader.readAndCheckSignature(h)){this.reader.index-=4;var d=this.reader.readString(4);throw new Error("Corrupted zip or bug: unexpected signature ("+o.pretty(d)+", expected "+o.pretty(h)+")")}},isSignature:function(h,d){var v=this.reader.index;this.reader.setIndex(h);var p=this.reader.readString(4)===d;return this.reader.setIndex(v),p},readBlockEndOfCentral:function(){this.diskNumber=this.reader.readInt(2),this.diskWithCentralDirStart=this.reader.readInt(2),this.centralDirRecordsOnThisDisk=this.reader.readInt(2),this.centralDirRecords=this.reader.readInt(2),this.centralDirSize=this.reader.readInt(4),this.centralDirOffset=this.reader.readInt(4),this.zipCommentLength=this.reader.readInt(2);var h=this.reader.readData(this.zipCommentLength),d=u.uint8array?"uint8array":"array",v=o.transformTo(d,h);this.zipComment=this.loadOptions.decodeFileName(v)},readBlockZip64EndOfCentral:function(){this.zip64EndOfCentralSize=this.reader.readInt(8),this.reader.skip(4),this.diskNumber=this.reader.readInt(4),this.diskWithCentralDirStart=this.reader.readInt(4),this.centralDirRecordsOnThisDisk=this.reader.readInt(8),this.centralDirRecords=this.reader.readInt(8),this.centralDirSize=this.reader.readInt(8),this.centralDirOffset=this.reader.readInt(8),this.zip64ExtensibleData={};for(var h,d,v,p=this.zip64EndOfCentralSize-44;0<p;)h=this.reader.readInt(2),d=this.reader.readInt(4),v=this.reader.readData(d),this.zip64ExtensibleData[h]={id:h,length:d,value:v}},readBlockZip64EndOfCentralLocator:function(){if(this.diskWithZip64CentralDirStart=this.reader.readInt(4),this.relativeOffsetEndOfZip64CentralDir=this.reader.readInt(8),this.disksCount=this.reader.readInt(4),1<this.disksCount)throw new Error("Multi-volumes zip are not supported")},readLocalFiles:function(){var h,d;for(h=0;h<this.files.length;h++)d=this.files[h],this.reader.setIndex(d.localHeaderOffset),this.checkSignature(s.LOCAL_FILE_HEADER),d.readLocalPart(this.reader),d.handleUTF8(),d.processAttributes()},readCentralDir:function(){var h;for(this.reader.setIndex(this.centralDirOffset);this.reader.readAndCheckSignature(s.CENTRAL_FILE_HEADER);)(h=new l({zip64:this.zip64},this.loadOptions)).readCentralPart(this.reader),this.files.push(h);if(this.centralDirRecords!==this.files.length&&this.centralDirRecords!==0&&this.files.length===0)throw new Error("Corrupted zip or bug: expected "+this.centralDirRecords+" records in central dir, got "+this.files.length)},readEndOfCentral:function(){var h=this.reader.lastIndexOfSignature(s.CENTRAL_DIRECTORY_END);if(h<0)throw this.isSignature(0,s.LOCAL_FILE_HEADER)?new Error("Corrupted zip: can't find end of central directory"):new Error("Can't find end of central directory : is this a zip file ? If it is, see https://stuk.github.io/jszip/documentation/howto/read_zip.html");this.reader.setIndex(h);var d=h;if(this.checkSignature(s.CENTRAL_DIRECTORY_END),this.readBlockEndOfCentral(),this.diskNumber===o.MAX_VALUE_16BITS||this.diskWithCentralDirStart===o.MAX_VALUE_16BITS||this.centralDirRecordsOnThisDisk===o.MAX_VALUE_16BITS||this.centralDirRecords===o.MAX_VALUE_16BITS||this.centralDirSize===o.MAX_VALUE_32BITS||this.centralDirOffset===o.MAX_VALUE_32BITS){if(this.zip64=!0,(h=this.reader.lastIndexOfSignature(s.ZIP64_CENTRAL_DIRECTORY_LOCATOR))<0)throw new Error("Corrupted zip: can't find the ZIP64 end of central directory locator");if(this.reader.setIndex(h),this.checkSignature(s.ZIP64_CENTRAL_DIRECTORY_LOCATOR),this.readBlockZip64EndOfCentralLocator(),!this.isSignature(this.relativeOffsetEndOfZip64CentralDir,s.ZIP64_CENTRAL_DIRECTORY_END)&&(this.relativeOffsetEndOfZip64CentralDir=this.reader.lastIndexOfSignature(s.ZIP64_CENTRAL_DIRECTORY_END),this.relativeOffsetEndOfZip64CentralDir<0))throw new Error("Corrupted zip: can't find the ZIP64 end of central directory");this.reader.setIndex(this.relativeOffsetEndOfZip64CentralDir),this.checkSignature(s.ZIP64_CENTRAL_DIRECTORY_END),this.readBlockZip64EndOfCentral()}var v=this.centralDirOffset+this.centralDirSize;this.zip64&&(v+=20,v+=12+this.zip64EndOfCentralSize);var p=d-v;if(0<p)this.isSignature(d,s.CENTRAL_FILE_HEADER)||(this.reader.zero=p);else if(p<0)throw new Error("Corrupted zip: missing "+Math.abs(p)+" bytes.")},prepareReader:function(h){this.reader=i(h)},load:function(h){this.prepareReader(h),this.readEndOfCentral(),this.readCentralDir(),this.readLocalFiles()}},n.exports=c},{"./reader/readerFor":22,"./signature":23,"./support":30,"./utils":32,"./zipEntry":34}],34:[function(t,n,a){var i=t("./reader/readerFor"),o=t("./utils"),s=t("./compressedObject"),l=t("./crc32"),u=t("./utf8"),c=t("./compressions"),h=t("./support");function d(v,p){this.options=v,this.loadOptions=p}d.prototype={isEncrypted:function(){return(1&this.bitFlag)==1},useUTF8:function(){return(2048&this.bitFlag)==2048},readLocalPart:function(v){var p,y;if(v.skip(22),this.fileNameLength=v.readInt(2),y=v.readInt(2),this.fileName=v.readData(this.fileNameLength),v.skip(y),this.compressedSize===-1||this.uncompressedSize===-1)throw new Error("Bug or corrupted zip : didn't get enough information from the central directory (compressedSize === -1 || uncompressedSize === -1)");if((p=function(_){for(var g in c)if(Object.prototype.hasOwnProperty.call(c,g)&&c[g].magic===_)return c[g];return null}(this.compressionMethod))===null)throw new Error("Corrupted zip : compression "+o.pretty(this.compressionMethod)+" unknown (inner file : "+o.transformTo("string",this.fileName)+")");this.decompressed=new s(this.compressedSize,this.uncompressedSize,this.crc32,p,v.readData(this.compressedSize))},readCentralPart:function(v){this.versionMadeBy=v.readInt(2),v.skip(2),this.bitFlag=v.readInt(2),this.compressionMethod=v.readString(2),this.date=v.readDate(),this.crc32=v.readInt(4),this.compressedSize=v.readInt(4),this.uncompressedSize=v.readInt(4);var p=v.readInt(2);if(this.extraFieldsLength=v.readInt(2),this.fileCommentLength=v.readInt(2),this.diskNumberStart=v.readInt(2),this.internalFileAttributes=v.readInt(2),this.externalFileAttributes=v.readInt(4),this.localHeaderOffset=v.readInt(4),this.isEncrypted())throw new Error("Encrypted zip are not supported");v.skip(p),this.readExtraFields(v),this.parseZIP64ExtraField(v),this.fileComment=v.readData(this.fileCommentLength)},processAttributes:function(){this.unixPermissions=null,this.dosPermissions=null;var v=this.versionMadeBy>>8;this.dir=!!(16&this.externalFileAttributes),v==0&&(this.dosPermissions=63&this.externalFileAttributes),v==3&&(this.unixPermissions=this.externalFileAttributes>>16&65535),this.dir||this.fileNameStr.slice(-1)!=="/"||(this.dir=!0)},parseZIP64ExtraField:function(){if(this.extraFields[1]){var v=i(this.extraFields[1].value);this.uncompressedSize===o.MAX_VALUE_32BITS&&(this.uncompressedSize=v.readInt(8)),this.compressedSize===o.MAX_VALUE_32BITS&&(this.compressedSize=v.readInt(8)),this.localHeaderOffset===o.MAX_VALUE_32BITS&&(this.localHeaderOffset=v.readInt(8)),this.diskNumberStart===o.MAX_VALUE_32BITS&&(this.diskNumberStart=v.readInt(4))}},readExtraFields:function(v){var p,y,_,g=v.index+this.extraFieldsLength;for(this.extraFields||(this.extraFields={});v.index+4<g;)p=v.readInt(2),y=v.readInt(2),_=v.readData(y),this.extraFields[p]={id:p,length:y,value:_};v.setIndex(g)},handleUTF8:function(){var v=h.uint8array?"uint8array":"array";if(this.useUTF8())this.fileNameStr=u.utf8decode(this.fileName),this.fileCommentStr=u.utf8decode(this.fileComment);else{var p=this.findExtraFieldUnicodePath();if(p!==null)this.fileNameStr=p;else{var y=o.transformTo(v,this.fileName);this.fileNameStr=this.loadOptions.decodeFileName(y)}var _=this.findExtraFieldUnicodeComment();if(_!==null)this.fileCommentStr=_;else{var g=o.transformTo(v,this.fileComment);this.fileCommentStr=this.loadOptions.decodeFileName(g)}}},findExtraFieldUnicodePath:function(){var v=this.extraFields[28789];if(v){var p=i(v.value);return p.readInt(1)!==1||l(this.fileName)!==p.readInt(4)?null:u.utf8decode(p.readData(v.length-5))}return null},findExtraFieldUnicodeComment:function(){var v=this.extraFields[25461];if(v){var p=i(v.value);return p.readInt(1)!==1||l(this.fileComment)!==p.readInt(4)?null:u.utf8decode(p.readData(v.length-5))}return null}},n.exports=d},{"./compressedObject":2,"./compressions":3,"./crc32":4,"./reader/readerFor":22,"./support":30,"./utf8":31,"./utils":32}],35:[function(t,n,a){function i(p,y,_){this.name=p,this.dir=_.dir,this.date=_.date,this.comment=_.comment,this.unixPermissions=_.unixPermissions,this.dosPermissions=_.dosPermissions,this._data=y,this._dataBinary=_.binary,this.options={compression:_.compression,compressionOptions:_.compressionOptions}}var o=t("./stream/StreamHelper"),s=t("./stream/DataWorker"),l=t("./utf8"),u=t("./compressedObject"),c=t("./stream/GenericWorker");i.prototype={internalStream:function(p){var y=null,_="string";try{if(!p)throw new Error("No output type specified.");var g=(_=p.toLowerCase())==="string"||_==="text";_!=="binarystring"&&_!=="text"||(_="string"),y=this._decompressWorker();var f=!this._dataBinary;f&&!g&&(y=y.pipe(new l.Utf8EncodeWorker)),!f&&g&&(y=y.pipe(new l.Utf8DecodeWorker))}catch(w){(y=new c("error")).error(w)}return new o(y,_,"")},async:function(p,y){return this.internalStream(p).accumulate(y)},nodeStream:function(p,y){return this.internalStream(p||"nodebuffer").toNodejsStream(y)},_compressWorker:function(p,y){if(this._data instanceof u&&this._data.compression.magic===p.magic)return this._data.getCompressedWorker();var _=this._decompressWorker();return this._dataBinary||(_=_.pipe(new l.Utf8EncodeWorker)),u.createWorkerFrom(_,p,y)},_decompressWorker:function(){return this._data instanceof u?this._data.getContentWorker():this._data instanceof c?this._data:new s(this._data)}};for(var h=["asText","asBinary","asNodeBuffer","asUint8Array","asArrayBuffer"],d=function(){throw new Error("This method has been removed in JSZip 3.0, please check the upgrade guide.")},v=0;v<h.length;v++)i.prototype[h[v]]=d;n.exports=i},{"./compressedObject":2,"./stream/DataWorker":27,"./stream/GenericWorker":28,"./stream/StreamHelper":29,"./utf8":31}],36:[function(t,n,a){(function(i){var o,s,l=i.MutationObserver||i.WebKitMutationObserver;if(l){var u=0,c=new l(p),h=i.document.createTextNode("");c.observe(h,{characterData:!0}),o=function(){h.data=u=++u%2}}else if(i.setImmediate||i.MessageChannel===void 0)o="document"in i&&"onreadystatechange"in i.document.createElement("script")?function(){var y=i.document.createElement("script");y.onreadystatechange=function(){p(),y.onreadystatechange=null,y.parentNode.removeChild(y),y=null},i.document.documentElement.appendChild(y)}:function(){setTimeout(p,0)};else{var d=new i.MessageChannel;d.port1.onmessage=p,o=function(){d.port2.postMessage(0)}}var v=[];function p(){var y,_;s=!0;for(var g=v.length;g;){for(_=v,v=[],y=-1;++y<g;)_[y]();g=v.length}s=!1}n.exports=function(y){v.push(y)!==1||s||o()}}).call(this,typeof pi<"u"?pi:typeof self<"u"?self:typeof window<"u"?window:{})},{}],37:[function(t,n,a){var i=t("immediate");function o(){}var s={},l=["REJECTED"],u=["FULFILLED"],c=["PENDING"];function h(g){if(typeof g!="function")throw new TypeError("resolver must be a function");this.state=c,this.queue=[],this.outcome=void 0,g!==o&&y(this,g)}function d(g,f,w){this.promise=g,typeof f=="function"&&(this.onFulfilled=f,this.callFulfilled=this.otherCallFulfilled),typeof w=="function"&&(this.onRejected=w,this.callRejected=this.otherCallRejected)}function v(g,f,w){i(function(){var x;try{x=f(w)}catch(S){return s.reject(g,S)}x===g?s.reject(g,new TypeError("Cannot resolve promise with itself")):s.resolve(g,x)})}function p(g){var f=g&&g.then;if(g&&(typeof g=="object"||typeof g=="function")&&typeof f=="function")return function(){f.apply(g,arguments)}}function y(g,f){var w=!1;function x(T){w||(w=!0,s.reject(g,T))}function S(T){w||(w=!0,s.resolve(g,T))}var A=_(function(){f(S,x)});A.status==="error"&&x(A.value)}function _(g,f){var w={};try{w.value=g(f),w.status="success"}catch(x){w.status="error",w.value=x}return w}(n.exports=h).prototype.finally=function(g){if(typeof g!="function")return this;var f=this.constructor;return this.then(function(w){return f.resolve(g()).then(function(){return w})},function(w){return f.resolve(g()).then(function(){throw w})})},h.prototype.catch=function(g){return this.then(null,g)},h.prototype.then=function(g,f){if(typeof g!="function"&&this.state===u||typeof f!="function"&&this.state===l)return this;var w=new this.constructor(o);return this.state!==c?v(w,this.state===u?g:f,this.outcome):this.queue.push(new d(w,g,f)),w},d.prototype.callFulfilled=function(g){s.resolve(this.promise,g)},d.prototype.otherCallFulfilled=function(g){v(this.promise,this.onFulfilled,g)},d.prototype.callRejected=function(g){s.reject(this.promise,g)},d.prototype.otherCallRejected=function(g){v(this.promise,this.onRejected,g)},s.resolve=function(g,f){var w=_(p,f);if(w.status==="error")return s.reject(g,w.value);var x=w.value;if(x)y(g,x);else{g.state=u,g.outcome=f;for(var S=-1,A=g.queue.length;++S<A;)g.queue[S].callFulfilled(f)}return g},s.reject=function(g,f){g.state=l,g.outcome=f;for(var w=-1,x=g.queue.length;++w<x;)g.queue[w].callRejected(f);return g},h.resolve=function(g){return g instanceof this?g:s.resolve(new this(o),g)},h.reject=function(g){var f=new this(o);return s.reject(f,g)},h.all=function(g){var f=this;if(Object.prototype.toString.call(g)!=="[object Array]")return this.reject(new TypeError("must be an array"));var w=g.length,x=!1;if(!w)return this.resolve([]);for(var S=new Array(w),A=0,T=-1,L=new this(o);++T<w;)M(g[T],T);return L;function M(I,R){f.resolve(I).then(function(P){S[R]=P,++A!==w||x||(x=!0,s.resolve(L,S))},function(P){x||(x=!0,s.reject(L,P))})}},h.race=function(g){var f=this;if(Object.prototype.toString.call(g)!=="[object Array]")return this.reject(new TypeError("must be an array"));var w=g.length,x=!1;if(!w)return this.resolve([]);for(var S=-1,A=new this(o);++S<w;)T=g[S],f.resolve(T).then(function(L){x||(x=!0,s.resolve(A,L))},function(L){x||(x=!0,s.reject(A,L))});var T;return A}},{immediate:36}],38:[function(t,n,a){var i={};(0,t("./lib/utils/common").assign)(i,t("./lib/deflate"),t("./lib/inflate"),t("./lib/zlib/constants")),n.exports=i},{"./lib/deflate":39,"./lib/inflate":40,"./lib/utils/common":41,"./lib/zlib/constants":44}],39:[function(t,n,a){var i=t("./zlib/deflate"),o=t("./utils/common"),s=t("./utils/strings"),l=t("./zlib/messages"),u=t("./zlib/zstream"),c=Object.prototype.toString,h=0,d=-1,v=0,p=8;function y(g){if(!(this instanceof y))return new y(g);this.options=o.assign({level:d,method:p,chunkSize:16384,windowBits:15,memLevel:8,strategy:v,to:""},g||{});var f=this.options;f.raw&&0<f.windowBits?f.windowBits=-f.windowBits:f.gzip&&0<f.windowBits&&f.windowBits<16&&(f.windowBits+=16),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new u,this.strm.avail_out=0;var w=i.deflateInit2(this.strm,f.level,f.method,f.windowBits,f.memLevel,f.strategy);if(w!==h)throw new Error(l[w]);if(f.header&&i.deflateSetHeader(this.strm,f.header),f.dictionary){var x;if(x=typeof f.dictionary=="string"?s.string2buf(f.dictionary):c.call(f.dictionary)==="[object ArrayBuffer]"?new Uint8Array(f.dictionary):f.dictionary,(w=i.deflateSetDictionary(this.strm,x))!==h)throw new Error(l[w]);this._dict_set=!0}}function _(g,f){var w=new y(f);if(w.push(g,!0),w.err)throw w.msg||l[w.err];return w.result}y.prototype.push=function(g,f){var w,x,S=this.strm,A=this.options.chunkSize;if(this.ended)return!1;x=f===~~f?f:f===!0?4:0,typeof g=="string"?S.input=s.string2buf(g):c.call(g)==="[object ArrayBuffer]"?S.input=new Uint8Array(g):S.input=g,S.next_in=0,S.avail_in=S.input.length;do{if(S.avail_out===0&&(S.output=new o.Buf8(A),S.next_out=0,S.avail_out=A),(w=i.deflate(S,x))!==1&&w!==h)return this.onEnd(w),!(this.ended=!0);S.avail_out!==0&&(S.avail_in!==0||x!==4&&x!==2)||(this.options.to==="string"?this.onData(s.buf2binstring(o.shrinkBuf(S.output,S.next_out))):this.onData(o.shrinkBuf(S.output,S.next_out)))}while((0<S.avail_in||S.avail_out===0)&&w!==1);return x===4?(w=i.deflateEnd(this.strm),this.onEnd(w),this.ended=!0,w===h):x!==2||(this.onEnd(h),!(S.avail_out=0))},y.prototype.onData=function(g){this.chunks.push(g)},y.prototype.onEnd=function(g){g===h&&(this.options.to==="string"?this.result=this.chunks.join(""):this.result=o.flattenChunks(this.chunks)),this.chunks=[],this.err=g,this.msg=this.strm.msg},a.Deflate=y,a.deflate=_,a.deflateRaw=function(g,f){return(f=f||{}).raw=!0,_(g,f)},a.gzip=function(g,f){return(f=f||{}).gzip=!0,_(g,f)}},{"./utils/common":41,"./utils/strings":42,"./zlib/deflate":46,"./zlib/messages":51,"./zlib/zstream":53}],40:[function(t,n,a){var i=t("./zlib/inflate"),o=t("./utils/common"),s=t("./utils/strings"),l=t("./zlib/constants"),u=t("./zlib/messages"),c=t("./zlib/zstream"),h=t("./zlib/gzheader"),d=Object.prototype.toString;function v(y){if(!(this instanceof v))return new v(y);this.options=o.assign({chunkSize:16384,windowBits:0,to:""},y||{});var _=this.options;_.raw&&0<=_.windowBits&&_.windowBits<16&&(_.windowBits=-_.windowBits,_.windowBits===0&&(_.windowBits=-15)),!(0<=_.windowBits&&_.windowBits<16)||y&&y.windowBits||(_.windowBits+=32),15<_.windowBits&&_.windowBits<48&&!(15&_.windowBits)&&(_.windowBits|=15),this.err=0,this.msg="",this.ended=!1,this.chunks=[],this.strm=new c,this.strm.avail_out=0;var g=i.inflateInit2(this.strm,_.windowBits);if(g!==l.Z_OK)throw new Error(u[g]);this.header=new h,i.inflateGetHeader(this.strm,this.header)}function p(y,_){var g=new v(_);if(g.push(y,!0),g.err)throw g.msg||u[g.err];return g.result}v.prototype.push=function(y,_){var g,f,w,x,S,A,T=this.strm,L=this.options.chunkSize,M=this.options.dictionary,I=!1;if(this.ended)return!1;f=_===~~_?_:_===!0?l.Z_FINISH:l.Z_NO_FLUSH,typeof y=="string"?T.input=s.binstring2buf(y):d.call(y)==="[object ArrayBuffer]"?T.input=new Uint8Array(y):T.input=y,T.next_in=0,T.avail_in=T.input.length;do{if(T.avail_out===0&&(T.output=new o.Buf8(L),T.next_out=0,T.avail_out=L),(g=i.inflate(T,l.Z_NO_FLUSH))===l.Z_NEED_DICT&&M&&(A=typeof M=="string"?s.string2buf(M):d.call(M)==="[object ArrayBuffer]"?new Uint8Array(M):M,g=i.inflateSetDictionary(this.strm,A)),g===l.Z_BUF_ERROR&&I===!0&&(g=l.Z_OK,I=!1),g!==l.Z_STREAM_END&&g!==l.Z_OK)return this.onEnd(g),!(this.ended=!0);T.next_out&&(T.avail_out!==0&&g!==l.Z_STREAM_END&&(T.avail_in!==0||f!==l.Z_FINISH&&f!==l.Z_SYNC_FLUSH)||(this.options.to==="string"?(w=s.utf8border(T.output,T.next_out),x=T.next_out-w,S=s.buf2string(T.output,w),T.next_out=x,T.avail_out=L-x,x&&o.arraySet(T.output,T.output,w,x,0),this.onData(S)):this.onData(o.shrinkBuf(T.output,T.next_out)))),T.avail_in===0&&T.avail_out===0&&(I=!0)}while((0<T.avail_in||T.avail_out===0)&&g!==l.Z_STREAM_END);return g===l.Z_STREAM_END&&(f=l.Z_FINISH),f===l.Z_FINISH?(g=i.inflateEnd(this.strm),this.onEnd(g),this.ended=!0,g===l.Z_OK):f!==l.Z_SYNC_FLUSH||(this.onEnd(l.Z_OK),!(T.avail_out=0))},v.prototype.onData=function(y){this.chunks.push(y)},v.prototype.onEnd=function(y){y===l.Z_OK&&(this.options.to==="string"?this.result=this.chunks.join(""):this.result=o.flattenChunks(this.chunks)),this.chunks=[],this.err=y,this.msg=this.strm.msg},a.Inflate=v,a.inflate=p,a.inflateRaw=function(y,_){return(_=_||{}).raw=!0,p(y,_)},a.ungzip=p},{"./utils/common":41,"./utils/strings":42,"./zlib/constants":44,"./zlib/gzheader":47,"./zlib/inflate":49,"./zlib/messages":51,"./zlib/zstream":53}],41:[function(t,n,a){var i=typeof Uint8Array<"u"&&typeof Uint16Array<"u"&&typeof Int32Array<"u";a.assign=function(l){for(var u=Array.prototype.slice.call(arguments,1);u.length;){var c=u.shift();if(c){if(typeof c!="object")throw new TypeError(c+"must be non-object");for(var h in c)c.hasOwnProperty(h)&&(l[h]=c[h])}}return l},a.shrinkBuf=function(l,u){return l.length===u?l:l.subarray?l.subarray(0,u):(l.length=u,l)};var o={arraySet:function(l,u,c,h,d){if(u.subarray&&l.subarray)l.set(u.subarray(c,c+h),d);else for(var v=0;v<h;v++)l[d+v]=u[c+v]},flattenChunks:function(l){var u,c,h,d,v,p;for(u=h=0,c=l.length;u<c;u++)h+=l[u].length;for(p=new Uint8Array(h),u=d=0,c=l.length;u<c;u++)v=l[u],p.set(v,d),d+=v.length;return p}},s={arraySet:function(l,u,c,h,d){for(var v=0;v<h;v++)l[d+v]=u[c+v]},flattenChunks:function(l){return[].concat.apply([],l)}};a.setTyped=function(l){l?(a.Buf8=Uint8Array,a.Buf16=Uint16Array,a.Buf32=Int32Array,a.assign(a,o)):(a.Buf8=Array,a.Buf16=Array,a.Buf32=Array,a.assign(a,s))},a.setTyped(i)},{}],42:[function(t,n,a){var i=t("./common"),o=!0,s=!0;try{String.fromCharCode.apply(null,[0])}catch{o=!1}try{String.fromCharCode.apply(null,new Uint8Array(1))}catch{s=!1}for(var l=new i.Buf8(256),u=0;u<256;u++)l[u]=252<=u?6:248<=u?5:240<=u?4:224<=u?3:192<=u?2:1;function c(h,d){if(d<65537&&(h.subarray&&s||!h.subarray&&o))return String.fromCharCode.apply(null,i.shrinkBuf(h,d));for(var v="",p=0;p<d;p++)v+=String.fromCharCode(h[p]);return v}l[254]=l[254]=1,a.string2buf=function(h){var d,v,p,y,_,g=h.length,f=0;for(y=0;y<g;y++)(64512&(v=h.charCodeAt(y)))==55296&&y+1<g&&(64512&(p=h.charCodeAt(y+1)))==56320&&(v=65536+(v-55296<<10)+(p-56320),y++),f+=v<128?1:v<2048?2:v<65536?3:4;for(d=new i.Buf8(f),y=_=0;_<f;y++)(64512&(v=h.charCodeAt(y)))==55296&&y+1<g&&(64512&(p=h.charCodeAt(y+1)))==56320&&(v=65536+(v-55296<<10)+(p-56320),y++),v<128?d[_++]=v:(v<2048?d[_++]=192|v>>>6:(v<65536?d[_++]=224|v>>>12:(d[_++]=240|v>>>18,d[_++]=128|v>>>12&63),d[_++]=128|v>>>6&63),d[_++]=128|63&v);return d},a.buf2binstring=function(h){return c(h,h.length)},a.binstring2buf=function(h){for(var d=new i.Buf8(h.length),v=0,p=d.length;v<p;v++)d[v]=h.charCodeAt(v);return d},a.buf2string=function(h,d){var v,p,y,_,g=d||h.length,f=new Array(2*g);for(v=p=0;v<g;)if((y=h[v++])<128)f[p++]=y;else if(4<(_=l[y]))f[p++]=65533,v+=_-1;else{for(y&=_===2?31:_===3?15:7;1<_&&v<g;)y=y<<6|63&h[v++],_--;1<_?f[p++]=65533:y<65536?f[p++]=y:(y-=65536,f[p++]=55296|y>>10&1023,f[p++]=56320|1023&y)}return c(f,p)},a.utf8border=function(h,d){var v;for((d=d||h.length)>h.length&&(d=h.length),v=d-1;0<=v&&(192&h[v])==128;)v--;return v<0||v===0?d:v+l[h[v]]>d?v:d}},{"./common":41}],43:[function(t,n,a){n.exports=function(i,o,s,l){for(var u=65535&i|0,c=i>>>16&65535|0,h=0;s!==0;){for(s-=h=2e3<s?2e3:s;c=c+(u=u+o[l++]|0)|0,--h;);u%=65521,c%=65521}return u|c<<16|0}},{}],44:[function(t,n,a){n.exports={Z_NO_FLUSH:0,Z_PARTIAL_FLUSH:1,Z_SYNC_FLUSH:2,Z_FULL_FLUSH:3,Z_FINISH:4,Z_BLOCK:5,Z_TREES:6,Z_OK:0,Z_STREAM_END:1,Z_NEED_DICT:2,Z_ERRNO:-1,Z_STREAM_ERROR:-2,Z_DATA_ERROR:-3,Z_BUF_ERROR:-5,Z_NO_COMPRESSION:0,Z_BEST_SPEED:1,Z_BEST_COMPRESSION:9,Z_DEFAULT_COMPRESSION:-1,Z_FILTERED:1,Z_HUFFMAN_ONLY:2,Z_RLE:3,Z_FIXED:4,Z_DEFAULT_STRATEGY:0,Z_BINARY:0,Z_TEXT:1,Z_UNKNOWN:2,Z_DEFLATED:8}},{}],45:[function(t,n,a){var i=function(){for(var o,s=[],l=0;l<256;l++){o=l;for(var u=0;u<8;u++)o=1&o?3988292384^o>>>1:o>>>1;s[l]=o}return s}();n.exports=function(o,s,l,u){var c=i,h=u+l;o^=-1;for(var d=u;d<h;d++)o=o>>>8^c[255&(o^s[d])];return-1^o}},{}],46:[function(t,n,a){var i,o=t("../utils/common"),s=t("./trees"),l=t("./adler32"),u=t("./crc32"),c=t("./messages"),h=0,d=4,v=0,p=-2,y=-1,_=4,g=2,f=8,w=9,x=286,S=30,A=19,T=2*x+1,L=15,M=3,I=258,R=I+M+1,P=42,E=113,D=1,N=2,V=3,W=4;function $(O,st){return O.msg=c[st],st}function H(O){return(O<<1)-(4<O?9:0)}function K(O){for(var st=O.length;0<=--st;)O[st]=0}function U(O){var st=O.state,nt=st.pending;nt>O.avail_out&&(nt=O.avail_out),nt!==0&&(o.arraySet(O.output,st.pending_buf,st.pending_out,nt,O.next_out),O.next_out+=nt,st.pending_out+=nt,O.total_out+=nt,O.avail_out-=nt,st.pending-=nt,st.pending===0&&(st.pending_out=0))}function j(O,st){s._tr_flush_block(O,0<=O.block_start?O.block_start:-1,O.strstart-O.block_start,st),O.block_start=O.strstart,U(O.strm)}function ut(O,st){O.pending_buf[O.pending++]=st}function ot(O,st){O.pending_buf[O.pending++]=st>>>8&255,O.pending_buf[O.pending++]=255&st}function it(O,st){var nt,X,Z=O.max_chain_length,J=O.strstart,pt=O.prev_length,vt=O.nice_match,at=O.strstart>O.w_size-R?O.strstart-(O.w_size-R):0,Tt=O.window,Bt=O.w_mask,Ct=O.prev,Yt=O.strstart+I,be=Tt[J+pt-1],se=Tt[J+pt];O.prev_length>=O.good_match&&(Z>>=2),vt>O.lookahead&&(vt=O.lookahead);do if(Tt[(nt=st)+pt]===se&&Tt[nt+pt-1]===be&&Tt[nt]===Tt[J]&&Tt[++nt]===Tt[J+1]){J+=2,nt++;do;while(Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&Tt[++J]===Tt[++nt]&&J<Yt);if(X=I-(Yt-J),J=Yt-I,pt<X){if(O.match_start=st,vt<=(pt=X))break;be=Tt[J+pt-1],se=Tt[J+pt]}}while((st=Ct[st&Bt])>at&&--Z!=0);return pt<=O.lookahead?pt:O.lookahead}function Et(O){var st,nt,X,Z,J,pt,vt,at,Tt,Bt,Ct=O.w_size;do{if(Z=O.window_size-O.lookahead-O.strstart,O.strstart>=Ct+(Ct-R)){for(o.arraySet(O.window,O.window,Ct,Ct,0),O.match_start-=Ct,O.strstart-=Ct,O.block_start-=Ct,st=nt=O.hash_size;X=O.head[--st],O.head[st]=Ct<=X?X-Ct:0,--nt;);for(st=nt=Ct;X=O.prev[--st],O.prev[st]=Ct<=X?X-Ct:0,--nt;);Z+=Ct}if(O.strm.avail_in===0)break;if(pt=O.strm,vt=O.window,at=O.strstart+O.lookahead,Tt=Z,Bt=void 0,Bt=pt.avail_in,Tt<Bt&&(Bt=Tt),nt=Bt===0?0:(pt.avail_in-=Bt,o.arraySet(vt,pt.input,pt.next_in,Bt,at),pt.state.wrap===1?pt.adler=l(pt.adler,vt,Bt,at):pt.state.wrap===2&&(pt.adler=u(pt.adler,vt,Bt,at)),pt.next_in+=Bt,pt.total_in+=Bt,Bt),O.lookahead+=nt,O.lookahead+O.insert>=M)for(J=O.strstart-O.insert,O.ins_h=O.window[J],O.ins_h=(O.ins_h<<O.hash_shift^O.window[J+1])&O.hash_mask;O.insert&&(O.ins_h=(O.ins_h<<O.hash_shift^O.window[J+M-1])&O.hash_mask,O.prev[J&O.w_mask]=O.head[O.ins_h],O.head[O.ins_h]=J,J++,O.insert--,!(O.lookahead+O.insert<M)););}while(O.lookahead<R&&O.strm.avail_in!==0)}function jt(O,st){for(var nt,X;;){if(O.lookahead<R){if(Et(O),O.lookahead<R&&st===h)return D;if(O.lookahead===0)break}if(nt=0,O.lookahead>=M&&(O.ins_h=(O.ins_h<<O.hash_shift^O.window[O.strstart+M-1])&O.hash_mask,nt=O.prev[O.strstart&O.w_mask]=O.head[O.ins_h],O.head[O.ins_h]=O.strstart),nt!==0&&O.strstart-nt<=O.w_size-R&&(O.match_length=it(O,nt)),O.match_length>=M)if(X=s._tr_tally(O,O.strstart-O.match_start,O.match_length-M),O.lookahead-=O.match_length,O.match_length<=O.max_lazy_match&&O.lookahead>=M){for(O.match_length--;O.strstart++,O.ins_h=(O.ins_h<<O.hash_shift^O.window[O.strstart+M-1])&O.hash_mask,nt=O.prev[O.strstart&O.w_mask]=O.head[O.ins_h],O.head[O.ins_h]=O.strstart,--O.match_length!=0;);O.strstart++}else O.strstart+=O.match_length,O.match_length=0,O.ins_h=O.window[O.strstart],O.ins_h=(O.ins_h<<O.hash_shift^O.window[O.strstart+1])&O.hash_mask;else X=s._tr_tally(O,0,O.window[O.strstart]),O.lookahead--,O.strstart++;if(X&&(j(O,!1),O.strm.avail_out===0))return D}return O.insert=O.strstart<M-1?O.strstart:M-1,st===d?(j(O,!0),O.strm.avail_out===0?V:W):O.last_lit&&(j(O,!1),O.strm.avail_out===0)?D:N}function bt(O,st){for(var nt,X,Z;;){if(O.lookahead<R){if(Et(O),O.lookahead<R&&st===h)return D;if(O.lookahead===0)break}if(nt=0,O.lookahead>=M&&(O.ins_h=(O.ins_h<<O.hash_shift^O.window[O.strstart+M-1])&O.hash_mask,nt=O.prev[O.strstart&O.w_mask]=O.head[O.ins_h],O.head[O.ins_h]=O.strstart),O.prev_length=O.match_length,O.prev_match=O.match_start,O.match_length=M-1,nt!==0&&O.prev_length<O.max_lazy_match&&O.strstart-nt<=O.w_size-R&&(O.match_length=it(O,nt),O.match_length<=5&&(O.strategy===1||O.match_length===M&&4096<O.strstart-O.match_start)&&(O.match_length=M-1)),O.prev_length>=M&&O.match_length<=O.prev_length){for(Z=O.strstart+O.lookahead-M,X=s._tr_tally(O,O.strstart-1-O.prev_match,O.prev_length-M),O.lookahead-=O.prev_length-1,O.prev_length-=2;++O.strstart<=Z&&(O.ins_h=(O.ins_h<<O.hash_shift^O.window[O.strstart+M-1])&O.hash_mask,nt=O.prev[O.strstart&O.w_mask]=O.head[O.ins_h],O.head[O.ins_h]=O.strstart),--O.prev_length!=0;);if(O.match_available=0,O.match_length=M-1,O.strstart++,X&&(j(O,!1),O.strm.avail_out===0))return D}else if(O.match_available){if((X=s._tr_tally(O,0,O.window[O.strstart-1]))&&j(O,!1),O.strstart++,O.lookahead--,O.strm.avail_out===0)return D}else O.match_available=1,O.strstart++,O.lookahead--}return O.match_available&&(X=s._tr_tally(O,0,O.window[O.strstart-1]),O.match_available=0),O.insert=O.strstart<M-1?O.strstart:M-1,st===d?(j(O,!0),O.strm.avail_out===0?V:W):O.last_lit&&(j(O,!1),O.strm.avail_out===0)?D:N}function wt(O,st,nt,X,Z){this.good_length=O,this.max_lazy=st,this.nice_length=nt,this.max_chain=X,this.func=Z}function Ot(){this.strm=null,this.status=0,this.pending_buf=null,this.pending_buf_size=0,this.pending_out=0,this.pending=0,this.wrap=0,this.gzhead=null,this.gzindex=0,this.method=f,this.last_flush=-1,this.w_size=0,this.w_bits=0,this.w_mask=0,this.window=null,this.window_size=0,this.prev=null,this.head=null,this.ins_h=0,this.hash_size=0,this.hash_bits=0,this.hash_mask=0,this.hash_shift=0,this.block_start=0,this.match_length=0,this.prev_match=0,this.match_available=0,this.strstart=0,this.match_start=0,this.lookahead=0,this.prev_length=0,this.max_chain_length=0,this.max_lazy_match=0,this.level=0,this.strategy=0,this.good_match=0,this.nice_match=0,this.dyn_ltree=new o.Buf16(2*T),this.dyn_dtree=new o.Buf16(2*(2*S+1)),this.bl_tree=new o.Buf16(2*(2*A+1)),K(this.dyn_ltree),K(this.dyn_dtree),K(this.bl_tree),this.l_desc=null,this.d_desc=null,this.bl_desc=null,this.bl_count=new o.Buf16(L+1),this.heap=new o.Buf16(2*x+1),K(this.heap),this.heap_len=0,this.heap_max=0,this.depth=new o.Buf16(2*x+1),K(this.depth),this.l_buf=0,this.lit_bufsize=0,this.last_lit=0,this.d_buf=0,this.opt_len=0,this.static_len=0,this.matches=0,this.insert=0,this.bi_buf=0,this.bi_valid=0}function xt(O){var st;return O&&O.state?(O.total_in=O.total_out=0,O.data_type=g,(st=O.state).pending=0,st.pending_out=0,st.wrap<0&&(st.wrap=-st.wrap),st.status=st.wrap?P:E,O.adler=st.wrap===2?0:1,st.last_flush=h,s._tr_init(st),v):$(O,p)}function kt(O){var st=xt(O);return st===v&&function(nt){nt.window_size=2*nt.w_size,K(nt.head),nt.max_lazy_match=i[nt.level].max_lazy,nt.good_match=i[nt.level].good_length,nt.nice_match=i[nt.level].nice_length,nt.max_chain_length=i[nt.level].max_chain,nt.strstart=0,nt.block_start=0,nt.lookahead=0,nt.insert=0,nt.match_length=nt.prev_length=M-1,nt.match_available=0,nt.ins_h=0}(O.state),st}function ae(O,st,nt,X,Z,J){if(!O)return p;var pt=1;if(st===y&&(st=6),X<0?(pt=0,X=-X):15<X&&(pt=2,X-=16),Z<1||w<Z||nt!==f||X<8||15<X||st<0||9<st||J<0||_<J)return $(O,p);X===8&&(X=9);var vt=new Ot;return(O.state=vt).strm=O,vt.wrap=pt,vt.gzhead=null,vt.w_bits=X,vt.w_size=1<<vt.w_bits,vt.w_mask=vt.w_size-1,vt.hash_bits=Z+7,vt.hash_size=1<<vt.hash_bits,vt.hash_mask=vt.hash_size-1,vt.hash_shift=~~((vt.hash_bits+M-1)/M),vt.window=new o.Buf8(2*vt.w_size),vt.head=new o.Buf16(vt.hash_size),vt.prev=new o.Buf16(vt.w_size),vt.lit_bufsize=1<<Z+6,vt.pending_buf_size=4*vt.lit_bufsize,vt.pending_buf=new o.Buf8(vt.pending_buf_size),vt.d_buf=1*vt.lit_bufsize,vt.l_buf=3*vt.lit_bufsize,vt.level=st,vt.strategy=J,vt.method=nt,kt(O)}i=[new wt(0,0,0,0,function(O,st){var nt=65535;for(nt>O.pending_buf_size-5&&(nt=O.pending_buf_size-5);;){if(O.lookahead<=1){if(Et(O),O.lookahead===0&&st===h)return D;if(O.lookahead===0)break}O.strstart+=O.lookahead,O.lookahead=0;var X=O.block_start+nt;if((O.strstart===0||O.strstart>=X)&&(O.lookahead=O.strstart-X,O.strstart=X,j(O,!1),O.strm.avail_out===0)||O.strstart-O.block_start>=O.w_size-R&&(j(O,!1),O.strm.avail_out===0))return D}return O.insert=0,st===d?(j(O,!0),O.strm.avail_out===0?V:W):(O.strstart>O.block_start&&(j(O,!1),O.strm.avail_out),D)}),new wt(4,4,8,4,jt),new wt(4,5,16,8,jt),new wt(4,6,32,32,jt),new wt(4,4,16,16,bt),new wt(8,16,32,32,bt),new wt(8,16,128,128,bt),new wt(8,32,128,256,bt),new wt(32,128,258,1024,bt),new wt(32,258,258,4096,bt)],a.deflateInit=function(O,st){return ae(O,st,f,15,8,0)},a.deflateInit2=ae,a.deflateReset=kt,a.deflateResetKeep=xt,a.deflateSetHeader=function(O,st){return O&&O.state?O.state.wrap!==2?p:(O.state.gzhead=st,v):p},a.deflate=function(O,st){var nt,X,Z,J;if(!O||!O.state||5<st||st<0)return O?$(O,p):p;if(X=O.state,!O.output||!O.input&&O.avail_in!==0||X.status===666&&st!==d)return $(O,O.avail_out===0?-5:p);if(X.strm=O,nt=X.last_flush,X.last_flush=st,X.status===P)if(X.wrap===2)O.adler=0,ut(X,31),ut(X,139),ut(X,8),X.gzhead?(ut(X,(X.gzhead.text?1:0)+(X.gzhead.hcrc?2:0)+(X.gzhead.extra?4:0)+(X.gzhead.name?8:0)+(X.gzhead.comment?16:0)),ut(X,255&X.gzhead.time),ut(X,X.gzhead.time>>8&255),ut(X,X.gzhead.time>>16&255),ut(X,X.gzhead.time>>24&255),ut(X,X.level===9?2:2<=X.strategy||X.level<2?4:0),ut(X,255&X.gzhead.os),X.gzhead.extra&&X.gzhead.extra.length&&(ut(X,255&X.gzhead.extra.length),ut(X,X.gzhead.extra.length>>8&255)),X.gzhead.hcrc&&(O.adler=u(O.adler,X.pending_buf,X.pending,0)),X.gzindex=0,X.status=69):(ut(X,0),ut(X,0),ut(X,0),ut(X,0),ut(X,0),ut(X,X.level===9?2:2<=X.strategy||X.level<2?4:0),ut(X,3),X.status=E);else{var pt=f+(X.w_bits-8<<4)<<8;pt|=(2<=X.strategy||X.level<2?0:X.level<6?1:X.level===6?2:3)<<6,X.strstart!==0&&(pt|=32),pt+=31-pt%31,X.status=E,ot(X,pt),X.strstart!==0&&(ot(X,O.adler>>>16),ot(X,65535&O.adler)),O.adler=1}if(X.status===69)if(X.gzhead.extra){for(Z=X.pending;X.gzindex<(65535&X.gzhead.extra.length)&&(X.pending!==X.pending_buf_size||(X.gzhead.hcrc&&X.pending>Z&&(O.adler=u(O.adler,X.pending_buf,X.pending-Z,Z)),U(O),Z=X.pending,X.pending!==X.pending_buf_size));)ut(X,255&X.gzhead.extra[X.gzindex]),X.gzindex++;X.gzhead.hcrc&&X.pending>Z&&(O.adler=u(O.adler,X.pending_buf,X.pending-Z,Z)),X.gzindex===X.gzhead.extra.length&&(X.gzindex=0,X.status=73)}else X.status=73;if(X.status===73)if(X.gzhead.name){Z=X.pending;do{if(X.pending===X.pending_buf_size&&(X.gzhead.hcrc&&X.pending>Z&&(O.adler=u(O.adler,X.pending_buf,X.pending-Z,Z)),U(O),Z=X.pending,X.pending===X.pending_buf_size)){J=1;break}J=X.gzindex<X.gzhead.name.length?255&X.gzhead.name.charCodeAt(X.gzindex++):0,ut(X,J)}while(J!==0);X.gzhead.hcrc&&X.pending>Z&&(O.adler=u(O.adler,X.pending_buf,X.pending-Z,Z)),J===0&&(X.gzindex=0,X.status=91)}else X.status=91;if(X.status===91)if(X.gzhead.comment){Z=X.pending;do{if(X.pending===X.pending_buf_size&&(X.gzhead.hcrc&&X.pending>Z&&(O.adler=u(O.adler,X.pending_buf,X.pending-Z,Z)),U(O),Z=X.pending,X.pending===X.pending_buf_size)){J=1;break}J=X.gzindex<X.gzhead.comment.length?255&X.gzhead.comment.charCodeAt(X.gzindex++):0,ut(X,J)}while(J!==0);X.gzhead.hcrc&&X.pending>Z&&(O.adler=u(O.adler,X.pending_buf,X.pending-Z,Z)),J===0&&(X.status=103)}else X.status=103;if(X.status===103&&(X.gzhead.hcrc?(X.pending+2>X.pending_buf_size&&U(O),X.pending+2<=X.pending_buf_size&&(ut(X,255&O.adler),ut(X,O.adler>>8&255),O.adler=0,X.status=E)):X.status=E),X.pending!==0){if(U(O),O.avail_out===0)return X.last_flush=-1,v}else if(O.avail_in===0&&H(st)<=H(nt)&&st!==d)return $(O,-5);if(X.status===666&&O.avail_in!==0)return $(O,-5);if(O.avail_in!==0||X.lookahead!==0||st!==h&&X.status!==666){var vt=X.strategy===2?function(at,Tt){for(var Bt;;){if(at.lookahead===0&&(Et(at),at.lookahead===0)){if(Tt===h)return D;break}if(at.match_length=0,Bt=s._tr_tally(at,0,at.window[at.strstart]),at.lookahead--,at.strstart++,Bt&&(j(at,!1),at.strm.avail_out===0))return D}return at.insert=0,Tt===d?(j(at,!0),at.strm.avail_out===0?V:W):at.last_lit&&(j(at,!1),at.strm.avail_out===0)?D:N}(X,st):X.strategy===3?function(at,Tt){for(var Bt,Ct,Yt,be,se=at.window;;){if(at.lookahead<=I){if(Et(at),at.lookahead<=I&&Tt===h)return D;if(at.lookahead===0)break}if(at.match_length=0,at.lookahead>=M&&0<at.strstart&&(Ct=se[Yt=at.strstart-1])===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]){be=at.strstart+I;do;while(Ct===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]&&Ct===se[++Yt]&&Yt<be);at.match_length=I-(be-Yt),at.match_length>at.lookahead&&(at.match_length=at.lookahead)}if(at.match_length>=M?(Bt=s._tr_tally(at,1,at.match_length-M),at.lookahead-=at.match_length,at.strstart+=at.match_length,at.match_length=0):(Bt=s._tr_tally(at,0,at.window[at.strstart]),at.lookahead--,at.strstart++),Bt&&(j(at,!1),at.strm.avail_out===0))return D}return at.insert=0,Tt===d?(j(at,!0),at.strm.avail_out===0?V:W):at.last_lit&&(j(at,!1),at.strm.avail_out===0)?D:N}(X,st):i[X.level].func(X,st);if(vt!==V&&vt!==W||(X.status=666),vt===D||vt===V)return O.avail_out===0&&(X.last_flush=-1),v;if(vt===N&&(st===1?s._tr_align(X):st!==5&&(s._tr_stored_block(X,0,0,!1),st===3&&(K(X.head),X.lookahead===0&&(X.strstart=0,X.block_start=0,X.insert=0))),U(O),O.avail_out===0))return X.last_flush=-1,v}return st!==d?v:X.wrap<=0?1:(X.wrap===2?(ut(X,255&O.adler),ut(X,O.adler>>8&255),ut(X,O.adler>>16&255),ut(X,O.adler>>24&255),ut(X,255&O.total_in),ut(X,O.total_in>>8&255),ut(X,O.total_in>>16&255),ut(X,O.total_in>>24&255)):(ot(X,O.adler>>>16),ot(X,65535&O.adler)),U(O),0<X.wrap&&(X.wrap=-X.wrap),X.pending!==0?v:1)},a.deflateEnd=function(O){var st;return O&&O.state?(st=O.state.status)!==P&&st!==69&&st!==73&&st!==91&&st!==103&&st!==E&&st!==666?$(O,p):(O.state=null,st===E?$(O,-3):v):p},a.deflateSetDictionary=function(O,st){var nt,X,Z,J,pt,vt,at,Tt,Bt=st.length;if(!O||!O.state||(J=(nt=O.state).wrap)===2||J===1&&nt.status!==P||nt.lookahead)return p;for(J===1&&(O.adler=l(O.adler,st,Bt,0)),nt.wrap=0,Bt>=nt.w_size&&(J===0&&(K(nt.head),nt.strstart=0,nt.block_start=0,nt.insert=0),Tt=new o.Buf8(nt.w_size),o.arraySet(Tt,st,Bt-nt.w_size,nt.w_size,0),st=Tt,Bt=nt.w_size),pt=O.avail_in,vt=O.next_in,at=O.input,O.avail_in=Bt,O.next_in=0,O.input=st,Et(nt);nt.lookahead>=M;){for(X=nt.strstart,Z=nt.lookahead-(M-1);nt.ins_h=(nt.ins_h<<nt.hash_shift^nt.window[X+M-1])&nt.hash_mask,nt.prev[X&nt.w_mask]=nt.head[nt.ins_h],nt.head[nt.ins_h]=X,X++,--Z;);nt.strstart=X,nt.lookahead=M-1,Et(nt)}return nt.strstart+=nt.lookahead,nt.block_start=nt.strstart,nt.insert=nt.lookahead,nt.lookahead=0,nt.match_length=nt.prev_length=M-1,nt.match_available=0,O.next_in=vt,O.input=at,O.avail_in=pt,nt.wrap=J,v},a.deflateInfo="pako deflate (from Nodeca project)"},{"../utils/common":41,"./adler32":43,"./crc32":45,"./messages":51,"./trees":52}],47:[function(t,n,a){n.exports=function(){this.text=0,this.time=0,this.xflags=0,this.os=0,this.extra=null,this.extra_len=0,this.name="",this.comment="",this.hcrc=0,this.done=!1}},{}],48:[function(t,n,a){n.exports=function(i,o){var s,l,u,c,h,d,v,p,y,_,g,f,w,x,S,A,T,L,M,I,R,P,E,D,N;s=i.state,l=i.next_in,D=i.input,u=l+(i.avail_in-5),c=i.next_out,N=i.output,h=c-(o-i.avail_out),d=c+(i.avail_out-257),v=s.dmax,p=s.wsize,y=s.whave,_=s.wnext,g=s.window,f=s.hold,w=s.bits,x=s.lencode,S=s.distcode,A=(1<<s.lenbits)-1,T=(1<<s.distbits)-1;t:do{w<15&&(f+=D[l++]<<w,w+=8,f+=D[l++]<<w,w+=8),L=x[f&A];e:for(;;){if(f>>>=M=L>>>24,w-=M,(M=L>>>16&255)===0)N[c++]=65535&L;else{if(!(16&M)){if(!(64&M)){L=x[(65535&L)+(f&(1<<M)-1)];continue e}if(32&M){s.mode=12;break t}i.msg="invalid literal/length code",s.mode=30;break t}I=65535&L,(M&=15)&&(w<M&&(f+=D[l++]<<w,w+=8),I+=f&(1<<M)-1,f>>>=M,w-=M),w<15&&(f+=D[l++]<<w,w+=8,f+=D[l++]<<w,w+=8),L=S[f&T];r:for(;;){if(f>>>=M=L>>>24,w-=M,!(16&(M=L>>>16&255))){if(!(64&M)){L=S[(65535&L)+(f&(1<<M)-1)];continue r}i.msg="invalid distance code",s.mode=30;break t}if(R=65535&L,w<(M&=15)&&(f+=D[l++]<<w,(w+=8)<M&&(f+=D[l++]<<w,w+=8)),v<(R+=f&(1<<M)-1)){i.msg="invalid distance too far back",s.mode=30;break t}if(f>>>=M,w-=M,(M=c-h)<R){if(y<(M=R-M)&&s.sane){i.msg="invalid distance too far back",s.mode=30;break t}if(E=g,(P=0)===_){if(P+=p-M,M<I){for(I-=M;N[c++]=g[P++],--M;);P=c-R,E=N}}else if(_<M){if(P+=p+_-M,(M-=_)<I){for(I-=M;N[c++]=g[P++],--M;);if(P=0,_<I){for(I-=M=_;N[c++]=g[P++],--M;);P=c-R,E=N}}}else if(P+=_-M,M<I){for(I-=M;N[c++]=g[P++],--M;);P=c-R,E=N}for(;2<I;)N[c++]=E[P++],N[c++]=E[P++],N[c++]=E[P++],I-=3;I&&(N[c++]=E[P++],1<I&&(N[c++]=E[P++]))}else{for(P=c-R;N[c++]=N[P++],N[c++]=N[P++],N[c++]=N[P++],2<(I-=3););I&&(N[c++]=N[P++],1<I&&(N[c++]=N[P++]))}break}}break}}while(l<u&&c<d);l-=I=w>>3,f&=(1<<(w-=I<<3))-1,i.next_in=l,i.next_out=c,i.avail_in=l<u?u-l+5:5-(l-u),i.avail_out=c<d?d-c+257:257-(c-d),s.hold=f,s.bits=w}},{}],49:[function(t,n,a){var i=t("../utils/common"),o=t("./adler32"),s=t("./crc32"),l=t("./inffast"),u=t("./inftrees"),c=1,h=2,d=0,v=-2,p=1,y=852,_=592;function g(P){return(P>>>24&255)+(P>>>8&65280)+((65280&P)<<8)+((255&P)<<24)}function f(){this.mode=0,this.last=!1,this.wrap=0,this.havedict=!1,this.flags=0,this.dmax=0,this.check=0,this.total=0,this.head=null,this.wbits=0,this.wsize=0,this.whave=0,this.wnext=0,this.window=null,this.hold=0,this.bits=0,this.length=0,this.offset=0,this.extra=0,this.lencode=null,this.distcode=null,this.lenbits=0,this.distbits=0,this.ncode=0,this.nlen=0,this.ndist=0,this.have=0,this.next=null,this.lens=new i.Buf16(320),this.work=new i.Buf16(288),this.lendyn=null,this.distdyn=null,this.sane=0,this.back=0,this.was=0}function w(P){var E;return P&&P.state?(E=P.state,P.total_in=P.total_out=E.total=0,P.msg="",E.wrap&&(P.adler=1&E.wrap),E.mode=p,E.last=0,E.havedict=0,E.dmax=32768,E.head=null,E.hold=0,E.bits=0,E.lencode=E.lendyn=new i.Buf32(y),E.distcode=E.distdyn=new i.Buf32(_),E.sane=1,E.back=-1,d):v}function x(P){var E;return P&&P.state?((E=P.state).wsize=0,E.whave=0,E.wnext=0,w(P)):v}function S(P,E){var D,N;return P&&P.state?(N=P.state,E<0?(D=0,E=-E):(D=1+(E>>4),E<48&&(E&=15)),E&&(E<8||15<E)?v:(N.window!==null&&N.wbits!==E&&(N.window=null),N.wrap=D,N.wbits=E,x(P))):v}function A(P,E){var D,N;return P?(N=new f,(P.state=N).window=null,(D=S(P,E))!==d&&(P.state=null),D):v}var T,L,M=!0;function I(P){if(M){var E;for(T=new i.Buf32(512),L=new i.Buf32(32),E=0;E<144;)P.lens[E++]=8;for(;E<256;)P.lens[E++]=9;for(;E<280;)P.lens[E++]=7;for(;E<288;)P.lens[E++]=8;for(u(c,P.lens,0,288,T,0,P.work,{bits:9}),E=0;E<32;)P.lens[E++]=5;u(h,P.lens,0,32,L,0,P.work,{bits:5}),M=!1}P.lencode=T,P.lenbits=9,P.distcode=L,P.distbits=5}function R(P,E,D,N){var V,W=P.state;return W.window===null&&(W.wsize=1<<W.wbits,W.wnext=0,W.whave=0,W.window=new i.Buf8(W.wsize)),N>=W.wsize?(i.arraySet(W.window,E,D-W.wsize,W.wsize,0),W.wnext=0,W.whave=W.wsize):(N<(V=W.wsize-W.wnext)&&(V=N),i.arraySet(W.window,E,D-N,V,W.wnext),(N-=V)?(i.arraySet(W.window,E,D-N,N,0),W.wnext=N,W.whave=W.wsize):(W.wnext+=V,W.wnext===W.wsize&&(W.wnext=0),W.whave<W.wsize&&(W.whave+=V))),0}a.inflateReset=x,a.inflateReset2=S,a.inflateResetKeep=w,a.inflateInit=function(P){return A(P,15)},a.inflateInit2=A,a.inflate=function(P,E){var D,N,V,W,$,H,K,U,j,ut,ot,it,Et,jt,bt,wt,Ot,xt,kt,ae,O,st,nt,X,Z=0,J=new i.Buf8(4),pt=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15];if(!P||!P.state||!P.output||!P.input&&P.avail_in!==0)return v;(D=P.state).mode===12&&(D.mode=13),$=P.next_out,V=P.output,K=P.avail_out,W=P.next_in,N=P.input,H=P.avail_in,U=D.hold,j=D.bits,ut=H,ot=K,st=d;t:for(;;)switch(D.mode){case p:if(D.wrap===0){D.mode=13;break}for(;j<16;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(2&D.wrap&&U===35615){J[D.check=0]=255&U,J[1]=U>>>8&255,D.check=s(D.check,J,2,0),j=U=0,D.mode=2;break}if(D.flags=0,D.head&&(D.head.done=!1),!(1&D.wrap)||(((255&U)<<8)+(U>>8))%31){P.msg="incorrect header check",D.mode=30;break}if((15&U)!=8){P.msg="unknown compression method",D.mode=30;break}if(j-=4,O=8+(15&(U>>>=4)),D.wbits===0)D.wbits=O;else if(O>D.wbits){P.msg="invalid window size",D.mode=30;break}D.dmax=1<<O,P.adler=D.check=1,D.mode=512&U?10:12,j=U=0;break;case 2:for(;j<16;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(D.flags=U,(255&D.flags)!=8){P.msg="unknown compression method",D.mode=30;break}if(57344&D.flags){P.msg="unknown header flags set",D.mode=30;break}D.head&&(D.head.text=U>>8&1),512&D.flags&&(J[0]=255&U,J[1]=U>>>8&255,D.check=s(D.check,J,2,0)),j=U=0,D.mode=3;case 3:for(;j<32;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}D.head&&(D.head.time=U),512&D.flags&&(J[0]=255&U,J[1]=U>>>8&255,J[2]=U>>>16&255,J[3]=U>>>24&255,D.check=s(D.check,J,4,0)),j=U=0,D.mode=4;case 4:for(;j<16;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}D.head&&(D.head.xflags=255&U,D.head.os=U>>8),512&D.flags&&(J[0]=255&U,J[1]=U>>>8&255,D.check=s(D.check,J,2,0)),j=U=0,D.mode=5;case 5:if(1024&D.flags){for(;j<16;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}D.length=U,D.head&&(D.head.extra_len=U),512&D.flags&&(J[0]=255&U,J[1]=U>>>8&255,D.check=s(D.check,J,2,0)),j=U=0}else D.head&&(D.head.extra=null);D.mode=6;case 6:if(1024&D.flags&&(H<(it=D.length)&&(it=H),it&&(D.head&&(O=D.head.extra_len-D.length,D.head.extra||(D.head.extra=new Array(D.head.extra_len)),i.arraySet(D.head.extra,N,W,it,O)),512&D.flags&&(D.check=s(D.check,N,it,W)),H-=it,W+=it,D.length-=it),D.length))break t;D.length=0,D.mode=7;case 7:if(2048&D.flags){if(H===0)break t;for(it=0;O=N[W+it++],D.head&&O&&D.length<65536&&(D.head.name+=String.fromCharCode(O)),O&&it<H;);if(512&D.flags&&(D.check=s(D.check,N,it,W)),H-=it,W+=it,O)break t}else D.head&&(D.head.name=null);D.length=0,D.mode=8;case 8:if(4096&D.flags){if(H===0)break t;for(it=0;O=N[W+it++],D.head&&O&&D.length<65536&&(D.head.comment+=String.fromCharCode(O)),O&&it<H;);if(512&D.flags&&(D.check=s(D.check,N,it,W)),H-=it,W+=it,O)break t}else D.head&&(D.head.comment=null);D.mode=9;case 9:if(512&D.flags){for(;j<16;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(U!==(65535&D.check)){P.msg="header crc mismatch",D.mode=30;break}j=U=0}D.head&&(D.head.hcrc=D.flags>>9&1,D.head.done=!0),P.adler=D.check=0,D.mode=12;break;case 10:for(;j<32;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}P.adler=D.check=g(U),j=U=0,D.mode=11;case 11:if(D.havedict===0)return P.next_out=$,P.avail_out=K,P.next_in=W,P.avail_in=H,D.hold=U,D.bits=j,2;P.adler=D.check=1,D.mode=12;case 12:if(E===5||E===6)break t;case 13:if(D.last){U>>>=7&j,j-=7&j,D.mode=27;break}for(;j<3;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}switch(D.last=1&U,j-=1,3&(U>>>=1)){case 0:D.mode=14;break;case 1:if(I(D),D.mode=20,E!==6)break;U>>>=2,j-=2;break t;case 2:D.mode=17;break;case 3:P.msg="invalid block type",D.mode=30}U>>>=2,j-=2;break;case 14:for(U>>>=7&j,j-=7&j;j<32;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if((65535&U)!=(U>>>16^65535)){P.msg="invalid stored block lengths",D.mode=30;break}if(D.length=65535&U,j=U=0,D.mode=15,E===6)break t;case 15:D.mode=16;case 16:if(it=D.length){if(H<it&&(it=H),K<it&&(it=K),it===0)break t;i.arraySet(V,N,W,it,$),H-=it,W+=it,K-=it,$+=it,D.length-=it;break}D.mode=12;break;case 17:for(;j<14;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(D.nlen=257+(31&U),U>>>=5,j-=5,D.ndist=1+(31&U),U>>>=5,j-=5,D.ncode=4+(15&U),U>>>=4,j-=4,286<D.nlen||30<D.ndist){P.msg="too many length or distance symbols",D.mode=30;break}D.have=0,D.mode=18;case 18:for(;D.have<D.ncode;){for(;j<3;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}D.lens[pt[D.have++]]=7&U,U>>>=3,j-=3}for(;D.have<19;)D.lens[pt[D.have++]]=0;if(D.lencode=D.lendyn,D.lenbits=7,nt={bits:D.lenbits},st=u(0,D.lens,0,19,D.lencode,0,D.work,nt),D.lenbits=nt.bits,st){P.msg="invalid code lengths set",D.mode=30;break}D.have=0,D.mode=19;case 19:for(;D.have<D.nlen+D.ndist;){for(;wt=(Z=D.lencode[U&(1<<D.lenbits)-1])>>>16&255,Ot=65535&Z,!((bt=Z>>>24)<=j);){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(Ot<16)U>>>=bt,j-=bt,D.lens[D.have++]=Ot;else{if(Ot===16){for(X=bt+2;j<X;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(U>>>=bt,j-=bt,D.have===0){P.msg="invalid bit length repeat",D.mode=30;break}O=D.lens[D.have-1],it=3+(3&U),U>>>=2,j-=2}else if(Ot===17){for(X=bt+3;j<X;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}j-=bt,O=0,it=3+(7&(U>>>=bt)),U>>>=3,j-=3}else{for(X=bt+7;j<X;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}j-=bt,O=0,it=11+(127&(U>>>=bt)),U>>>=7,j-=7}if(D.have+it>D.nlen+D.ndist){P.msg="invalid bit length repeat",D.mode=30;break}for(;it--;)D.lens[D.have++]=O}}if(D.mode===30)break;if(D.lens[256]===0){P.msg="invalid code -- missing end-of-block",D.mode=30;break}if(D.lenbits=9,nt={bits:D.lenbits},st=u(c,D.lens,0,D.nlen,D.lencode,0,D.work,nt),D.lenbits=nt.bits,st){P.msg="invalid literal/lengths set",D.mode=30;break}if(D.distbits=6,D.distcode=D.distdyn,nt={bits:D.distbits},st=u(h,D.lens,D.nlen,D.ndist,D.distcode,0,D.work,nt),D.distbits=nt.bits,st){P.msg="invalid distances set",D.mode=30;break}if(D.mode=20,E===6)break t;case 20:D.mode=21;case 21:if(6<=H&&258<=K){P.next_out=$,P.avail_out=K,P.next_in=W,P.avail_in=H,D.hold=U,D.bits=j,l(P,ot),$=P.next_out,V=P.output,K=P.avail_out,W=P.next_in,N=P.input,H=P.avail_in,U=D.hold,j=D.bits,D.mode===12&&(D.back=-1);break}for(D.back=0;wt=(Z=D.lencode[U&(1<<D.lenbits)-1])>>>16&255,Ot=65535&Z,!((bt=Z>>>24)<=j);){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(wt&&!(240&wt)){for(xt=bt,kt=wt,ae=Ot;wt=(Z=D.lencode[ae+((U&(1<<xt+kt)-1)>>xt)])>>>16&255,Ot=65535&Z,!(xt+(bt=Z>>>24)<=j);){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}U>>>=xt,j-=xt,D.back+=xt}if(U>>>=bt,j-=bt,D.back+=bt,D.length=Ot,wt===0){D.mode=26;break}if(32&wt){D.back=-1,D.mode=12;break}if(64&wt){P.msg="invalid literal/length code",D.mode=30;break}D.extra=15&wt,D.mode=22;case 22:if(D.extra){for(X=D.extra;j<X;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}D.length+=U&(1<<D.extra)-1,U>>>=D.extra,j-=D.extra,D.back+=D.extra}D.was=D.length,D.mode=23;case 23:for(;wt=(Z=D.distcode[U&(1<<D.distbits)-1])>>>16&255,Ot=65535&Z,!((bt=Z>>>24)<=j);){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(!(240&wt)){for(xt=bt,kt=wt,ae=Ot;wt=(Z=D.distcode[ae+((U&(1<<xt+kt)-1)>>xt)])>>>16&255,Ot=65535&Z,!(xt+(bt=Z>>>24)<=j);){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}U>>>=xt,j-=xt,D.back+=xt}if(U>>>=bt,j-=bt,D.back+=bt,64&wt){P.msg="invalid distance code",D.mode=30;break}D.offset=Ot,D.extra=15&wt,D.mode=24;case 24:if(D.extra){for(X=D.extra;j<X;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}D.offset+=U&(1<<D.extra)-1,U>>>=D.extra,j-=D.extra,D.back+=D.extra}if(D.offset>D.dmax){P.msg="invalid distance too far back",D.mode=30;break}D.mode=25;case 25:if(K===0)break t;if(it=ot-K,D.offset>it){if((it=D.offset-it)>D.whave&&D.sane){P.msg="invalid distance too far back",D.mode=30;break}Et=it>D.wnext?(it-=D.wnext,D.wsize-it):D.wnext-it,it>D.length&&(it=D.length),jt=D.window}else jt=V,Et=$-D.offset,it=D.length;for(K<it&&(it=K),K-=it,D.length-=it;V[$++]=jt[Et++],--it;);D.length===0&&(D.mode=21);break;case 26:if(K===0)break t;V[$++]=D.length,K--,D.mode=21;break;case 27:if(D.wrap){for(;j<32;){if(H===0)break t;H--,U|=N[W++]<<j,j+=8}if(ot-=K,P.total_out+=ot,D.total+=ot,ot&&(P.adler=D.check=D.flags?s(D.check,V,ot,$-ot):o(D.check,V,ot,$-ot)),ot=K,(D.flags?U:g(U))!==D.check){P.msg="incorrect data check",D.mode=30;break}j=U=0}D.mode=28;case 28:if(D.wrap&&D.flags){for(;j<32;){if(H===0)break t;H--,U+=N[W++]<<j,j+=8}if(U!==(4294967295&D.total)){P.msg="incorrect length check",D.mode=30;break}j=U=0}D.mode=29;case 29:st=1;break t;case 30:st=-3;break t;case 31:return-4;case 32:default:return v}return P.next_out=$,P.avail_out=K,P.next_in=W,P.avail_in=H,D.hold=U,D.bits=j,(D.wsize||ot!==P.avail_out&&D.mode<30&&(D.mode<27||E!==4))&&R(P,P.output,P.next_out,ot-P.avail_out)?(D.mode=31,-4):(ut-=P.avail_in,ot-=P.avail_out,P.total_in+=ut,P.total_out+=ot,D.total+=ot,D.wrap&&ot&&(P.adler=D.check=D.flags?s(D.check,V,ot,P.next_out-ot):o(D.check,V,ot,P.next_out-ot)),P.data_type=D.bits+(D.last?64:0)+(D.mode===12?128:0)+(D.mode===20||D.mode===15?256:0),(ut==0&&ot===0||E===4)&&st===d&&(st=-5),st)},a.inflateEnd=function(P){if(!P||!P.state)return v;var E=P.state;return E.window&&(E.window=null),P.state=null,d},a.inflateGetHeader=function(P,E){var D;return P&&P.state&&2&(D=P.state).wrap?((D.head=E).done=!1,d):v},a.inflateSetDictionary=function(P,E){var D,N=E.length;return P&&P.state?(D=P.state).wrap!==0&&D.mode!==11?v:D.mode===11&&o(1,E,N,0)!==D.check?-3:R(P,E,N,N)?(D.mode=31,-4):(D.havedict=1,d):v},a.inflateInfo="pako inflate (from Nodeca project)"},{"../utils/common":41,"./adler32":43,"./crc32":45,"./inffast":48,"./inftrees":50}],50:[function(t,n,a){var i=t("../utils/common"),o=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,0,0],s=[16,16,16,16,16,16,16,16,17,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,16,72,78],l=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577,0,0],u=[16,16,16,16,17,17,18,18,19,19,20,20,21,21,22,22,23,23,24,24,25,25,26,26,27,27,28,28,29,29,64,64];n.exports=function(c,h,d,v,p,y,_,g){var f,w,x,S,A,T,L,M,I,R=g.bits,P=0,E=0,D=0,N=0,V=0,W=0,$=0,H=0,K=0,U=0,j=null,ut=0,ot=new i.Buf16(16),it=new i.Buf16(16),Et=null,jt=0;for(P=0;P<=15;P++)ot[P]=0;for(E=0;E<v;E++)ot[h[d+E]]++;for(V=R,N=15;1<=N&&ot[N]===0;N--);if(N<V&&(V=N),N===0)return p[y++]=20971520,p[y++]=20971520,g.bits=1,0;for(D=1;D<N&&ot[D]===0;D++);for(V<D&&(V=D),P=H=1;P<=15;P++)if(H<<=1,(H-=ot[P])<0)return-1;if(0<H&&(c===0||N!==1))return-1;for(it[1]=0,P=1;P<15;P++)it[P+1]=it[P]+ot[P];for(E=0;E<v;E++)h[d+E]!==0&&(_[it[h[d+E]]++]=E);if(T=c===0?(j=Et=_,19):c===1?(j=o,ut-=257,Et=s,jt-=257,256):(j=l,Et=u,-1),P=D,A=y,$=E=U=0,x=-1,S=(K=1<<(W=V))-1,c===1&&852<K||c===2&&592<K)return 1;for(;;){for(L=P-$,I=_[E]<T?(M=0,_[E]):_[E]>T?(M=Et[jt+_[E]],j[ut+_[E]]):(M=96,0),f=1<<P-$,D=w=1<<W;p[A+(U>>$)+(w-=f)]=L<<24|M<<16|I|0,w!==0;);for(f=1<<P-1;U&f;)f>>=1;if(f!==0?(U&=f-1,U+=f):U=0,E++,--ot[P]==0){if(P===N)break;P=h[d+_[E]]}if(V<P&&(U&S)!==x){for($===0&&($=V),A+=D,H=1<<(W=P-$);W+$<N&&!((H-=ot[W+$])<=0);)W++,H<<=1;if(K+=1<<W,c===1&&852<K||c===2&&592<K)return 1;p[x=U&S]=V<<24|W<<16|A-y|0}}return U!==0&&(p[A+U]=P-$<<24|64<<16|0),g.bits=V,0}},{"../utils/common":41}],51:[function(t,n,a){n.exports={2:"need dictionary",1:"stream end",0:"","-1":"file error","-2":"stream error","-3":"data error","-4":"insufficient memory","-5":"buffer error","-6":"incompatible version"}},{}],52:[function(t,n,a){var i=t("../utils/common"),o=0,s=1;function l(Z){for(var J=Z.length;0<=--J;)Z[J]=0}var u=0,c=29,h=256,d=h+1+c,v=30,p=19,y=2*d+1,_=15,g=16,f=7,w=256,x=16,S=17,A=18,T=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0],L=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,13],M=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7],I=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],R=new Array(2*(d+2));l(R);var P=new Array(2*v);l(P);var E=new Array(512);l(E);var D=new Array(256);l(D);var N=new Array(c);l(N);var V,W,$,H=new Array(v);function K(Z,J,pt,vt,at){this.static_tree=Z,this.extra_bits=J,this.extra_base=pt,this.elems=vt,this.max_length=at,this.has_stree=Z&&Z.length}function U(Z,J){this.dyn_tree=Z,this.max_code=0,this.stat_desc=J}function j(Z){return Z<256?E[Z]:E[256+(Z>>>7)]}function ut(Z,J){Z.pending_buf[Z.pending++]=255&J,Z.pending_buf[Z.pending++]=J>>>8&255}function ot(Z,J,pt){Z.bi_valid>g-pt?(Z.bi_buf|=J<<Z.bi_valid&65535,ut(Z,Z.bi_buf),Z.bi_buf=J>>g-Z.bi_valid,Z.bi_valid+=pt-g):(Z.bi_buf|=J<<Z.bi_valid&65535,Z.bi_valid+=pt)}function it(Z,J,pt){ot(Z,pt[2*J],pt[2*J+1])}function Et(Z,J){for(var pt=0;pt|=1&Z,Z>>>=1,pt<<=1,0<--J;);return pt>>>1}function jt(Z,J,pt){var vt,at,Tt=new Array(_+1),Bt=0;for(vt=1;vt<=_;vt++)Tt[vt]=Bt=Bt+pt[vt-1]<<1;for(at=0;at<=J;at++){var Ct=Z[2*at+1];Ct!==0&&(Z[2*at]=Et(Tt[Ct]++,Ct))}}function bt(Z){var J;for(J=0;J<d;J++)Z.dyn_ltree[2*J]=0;for(J=0;J<v;J++)Z.dyn_dtree[2*J]=0;for(J=0;J<p;J++)Z.bl_tree[2*J]=0;Z.dyn_ltree[2*w]=1,Z.opt_len=Z.static_len=0,Z.last_lit=Z.matches=0}function wt(Z){8<Z.bi_valid?ut(Z,Z.bi_buf):0<Z.bi_valid&&(Z.pending_buf[Z.pending++]=Z.bi_buf),Z.bi_buf=0,Z.bi_valid=0}function Ot(Z,J,pt,vt){var at=2*J,Tt=2*pt;return Z[at]<Z[Tt]||Z[at]===Z[Tt]&&vt[J]<=vt[pt]}function xt(Z,J,pt){for(var vt=Z.heap[pt],at=pt<<1;at<=Z.heap_len&&(at<Z.heap_len&&Ot(J,Z.heap[at+1],Z.heap[at],Z.depth)&&at++,!Ot(J,vt,Z.heap[at],Z.depth));)Z.heap[pt]=Z.heap[at],pt=at,at<<=1;Z.heap[pt]=vt}function kt(Z,J,pt){var vt,at,Tt,Bt,Ct=0;if(Z.last_lit!==0)for(;vt=Z.pending_buf[Z.d_buf+2*Ct]<<8|Z.pending_buf[Z.d_buf+2*Ct+1],at=Z.pending_buf[Z.l_buf+Ct],Ct++,vt===0?it(Z,at,J):(it(Z,(Tt=D[at])+h+1,J),(Bt=T[Tt])!==0&&ot(Z,at-=N[Tt],Bt),it(Z,Tt=j(--vt),pt),(Bt=L[Tt])!==0&&ot(Z,vt-=H[Tt],Bt)),Ct<Z.last_lit;);it(Z,w,J)}function ae(Z,J){var pt,vt,at,Tt=J.dyn_tree,Bt=J.stat_desc.static_tree,Ct=J.stat_desc.has_stree,Yt=J.stat_desc.elems,be=-1;for(Z.heap_len=0,Z.heap_max=y,pt=0;pt<Yt;pt++)Tt[2*pt]!==0?(Z.heap[++Z.heap_len]=be=pt,Z.depth[pt]=0):Tt[2*pt+1]=0;for(;Z.heap_len<2;)Tt[2*(at=Z.heap[++Z.heap_len]=be<2?++be:0)]=1,Z.depth[at]=0,Z.opt_len--,Ct&&(Z.static_len-=Bt[2*at+1]);for(J.max_code=be,pt=Z.heap_len>>1;1<=pt;pt--)xt(Z,Tt,pt);for(at=Yt;pt=Z.heap[1],Z.heap[1]=Z.heap[Z.heap_len--],xt(Z,Tt,1),vt=Z.heap[1],Z.heap[--Z.heap_max]=pt,Z.heap[--Z.heap_max]=vt,Tt[2*at]=Tt[2*pt]+Tt[2*vt],Z.depth[at]=(Z.depth[pt]>=Z.depth[vt]?Z.depth[pt]:Z.depth[vt])+1,Tt[2*pt+1]=Tt[2*vt+1]=at,Z.heap[1]=at++,xt(Z,Tt,1),2<=Z.heap_len;);Z.heap[--Z.heap_max]=Z.heap[1],function(se,lr){var gn,xr,yn,Be,In,aa,Cr=lr.dyn_tree,Aa=lr.max_code,Mo=lr.stat_desc.static_tree,we=lr.stat_desc.has_stree,er=lr.stat_desc.extra_bits,Au=lr.stat_desc.extra_base,Ei=lr.stat_desc.max_length,Ks=0;for(Be=0;Be<=_;Be++)se.bl_count[Be]=0;for(Cr[2*se.heap[se.heap_max]+1]=0,gn=se.heap_max+1;gn<y;gn++)Ei<(Be=Cr[2*Cr[2*(xr=se.heap[gn])+1]+1]+1)&&(Be=Ei,Ks++),Cr[2*xr+1]=Be,Aa<xr||(se.bl_count[Be]++,In=0,Au<=xr&&(In=er[xr-Au]),aa=Cr[2*xr],se.opt_len+=aa*(Be+In),we&&(se.static_len+=aa*(Mo[2*xr+1]+In)));if(Ks!==0){do{for(Be=Ei-1;se.bl_count[Be]===0;)Be--;se.bl_count[Be]--,se.bl_count[Be+1]+=2,se.bl_count[Ei]--,Ks-=2}while(0<Ks);for(Be=Ei;Be!==0;Be--)for(xr=se.bl_count[Be];xr!==0;)Aa<(yn=se.heap[--gn])||(Cr[2*yn+1]!==Be&&(se.opt_len+=(Be-Cr[2*yn+1])*Cr[2*yn],Cr[2*yn+1]=Be),xr--)}}(Z,J),jt(Tt,be,Z.bl_count)}function O(Z,J,pt){var vt,at,Tt=-1,Bt=J[1],Ct=0,Yt=7,be=4;for(Bt===0&&(Yt=138,be=3),J[2*(pt+1)+1]=65535,vt=0;vt<=pt;vt++)at=Bt,Bt=J[2*(vt+1)+1],++Ct<Yt&&at===Bt||(Ct<be?Z.bl_tree[2*at]+=Ct:at!==0?(at!==Tt&&Z.bl_tree[2*at]++,Z.bl_tree[2*x]++):Ct<=10?Z.bl_tree[2*S]++:Z.bl_tree[2*A]++,Tt=at,be=(Ct=0)===Bt?(Yt=138,3):at===Bt?(Yt=6,3):(Yt=7,4))}function st(Z,J,pt){var vt,at,Tt=-1,Bt=J[1],Ct=0,Yt=7,be=4;for(Bt===0&&(Yt=138,be=3),vt=0;vt<=pt;vt++)if(at=Bt,Bt=J[2*(vt+1)+1],!(++Ct<Yt&&at===Bt)){if(Ct<be)for(;it(Z,at,Z.bl_tree),--Ct!=0;);else at!==0?(at!==Tt&&(it(Z,at,Z.bl_tree),Ct--),it(Z,x,Z.bl_tree),ot(Z,Ct-3,2)):Ct<=10?(it(Z,S,Z.bl_tree),ot(Z,Ct-3,3)):(it(Z,A,Z.bl_tree),ot(Z,Ct-11,7));Tt=at,be=(Ct=0)===Bt?(Yt=138,3):at===Bt?(Yt=6,3):(Yt=7,4)}}l(H);var nt=!1;function X(Z,J,pt,vt){ot(Z,(u<<1)+(vt?1:0),3),function(at,Tt,Bt,Ct){wt(at),ut(at,Bt),ut(at,~Bt),i.arraySet(at.pending_buf,at.window,Tt,Bt,at.pending),at.pending+=Bt}(Z,J,pt)}a._tr_init=function(Z){nt||(function(){var J,pt,vt,at,Tt,Bt=new Array(_+1);for(at=vt=0;at<c-1;at++)for(N[at]=vt,J=0;J<1<<T[at];J++)D[vt++]=at;for(D[vt-1]=at,at=Tt=0;at<16;at++)for(H[at]=Tt,J=0;J<1<<L[at];J++)E[Tt++]=at;for(Tt>>=7;at<v;at++)for(H[at]=Tt<<7,J=0;J<1<<L[at]-7;J++)E[256+Tt++]=at;for(pt=0;pt<=_;pt++)Bt[pt]=0;for(J=0;J<=143;)R[2*J+1]=8,J++,Bt[8]++;for(;J<=255;)R[2*J+1]=9,J++,Bt[9]++;for(;J<=279;)R[2*J+1]=7,J++,Bt[7]++;for(;J<=287;)R[2*J+1]=8,J++,Bt[8]++;for(jt(R,d+1,Bt),J=0;J<v;J++)P[2*J+1]=5,P[2*J]=Et(J,5);V=new K(R,T,h+1,d,_),W=new K(P,L,0,v,_),$=new K(new Array(0),M,0,p,f)}(),nt=!0),Z.l_desc=new U(Z.dyn_ltree,V),Z.d_desc=new U(Z.dyn_dtree,W),Z.bl_desc=new U(Z.bl_tree,$),Z.bi_buf=0,Z.bi_valid=0,bt(Z)},a._tr_stored_block=X,a._tr_flush_block=function(Z,J,pt,vt){var at,Tt,Bt=0;0<Z.level?(Z.strm.data_type===2&&(Z.strm.data_type=function(Ct){var Yt,be=4093624447;for(Yt=0;Yt<=31;Yt++,be>>>=1)if(1&be&&Ct.dyn_ltree[2*Yt]!==0)return o;if(Ct.dyn_ltree[18]!==0||Ct.dyn_ltree[20]!==0||Ct.dyn_ltree[26]!==0)return s;for(Yt=32;Yt<h;Yt++)if(Ct.dyn_ltree[2*Yt]!==0)return s;return o}(Z)),ae(Z,Z.l_desc),ae(Z,Z.d_desc),Bt=function(Ct){var Yt;for(O(Ct,Ct.dyn_ltree,Ct.l_desc.max_code),O(Ct,Ct.dyn_dtree,Ct.d_desc.max_code),ae(Ct,Ct.bl_desc),Yt=p-1;3<=Yt&&Ct.bl_tree[2*I[Yt]+1]===0;Yt--);return Ct.opt_len+=3*(Yt+1)+5+5+4,Yt}(Z),at=Z.opt_len+3+7>>>3,(Tt=Z.static_len+3+7>>>3)<=at&&(at=Tt)):at=Tt=pt+5,pt+4<=at&&J!==-1?X(Z,J,pt,vt):Z.strategy===4||Tt===at?(ot(Z,2+(vt?1:0),3),kt(Z,R,P)):(ot(Z,4+(vt?1:0),3),function(Ct,Yt,be,se){var lr;for(ot(Ct,Yt-257,5),ot(Ct,be-1,5),ot(Ct,se-4,4),lr=0;lr<se;lr++)ot(Ct,Ct.bl_tree[2*I[lr]+1],3);st(Ct,Ct.dyn_ltree,Yt-1),st(Ct,Ct.dyn_dtree,be-1)}(Z,Z.l_desc.max_code+1,Z.d_desc.max_code+1,Bt+1),kt(Z,Z.dyn_ltree,Z.dyn_dtree)),bt(Z),vt&&wt(Z)},a._tr_tally=function(Z,J,pt){return Z.pending_buf[Z.d_buf+2*Z.last_lit]=J>>>8&255,Z.pending_buf[Z.d_buf+2*Z.last_lit+1]=255&J,Z.pending_buf[Z.l_buf+Z.last_lit]=255&pt,Z.last_lit++,J===0?Z.dyn_ltree[2*pt]++:(Z.matches++,J--,Z.dyn_ltree[2*(D[pt]+h+1)]++,Z.dyn_dtree[2*j(J)]++),Z.last_lit===Z.lit_bufsize-1},a._tr_align=function(Z){ot(Z,2,3),it(Z,w,R),function(J){J.bi_valid===16?(ut(J,J.bi_buf),J.bi_buf=0,J.bi_valid=0):8<=J.bi_valid&&(J.pending_buf[J.pending++]=255&J.bi_buf,J.bi_buf>>=8,J.bi_valid-=8)}(Z)}},{"../utils/common":41}],53:[function(t,n,a){n.exports=function(){this.input=null,this.next_in=0,this.avail_in=0,this.total_in=0,this.output=null,this.next_out=0,this.avail_out=0,this.total_out=0,this.msg="",this.state=null,this.data_type=2,this.adler=0}},{}],54:[function(t,n,a){(function(i){(function(o,s){if(!o.setImmediate){var l,u,c,h,d=1,v={},p=!1,y=o.document,_=Object.getPrototypeOf&&Object.getPrototypeOf(o);_=_&&_.setTimeout?_:o,l={}.toString.call(o.process)==="[object process]"?function(x){process.nextTick(function(){f(x)})}:function(){if(o.postMessage&&!o.importScripts){var x=!0,S=o.onmessage;return o.onmessage=function(){x=!1},o.postMessage("","*"),o.onmessage=S,x}}()?(h="setImmediate$"+Math.random()+"$",o.addEventListener?o.addEventListener("message",w,!1):o.attachEvent("onmessage",w),function(x){o.postMessage(h+x,"*")}):o.MessageChannel?((c=new MessageChannel).port1.onmessage=function(x){f(x.data)},function(x){c.port2.postMessage(x)}):y&&"onreadystatechange"in y.createElement("script")?(u=y.documentElement,function(x){var S=y.createElement("script");S.onreadystatechange=function(){f(x),S.onreadystatechange=null,u.removeChild(S),S=null},u.appendChild(S)}):function(x){setTimeout(f,0,x)},_.setImmediate=function(x){typeof x!="function"&&(x=new Function(""+x));for(var S=new Array(arguments.length-1),A=0;A<S.length;A++)S[A]=arguments[A+1];var T={callback:x,args:S};return v[d]=T,l(d),d++},_.clearImmediate=g}function g(x){delete v[x]}function f(x){if(p)setTimeout(f,0,x);else{var S=v[x];if(S){p=!0;try{(function(A){var T=A.callback,L=A.args;switch(L.length){case 0:T();break;case 1:T(L[0]);break;case 2:T(L[0],L[1]);break;case 3:T(L[0],L[1],L[2]);break;default:T.apply(s,L)}})(S)}finally{g(x),p=!1}}}}function w(x){x.source===o&&typeof x.data=="string"&&x.data.indexOf(h)===0&&f(+x.data.slice(h.length))}})(typeof self>"u"?i===void 0?this:i:self)}).call(this,typeof pi<"u"?pi:typeof self<"u"?self:typeof window<"u"?window:{})},{}]},{},[10])(10)})})(EI);var t6=EI.exports;const e6=JG(t6);var fd={exports:{}};/**
 * @license
 * Lodash <https://lodash.com/>
 * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */fd.exports;(function(r,e){(function(){var t,n="4.17.21",a=200,i="Unsupported core-js use. Try https://npms.io/search?q=ponyfill.",o="Expected a function",s="Invalid `variable` option passed into `_.template`",l="__lodash_hash_undefined__",u=500,c="__lodash_placeholder__",h=1,d=2,v=4,p=1,y=2,_=1,g=2,f=4,w=8,x=16,S=32,A=64,T=128,L=256,M=512,I=30,R="...",P=800,E=16,D=1,N=2,V=3,W=1/0,$=9007199254740991,H=17976931348623157e292,K=NaN,U=4294967295,j=U-1,ut=U>>>1,ot=[["ary",T],["bind",_],["bindKey",g],["curry",w],["curryRight",x],["flip",M],["partial",S],["partialRight",A],["rearg",L]],it="[object Arguments]",Et="[object Array]",jt="[object AsyncFunction]",bt="[object Boolean]",wt="[object Date]",Ot="[object DOMException]",xt="[object Error]",kt="[object Function]",ae="[object GeneratorFunction]",O="[object Map]",st="[object Number]",nt="[object Null]",X="[object Object]",Z="[object Promise]",J="[object Proxy]",pt="[object RegExp]",vt="[object Set]",at="[object String]",Tt="[object Symbol]",Bt="[object Undefined]",Ct="[object WeakMap]",Yt="[object WeakSet]",be="[object ArrayBuffer]",se="[object DataView]",lr="[object Float32Array]",gn="[object Float64Array]",xr="[object Int8Array]",yn="[object Int16Array]",Be="[object Int32Array]",In="[object Uint8Array]",aa="[object Uint8ClampedArray]",Cr="[object Uint16Array]",Aa="[object Uint32Array]",Mo=/\b__p \+= '';/g,we=/\b(__p \+=) '' \+/g,er=/(__e\(.*?\)|\b__t\)) \+\n'';/g,Au=/&(?:amp|lt|gt|quot|#39);/g,Ei=/[&<>"']/g,Ks=RegExp(Au.source),AB=RegExp(Ei.source),TB=/<%-([\s\S]+?)%>/g,CB=/<%([\s\S]+?)%>/g,Ux=/<%=([\s\S]+?)%>/g,LB=/\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,MB=/^\w*$/,DB=/[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g,Qp=/[\\^$.*+?()[\]{}|]/g,IB=RegExp(Qp.source),Jp=/^\s+/,PB=/\s/,kB=/\{(?:\n\/\* \[wrapped with .+\] \*\/)?\n?/,RB=/\{\n\/\* \[wrapped with (.+)\] \*/,EB=/,? & /,OB=/[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g,BB=/[()=,{}\[\]\/\s]/,NB=/\\(\\)?/g,zB=/\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g,Zx=/\w*$/,FB=/^[-+]0x[0-9a-f]+$/i,VB=/^0b[01]+$/i,GB=/^\[object .+?Constructor\]$/,WB=/^0o[0-7]+$/i,HB=/^(?:0|[1-9]\d*)$/,UB=/[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g,qh=/($^)/,ZB=/['\n\r\u2028\u2029\\]/g,Kh="\\ud800-\\udfff",YB="\\u0300-\\u036f",XB="\\ufe20-\\ufe2f",$B="\\u20d0-\\u20ff",Yx=YB+XB+$B,Xx="\\u2700-\\u27bf",$x="a-z\\xdf-\\xf6\\xf8-\\xff",jB="\\xac\\xb1\\xd7\\xf7",qB="\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf",KB="\\u2000-\\u206f",QB=" \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000",jx="A-Z\\xc0-\\xd6\\xd8-\\xde",qx="\\ufe0e\\ufe0f",Kx=jB+qB+KB+QB,tg="['’]",JB="["+Kh+"]",Qx="["+Kx+"]",Qh="["+Yx+"]",Jx="\\d+",tN="["+Xx+"]",tb="["+$x+"]",eb="[^"+Kh+Kx+Jx+Xx+$x+jx+"]",eg="\\ud83c[\\udffb-\\udfff]",eN="(?:"+Qh+"|"+eg+")",rb="[^"+Kh+"]",rg="(?:\\ud83c[\\udde6-\\uddff]){2}",ng="[\\ud800-\\udbff][\\udc00-\\udfff]",Qs="["+jx+"]",nb="\\u200d",ab="(?:"+tb+"|"+eb+")",rN="(?:"+Qs+"|"+eb+")",ib="(?:"+tg+"(?:d|ll|m|re|s|t|ve))?",ob="(?:"+tg+"(?:D|LL|M|RE|S|T|VE))?",sb=eN+"?",lb="["+qx+"]?",nN="(?:"+nb+"(?:"+[rb,rg,ng].join("|")+")"+lb+sb+")*",aN="\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])",iN="\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])",ub=lb+sb+nN,oN="(?:"+[tN,rg,ng].join("|")+")"+ub,sN="(?:"+[rb+Qh+"?",Qh,rg,ng,JB].join("|")+")",lN=RegExp(tg,"g"),uN=RegExp(Qh,"g"),ag=RegExp(eg+"(?="+eg+")|"+sN+ub,"g"),cN=RegExp([Qs+"?"+tb+"+"+ib+"(?="+[Qx,Qs,"$"].join("|")+")",rN+"+"+ob+"(?="+[Qx,Qs+ab,"$"].join("|")+")",Qs+"?"+ab+"+"+ib,Qs+"+"+ob,iN,aN,Jx,oN].join("|"),"g"),hN=RegExp("["+nb+Kh+Yx+qx+"]"),fN=/[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/,vN=["Array","Buffer","DataView","Date","Error","Float32Array","Float64Array","Function","Int8Array","Int16Array","Int32Array","Map","Math","Object","Promise","RegExp","Set","String","Symbol","TypeError","Uint8Array","Uint8ClampedArray","Uint16Array","Uint32Array","WeakMap","_","clearTimeout","isFinite","parseInt","setTimeout"],dN=-1,Ye={};Ye[lr]=Ye[gn]=Ye[xr]=Ye[yn]=Ye[Be]=Ye[In]=Ye[aa]=Ye[Cr]=Ye[Aa]=!0,Ye[it]=Ye[Et]=Ye[be]=Ye[bt]=Ye[se]=Ye[wt]=Ye[xt]=Ye[kt]=Ye[O]=Ye[st]=Ye[X]=Ye[pt]=Ye[vt]=Ye[at]=Ye[Ct]=!1;var Ue={};Ue[it]=Ue[Et]=Ue[be]=Ue[se]=Ue[bt]=Ue[wt]=Ue[lr]=Ue[gn]=Ue[xr]=Ue[yn]=Ue[Be]=Ue[O]=Ue[st]=Ue[X]=Ue[pt]=Ue[vt]=Ue[at]=Ue[Tt]=Ue[In]=Ue[aa]=Ue[Cr]=Ue[Aa]=!0,Ue[xt]=Ue[kt]=Ue[Ct]=!1;var pN={À:"A",Á:"A",Â:"A",Ã:"A",Ä:"A",Å:"A",à:"a",á:"a",â:"a",ã:"a",ä:"a",å:"a",Ç:"C",ç:"c",Ð:"D",ð:"d",È:"E",É:"E",Ê:"E",Ë:"E",è:"e",é:"e",ê:"e",ë:"e",Ì:"I",Í:"I",Î:"I",Ï:"I",ì:"i",í:"i",î:"i",ï:"i",Ñ:"N",ñ:"n",Ò:"O",Ó:"O",Ô:"O",Õ:"O",Ö:"O",Ø:"O",ò:"o",ó:"o",ô:"o",õ:"o",ö:"o",ø:"o",Ù:"U",Ú:"U",Û:"U",Ü:"U",ù:"u",ú:"u",û:"u",ü:"u",Ý:"Y",ý:"y",ÿ:"y",Æ:"Ae",æ:"ae",Þ:"Th",þ:"th",ß:"ss",Ā:"A",Ă:"A",Ą:"A",ā:"a",ă:"a",ą:"a",Ć:"C",Ĉ:"C",Ċ:"C",Č:"C",ć:"c",ĉ:"c",ċ:"c",č:"c",Ď:"D",Đ:"D",ď:"d",đ:"d",Ē:"E",Ĕ:"E",Ė:"E",Ę:"E",Ě:"E",ē:"e",ĕ:"e",ė:"e",ę:"e",ě:"e",Ĝ:"G",Ğ:"G",Ġ:"G",Ģ:"G",ĝ:"g",ğ:"g",ġ:"g",ģ:"g",Ĥ:"H",Ħ:"H",ĥ:"h",ħ:"h",Ĩ:"I",Ī:"I",Ĭ:"I",Į:"I",İ:"I",ĩ:"i",ī:"i",ĭ:"i",į:"i",ı:"i",Ĵ:"J",ĵ:"j",Ķ:"K",ķ:"k",ĸ:"k",Ĺ:"L",Ļ:"L",Ľ:"L",Ŀ:"L",Ł:"L",ĺ:"l",ļ:"l",ľ:"l",ŀ:"l",ł:"l",Ń:"N",Ņ:"N",Ň:"N",Ŋ:"N",ń:"n",ņ:"n",ň:"n",ŋ:"n",Ō:"O",Ŏ:"O",Ő:"O",ō:"o",ŏ:"o",ő:"o",Ŕ:"R",Ŗ:"R",Ř:"R",ŕ:"r",ŗ:"r",ř:"r",Ś:"S",Ŝ:"S",Ş:"S",Š:"S",ś:"s",ŝ:"s",ş:"s",š:"s",Ţ:"T",Ť:"T",Ŧ:"T",ţ:"t",ť:"t",ŧ:"t",Ũ:"U",Ū:"U",Ŭ:"U",Ů:"U",Ű:"U",Ų:"U",ũ:"u",ū:"u",ŭ:"u",ů:"u",ű:"u",ų:"u",Ŵ:"W",ŵ:"w",Ŷ:"Y",ŷ:"y",Ÿ:"Y",Ź:"Z",Ż:"Z",Ž:"Z",ź:"z",ż:"z",ž:"z",Ĳ:"IJ",ĳ:"ij",Œ:"Oe",œ:"oe",ŉ:"'n",ſ:"s"},gN={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"},yN={"&amp;":"&","&lt;":"<","&gt;":">","&quot;":'"',"&#39;":"'"},mN={"\\":"\\","'":"'","\n":"n","\r":"r","\u2028":"u2028","\u2029":"u2029"},_N=parseFloat,wN=parseInt,cb=typeof pi=="object"&&pi&&pi.Object===Object&&pi,xN=typeof self=="object"&&self&&self.Object===Object&&self,Lr=cb||xN||Function("return this")(),ig=e&&!e.nodeType&&e,Do=ig&&!0&&r&&!r.nodeType&&r,hb=Do&&Do.exports===ig,og=hb&&cb.process,Pn=function(){try{var tt=Do&&Do.require&&Do.require("util").types;return tt||og&&og.binding&&og.binding("util")}catch{}}(),fb=Pn&&Pn.isArrayBuffer,vb=Pn&&Pn.isDate,db=Pn&&Pn.isMap,pb=Pn&&Pn.isRegExp,gb=Pn&&Pn.isSet,yb=Pn&&Pn.isTypedArray;function mn(tt,dt,ct){switch(ct.length){case 0:return tt.call(dt);case 1:return tt.call(dt,ct[0]);case 2:return tt.call(dt,ct[0],ct[1]);case 3:return tt.call(dt,ct[0],ct[1],ct[2])}return tt.apply(dt,ct)}function bN(tt,dt,ct,Ft){for(var ce=-1,Pe=tt==null?0:tt.length;++ce<Pe;){var hr=tt[ce];dt(Ft,hr,ct(hr),tt)}return Ft}function kn(tt,dt){for(var ct=-1,Ft=tt==null?0:tt.length;++ct<Ft&&dt(tt[ct],ct,tt)!==!1;);return tt}function SN(tt,dt){for(var ct=tt==null?0:tt.length;ct--&&dt(tt[ct],ct,tt)!==!1;);return tt}function mb(tt,dt){for(var ct=-1,Ft=tt==null?0:tt.length;++ct<Ft;)if(!dt(tt[ct],ct,tt))return!1;return!0}function Oi(tt,dt){for(var ct=-1,Ft=tt==null?0:tt.length,ce=0,Pe=[];++ct<Ft;){var hr=tt[ct];dt(hr,ct,tt)&&(Pe[ce++]=hr)}return Pe}function Jh(tt,dt){var ct=tt==null?0:tt.length;return!!ct&&Js(tt,dt,0)>-1}function sg(tt,dt,ct){for(var Ft=-1,ce=tt==null?0:tt.length;++Ft<ce;)if(ct(dt,tt[Ft]))return!0;return!1}function $e(tt,dt){for(var ct=-1,Ft=tt==null?0:tt.length,ce=Array(Ft);++ct<Ft;)ce[ct]=dt(tt[ct],ct,tt);return ce}function Bi(tt,dt){for(var ct=-1,Ft=dt.length,ce=tt.length;++ct<Ft;)tt[ce+ct]=dt[ct];return tt}function lg(tt,dt,ct,Ft){var ce=-1,Pe=tt==null?0:tt.length;for(Ft&&Pe&&(ct=tt[++ce]);++ce<Pe;)ct=dt(ct,tt[ce],ce,tt);return ct}function AN(tt,dt,ct,Ft){var ce=tt==null?0:tt.length;for(Ft&&ce&&(ct=tt[--ce]);ce--;)ct=dt(ct,tt[ce],ce,tt);return ct}function ug(tt,dt){for(var ct=-1,Ft=tt==null?0:tt.length;++ct<Ft;)if(dt(tt[ct],ct,tt))return!0;return!1}var TN=cg("length");function CN(tt){return tt.split("")}function LN(tt){return tt.match(OB)||[]}function _b(tt,dt,ct){var Ft;return ct(tt,function(ce,Pe,hr){if(dt(ce,Pe,hr))return Ft=Pe,!1}),Ft}function tf(tt,dt,ct,Ft){for(var ce=tt.length,Pe=ct+(Ft?1:-1);Ft?Pe--:++Pe<ce;)if(dt(tt[Pe],Pe,tt))return Pe;return-1}function Js(tt,dt,ct){return dt===dt?FN(tt,dt,ct):tf(tt,wb,ct)}function MN(tt,dt,ct,Ft){for(var ce=ct-1,Pe=tt.length;++ce<Pe;)if(Ft(tt[ce],dt))return ce;return-1}function wb(tt){return tt!==tt}function xb(tt,dt){var ct=tt==null?0:tt.length;return ct?fg(tt,dt)/ct:K}function cg(tt){return function(dt){return dt==null?t:dt[tt]}}function hg(tt){return function(dt){return tt==null?t:tt[dt]}}function bb(tt,dt,ct,Ft,ce){return ce(tt,function(Pe,hr,We){ct=Ft?(Ft=!1,Pe):dt(ct,Pe,hr,We)}),ct}function DN(tt,dt){var ct=tt.length;for(tt.sort(dt);ct--;)tt[ct]=tt[ct].value;return tt}function fg(tt,dt){for(var ct,Ft=-1,ce=tt.length;++Ft<ce;){var Pe=dt(tt[Ft]);Pe!==t&&(ct=ct===t?Pe:ct+Pe)}return ct}function vg(tt,dt){for(var ct=-1,Ft=Array(tt);++ct<tt;)Ft[ct]=dt(ct);return Ft}function IN(tt,dt){return $e(dt,function(ct){return[ct,tt[ct]]})}function Sb(tt){return tt&&tt.slice(0,Lb(tt)+1).replace(Jp,"")}function _n(tt){return function(dt){return tt(dt)}}function dg(tt,dt){return $e(dt,function(ct){return tt[ct]})}function Tu(tt,dt){return tt.has(dt)}function Ab(tt,dt){for(var ct=-1,Ft=tt.length;++ct<Ft&&Js(dt,tt[ct],0)>-1;);return ct}function Tb(tt,dt){for(var ct=tt.length;ct--&&Js(dt,tt[ct],0)>-1;);return ct}function PN(tt,dt){for(var ct=tt.length,Ft=0;ct--;)tt[ct]===dt&&++Ft;return Ft}var kN=hg(pN),RN=hg(gN);function EN(tt){return"\\"+mN[tt]}function ON(tt,dt){return tt==null?t:tt[dt]}function tl(tt){return hN.test(tt)}function BN(tt){return fN.test(tt)}function NN(tt){for(var dt,ct=[];!(dt=tt.next()).done;)ct.push(dt.value);return ct}function pg(tt){var dt=-1,ct=Array(tt.size);return tt.forEach(function(Ft,ce){ct[++dt]=[ce,Ft]}),ct}function Cb(tt,dt){return function(ct){return tt(dt(ct))}}function Ni(tt,dt){for(var ct=-1,Ft=tt.length,ce=0,Pe=[];++ct<Ft;){var hr=tt[ct];(hr===dt||hr===c)&&(tt[ct]=c,Pe[ce++]=ct)}return Pe}function ef(tt){var dt=-1,ct=Array(tt.size);return tt.forEach(function(Ft){ct[++dt]=Ft}),ct}function zN(tt){var dt=-1,ct=Array(tt.size);return tt.forEach(function(Ft){ct[++dt]=[Ft,Ft]}),ct}function FN(tt,dt,ct){for(var Ft=ct-1,ce=tt.length;++Ft<ce;)if(tt[Ft]===dt)return Ft;return-1}function VN(tt,dt,ct){for(var Ft=ct+1;Ft--;)if(tt[Ft]===dt)return Ft;return Ft}function el(tt){return tl(tt)?WN(tt):TN(tt)}function ia(tt){return tl(tt)?HN(tt):CN(tt)}function Lb(tt){for(var dt=tt.length;dt--&&PB.test(tt.charAt(dt)););return dt}var GN=hg(yN);function WN(tt){for(var dt=ag.lastIndex=0;ag.test(tt);)++dt;return dt}function HN(tt){return tt.match(ag)||[]}function UN(tt){return tt.match(cN)||[]}var ZN=function tt(dt){dt=dt==null?Lr:rl.defaults(Lr.Object(),dt,rl.pick(Lr,vN));var ct=dt.Array,Ft=dt.Date,ce=dt.Error,Pe=dt.Function,hr=dt.Math,We=dt.Object,gg=dt.RegExp,YN=dt.String,Rn=dt.TypeError,rf=ct.prototype,XN=Pe.prototype,nl=We.prototype,nf=dt["__core-js_shared__"],af=XN.toString,Ne=nl.hasOwnProperty,$N=0,Mb=function(){var m=/[^.]+$/.exec(nf&&nf.keys&&nf.keys.IE_PROTO||"");return m?"Symbol(src)_1."+m:""}(),of=nl.toString,jN=af.call(We),qN=Lr._,KN=gg("^"+af.call(Ne).replace(Qp,"\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g,"$1.*?")+"$"),sf=hb?dt.Buffer:t,zi=dt.Symbol,lf=dt.Uint8Array,Db=sf?sf.allocUnsafe:t,uf=Cb(We.getPrototypeOf,We),Ib=We.create,Pb=nl.propertyIsEnumerable,cf=rf.splice,kb=zi?zi.isConcatSpreadable:t,Cu=zi?zi.iterator:t,Io=zi?zi.toStringTag:t,hf=function(){try{var m=Oo(We,"defineProperty");return m({},"",{}),m}catch{}}(),QN=dt.clearTimeout!==Lr.clearTimeout&&dt.clearTimeout,JN=Ft&&Ft.now!==Lr.Date.now&&Ft.now,t3=dt.setTimeout!==Lr.setTimeout&&dt.setTimeout,ff=hr.ceil,vf=hr.floor,yg=We.getOwnPropertySymbols,e3=sf?sf.isBuffer:t,Rb=dt.isFinite,r3=rf.join,n3=Cb(We.keys,We),fr=hr.max,Er=hr.min,a3=Ft.now,i3=dt.parseInt,Eb=hr.random,o3=rf.reverse,mg=Oo(dt,"DataView"),Lu=Oo(dt,"Map"),_g=Oo(dt,"Promise"),al=Oo(dt,"Set"),Mu=Oo(dt,"WeakMap"),Du=Oo(We,"create"),df=Mu&&new Mu,il={},s3=Bo(mg),l3=Bo(Lu),u3=Bo(_g),c3=Bo(al),h3=Bo(Mu),pf=zi?zi.prototype:t,Iu=pf?pf.valueOf:t,Ob=pf?pf.toString:t;function F(m){if(Qe(m)&&!he(m)&&!(m instanceof Se)){if(m instanceof En)return m;if(Ne.call(m,"__wrapped__"))return BS(m)}return new En(m)}var ol=function(){function m(){}return function(b){if(!je(b))return{};if(Ib)return Ib(b);m.prototype=b;var C=new m;return m.prototype=t,C}}();function gf(){}function En(m,b){this.__wrapped__=m,this.__actions__=[],this.__chain__=!!b,this.__index__=0,this.__values__=t}F.templateSettings={escape:TB,evaluate:CB,interpolate:Ux,variable:"",imports:{_:F}},F.prototype=gf.prototype,F.prototype.constructor=F,En.prototype=ol(gf.prototype),En.prototype.constructor=En;function Se(m){this.__wrapped__=m,this.__actions__=[],this.__dir__=1,this.__filtered__=!1,this.__iteratees__=[],this.__takeCount__=U,this.__views__=[]}function f3(){var m=new Se(this.__wrapped__);return m.__actions__=an(this.__actions__),m.__dir__=this.__dir__,m.__filtered__=this.__filtered__,m.__iteratees__=an(this.__iteratees__),m.__takeCount__=this.__takeCount__,m.__views__=an(this.__views__),m}function v3(){if(this.__filtered__){var m=new Se(this);m.__dir__=-1,m.__filtered__=!0}else m=this.clone(),m.__dir__*=-1;return m}function d3(){var m=this.__wrapped__.value(),b=this.__dir__,C=he(m),k=b<0,z=C?m.length:0,G=Cz(0,z,this.__views__),q=G.start,Q=G.end,et=Q-q,yt=k?Q:q-1,mt=this.__iteratees__,St=mt.length,Rt=0,Ut=Er(et,this.__takeCount__);if(!C||!k&&z==et&&Ut==et)return iS(m,this.__actions__);var ee=[];t:for(;et--&&Rt<Ut;){yt+=b;for(var ge=-1,re=m[yt];++ge<St;){var xe=mt[ge],Ce=xe.iteratee,bn=xe.type,Zr=Ce(re);if(bn==N)re=Zr;else if(!Zr){if(bn==D)continue t;break t}}ee[Rt++]=re}return ee}Se.prototype=ol(gf.prototype),Se.prototype.constructor=Se;function Po(m){var b=-1,C=m==null?0:m.length;for(this.clear();++b<C;){var k=m[b];this.set(k[0],k[1])}}function p3(){this.__data__=Du?Du(null):{},this.size=0}function g3(m){var b=this.has(m)&&delete this.__data__[m];return this.size-=b?1:0,b}function y3(m){var b=this.__data__;if(Du){var C=b[m];return C===l?t:C}return Ne.call(b,m)?b[m]:t}function m3(m){var b=this.__data__;return Du?b[m]!==t:Ne.call(b,m)}function _3(m,b){var C=this.__data__;return this.size+=this.has(m)?0:1,C[m]=Du&&b===t?l:b,this}Po.prototype.clear=p3,Po.prototype.delete=g3,Po.prototype.get=y3,Po.prototype.has=m3,Po.prototype.set=_3;function ti(m){var b=-1,C=m==null?0:m.length;for(this.clear();++b<C;){var k=m[b];this.set(k[0],k[1])}}function w3(){this.__data__=[],this.size=0}function x3(m){var b=this.__data__,C=yf(b,m);if(C<0)return!1;var k=b.length-1;return C==k?b.pop():cf.call(b,C,1),--this.size,!0}function b3(m){var b=this.__data__,C=yf(b,m);return C<0?t:b[C][1]}function S3(m){return yf(this.__data__,m)>-1}function A3(m,b){var C=this.__data__,k=yf(C,m);return k<0?(++this.size,C.push([m,b])):C[k][1]=b,this}ti.prototype.clear=w3,ti.prototype.delete=x3,ti.prototype.get=b3,ti.prototype.has=S3,ti.prototype.set=A3;function ei(m){var b=-1,C=m==null?0:m.length;for(this.clear();++b<C;){var k=m[b];this.set(k[0],k[1])}}function T3(){this.size=0,this.__data__={hash:new Po,map:new(Lu||ti),string:new Po}}function C3(m){var b=Df(this,m).delete(m);return this.size-=b?1:0,b}function L3(m){return Df(this,m).get(m)}function M3(m){return Df(this,m).has(m)}function D3(m,b){var C=Df(this,m),k=C.size;return C.set(m,b),this.size+=C.size==k?0:1,this}ei.prototype.clear=T3,ei.prototype.delete=C3,ei.prototype.get=L3,ei.prototype.has=M3,ei.prototype.set=D3;function ko(m){var b=-1,C=m==null?0:m.length;for(this.__data__=new ei;++b<C;)this.add(m[b])}function I3(m){return this.__data__.set(m,l),this}function P3(m){return this.__data__.has(m)}ko.prototype.add=ko.prototype.push=I3,ko.prototype.has=P3;function oa(m){var b=this.__data__=new ti(m);this.size=b.size}function k3(){this.__data__=new ti,this.size=0}function R3(m){var b=this.__data__,C=b.delete(m);return this.size=b.size,C}function E3(m){return this.__data__.get(m)}function O3(m){return this.__data__.has(m)}function B3(m,b){var C=this.__data__;if(C instanceof ti){var k=C.__data__;if(!Lu||k.length<a-1)return k.push([m,b]),this.size=++C.size,this;C=this.__data__=new ei(k)}return C.set(m,b),this.size=C.size,this}oa.prototype.clear=k3,oa.prototype.delete=R3,oa.prototype.get=E3,oa.prototype.has=O3,oa.prototype.set=B3;function Bb(m,b){var C=he(m),k=!C&&No(m),z=!C&&!k&&Hi(m),G=!C&&!k&&!z&&cl(m),q=C||k||z||G,Q=q?vg(m.length,YN):[],et=Q.length;for(var yt in m)(b||Ne.call(m,yt))&&!(q&&(yt=="length"||z&&(yt=="offset"||yt=="parent")||G&&(yt=="buffer"||yt=="byteLength"||yt=="byteOffset")||ii(yt,et)))&&Q.push(yt);return Q}function Nb(m){var b=m.length;return b?m[Ig(0,b-1)]:t}function N3(m,b){return If(an(m),Ro(b,0,m.length))}function z3(m){return If(an(m))}function wg(m,b,C){(C!==t&&!sa(m[b],C)||C===t&&!(b in m))&&ri(m,b,C)}function Pu(m,b,C){var k=m[b];(!(Ne.call(m,b)&&sa(k,C))||C===t&&!(b in m))&&ri(m,b,C)}function yf(m,b){for(var C=m.length;C--;)if(sa(m[C][0],b))return C;return-1}function F3(m,b,C,k){return Fi(m,function(z,G,q){b(k,z,C(z),q)}),k}function zb(m,b){return m&&Ca(b,br(b),m)}function V3(m,b){return m&&Ca(b,sn(b),m)}function ri(m,b,C){b=="__proto__"&&hf?hf(m,b,{configurable:!0,enumerable:!0,value:C,writable:!0}):m[b]=C}function xg(m,b){for(var C=-1,k=b.length,z=ct(k),G=m==null;++C<k;)z[C]=G?t:ey(m,b[C]);return z}function Ro(m,b,C){return m===m&&(C!==t&&(m=m<=C?m:C),b!==t&&(m=m>=b?m:b)),m}function On(m,b,C,k,z,G){var q,Q=b&h,et=b&d,yt=b&v;if(C&&(q=z?C(m,k,z,G):C(m)),q!==t)return q;if(!je(m))return m;var mt=he(m);if(mt){if(q=Mz(m),!Q)return an(m,q)}else{var St=Or(m),Rt=St==kt||St==ae;if(Hi(m))return lS(m,Q);if(St==X||St==it||Rt&&!z){if(q=et||Rt?{}:LS(m),!Q)return et?yz(m,V3(q,m)):gz(m,zb(q,m))}else{if(!Ue[St])return z?m:{};q=Dz(m,St,Q)}}G||(G=new oa);var Ut=G.get(m);if(Ut)return Ut;G.set(m,q),r2(m)?m.forEach(function(re){q.add(On(re,b,C,re,m,G))}):t2(m)&&m.forEach(function(re,xe){q.set(xe,On(re,b,C,xe,m,G))});var ee=yt?et?Gg:Vg:et?sn:br,ge=mt?t:ee(m);return kn(ge||m,function(re,xe){ge&&(xe=re,re=m[xe]),Pu(q,xe,On(re,b,C,xe,m,G))}),q}function G3(m){var b=br(m);return function(C){return Fb(C,m,b)}}function Fb(m,b,C){var k=C.length;if(m==null)return!k;for(m=We(m);k--;){var z=C[k],G=b[z],q=m[z];if(q===t&&!(z in m)||!G(q))return!1}return!0}function Vb(m,b,C){if(typeof m!="function")throw new Rn(o);return zu(function(){m.apply(t,C)},b)}function ku(m,b,C,k){var z=-1,G=Jh,q=!0,Q=m.length,et=[],yt=b.length;if(!Q)return et;C&&(b=$e(b,_n(C))),k?(G=sg,q=!1):b.length>=a&&(G=Tu,q=!1,b=new ko(b));t:for(;++z<Q;){var mt=m[z],St=C==null?mt:C(mt);if(mt=k||mt!==0?mt:0,q&&St===St){for(var Rt=yt;Rt--;)if(b[Rt]===St)continue t;et.push(mt)}else G(b,St,k)||et.push(mt)}return et}var Fi=vS(Ta),Gb=vS(Sg,!0);function W3(m,b){var C=!0;return Fi(m,function(k,z,G){return C=!!b(k,z,G),C}),C}function mf(m,b,C){for(var k=-1,z=m.length;++k<z;){var G=m[k],q=b(G);if(q!=null&&(Q===t?q===q&&!xn(q):C(q,Q)))var Q=q,et=G}return et}function H3(m,b,C,k){var z=m.length;for(C=de(C),C<0&&(C=-C>z?0:z+C),k=k===t||k>z?z:de(k),k<0&&(k+=z),k=C>k?0:a2(k);C<k;)m[C++]=b;return m}function Wb(m,b){var C=[];return Fi(m,function(k,z,G){b(k,z,G)&&C.push(k)}),C}function Mr(m,b,C,k,z){var G=-1,q=m.length;for(C||(C=Pz),z||(z=[]);++G<q;){var Q=m[G];b>0&&C(Q)?b>1?Mr(Q,b-1,C,k,z):Bi(z,Q):k||(z[z.length]=Q)}return z}var bg=dS(),Hb=dS(!0);function Ta(m,b){return m&&bg(m,b,br)}function Sg(m,b){return m&&Hb(m,b,br)}function _f(m,b){return Oi(b,function(C){return oi(m[C])})}function Eo(m,b){b=Gi(b,m);for(var C=0,k=b.length;m!=null&&C<k;)m=m[La(b[C++])];return C&&C==k?m:t}function Ub(m,b,C){var k=b(m);return he(m)?k:Bi(k,C(m))}function Hr(m){return m==null?m===t?Bt:nt:Io&&Io in We(m)?Tz(m):zz(m)}function Ag(m,b){return m>b}function U3(m,b){return m!=null&&Ne.call(m,b)}function Z3(m,b){return m!=null&&b in We(m)}function Y3(m,b,C){return m>=Er(b,C)&&m<fr(b,C)}function Tg(m,b,C){for(var k=C?sg:Jh,z=m[0].length,G=m.length,q=G,Q=ct(G),et=1/0,yt=[];q--;){var mt=m[q];q&&b&&(mt=$e(mt,_n(b))),et=Er(mt.length,et),Q[q]=!C&&(b||z>=120&&mt.length>=120)?new ko(q&&mt):t}mt=m[0];var St=-1,Rt=Q[0];t:for(;++St<z&&yt.length<et;){var Ut=mt[St],ee=b?b(Ut):Ut;if(Ut=C||Ut!==0?Ut:0,!(Rt?Tu(Rt,ee):k(yt,ee,C))){for(q=G;--q;){var ge=Q[q];if(!(ge?Tu(ge,ee):k(m[q],ee,C)))continue t}Rt&&Rt.push(ee),yt.push(Ut)}}return yt}function X3(m,b,C,k){return Ta(m,function(z,G,q){b(k,C(z),G,q)}),k}function Ru(m,b,C){b=Gi(b,m),m=PS(m,b);var k=m==null?m:m[La(Nn(b))];return k==null?t:mn(k,m,C)}function Zb(m){return Qe(m)&&Hr(m)==it}function $3(m){return Qe(m)&&Hr(m)==be}function j3(m){return Qe(m)&&Hr(m)==wt}function Eu(m,b,C,k,z){return m===b?!0:m==null||b==null||!Qe(m)&&!Qe(b)?m!==m&&b!==b:q3(m,b,C,k,Eu,z)}function q3(m,b,C,k,z,G){var q=he(m),Q=he(b),et=q?Et:Or(m),yt=Q?Et:Or(b);et=et==it?X:et,yt=yt==it?X:yt;var mt=et==X,St=yt==X,Rt=et==yt;if(Rt&&Hi(m)){if(!Hi(b))return!1;q=!0,mt=!1}if(Rt&&!mt)return G||(G=new oa),q||cl(m)?AS(m,b,C,k,z,G):Sz(m,b,et,C,k,z,G);if(!(C&p)){var Ut=mt&&Ne.call(m,"__wrapped__"),ee=St&&Ne.call(b,"__wrapped__");if(Ut||ee){var ge=Ut?m.value():m,re=ee?b.value():b;return G||(G=new oa),z(ge,re,C,k,G)}}return Rt?(G||(G=new oa),Az(m,b,C,k,z,G)):!1}function K3(m){return Qe(m)&&Or(m)==O}function Cg(m,b,C,k){var z=C.length,G=z,q=!k;if(m==null)return!G;for(m=We(m);z--;){var Q=C[z];if(q&&Q[2]?Q[1]!==m[Q[0]]:!(Q[0]in m))return!1}for(;++z<G;){Q=C[z];var et=Q[0],yt=m[et],mt=Q[1];if(q&&Q[2]){if(yt===t&&!(et in m))return!1}else{var St=new oa;if(k)var Rt=k(yt,mt,et,m,b,St);if(!(Rt===t?Eu(mt,yt,p|y,k,St):Rt))return!1}}return!0}function Yb(m){if(!je(m)||Rz(m))return!1;var b=oi(m)?KN:GB;return b.test(Bo(m))}function Q3(m){return Qe(m)&&Hr(m)==pt}function J3(m){return Qe(m)&&Or(m)==vt}function tz(m){return Qe(m)&&Bf(m.length)&&!!Ye[Hr(m)]}function Xb(m){return typeof m=="function"?m:m==null?ln:typeof m=="object"?he(m)?qb(m[0],m[1]):jb(m):p2(m)}function Lg(m){if(!Nu(m))return n3(m);var b=[];for(var C in We(m))Ne.call(m,C)&&C!="constructor"&&b.push(C);return b}function ez(m){if(!je(m))return Nz(m);var b=Nu(m),C=[];for(var k in m)k=="constructor"&&(b||!Ne.call(m,k))||C.push(k);return C}function Mg(m,b){return m<b}function $b(m,b){var C=-1,k=on(m)?ct(m.length):[];return Fi(m,function(z,G,q){k[++C]=b(z,G,q)}),k}function jb(m){var b=Hg(m);return b.length==1&&b[0][2]?DS(b[0][0],b[0][1]):function(C){return C===m||Cg(C,m,b)}}function qb(m,b){return Zg(m)&&MS(b)?DS(La(m),b):function(C){var k=ey(C,m);return k===t&&k===b?ry(C,m):Eu(b,k,p|y)}}function wf(m,b,C,k,z){m!==b&&bg(b,function(G,q){if(z||(z=new oa),je(G))rz(m,b,q,C,wf,k,z);else{var Q=k?k(Xg(m,q),G,q+"",m,b,z):t;Q===t&&(Q=G),wg(m,q,Q)}},sn)}function rz(m,b,C,k,z,G,q){var Q=Xg(m,C),et=Xg(b,C),yt=q.get(et);if(yt){wg(m,C,yt);return}var mt=G?G(Q,et,C+"",m,b,q):t,St=mt===t;if(St){var Rt=he(et),Ut=!Rt&&Hi(et),ee=!Rt&&!Ut&&cl(et);mt=et,Rt||Ut||ee?he(Q)?mt=Q:rr(Q)?mt=an(Q):Ut?(St=!1,mt=lS(et,!0)):ee?(St=!1,mt=uS(et,!0)):mt=[]:Fu(et)||No(et)?(mt=Q,No(Q)?mt=i2(Q):(!je(Q)||oi(Q))&&(mt=LS(et))):St=!1}St&&(q.set(et,mt),z(mt,et,k,G,q),q.delete(et)),wg(m,C,mt)}function Kb(m,b){var C=m.length;if(C)return b+=b<0?C:0,ii(b,C)?m[b]:t}function Qb(m,b,C){b.length?b=$e(b,function(G){return he(G)?function(q){return Eo(q,G.length===1?G[0]:G)}:G}):b=[ln];var k=-1;b=$e(b,_n(Jt()));var z=$b(m,function(G,q,Q){var et=$e(b,function(yt){return yt(G)});return{criteria:et,index:++k,value:G}});return DN(z,function(G,q){return pz(G,q,C)})}function nz(m,b){return Jb(m,b,function(C,k){return ry(m,k)})}function Jb(m,b,C){for(var k=-1,z=b.length,G={};++k<z;){var q=b[k],Q=Eo(m,q);C(Q,q)&&Ou(G,Gi(q,m),Q)}return G}function az(m){return function(b){return Eo(b,m)}}function Dg(m,b,C,k){var z=k?MN:Js,G=-1,q=b.length,Q=m;for(m===b&&(b=an(b)),C&&(Q=$e(m,_n(C)));++G<q;)for(var et=0,yt=b[G],mt=C?C(yt):yt;(et=z(Q,mt,et,k))>-1;)Q!==m&&cf.call(Q,et,1),cf.call(m,et,1);return m}function tS(m,b){for(var C=m?b.length:0,k=C-1;C--;){var z=b[C];if(C==k||z!==G){var G=z;ii(z)?cf.call(m,z,1):Rg(m,z)}}return m}function Ig(m,b){return m+vf(Eb()*(b-m+1))}function iz(m,b,C,k){for(var z=-1,G=fr(ff((b-m)/(C||1)),0),q=ct(G);G--;)q[k?G:++z]=m,m+=C;return q}function Pg(m,b){var C="";if(!m||b<1||b>$)return C;do b%2&&(C+=m),b=vf(b/2),b&&(m+=m);while(b);return C}function me(m,b){return $g(IS(m,b,ln),m+"")}function oz(m){return Nb(hl(m))}function sz(m,b){var C=hl(m);return If(C,Ro(b,0,C.length))}function Ou(m,b,C,k){if(!je(m))return m;b=Gi(b,m);for(var z=-1,G=b.length,q=G-1,Q=m;Q!=null&&++z<G;){var et=La(b[z]),yt=C;if(et==="__proto__"||et==="constructor"||et==="prototype")return m;if(z!=q){var mt=Q[et];yt=k?k(mt,et,Q):t,yt===t&&(yt=je(mt)?mt:ii(b[z+1])?[]:{})}Pu(Q,et,yt),Q=Q[et]}return m}var eS=df?function(m,b){return df.set(m,b),m}:ln,lz=hf?function(m,b){return hf(m,"toString",{configurable:!0,enumerable:!1,value:ay(b),writable:!0})}:ln;function uz(m){return If(hl(m))}function Bn(m,b,C){var k=-1,z=m.length;b<0&&(b=-b>z?0:z+b),C=C>z?z:C,C<0&&(C+=z),z=b>C?0:C-b>>>0,b>>>=0;for(var G=ct(z);++k<z;)G[k]=m[k+b];return G}function cz(m,b){var C;return Fi(m,function(k,z,G){return C=b(k,z,G),!C}),!!C}function xf(m,b,C){var k=0,z=m==null?k:m.length;if(typeof b=="number"&&b===b&&z<=ut){for(;k<z;){var G=k+z>>>1,q=m[G];q!==null&&!xn(q)&&(C?q<=b:q<b)?k=G+1:z=G}return z}return kg(m,b,ln,C)}function kg(m,b,C,k){var z=0,G=m==null?0:m.length;if(G===0)return 0;b=C(b);for(var q=b!==b,Q=b===null,et=xn(b),yt=b===t;z<G;){var mt=vf((z+G)/2),St=C(m[mt]),Rt=St!==t,Ut=St===null,ee=St===St,ge=xn(St);if(q)var re=k||ee;else yt?re=ee&&(k||Rt):Q?re=ee&&Rt&&(k||!Ut):et?re=ee&&Rt&&!Ut&&(k||!ge):Ut||ge?re=!1:re=k?St<=b:St<b;re?z=mt+1:G=mt}return Er(G,j)}function rS(m,b){for(var C=-1,k=m.length,z=0,G=[];++C<k;){var q=m[C],Q=b?b(q):q;if(!C||!sa(Q,et)){var et=Q;G[z++]=q===0?0:q}}return G}function nS(m){return typeof m=="number"?m:xn(m)?K:+m}function wn(m){if(typeof m=="string")return m;if(he(m))return $e(m,wn)+"";if(xn(m))return Ob?Ob.call(m):"";var b=m+"";return b=="0"&&1/m==-W?"-0":b}function Vi(m,b,C){var k=-1,z=Jh,G=m.length,q=!0,Q=[],et=Q;if(C)q=!1,z=sg;else if(G>=a){var yt=b?null:xz(m);if(yt)return ef(yt);q=!1,z=Tu,et=new ko}else et=b?[]:Q;t:for(;++k<G;){var mt=m[k],St=b?b(mt):mt;if(mt=C||mt!==0?mt:0,q&&St===St){for(var Rt=et.length;Rt--;)if(et[Rt]===St)continue t;b&&et.push(St),Q.push(mt)}else z(et,St,C)||(et!==Q&&et.push(St),Q.push(mt))}return Q}function Rg(m,b){return b=Gi(b,m),m=PS(m,b),m==null||delete m[La(Nn(b))]}function aS(m,b,C,k){return Ou(m,b,C(Eo(m,b)),k)}function bf(m,b,C,k){for(var z=m.length,G=k?z:-1;(k?G--:++G<z)&&b(m[G],G,m););return C?Bn(m,k?0:G,k?G+1:z):Bn(m,k?G+1:0,k?z:G)}function iS(m,b){var C=m;return C instanceof Se&&(C=C.value()),lg(b,function(k,z){return z.func.apply(z.thisArg,Bi([k],z.args))},C)}function Eg(m,b,C){var k=m.length;if(k<2)return k?Vi(m[0]):[];for(var z=-1,G=ct(k);++z<k;)for(var q=m[z],Q=-1;++Q<k;)Q!=z&&(G[z]=ku(G[z]||q,m[Q],b,C));return Vi(Mr(G,1),b,C)}function oS(m,b,C){for(var k=-1,z=m.length,G=b.length,q={};++k<z;){var Q=k<G?b[k]:t;C(q,m[k],Q)}return q}function Og(m){return rr(m)?m:[]}function Bg(m){return typeof m=="function"?m:ln}function Gi(m,b){return he(m)?m:Zg(m,b)?[m]:OS(Ee(m))}var hz=me;function Wi(m,b,C){var k=m.length;return C=C===t?k:C,!b&&C>=k?m:Bn(m,b,C)}var sS=QN||function(m){return Lr.clearTimeout(m)};function lS(m,b){if(b)return m.slice();var C=m.length,k=Db?Db(C):new m.constructor(C);return m.copy(k),k}function Ng(m){var b=new m.constructor(m.byteLength);return new lf(b).set(new lf(m)),b}function fz(m,b){var C=b?Ng(m.buffer):m.buffer;return new m.constructor(C,m.byteOffset,m.byteLength)}function vz(m){var b=new m.constructor(m.source,Zx.exec(m));return b.lastIndex=m.lastIndex,b}function dz(m){return Iu?We(Iu.call(m)):{}}function uS(m,b){var C=b?Ng(m.buffer):m.buffer;return new m.constructor(C,m.byteOffset,m.length)}function cS(m,b){if(m!==b){var C=m!==t,k=m===null,z=m===m,G=xn(m),q=b!==t,Q=b===null,et=b===b,yt=xn(b);if(!Q&&!yt&&!G&&m>b||G&&q&&et&&!Q&&!yt||k&&q&&et||!C&&et||!z)return 1;if(!k&&!G&&!yt&&m<b||yt&&C&&z&&!k&&!G||Q&&C&&z||!q&&z||!et)return-1}return 0}function pz(m,b,C){for(var k=-1,z=m.criteria,G=b.criteria,q=z.length,Q=C.length;++k<q;){var et=cS(z[k],G[k]);if(et){if(k>=Q)return et;var yt=C[k];return et*(yt=="desc"?-1:1)}}return m.index-b.index}function hS(m,b,C,k){for(var z=-1,G=m.length,q=C.length,Q=-1,et=b.length,yt=fr(G-q,0),mt=ct(et+yt),St=!k;++Q<et;)mt[Q]=b[Q];for(;++z<q;)(St||z<G)&&(mt[C[z]]=m[z]);for(;yt--;)mt[Q++]=m[z++];return mt}function fS(m,b,C,k){for(var z=-1,G=m.length,q=-1,Q=C.length,et=-1,yt=b.length,mt=fr(G-Q,0),St=ct(mt+yt),Rt=!k;++z<mt;)St[z]=m[z];for(var Ut=z;++et<yt;)St[Ut+et]=b[et];for(;++q<Q;)(Rt||z<G)&&(St[Ut+C[q]]=m[z++]);return St}function an(m,b){var C=-1,k=m.length;for(b||(b=ct(k));++C<k;)b[C]=m[C];return b}function Ca(m,b,C,k){var z=!C;C||(C={});for(var G=-1,q=b.length;++G<q;){var Q=b[G],et=k?k(C[Q],m[Q],Q,C,m):t;et===t&&(et=m[Q]),z?ri(C,Q,et):Pu(C,Q,et)}return C}function gz(m,b){return Ca(m,Ug(m),b)}function yz(m,b){return Ca(m,TS(m),b)}function Sf(m,b){return function(C,k){var z=he(C)?bN:F3,G=b?b():{};return z(C,m,Jt(k,2),G)}}function sl(m){return me(function(b,C){var k=-1,z=C.length,G=z>1?C[z-1]:t,q=z>2?C[2]:t;for(G=m.length>3&&typeof G=="function"?(z--,G):t,q&&Ur(C[0],C[1],q)&&(G=z<3?t:G,z=1),b=We(b);++k<z;){var Q=C[k];Q&&m(b,Q,k,G)}return b})}function vS(m,b){return function(C,k){if(C==null)return C;if(!on(C))return m(C,k);for(var z=C.length,G=b?z:-1,q=We(C);(b?G--:++G<z)&&k(q[G],G,q)!==!1;);return C}}function dS(m){return function(b,C,k){for(var z=-1,G=We(b),q=k(b),Q=q.length;Q--;){var et=q[m?Q:++z];if(C(G[et],et,G)===!1)break}return b}}function mz(m,b,C){var k=b&_,z=Bu(m);function G(){var q=this&&this!==Lr&&this instanceof G?z:m;return q.apply(k?C:this,arguments)}return G}function pS(m){return function(b){b=Ee(b);var C=tl(b)?ia(b):t,k=C?C[0]:b.charAt(0),z=C?Wi(C,1).join(""):b.slice(1);return k[m]()+z}}function ll(m){return function(b){return lg(v2(f2(b).replace(lN,"")),m,"")}}function Bu(m){return function(){var b=arguments;switch(b.length){case 0:return new m;case 1:return new m(b[0]);case 2:return new m(b[0],b[1]);case 3:return new m(b[0],b[1],b[2]);case 4:return new m(b[0],b[1],b[2],b[3]);case 5:return new m(b[0],b[1],b[2],b[3],b[4]);case 6:return new m(b[0],b[1],b[2],b[3],b[4],b[5]);case 7:return new m(b[0],b[1],b[2],b[3],b[4],b[5],b[6])}var C=ol(m.prototype),k=m.apply(C,b);return je(k)?k:C}}function _z(m,b,C){var k=Bu(m);function z(){for(var G=arguments.length,q=ct(G),Q=G,et=ul(z);Q--;)q[Q]=arguments[Q];var yt=G<3&&q[0]!==et&&q[G-1]!==et?[]:Ni(q,et);if(G-=yt.length,G<C)return wS(m,b,Af,z.placeholder,t,q,yt,t,t,C-G);var mt=this&&this!==Lr&&this instanceof z?k:m;return mn(mt,this,q)}return z}function gS(m){return function(b,C,k){var z=We(b);if(!on(b)){var G=Jt(C,3);b=br(b),C=function(Q){return G(z[Q],Q,z)}}var q=m(b,C,k);return q>-1?z[G?b[q]:q]:t}}function yS(m){return ai(function(b){var C=b.length,k=C,z=En.prototype.thru;for(m&&b.reverse();k--;){var G=b[k];if(typeof G!="function")throw new Rn(o);if(z&&!q&&Mf(G)=="wrapper")var q=new En([],!0)}for(k=q?k:C;++k<C;){G=b[k];var Q=Mf(G),et=Q=="wrapper"?Wg(G):t;et&&Yg(et[0])&&et[1]==(T|w|S|L)&&!et[4].length&&et[9]==1?q=q[Mf(et[0])].apply(q,et[3]):q=G.length==1&&Yg(G)?q[Q]():q.thru(G)}return function(){var yt=arguments,mt=yt[0];if(q&&yt.length==1&&he(mt))return q.plant(mt).value();for(var St=0,Rt=C?b[St].apply(this,yt):mt;++St<C;)Rt=b[St].call(this,Rt);return Rt}})}function Af(m,b,C,k,z,G,q,Q,et,yt){var mt=b&T,St=b&_,Rt=b&g,Ut=b&(w|x),ee=b&M,ge=Rt?t:Bu(m);function re(){for(var xe=arguments.length,Ce=ct(xe),bn=xe;bn--;)Ce[bn]=arguments[bn];if(Ut)var Zr=ul(re),Sn=PN(Ce,Zr);if(k&&(Ce=hS(Ce,k,z,Ut)),G&&(Ce=fS(Ce,G,q,Ut)),xe-=Sn,Ut&&xe<yt){var nr=Ni(Ce,Zr);return wS(m,b,Af,re.placeholder,C,Ce,nr,Q,et,yt-xe)}var la=St?C:this,li=Rt?la[m]:m;return xe=Ce.length,Q?Ce=Fz(Ce,Q):ee&&xe>1&&Ce.reverse(),mt&&et<xe&&(Ce.length=et),this&&this!==Lr&&this instanceof re&&(li=ge||Bu(li)),li.apply(la,Ce)}return re}function mS(m,b){return function(C,k){return X3(C,m,b(k),{})}}function Tf(m,b){return function(C,k){var z;if(C===t&&k===t)return b;if(C!==t&&(z=C),k!==t){if(z===t)return k;typeof C=="string"||typeof k=="string"?(C=wn(C),k=wn(k)):(C=nS(C),k=nS(k)),z=m(C,k)}return z}}function zg(m){return ai(function(b){return b=$e(b,_n(Jt())),me(function(C){var k=this;return m(b,function(z){return mn(z,k,C)})})})}function Cf(m,b){b=b===t?" ":wn(b);var C=b.length;if(C<2)return C?Pg(b,m):b;var k=Pg(b,ff(m/el(b)));return tl(b)?Wi(ia(k),0,m).join(""):k.slice(0,m)}function wz(m,b,C,k){var z=b&_,G=Bu(m);function q(){for(var Q=-1,et=arguments.length,yt=-1,mt=k.length,St=ct(mt+et),Rt=this&&this!==Lr&&this instanceof q?G:m;++yt<mt;)St[yt]=k[yt];for(;et--;)St[yt++]=arguments[++Q];return mn(Rt,z?C:this,St)}return q}function _S(m){return function(b,C,k){return k&&typeof k!="number"&&Ur(b,C,k)&&(C=k=t),b=si(b),C===t?(C=b,b=0):C=si(C),k=k===t?b<C?1:-1:si(k),iz(b,C,k,m)}}function Lf(m){return function(b,C){return typeof b=="string"&&typeof C=="string"||(b=zn(b),C=zn(C)),m(b,C)}}function wS(m,b,C,k,z,G,q,Q,et,yt){var mt=b&w,St=mt?q:t,Rt=mt?t:q,Ut=mt?G:t,ee=mt?t:G;b|=mt?S:A,b&=~(mt?A:S),b&f||(b&=-4);var ge=[m,b,z,Ut,St,ee,Rt,Q,et,yt],re=C.apply(t,ge);return Yg(m)&&kS(re,ge),re.placeholder=k,RS(re,m,b)}function Fg(m){var b=hr[m];return function(C,k){if(C=zn(C),k=k==null?0:Er(de(k),292),k&&Rb(C)){var z=(Ee(C)+"e").split("e"),G=b(z[0]+"e"+(+z[1]+k));return z=(Ee(G)+"e").split("e"),+(z[0]+"e"+(+z[1]-k))}return b(C)}}var xz=al&&1/ef(new al([,-0]))[1]==W?function(m){return new al(m)}:sy;function xS(m){return function(b){var C=Or(b);return C==O?pg(b):C==vt?zN(b):IN(b,m(b))}}function ni(m,b,C,k,z,G,q,Q){var et=b&g;if(!et&&typeof m!="function")throw new Rn(o);var yt=k?k.length:0;if(yt||(b&=-97,k=z=t),q=q===t?q:fr(de(q),0),Q=Q===t?Q:de(Q),yt-=z?z.length:0,b&A){var mt=k,St=z;k=z=t}var Rt=et?t:Wg(m),Ut=[m,b,C,k,z,mt,St,G,q,Q];if(Rt&&Bz(Ut,Rt),m=Ut[0],b=Ut[1],C=Ut[2],k=Ut[3],z=Ut[4],Q=Ut[9]=Ut[9]===t?et?0:m.length:fr(Ut[9]-yt,0),!Q&&b&(w|x)&&(b&=-25),!b||b==_)var ee=mz(m,b,C);else b==w||b==x?ee=_z(m,b,Q):(b==S||b==(_|S))&&!z.length?ee=wz(m,b,C,k):ee=Af.apply(t,Ut);var ge=Rt?eS:kS;return RS(ge(ee,Ut),m,b)}function bS(m,b,C,k){return m===t||sa(m,nl[C])&&!Ne.call(k,C)?b:m}function SS(m,b,C,k,z,G){return je(m)&&je(b)&&(G.set(b,m),wf(m,b,t,SS,G),G.delete(b)),m}function bz(m){return Fu(m)?t:m}function AS(m,b,C,k,z,G){var q=C&p,Q=m.length,et=b.length;if(Q!=et&&!(q&&et>Q))return!1;var yt=G.get(m),mt=G.get(b);if(yt&&mt)return yt==b&&mt==m;var St=-1,Rt=!0,Ut=C&y?new ko:t;for(G.set(m,b),G.set(b,m);++St<Q;){var ee=m[St],ge=b[St];if(k)var re=q?k(ge,ee,St,b,m,G):k(ee,ge,St,m,b,G);if(re!==t){if(re)continue;Rt=!1;break}if(Ut){if(!ug(b,function(xe,Ce){if(!Tu(Ut,Ce)&&(ee===xe||z(ee,xe,C,k,G)))return Ut.push(Ce)})){Rt=!1;break}}else if(!(ee===ge||z(ee,ge,C,k,G))){Rt=!1;break}}return G.delete(m),G.delete(b),Rt}function Sz(m,b,C,k,z,G,q){switch(C){case se:if(m.byteLength!=b.byteLength||m.byteOffset!=b.byteOffset)return!1;m=m.buffer,b=b.buffer;case be:return!(m.byteLength!=b.byteLength||!G(new lf(m),new lf(b)));case bt:case wt:case st:return sa(+m,+b);case xt:return m.name==b.name&&m.message==b.message;case pt:case at:return m==b+"";case O:var Q=pg;case vt:var et=k&p;if(Q||(Q=ef),m.size!=b.size&&!et)return!1;var yt=q.get(m);if(yt)return yt==b;k|=y,q.set(m,b);var mt=AS(Q(m),Q(b),k,z,G,q);return q.delete(m),mt;case Tt:if(Iu)return Iu.call(m)==Iu.call(b)}return!1}function Az(m,b,C,k,z,G){var q=C&p,Q=Vg(m),et=Q.length,yt=Vg(b),mt=yt.length;if(et!=mt&&!q)return!1;for(var St=et;St--;){var Rt=Q[St];if(!(q?Rt in b:Ne.call(b,Rt)))return!1}var Ut=G.get(m),ee=G.get(b);if(Ut&&ee)return Ut==b&&ee==m;var ge=!0;G.set(m,b),G.set(b,m);for(var re=q;++St<et;){Rt=Q[St];var xe=m[Rt],Ce=b[Rt];if(k)var bn=q?k(Ce,xe,Rt,b,m,G):k(xe,Ce,Rt,m,b,G);if(!(bn===t?xe===Ce||z(xe,Ce,C,k,G):bn)){ge=!1;break}re||(re=Rt=="constructor")}if(ge&&!re){var Zr=m.constructor,Sn=b.constructor;Zr!=Sn&&"constructor"in m&&"constructor"in b&&!(typeof Zr=="function"&&Zr instanceof Zr&&typeof Sn=="function"&&Sn instanceof Sn)&&(ge=!1)}return G.delete(m),G.delete(b),ge}function ai(m){return $g(IS(m,t,FS),m+"")}function Vg(m){return Ub(m,br,Ug)}function Gg(m){return Ub(m,sn,TS)}var Wg=df?function(m){return df.get(m)}:sy;function Mf(m){for(var b=m.name+"",C=il[b],k=Ne.call(il,b)?C.length:0;k--;){var z=C[k],G=z.func;if(G==null||G==m)return z.name}return b}function ul(m){var b=Ne.call(F,"placeholder")?F:m;return b.placeholder}function Jt(){var m=F.iteratee||iy;return m=m===iy?Xb:m,arguments.length?m(arguments[0],arguments[1]):m}function Df(m,b){var C=m.__data__;return kz(b)?C[typeof b=="string"?"string":"hash"]:C.map}function Hg(m){for(var b=br(m),C=b.length;C--;){var k=b[C],z=m[k];b[C]=[k,z,MS(z)]}return b}function Oo(m,b){var C=ON(m,b);return Yb(C)?C:t}function Tz(m){var b=Ne.call(m,Io),C=m[Io];try{m[Io]=t;var k=!0}catch{}var z=of.call(m);return k&&(b?m[Io]=C:delete m[Io]),z}var Ug=yg?function(m){return m==null?[]:(m=We(m),Oi(yg(m),function(b){return Pb.call(m,b)}))}:ly,TS=yg?function(m){for(var b=[];m;)Bi(b,Ug(m)),m=uf(m);return b}:ly,Or=Hr;(mg&&Or(new mg(new ArrayBuffer(1)))!=se||Lu&&Or(new Lu)!=O||_g&&Or(_g.resolve())!=Z||al&&Or(new al)!=vt||Mu&&Or(new Mu)!=Ct)&&(Or=function(m){var b=Hr(m),C=b==X?m.constructor:t,k=C?Bo(C):"";if(k)switch(k){case s3:return se;case l3:return O;case u3:return Z;case c3:return vt;case h3:return Ct}return b});function Cz(m,b,C){for(var k=-1,z=C.length;++k<z;){var G=C[k],q=G.size;switch(G.type){case"drop":m+=q;break;case"dropRight":b-=q;break;case"take":b=Er(b,m+q);break;case"takeRight":m=fr(m,b-q);break}}return{start:m,end:b}}function Lz(m){var b=m.match(RB);return b?b[1].split(EB):[]}function CS(m,b,C){b=Gi(b,m);for(var k=-1,z=b.length,G=!1;++k<z;){var q=La(b[k]);if(!(G=m!=null&&C(m,q)))break;m=m[q]}return G||++k!=z?G:(z=m==null?0:m.length,!!z&&Bf(z)&&ii(q,z)&&(he(m)||No(m)))}function Mz(m){var b=m.length,C=new m.constructor(b);return b&&typeof m[0]=="string"&&Ne.call(m,"index")&&(C.index=m.index,C.input=m.input),C}function LS(m){return typeof m.constructor=="function"&&!Nu(m)?ol(uf(m)):{}}function Dz(m,b,C){var k=m.constructor;switch(b){case be:return Ng(m);case bt:case wt:return new k(+m);case se:return fz(m,C);case lr:case gn:case xr:case yn:case Be:case In:case aa:case Cr:case Aa:return uS(m,C);case O:return new k;case st:case at:return new k(m);case pt:return vz(m);case vt:return new k;case Tt:return dz(m)}}function Iz(m,b){var C=b.length;if(!C)return m;var k=C-1;return b[k]=(C>1?"& ":"")+b[k],b=b.join(C>2?", ":" "),m.replace(kB,`{
/* [wrapped with `+b+`] */
`)}function Pz(m){return he(m)||No(m)||!!(kb&&m&&m[kb])}function ii(m,b){var C=typeof m;return b=b??$,!!b&&(C=="number"||C!="symbol"&&HB.test(m))&&m>-1&&m%1==0&&m<b}function Ur(m,b,C){if(!je(C))return!1;var k=typeof b;return(k=="number"?on(C)&&ii(b,C.length):k=="string"&&b in C)?sa(C[b],m):!1}function Zg(m,b){if(he(m))return!1;var C=typeof m;return C=="number"||C=="symbol"||C=="boolean"||m==null||xn(m)?!0:MB.test(m)||!LB.test(m)||b!=null&&m in We(b)}function kz(m){var b=typeof m;return b=="string"||b=="number"||b=="symbol"||b=="boolean"?m!=="__proto__":m===null}function Yg(m){var b=Mf(m),C=F[b];if(typeof C!="function"||!(b in Se.prototype))return!1;if(m===C)return!0;var k=Wg(C);return!!k&&m===k[0]}function Rz(m){return!!Mb&&Mb in m}var Ez=nf?oi:uy;function Nu(m){var b=m&&m.constructor,C=typeof b=="function"&&b.prototype||nl;return m===C}function MS(m){return m===m&&!je(m)}function DS(m,b){return function(C){return C==null?!1:C[m]===b&&(b!==t||m in We(C))}}function Oz(m){var b=Ef(m,function(k){return C.size===u&&C.clear(),k}),C=b.cache;return b}function Bz(m,b){var C=m[1],k=b[1],z=C|k,G=z<(_|g|T),q=k==T&&C==w||k==T&&C==L&&m[7].length<=b[8]||k==(T|L)&&b[7].length<=b[8]&&C==w;if(!(G||q))return m;k&_&&(m[2]=b[2],z|=C&_?0:f);var Q=b[3];if(Q){var et=m[3];m[3]=et?hS(et,Q,b[4]):Q,m[4]=et?Ni(m[3],c):b[4]}return Q=b[5],Q&&(et=m[5],m[5]=et?fS(et,Q,b[6]):Q,m[6]=et?Ni(m[5],c):b[6]),Q=b[7],Q&&(m[7]=Q),k&T&&(m[8]=m[8]==null?b[8]:Er(m[8],b[8])),m[9]==null&&(m[9]=b[9]),m[0]=b[0],m[1]=z,m}function Nz(m){var b=[];if(m!=null)for(var C in We(m))b.push(C);return b}function zz(m){return of.call(m)}function IS(m,b,C){return b=fr(b===t?m.length-1:b,0),function(){for(var k=arguments,z=-1,G=fr(k.length-b,0),q=ct(G);++z<G;)q[z]=k[b+z];z=-1;for(var Q=ct(b+1);++z<b;)Q[z]=k[z];return Q[b]=C(q),mn(m,this,Q)}}function PS(m,b){return b.length<2?m:Eo(m,Bn(b,0,-1))}function Fz(m,b){for(var C=m.length,k=Er(b.length,C),z=an(m);k--;){var G=b[k];m[k]=ii(G,C)?z[G]:t}return m}function Xg(m,b){if(!(b==="constructor"&&typeof m[b]=="function")&&b!="__proto__")return m[b]}var kS=ES(eS),zu=t3||function(m,b){return Lr.setTimeout(m,b)},$g=ES(lz);function RS(m,b,C){var k=b+"";return $g(m,Iz(k,Vz(Lz(k),C)))}function ES(m){var b=0,C=0;return function(){var k=a3(),z=E-(k-C);if(C=k,z>0){if(++b>=P)return arguments[0]}else b=0;return m.apply(t,arguments)}}function If(m,b){var C=-1,k=m.length,z=k-1;for(b=b===t?k:b;++C<b;){var G=Ig(C,z),q=m[G];m[G]=m[C],m[C]=q}return m.length=b,m}var OS=Oz(function(m){var b=[];return m.charCodeAt(0)===46&&b.push(""),m.replace(DB,function(C,k,z,G){b.push(z?G.replace(NB,"$1"):k||C)}),b});function La(m){if(typeof m=="string"||xn(m))return m;var b=m+"";return b=="0"&&1/m==-W?"-0":b}function Bo(m){if(m!=null){try{return af.call(m)}catch{}try{return m+""}catch{}}return""}function Vz(m,b){return kn(ot,function(C){var k="_."+C[0];b&C[1]&&!Jh(m,k)&&m.push(k)}),m.sort()}function BS(m){if(m instanceof Se)return m.clone();var b=new En(m.__wrapped__,m.__chain__);return b.__actions__=an(m.__actions__),b.__index__=m.__index__,b.__values__=m.__values__,b}function Gz(m,b,C){(C?Ur(m,b,C):b===t)?b=1:b=fr(de(b),0);var k=m==null?0:m.length;if(!k||b<1)return[];for(var z=0,G=0,q=ct(ff(k/b));z<k;)q[G++]=Bn(m,z,z+=b);return q}function Wz(m){for(var b=-1,C=m==null?0:m.length,k=0,z=[];++b<C;){var G=m[b];G&&(z[k++]=G)}return z}function Hz(){var m=arguments.length;if(!m)return[];for(var b=ct(m-1),C=arguments[0],k=m;k--;)b[k-1]=arguments[k];return Bi(he(C)?an(C):[C],Mr(b,1))}var Uz=me(function(m,b){return rr(m)?ku(m,Mr(b,1,rr,!0)):[]}),Zz=me(function(m,b){var C=Nn(b);return rr(C)&&(C=t),rr(m)?ku(m,Mr(b,1,rr,!0),Jt(C,2)):[]}),Yz=me(function(m,b){var C=Nn(b);return rr(C)&&(C=t),rr(m)?ku(m,Mr(b,1,rr,!0),t,C):[]});function Xz(m,b,C){var k=m==null?0:m.length;return k?(b=C||b===t?1:de(b),Bn(m,b<0?0:b,k)):[]}function $z(m,b,C){var k=m==null?0:m.length;return k?(b=C||b===t?1:de(b),b=k-b,Bn(m,0,b<0?0:b)):[]}function jz(m,b){return m&&m.length?bf(m,Jt(b,3),!0,!0):[]}function qz(m,b){return m&&m.length?bf(m,Jt(b,3),!0):[]}function Kz(m,b,C,k){var z=m==null?0:m.length;return z?(C&&typeof C!="number"&&Ur(m,b,C)&&(C=0,k=z),H3(m,b,C,k)):[]}function NS(m,b,C){var k=m==null?0:m.length;if(!k)return-1;var z=C==null?0:de(C);return z<0&&(z=fr(k+z,0)),tf(m,Jt(b,3),z)}function zS(m,b,C){var k=m==null?0:m.length;if(!k)return-1;var z=k-1;return C!==t&&(z=de(C),z=C<0?fr(k+z,0):Er(z,k-1)),tf(m,Jt(b,3),z,!0)}function FS(m){var b=m==null?0:m.length;return b?Mr(m,1):[]}function Qz(m){var b=m==null?0:m.length;return b?Mr(m,W):[]}function Jz(m,b){var C=m==null?0:m.length;return C?(b=b===t?1:de(b),Mr(m,b)):[]}function tF(m){for(var b=-1,C=m==null?0:m.length,k={};++b<C;){var z=m[b];k[z[0]]=z[1]}return k}function VS(m){return m&&m.length?m[0]:t}function eF(m,b,C){var k=m==null?0:m.length;if(!k)return-1;var z=C==null?0:de(C);return z<0&&(z=fr(k+z,0)),Js(m,b,z)}function rF(m){var b=m==null?0:m.length;return b?Bn(m,0,-1):[]}var nF=me(function(m){var b=$e(m,Og);return b.length&&b[0]===m[0]?Tg(b):[]}),aF=me(function(m){var b=Nn(m),C=$e(m,Og);return b===Nn(C)?b=t:C.pop(),C.length&&C[0]===m[0]?Tg(C,Jt(b,2)):[]}),iF=me(function(m){var b=Nn(m),C=$e(m,Og);return b=typeof b=="function"?b:t,b&&C.pop(),C.length&&C[0]===m[0]?Tg(C,t,b):[]});function oF(m,b){return m==null?"":r3.call(m,b)}function Nn(m){var b=m==null?0:m.length;return b?m[b-1]:t}function sF(m,b,C){var k=m==null?0:m.length;if(!k)return-1;var z=k;return C!==t&&(z=de(C),z=z<0?fr(k+z,0):Er(z,k-1)),b===b?VN(m,b,z):tf(m,wb,z,!0)}function lF(m,b){return m&&m.length?Kb(m,de(b)):t}var uF=me(GS);function GS(m,b){return m&&m.length&&b&&b.length?Dg(m,b):m}function cF(m,b,C){return m&&m.length&&b&&b.length?Dg(m,b,Jt(C,2)):m}function hF(m,b,C){return m&&m.length&&b&&b.length?Dg(m,b,t,C):m}var fF=ai(function(m,b){var C=m==null?0:m.length,k=xg(m,b);return tS(m,$e(b,function(z){return ii(z,C)?+z:z}).sort(cS)),k});function vF(m,b){var C=[];if(!(m&&m.length))return C;var k=-1,z=[],G=m.length;for(b=Jt(b,3);++k<G;){var q=m[k];b(q,k,m)&&(C.push(q),z.push(k))}return tS(m,z),C}function jg(m){return m==null?m:o3.call(m)}function dF(m,b,C){var k=m==null?0:m.length;return k?(C&&typeof C!="number"&&Ur(m,b,C)?(b=0,C=k):(b=b==null?0:de(b),C=C===t?k:de(C)),Bn(m,b,C)):[]}function pF(m,b){return xf(m,b)}function gF(m,b,C){return kg(m,b,Jt(C,2))}function yF(m,b){var C=m==null?0:m.length;if(C){var k=xf(m,b);if(k<C&&sa(m[k],b))return k}return-1}function mF(m,b){return xf(m,b,!0)}function _F(m,b,C){return kg(m,b,Jt(C,2),!0)}function wF(m,b){var C=m==null?0:m.length;if(C){var k=xf(m,b,!0)-1;if(sa(m[k],b))return k}return-1}function xF(m){return m&&m.length?rS(m):[]}function bF(m,b){return m&&m.length?rS(m,Jt(b,2)):[]}function SF(m){var b=m==null?0:m.length;return b?Bn(m,1,b):[]}function AF(m,b,C){return m&&m.length?(b=C||b===t?1:de(b),Bn(m,0,b<0?0:b)):[]}function TF(m,b,C){var k=m==null?0:m.length;return k?(b=C||b===t?1:de(b),b=k-b,Bn(m,b<0?0:b,k)):[]}function CF(m,b){return m&&m.length?bf(m,Jt(b,3),!1,!0):[]}function LF(m,b){return m&&m.length?bf(m,Jt(b,3)):[]}var MF=me(function(m){return Vi(Mr(m,1,rr,!0))}),DF=me(function(m){var b=Nn(m);return rr(b)&&(b=t),Vi(Mr(m,1,rr,!0),Jt(b,2))}),IF=me(function(m){var b=Nn(m);return b=typeof b=="function"?b:t,Vi(Mr(m,1,rr,!0),t,b)});function PF(m){return m&&m.length?Vi(m):[]}function kF(m,b){return m&&m.length?Vi(m,Jt(b,2)):[]}function RF(m,b){return b=typeof b=="function"?b:t,m&&m.length?Vi(m,t,b):[]}function qg(m){if(!(m&&m.length))return[];var b=0;return m=Oi(m,function(C){if(rr(C))return b=fr(C.length,b),!0}),vg(b,function(C){return $e(m,cg(C))})}function WS(m,b){if(!(m&&m.length))return[];var C=qg(m);return b==null?C:$e(C,function(k){return mn(b,t,k)})}var EF=me(function(m,b){return rr(m)?ku(m,b):[]}),OF=me(function(m){return Eg(Oi(m,rr))}),BF=me(function(m){var b=Nn(m);return rr(b)&&(b=t),Eg(Oi(m,rr),Jt(b,2))}),NF=me(function(m){var b=Nn(m);return b=typeof b=="function"?b:t,Eg(Oi(m,rr),t,b)}),zF=me(qg);function FF(m,b){return oS(m||[],b||[],Pu)}function VF(m,b){return oS(m||[],b||[],Ou)}var GF=me(function(m){var b=m.length,C=b>1?m[b-1]:t;return C=typeof C=="function"?(m.pop(),C):t,WS(m,C)});function HS(m){var b=F(m);return b.__chain__=!0,b}function WF(m,b){return b(m),m}function Pf(m,b){return b(m)}var HF=ai(function(m){var b=m.length,C=b?m[0]:0,k=this.__wrapped__,z=function(G){return xg(G,m)};return b>1||this.__actions__.length||!(k instanceof Se)||!ii(C)?this.thru(z):(k=k.slice(C,+C+(b?1:0)),k.__actions__.push({func:Pf,args:[z],thisArg:t}),new En(k,this.__chain__).thru(function(G){return b&&!G.length&&G.push(t),G}))});function UF(){return HS(this)}function ZF(){return new En(this.value(),this.__chain__)}function YF(){this.__values__===t&&(this.__values__=n2(this.value()));var m=this.__index__>=this.__values__.length,b=m?t:this.__values__[this.__index__++];return{done:m,value:b}}function XF(){return this}function $F(m){for(var b,C=this;C instanceof gf;){var k=BS(C);k.__index__=0,k.__values__=t,b?z.__wrapped__=k:b=k;var z=k;C=C.__wrapped__}return z.__wrapped__=m,b}function jF(){var m=this.__wrapped__;if(m instanceof Se){var b=m;return this.__actions__.length&&(b=new Se(this)),b=b.reverse(),b.__actions__.push({func:Pf,args:[jg],thisArg:t}),new En(b,this.__chain__)}return this.thru(jg)}function qF(){return iS(this.__wrapped__,this.__actions__)}var KF=Sf(function(m,b,C){Ne.call(m,C)?++m[C]:ri(m,C,1)});function QF(m,b,C){var k=he(m)?mb:W3;return C&&Ur(m,b,C)&&(b=t),k(m,Jt(b,3))}function JF(m,b){var C=he(m)?Oi:Wb;return C(m,Jt(b,3))}var t4=gS(NS),e4=gS(zS);function r4(m,b){return Mr(kf(m,b),1)}function n4(m,b){return Mr(kf(m,b),W)}function a4(m,b,C){return C=C===t?1:de(C),Mr(kf(m,b),C)}function US(m,b){var C=he(m)?kn:Fi;return C(m,Jt(b,3))}function ZS(m,b){var C=he(m)?SN:Gb;return C(m,Jt(b,3))}var i4=Sf(function(m,b,C){Ne.call(m,C)?m[C].push(b):ri(m,C,[b])});function o4(m,b,C,k){m=on(m)?m:hl(m),C=C&&!k?de(C):0;var z=m.length;return C<0&&(C=fr(z+C,0)),Nf(m)?C<=z&&m.indexOf(b,C)>-1:!!z&&Js(m,b,C)>-1}var s4=me(function(m,b,C){var k=-1,z=typeof b=="function",G=on(m)?ct(m.length):[];return Fi(m,function(q){G[++k]=z?mn(b,q,C):Ru(q,b,C)}),G}),l4=Sf(function(m,b,C){ri(m,C,b)});function kf(m,b){var C=he(m)?$e:$b;return C(m,Jt(b,3))}function u4(m,b,C,k){return m==null?[]:(he(b)||(b=b==null?[]:[b]),C=k?t:C,he(C)||(C=C==null?[]:[C]),Qb(m,b,C))}var c4=Sf(function(m,b,C){m[C?0:1].push(b)},function(){return[[],[]]});function h4(m,b,C){var k=he(m)?lg:bb,z=arguments.length<3;return k(m,Jt(b,4),C,z,Fi)}function f4(m,b,C){var k=he(m)?AN:bb,z=arguments.length<3;return k(m,Jt(b,4),C,z,Gb)}function v4(m,b){var C=he(m)?Oi:Wb;return C(m,Of(Jt(b,3)))}function d4(m){var b=he(m)?Nb:oz;return b(m)}function p4(m,b,C){(C?Ur(m,b,C):b===t)?b=1:b=de(b);var k=he(m)?N3:sz;return k(m,b)}function g4(m){var b=he(m)?z3:uz;return b(m)}function y4(m){if(m==null)return 0;if(on(m))return Nf(m)?el(m):m.length;var b=Or(m);return b==O||b==vt?m.size:Lg(m).length}function m4(m,b,C){var k=he(m)?ug:cz;return C&&Ur(m,b,C)&&(b=t),k(m,Jt(b,3))}var _4=me(function(m,b){if(m==null)return[];var C=b.length;return C>1&&Ur(m,b[0],b[1])?b=[]:C>2&&Ur(b[0],b[1],b[2])&&(b=[b[0]]),Qb(m,Mr(b,1),[])}),Rf=JN||function(){return Lr.Date.now()};function w4(m,b){if(typeof b!="function")throw new Rn(o);return m=de(m),function(){if(--m<1)return b.apply(this,arguments)}}function YS(m,b,C){return b=C?t:b,b=m&&b==null?m.length:b,ni(m,T,t,t,t,t,b)}function XS(m,b){var C;if(typeof b!="function")throw new Rn(o);return m=de(m),function(){return--m>0&&(C=b.apply(this,arguments)),m<=1&&(b=t),C}}var Kg=me(function(m,b,C){var k=_;if(C.length){var z=Ni(C,ul(Kg));k|=S}return ni(m,k,b,C,z)}),$S=me(function(m,b,C){var k=_|g;if(C.length){var z=Ni(C,ul($S));k|=S}return ni(b,k,m,C,z)});function jS(m,b,C){b=C?t:b;var k=ni(m,w,t,t,t,t,t,b);return k.placeholder=jS.placeholder,k}function qS(m,b,C){b=C?t:b;var k=ni(m,x,t,t,t,t,t,b);return k.placeholder=qS.placeholder,k}function KS(m,b,C){var k,z,G,q,Q,et,yt=0,mt=!1,St=!1,Rt=!0;if(typeof m!="function")throw new Rn(o);b=zn(b)||0,je(C)&&(mt=!!C.leading,St="maxWait"in C,G=St?fr(zn(C.maxWait)||0,b):G,Rt="trailing"in C?!!C.trailing:Rt);function Ut(nr){var la=k,li=z;return k=z=t,yt=nr,q=m.apply(li,la),q}function ee(nr){return yt=nr,Q=zu(xe,b),mt?Ut(nr):q}function ge(nr){var la=nr-et,li=nr-yt,g2=b-la;return St?Er(g2,G-li):g2}function re(nr){var la=nr-et,li=nr-yt;return et===t||la>=b||la<0||St&&li>=G}function xe(){var nr=Rf();if(re(nr))return Ce(nr);Q=zu(xe,ge(nr))}function Ce(nr){return Q=t,Rt&&k?Ut(nr):(k=z=t,q)}function bn(){Q!==t&&sS(Q),yt=0,k=et=z=Q=t}function Zr(){return Q===t?q:Ce(Rf())}function Sn(){var nr=Rf(),la=re(nr);if(k=arguments,z=this,et=nr,la){if(Q===t)return ee(et);if(St)return sS(Q),Q=zu(xe,b),Ut(et)}return Q===t&&(Q=zu(xe,b)),q}return Sn.cancel=bn,Sn.flush=Zr,Sn}var x4=me(function(m,b){return Vb(m,1,b)}),b4=me(function(m,b,C){return Vb(m,zn(b)||0,C)});function S4(m){return ni(m,M)}function Ef(m,b){if(typeof m!="function"||b!=null&&typeof b!="function")throw new Rn(o);var C=function(){var k=arguments,z=b?b.apply(this,k):k[0],G=C.cache;if(G.has(z))return G.get(z);var q=m.apply(this,k);return C.cache=G.set(z,q)||G,q};return C.cache=new(Ef.Cache||ei),C}Ef.Cache=ei;function Of(m){if(typeof m!="function")throw new Rn(o);return function(){var b=arguments;switch(b.length){case 0:return!m.call(this);case 1:return!m.call(this,b[0]);case 2:return!m.call(this,b[0],b[1]);case 3:return!m.call(this,b[0],b[1],b[2])}return!m.apply(this,b)}}function A4(m){return XS(2,m)}var T4=hz(function(m,b){b=b.length==1&&he(b[0])?$e(b[0],_n(Jt())):$e(Mr(b,1),_n(Jt()));var C=b.length;return me(function(k){for(var z=-1,G=Er(k.length,C);++z<G;)k[z]=b[z].call(this,k[z]);return mn(m,this,k)})}),Qg=me(function(m,b){var C=Ni(b,ul(Qg));return ni(m,S,t,b,C)}),QS=me(function(m,b){var C=Ni(b,ul(QS));return ni(m,A,t,b,C)}),C4=ai(function(m,b){return ni(m,L,t,t,t,b)});function L4(m,b){if(typeof m!="function")throw new Rn(o);return b=b===t?b:de(b),me(m,b)}function M4(m,b){if(typeof m!="function")throw new Rn(o);return b=b==null?0:fr(de(b),0),me(function(C){var k=C[b],z=Wi(C,0,b);return k&&Bi(z,k),mn(m,this,z)})}function D4(m,b,C){var k=!0,z=!0;if(typeof m!="function")throw new Rn(o);return je(C)&&(k="leading"in C?!!C.leading:k,z="trailing"in C?!!C.trailing:z),KS(m,b,{leading:k,maxWait:b,trailing:z})}function I4(m){return YS(m,1)}function P4(m,b){return Qg(Bg(b),m)}function k4(){if(!arguments.length)return[];var m=arguments[0];return he(m)?m:[m]}function R4(m){return On(m,v)}function E4(m,b){return b=typeof b=="function"?b:t,On(m,v,b)}function O4(m){return On(m,h|v)}function B4(m,b){return b=typeof b=="function"?b:t,On(m,h|v,b)}function N4(m,b){return b==null||Fb(m,b,br(b))}function sa(m,b){return m===b||m!==m&&b!==b}var z4=Lf(Ag),F4=Lf(function(m,b){return m>=b}),No=Zb(function(){return arguments}())?Zb:function(m){return Qe(m)&&Ne.call(m,"callee")&&!Pb.call(m,"callee")},he=ct.isArray,V4=fb?_n(fb):$3;function on(m){return m!=null&&Bf(m.length)&&!oi(m)}function rr(m){return Qe(m)&&on(m)}function G4(m){return m===!0||m===!1||Qe(m)&&Hr(m)==bt}var Hi=e3||uy,W4=vb?_n(vb):j3;function H4(m){return Qe(m)&&m.nodeType===1&&!Fu(m)}function U4(m){if(m==null)return!0;if(on(m)&&(he(m)||typeof m=="string"||typeof m.splice=="function"||Hi(m)||cl(m)||No(m)))return!m.length;var b=Or(m);if(b==O||b==vt)return!m.size;if(Nu(m))return!Lg(m).length;for(var C in m)if(Ne.call(m,C))return!1;return!0}function Z4(m,b){return Eu(m,b)}function Y4(m,b,C){C=typeof C=="function"?C:t;var k=C?C(m,b):t;return k===t?Eu(m,b,t,C):!!k}function Jg(m){if(!Qe(m))return!1;var b=Hr(m);return b==xt||b==Ot||typeof m.message=="string"&&typeof m.name=="string"&&!Fu(m)}function X4(m){return typeof m=="number"&&Rb(m)}function oi(m){if(!je(m))return!1;var b=Hr(m);return b==kt||b==ae||b==jt||b==J}function JS(m){return typeof m=="number"&&m==de(m)}function Bf(m){return typeof m=="number"&&m>-1&&m%1==0&&m<=$}function je(m){var b=typeof m;return m!=null&&(b=="object"||b=="function")}function Qe(m){return m!=null&&typeof m=="object"}var t2=db?_n(db):K3;function $4(m,b){return m===b||Cg(m,b,Hg(b))}function j4(m,b,C){return C=typeof C=="function"?C:t,Cg(m,b,Hg(b),C)}function q4(m){return e2(m)&&m!=+m}function K4(m){if(Ez(m))throw new ce(i);return Yb(m)}function Q4(m){return m===null}function J4(m){return m==null}function e2(m){return typeof m=="number"||Qe(m)&&Hr(m)==st}function Fu(m){if(!Qe(m)||Hr(m)!=X)return!1;var b=uf(m);if(b===null)return!0;var C=Ne.call(b,"constructor")&&b.constructor;return typeof C=="function"&&C instanceof C&&af.call(C)==jN}var ty=pb?_n(pb):Q3;function tV(m){return JS(m)&&m>=-$&&m<=$}var r2=gb?_n(gb):J3;function Nf(m){return typeof m=="string"||!he(m)&&Qe(m)&&Hr(m)==at}function xn(m){return typeof m=="symbol"||Qe(m)&&Hr(m)==Tt}var cl=yb?_n(yb):tz;function eV(m){return m===t}function rV(m){return Qe(m)&&Or(m)==Ct}function nV(m){return Qe(m)&&Hr(m)==Yt}var aV=Lf(Mg),iV=Lf(function(m,b){return m<=b});function n2(m){if(!m)return[];if(on(m))return Nf(m)?ia(m):an(m);if(Cu&&m[Cu])return NN(m[Cu]());var b=Or(m),C=b==O?pg:b==vt?ef:hl;return C(m)}function si(m){if(!m)return m===0?m:0;if(m=zn(m),m===W||m===-W){var b=m<0?-1:1;return b*H}return m===m?m:0}function de(m){var b=si(m),C=b%1;return b===b?C?b-C:b:0}function a2(m){return m?Ro(de(m),0,U):0}function zn(m){if(typeof m=="number")return m;if(xn(m))return K;if(je(m)){var b=typeof m.valueOf=="function"?m.valueOf():m;m=je(b)?b+"":b}if(typeof m!="string")return m===0?m:+m;m=Sb(m);var C=VB.test(m);return C||WB.test(m)?wN(m.slice(2),C?2:8):FB.test(m)?K:+m}function i2(m){return Ca(m,sn(m))}function oV(m){return m?Ro(de(m),-$,$):m===0?m:0}function Ee(m){return m==null?"":wn(m)}var sV=sl(function(m,b){if(Nu(b)||on(b)){Ca(b,br(b),m);return}for(var C in b)Ne.call(b,C)&&Pu(m,C,b[C])}),o2=sl(function(m,b){Ca(b,sn(b),m)}),zf=sl(function(m,b,C,k){Ca(b,sn(b),m,k)}),lV=sl(function(m,b,C,k){Ca(b,br(b),m,k)}),uV=ai(xg);function cV(m,b){var C=ol(m);return b==null?C:zb(C,b)}var hV=me(function(m,b){m=We(m);var C=-1,k=b.length,z=k>2?b[2]:t;for(z&&Ur(b[0],b[1],z)&&(k=1);++C<k;)for(var G=b[C],q=sn(G),Q=-1,et=q.length;++Q<et;){var yt=q[Q],mt=m[yt];(mt===t||sa(mt,nl[yt])&&!Ne.call(m,yt))&&(m[yt]=G[yt])}return m}),fV=me(function(m){return m.push(t,SS),mn(s2,t,m)});function vV(m,b){return _b(m,Jt(b,3),Ta)}function dV(m,b){return _b(m,Jt(b,3),Sg)}function pV(m,b){return m==null?m:bg(m,Jt(b,3),sn)}function gV(m,b){return m==null?m:Hb(m,Jt(b,3),sn)}function yV(m,b){return m&&Ta(m,Jt(b,3))}function mV(m,b){return m&&Sg(m,Jt(b,3))}function _V(m){return m==null?[]:_f(m,br(m))}function wV(m){return m==null?[]:_f(m,sn(m))}function ey(m,b,C){var k=m==null?t:Eo(m,b);return k===t?C:k}function xV(m,b){return m!=null&&CS(m,b,U3)}function ry(m,b){return m!=null&&CS(m,b,Z3)}var bV=mS(function(m,b,C){b!=null&&typeof b.toString!="function"&&(b=of.call(b)),m[b]=C},ay(ln)),SV=mS(function(m,b,C){b!=null&&typeof b.toString!="function"&&(b=of.call(b)),Ne.call(m,b)?m[b].push(C):m[b]=[C]},Jt),AV=me(Ru);function br(m){return on(m)?Bb(m):Lg(m)}function sn(m){return on(m)?Bb(m,!0):ez(m)}function TV(m,b){var C={};return b=Jt(b,3),Ta(m,function(k,z,G){ri(C,b(k,z,G),k)}),C}function CV(m,b){var C={};return b=Jt(b,3),Ta(m,function(k,z,G){ri(C,z,b(k,z,G))}),C}var LV=sl(function(m,b,C){wf(m,b,C)}),s2=sl(function(m,b,C,k){wf(m,b,C,k)}),MV=ai(function(m,b){var C={};if(m==null)return C;var k=!1;b=$e(b,function(G){return G=Gi(G,m),k||(k=G.length>1),G}),Ca(m,Gg(m),C),k&&(C=On(C,h|d|v,bz));for(var z=b.length;z--;)Rg(C,b[z]);return C});function DV(m,b){return l2(m,Of(Jt(b)))}var IV=ai(function(m,b){return m==null?{}:nz(m,b)});function l2(m,b){if(m==null)return{};var C=$e(Gg(m),function(k){return[k]});return b=Jt(b),Jb(m,C,function(k,z){return b(k,z[0])})}function PV(m,b,C){b=Gi(b,m);var k=-1,z=b.length;for(z||(z=1,m=t);++k<z;){var G=m==null?t:m[La(b[k])];G===t&&(k=z,G=C),m=oi(G)?G.call(m):G}return m}function kV(m,b,C){return m==null?m:Ou(m,b,C)}function RV(m,b,C,k){return k=typeof k=="function"?k:t,m==null?m:Ou(m,b,C,k)}var u2=xS(br),c2=xS(sn);function EV(m,b,C){var k=he(m),z=k||Hi(m)||cl(m);if(b=Jt(b,4),C==null){var G=m&&m.constructor;z?C=k?new G:[]:je(m)?C=oi(G)?ol(uf(m)):{}:C={}}return(z?kn:Ta)(m,function(q,Q,et){return b(C,q,Q,et)}),C}function OV(m,b){return m==null?!0:Rg(m,b)}function BV(m,b,C){return m==null?m:aS(m,b,Bg(C))}function NV(m,b,C,k){return k=typeof k=="function"?k:t,m==null?m:aS(m,b,Bg(C),k)}function hl(m){return m==null?[]:dg(m,br(m))}function zV(m){return m==null?[]:dg(m,sn(m))}function FV(m,b,C){return C===t&&(C=b,b=t),C!==t&&(C=zn(C),C=C===C?C:0),b!==t&&(b=zn(b),b=b===b?b:0),Ro(zn(m),b,C)}function VV(m,b,C){return b=si(b),C===t?(C=b,b=0):C=si(C),m=zn(m),Y3(m,b,C)}function GV(m,b,C){if(C&&typeof C!="boolean"&&Ur(m,b,C)&&(b=C=t),C===t&&(typeof b=="boolean"?(C=b,b=t):typeof m=="boolean"&&(C=m,m=t)),m===t&&b===t?(m=0,b=1):(m=si(m),b===t?(b=m,m=0):b=si(b)),m>b){var k=m;m=b,b=k}if(C||m%1||b%1){var z=Eb();return Er(m+z*(b-m+_N("1e-"+((z+"").length-1))),b)}return Ig(m,b)}var WV=ll(function(m,b,C){return b=b.toLowerCase(),m+(C?h2(b):b)});function h2(m){return ny(Ee(m).toLowerCase())}function f2(m){return m=Ee(m),m&&m.replace(UB,kN).replace(uN,"")}function HV(m,b,C){m=Ee(m),b=wn(b);var k=m.length;C=C===t?k:Ro(de(C),0,k);var z=C;return C-=b.length,C>=0&&m.slice(C,z)==b}function UV(m){return m=Ee(m),m&&AB.test(m)?m.replace(Ei,RN):m}function ZV(m){return m=Ee(m),m&&IB.test(m)?m.replace(Qp,"\\$&"):m}var YV=ll(function(m,b,C){return m+(C?"-":"")+b.toLowerCase()}),XV=ll(function(m,b,C){return m+(C?" ":"")+b.toLowerCase()}),$V=pS("toLowerCase");function jV(m,b,C){m=Ee(m),b=de(b);var k=b?el(m):0;if(!b||k>=b)return m;var z=(b-k)/2;return Cf(vf(z),C)+m+Cf(ff(z),C)}function qV(m,b,C){m=Ee(m),b=de(b);var k=b?el(m):0;return b&&k<b?m+Cf(b-k,C):m}function KV(m,b,C){m=Ee(m),b=de(b);var k=b?el(m):0;return b&&k<b?Cf(b-k,C)+m:m}function QV(m,b,C){return C||b==null?b=0:b&&(b=+b),i3(Ee(m).replace(Jp,""),b||0)}function JV(m,b,C){return(C?Ur(m,b,C):b===t)?b=1:b=de(b),Pg(Ee(m),b)}function tG(){var m=arguments,b=Ee(m[0]);return m.length<3?b:b.replace(m[1],m[2])}var eG=ll(function(m,b,C){return m+(C?"_":"")+b.toLowerCase()});function rG(m,b,C){return C&&typeof C!="number"&&Ur(m,b,C)&&(b=C=t),C=C===t?U:C>>>0,C?(m=Ee(m),m&&(typeof b=="string"||b!=null&&!ty(b))&&(b=wn(b),!b&&tl(m))?Wi(ia(m),0,C):m.split(b,C)):[]}var nG=ll(function(m,b,C){return m+(C?" ":"")+ny(b)});function aG(m,b,C){return m=Ee(m),C=C==null?0:Ro(de(C),0,m.length),b=wn(b),m.slice(C,C+b.length)==b}function iG(m,b,C){var k=F.templateSettings;C&&Ur(m,b,C)&&(b=t),m=Ee(m),b=zf({},b,k,bS);var z=zf({},b.imports,k.imports,bS),G=br(z),q=dg(z,G),Q,et,yt=0,mt=b.interpolate||qh,St="__p += '",Rt=gg((b.escape||qh).source+"|"+mt.source+"|"+(mt===Ux?zB:qh).source+"|"+(b.evaluate||qh).source+"|$","g"),Ut="//# sourceURL="+(Ne.call(b,"sourceURL")?(b.sourceURL+"").replace(/\s/g," "):"lodash.templateSources["+ ++dN+"]")+`
`;m.replace(Rt,function(re,xe,Ce,bn,Zr,Sn){return Ce||(Ce=bn),St+=m.slice(yt,Sn).replace(ZB,EN),xe&&(Q=!0,St+=`' +
__e(`+xe+`) +
'`),Zr&&(et=!0,St+=`';
`+Zr+`;
__p += '`),Ce&&(St+=`' +
((__t = (`+Ce+`)) == null ? '' : __t) +
'`),yt=Sn+re.length,re}),St+=`';
`;var ee=Ne.call(b,"variable")&&b.variable;if(!ee)St=`with (obj) {
`+St+`
}
`;else if(BB.test(ee))throw new ce(s);St=(et?St.replace(Mo,""):St).replace(we,"$1").replace(er,"$1;"),St="function("+(ee||"obj")+`) {
`+(ee?"":`obj || (obj = {});
`)+"var __t, __p = ''"+(Q?", __e = _.escape":"")+(et?`, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
`:`;
`)+St+`return __p
}`;var ge=d2(function(){return Pe(G,Ut+"return "+St).apply(t,q)});if(ge.source=St,Jg(ge))throw ge;return ge}function oG(m){return Ee(m).toLowerCase()}function sG(m){return Ee(m).toUpperCase()}function lG(m,b,C){if(m=Ee(m),m&&(C||b===t))return Sb(m);if(!m||!(b=wn(b)))return m;var k=ia(m),z=ia(b),G=Ab(k,z),q=Tb(k,z)+1;return Wi(k,G,q).join("")}function uG(m,b,C){if(m=Ee(m),m&&(C||b===t))return m.slice(0,Lb(m)+1);if(!m||!(b=wn(b)))return m;var k=ia(m),z=Tb(k,ia(b))+1;return Wi(k,0,z).join("")}function cG(m,b,C){if(m=Ee(m),m&&(C||b===t))return m.replace(Jp,"");if(!m||!(b=wn(b)))return m;var k=ia(m),z=Ab(k,ia(b));return Wi(k,z).join("")}function hG(m,b){var C=I,k=R;if(je(b)){var z="separator"in b?b.separator:z;C="length"in b?de(b.length):C,k="omission"in b?wn(b.omission):k}m=Ee(m);var G=m.length;if(tl(m)){var q=ia(m);G=q.length}if(C>=G)return m;var Q=C-el(k);if(Q<1)return k;var et=q?Wi(q,0,Q).join(""):m.slice(0,Q);if(z===t)return et+k;if(q&&(Q+=et.length-Q),ty(z)){if(m.slice(Q).search(z)){var yt,mt=et;for(z.global||(z=gg(z.source,Ee(Zx.exec(z))+"g")),z.lastIndex=0;yt=z.exec(mt);)var St=yt.index;et=et.slice(0,St===t?Q:St)}}else if(m.indexOf(wn(z),Q)!=Q){var Rt=et.lastIndexOf(z);Rt>-1&&(et=et.slice(0,Rt))}return et+k}function fG(m){return m=Ee(m),m&&Ks.test(m)?m.replace(Au,GN):m}var vG=ll(function(m,b,C){return m+(C?" ":"")+b.toUpperCase()}),ny=pS("toUpperCase");function v2(m,b,C){return m=Ee(m),b=C?t:b,b===t?BN(m)?UN(m):LN(m):m.match(b)||[]}var d2=me(function(m,b){try{return mn(m,t,b)}catch(C){return Jg(C)?C:new ce(C)}}),dG=ai(function(m,b){return kn(b,function(C){C=La(C),ri(m,C,Kg(m[C],m))}),m});function pG(m){var b=m==null?0:m.length,C=Jt();return m=b?$e(m,function(k){if(typeof k[1]!="function")throw new Rn(o);return[C(k[0]),k[1]]}):[],me(function(k){for(var z=-1;++z<b;){var G=m[z];if(mn(G[0],this,k))return mn(G[1],this,k)}})}function gG(m){return G3(On(m,h))}function ay(m){return function(){return m}}function yG(m,b){return m==null||m!==m?b:m}var mG=yS(),_G=yS(!0);function ln(m){return m}function iy(m){return Xb(typeof m=="function"?m:On(m,h))}function wG(m){return jb(On(m,h))}function xG(m,b){return qb(m,On(b,h))}var bG=me(function(m,b){return function(C){return Ru(C,m,b)}}),SG=me(function(m,b){return function(C){return Ru(m,C,b)}});function oy(m,b,C){var k=br(b),z=_f(b,k);C==null&&!(je(b)&&(z.length||!k.length))&&(C=b,b=m,m=this,z=_f(b,br(b)));var G=!(je(C)&&"chain"in C)||!!C.chain,q=oi(m);return kn(z,function(Q){var et=b[Q];m[Q]=et,q&&(m.prototype[Q]=function(){var yt=this.__chain__;if(G||yt){var mt=m(this.__wrapped__),St=mt.__actions__=an(this.__actions__);return St.push({func:et,args:arguments,thisArg:m}),mt.__chain__=yt,mt}return et.apply(m,Bi([this.value()],arguments))})}),m}function AG(){return Lr._===this&&(Lr._=qN),this}function sy(){}function TG(m){return m=de(m),me(function(b){return Kb(b,m)})}var CG=zg($e),LG=zg(mb),MG=zg(ug);function p2(m){return Zg(m)?cg(La(m)):az(m)}function DG(m){return function(b){return m==null?t:Eo(m,b)}}var IG=_S(),PG=_S(!0);function ly(){return[]}function uy(){return!1}function kG(){return{}}function RG(){return""}function EG(){return!0}function OG(m,b){if(m=de(m),m<1||m>$)return[];var C=U,k=Er(m,U);b=Jt(b),m-=U;for(var z=vg(k,b);++C<m;)b(C);return z}function BG(m){return he(m)?$e(m,La):xn(m)?[m]:an(OS(Ee(m)))}function NG(m){var b=++$N;return Ee(m)+b}var zG=Tf(function(m,b){return m+b},0),FG=Fg("ceil"),VG=Tf(function(m,b){return m/b},1),GG=Fg("floor");function WG(m){return m&&m.length?mf(m,ln,Ag):t}function HG(m,b){return m&&m.length?mf(m,Jt(b,2),Ag):t}function UG(m){return xb(m,ln)}function ZG(m,b){return xb(m,Jt(b,2))}function YG(m){return m&&m.length?mf(m,ln,Mg):t}function XG(m,b){return m&&m.length?mf(m,Jt(b,2),Mg):t}var $G=Tf(function(m,b){return m*b},1),jG=Fg("round"),qG=Tf(function(m,b){return m-b},0);function KG(m){return m&&m.length?fg(m,ln):0}function QG(m,b){return m&&m.length?fg(m,Jt(b,2)):0}return F.after=w4,F.ary=YS,F.assign=sV,F.assignIn=o2,F.assignInWith=zf,F.assignWith=lV,F.at=uV,F.before=XS,F.bind=Kg,F.bindAll=dG,F.bindKey=$S,F.castArray=k4,F.chain=HS,F.chunk=Gz,F.compact=Wz,F.concat=Hz,F.cond=pG,F.conforms=gG,F.constant=ay,F.countBy=KF,F.create=cV,F.curry=jS,F.curryRight=qS,F.debounce=KS,F.defaults=hV,F.defaultsDeep=fV,F.defer=x4,F.delay=b4,F.difference=Uz,F.differenceBy=Zz,F.differenceWith=Yz,F.drop=Xz,F.dropRight=$z,F.dropRightWhile=jz,F.dropWhile=qz,F.fill=Kz,F.filter=JF,F.flatMap=r4,F.flatMapDeep=n4,F.flatMapDepth=a4,F.flatten=FS,F.flattenDeep=Qz,F.flattenDepth=Jz,F.flip=S4,F.flow=mG,F.flowRight=_G,F.fromPairs=tF,F.functions=_V,F.functionsIn=wV,F.groupBy=i4,F.initial=rF,F.intersection=nF,F.intersectionBy=aF,F.intersectionWith=iF,F.invert=bV,F.invertBy=SV,F.invokeMap=s4,F.iteratee=iy,F.keyBy=l4,F.keys=br,F.keysIn=sn,F.map=kf,F.mapKeys=TV,F.mapValues=CV,F.matches=wG,F.matchesProperty=xG,F.memoize=Ef,F.merge=LV,F.mergeWith=s2,F.method=bG,F.methodOf=SG,F.mixin=oy,F.negate=Of,F.nthArg=TG,F.omit=MV,F.omitBy=DV,F.once=A4,F.orderBy=u4,F.over=CG,F.overArgs=T4,F.overEvery=LG,F.overSome=MG,F.partial=Qg,F.partialRight=QS,F.partition=c4,F.pick=IV,F.pickBy=l2,F.property=p2,F.propertyOf=DG,F.pull=uF,F.pullAll=GS,F.pullAllBy=cF,F.pullAllWith=hF,F.pullAt=fF,F.range=IG,F.rangeRight=PG,F.rearg=C4,F.reject=v4,F.remove=vF,F.rest=L4,F.reverse=jg,F.sampleSize=p4,F.set=kV,F.setWith=RV,F.shuffle=g4,F.slice=dF,F.sortBy=_4,F.sortedUniq=xF,F.sortedUniqBy=bF,F.split=rG,F.spread=M4,F.tail=SF,F.take=AF,F.takeRight=TF,F.takeRightWhile=CF,F.takeWhile=LF,F.tap=WF,F.throttle=D4,F.thru=Pf,F.toArray=n2,F.toPairs=u2,F.toPairsIn=c2,F.toPath=BG,F.toPlainObject=i2,F.transform=EV,F.unary=I4,F.union=MF,F.unionBy=DF,F.unionWith=IF,F.uniq=PF,F.uniqBy=kF,F.uniqWith=RF,F.unset=OV,F.unzip=qg,F.unzipWith=WS,F.update=BV,F.updateWith=NV,F.values=hl,F.valuesIn=zV,F.without=EF,F.words=v2,F.wrap=P4,F.xor=OF,F.xorBy=BF,F.xorWith=NF,F.zip=zF,F.zipObject=FF,F.zipObjectDeep=VF,F.zipWith=GF,F.entries=u2,F.entriesIn=c2,F.extend=o2,F.extendWith=zf,oy(F,F),F.add=zG,F.attempt=d2,F.camelCase=WV,F.capitalize=h2,F.ceil=FG,F.clamp=FV,F.clone=R4,F.cloneDeep=O4,F.cloneDeepWith=B4,F.cloneWith=E4,F.conformsTo=N4,F.deburr=f2,F.defaultTo=yG,F.divide=VG,F.endsWith=HV,F.eq=sa,F.escape=UV,F.escapeRegExp=ZV,F.every=QF,F.find=t4,F.findIndex=NS,F.findKey=vV,F.findLast=e4,F.findLastIndex=zS,F.findLastKey=dV,F.floor=GG,F.forEach=US,F.forEachRight=ZS,F.forIn=pV,F.forInRight=gV,F.forOwn=yV,F.forOwnRight=mV,F.get=ey,F.gt=z4,F.gte=F4,F.has=xV,F.hasIn=ry,F.head=VS,F.identity=ln,F.includes=o4,F.indexOf=eF,F.inRange=VV,F.invoke=AV,F.isArguments=No,F.isArray=he,F.isArrayBuffer=V4,F.isArrayLike=on,F.isArrayLikeObject=rr,F.isBoolean=G4,F.isBuffer=Hi,F.isDate=W4,F.isElement=H4,F.isEmpty=U4,F.isEqual=Z4,F.isEqualWith=Y4,F.isError=Jg,F.isFinite=X4,F.isFunction=oi,F.isInteger=JS,F.isLength=Bf,F.isMap=t2,F.isMatch=$4,F.isMatchWith=j4,F.isNaN=q4,F.isNative=K4,F.isNil=J4,F.isNull=Q4,F.isNumber=e2,F.isObject=je,F.isObjectLike=Qe,F.isPlainObject=Fu,F.isRegExp=ty,F.isSafeInteger=tV,F.isSet=r2,F.isString=Nf,F.isSymbol=xn,F.isTypedArray=cl,F.isUndefined=eV,F.isWeakMap=rV,F.isWeakSet=nV,F.join=oF,F.kebabCase=YV,F.last=Nn,F.lastIndexOf=sF,F.lowerCase=XV,F.lowerFirst=$V,F.lt=aV,F.lte=iV,F.max=WG,F.maxBy=HG,F.mean=UG,F.meanBy=ZG,F.min=YG,F.minBy=XG,F.stubArray=ly,F.stubFalse=uy,F.stubObject=kG,F.stubString=RG,F.stubTrue=EG,F.multiply=$G,F.nth=lF,F.noConflict=AG,F.noop=sy,F.now=Rf,F.pad=jV,F.padEnd=qV,F.padStart=KV,F.parseInt=QV,F.random=GV,F.reduce=h4,F.reduceRight=f4,F.repeat=JV,F.replace=tG,F.result=PV,F.round=jG,F.runInContext=tt,F.sample=d4,F.size=y4,F.snakeCase=eG,F.some=m4,F.sortedIndex=pF,F.sortedIndexBy=gF,F.sortedIndexOf=yF,F.sortedLastIndex=mF,F.sortedLastIndexBy=_F,F.sortedLastIndexOf=wF,F.startCase=nG,F.startsWith=aG,F.subtract=qG,F.sum=KG,F.sumBy=QG,F.template=iG,F.times=OG,F.toFinite=si,F.toInteger=de,F.toLength=a2,F.toLower=oG,F.toNumber=zn,F.toSafeInteger=oV,F.toString=Ee,F.toUpper=sG,F.trim=lG,F.trimEnd=uG,F.trimStart=cG,F.truncate=hG,F.unescape=fG,F.uniqueId=NG,F.upperCase=vG,F.upperFirst=ny,F.each=US,F.eachRight=ZS,F.first=VS,oy(F,function(){var m={};return Ta(F,function(b,C){Ne.call(F.prototype,C)||(m[C]=b)}),m}(),{chain:!1}),F.VERSION=n,kn(["bind","bindKey","curry","curryRight","partial","partialRight"],function(m){F[m].placeholder=F}),kn(["drop","take"],function(m,b){Se.prototype[m]=function(C){C=C===t?1:fr(de(C),0);var k=this.__filtered__&&!b?new Se(this):this.clone();return k.__filtered__?k.__takeCount__=Er(C,k.__takeCount__):k.__views__.push({size:Er(C,U),type:m+(k.__dir__<0?"Right":"")}),k},Se.prototype[m+"Right"]=function(C){return this.reverse()[m](C).reverse()}}),kn(["filter","map","takeWhile"],function(m,b){var C=b+1,k=C==D||C==V;Se.prototype[m]=function(z){var G=this.clone();return G.__iteratees__.push({iteratee:Jt(z,3),type:C}),G.__filtered__=G.__filtered__||k,G}}),kn(["head","last"],function(m,b){var C="take"+(b?"Right":"");Se.prototype[m]=function(){return this[C](1).value()[0]}}),kn(["initial","tail"],function(m,b){var C="drop"+(b?"":"Right");Se.prototype[m]=function(){return this.__filtered__?new Se(this):this[C](1)}}),Se.prototype.compact=function(){return this.filter(ln)},Se.prototype.find=function(m){return this.filter(m).head()},Se.prototype.findLast=function(m){return this.reverse().find(m)},Se.prototype.invokeMap=me(function(m,b){return typeof m=="function"?new Se(this):this.map(function(C){return Ru(C,m,b)})}),Se.prototype.reject=function(m){return this.filter(Of(Jt(m)))},Se.prototype.slice=function(m,b){m=de(m);var C=this;return C.__filtered__&&(m>0||b<0)?new Se(C):(m<0?C=C.takeRight(-m):m&&(C=C.drop(m)),b!==t&&(b=de(b),C=b<0?C.dropRight(-b):C.take(b-m)),C)},Se.prototype.takeRightWhile=function(m){return this.reverse().takeWhile(m).reverse()},Se.prototype.toArray=function(){return this.take(U)},Ta(Se.prototype,function(m,b){var C=/^(?:filter|find|map|reject)|While$/.test(b),k=/^(?:head|last)$/.test(b),z=F[k?"take"+(b=="last"?"Right":""):b],G=k||/^find/.test(b);z&&(F.prototype[b]=function(){var q=this.__wrapped__,Q=k?[1]:arguments,et=q instanceof Se,yt=Q[0],mt=et||he(q),St=function(xe){var Ce=z.apply(F,Bi([xe],Q));return k&&Rt?Ce[0]:Ce};mt&&C&&typeof yt=="function"&&yt.length!=1&&(et=mt=!1);var Rt=this.__chain__,Ut=!!this.__actions__.length,ee=G&&!Rt,ge=et&&!Ut;if(!G&&mt){q=ge?q:new Se(this);var re=m.apply(q,Q);return re.__actions__.push({func:Pf,args:[St],thisArg:t}),new En(re,Rt)}return ee&&ge?m.apply(this,Q):(re=this.thru(St),ee?k?re.value()[0]:re.value():re)})}),kn(["pop","push","shift","sort","splice","unshift"],function(m){var b=rf[m],C=/^(?:push|sort|unshift)$/.test(m)?"tap":"thru",k=/^(?:pop|shift)$/.test(m);F.prototype[m]=function(){var z=arguments;if(k&&!this.__chain__){var G=this.value();return b.apply(he(G)?G:[],z)}return this[C](function(q){return b.apply(he(q)?q:[],z)})}}),Ta(Se.prototype,function(m,b){var C=F[b];if(C){var k=C.name+"";Ne.call(il,k)||(il[k]=[]),il[k].push({name:b,func:C})}}),il[Af(t,g).name]=[{name:"wrapper",func:t}],Se.prototype.clone=f3,Se.prototype.reverse=v3,Se.prototype.value=d3,F.prototype.at=HF,F.prototype.chain=UF,F.prototype.commit=ZF,F.prototype.next=YF,F.prototype.plant=$F,F.prototype.reverse=jF,F.prototype.toJSON=F.prototype.valueOf=F.prototype.value=qF,F.prototype.first=F.prototype.head,Cu&&(F.prototype[Cu]=XF),F},rl=ZN();Do?((Do.exports=rl)._=rl,ig._=rl):Lr._=rl}).call(pi)})(fd,fd.exports);var Y=fd.exports,Dr=[];for(var cy=0;cy<256;++cy)Dr.push((cy+256).toString(16).slice(1));function r6(r,e=0){return(Dr[r[e+0]]+Dr[r[e+1]]+Dr[r[e+2]]+Dr[r[e+3]]+"-"+Dr[r[e+4]]+Dr[r[e+5]]+"-"+Dr[r[e+6]]+Dr[r[e+7]]+"-"+Dr[r[e+8]]+Dr[r[e+9]]+"-"+Dr[r[e+10]]+Dr[r[e+11]]+Dr[r[e+12]]+Dr[r[e+13]]+Dr[r[e+14]]+Dr[r[e+15]]).toLowerCase()}var Vf,n6=new Uint8Array(16);function a6(){if(!Vf&&(Vf=typeof crypto<"u"&&crypto.getRandomValues&&crypto.getRandomValues.bind(crypto),!Vf))throw new Error("crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported");return Vf(n6)}var i6=typeof crypto<"u"&&crypto.randomUUID&&crypto.randomUUID.bind(crypto);const y2={randomUUID:i6};function o6(r,e,t){if(y2.randomUUID&&!r)return y2.randomUUID();r=r||{};var n=r.random||(r.rng||a6)();return n[6]=n[6]&15|64,n[8]=n[8]&63|128,r6(n)}/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var G0=function(r,e){return G0=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var a in n)Object.prototype.hasOwnProperty.call(n,a)&&(t[a]=n[a])},G0(r,e)};function rt(r,e){if(typeof e!="function"&&e!==null)throw new TypeError("Class extends value "+String(e)+" is not a constructor or null");G0(r,e);function t(){this.constructor=r}r.prototype=e===null?Object.create(e):(t.prototype=e.prototype,new t)}var s6=function(){function r(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return r}(),l6=function(){function r(){this.browser=new s6,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return r}(),oe=new l6;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(oe.wxa=!0,oe.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?oe.worker=!0:!oe.hasGlobalWindow||"Deno"in window?(oe.node=!0,oe.svgSupported=!0):u6(navigator.userAgent,oe);function u6(r,e){var t=e.browser,n=r.match(/Firefox\/([\d.]+)/),a=r.match(/MSIE\s([\d.]+)/)||r.match(/Trident\/.+?rv:(([\d.]+))/),i=r.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(r);n&&(t.firefox=!0,t.version=n[1]),a&&(t.ie=!0,t.version=a[1]),i&&(t.edge=!0,t.version=i[1],t.newEdge=+i[1].split(".")[0]>18),o&&(t.weChat=!0),e.svgSupported=typeof SVGRect<"u",e.touchEventsSupported="ontouchstart"in window&&!t.ie&&!t.edge,e.pointerEventsSupported="onpointerdown"in window&&(t.edge||t.ie&&+t.version>=11),e.domSupported=typeof document<"u";var s=document.documentElement.style;e.transform3dSupported=(t.ie&&"transition"in s||t.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in s)&&!("OTransition"in s),e.transformSupported=e.transform3dSupported||t.ie&&+t.version>=9}var E1=12,OI="sans-serif",mo=E1+"px "+OI,c6=20,h6=100,f6="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function v6(r){var e={};if(typeof JSON>"u")return e;for(var t=0;t<r.length;t++){var n=String.fromCharCode(t+32),a=(r.charCodeAt(t)-c6)/h6;e[n]=a}return e}var d6=v6(f6),_o={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:function(){var r,e;return function(t,n){if(!r){var a=_o.createCanvas();r=a&&a.getContext("2d")}if(r)return e!==n&&(e=r.font=n||mo),r.measureText(t);t=t||"",n=n||mo;var i=/((?:\d+)?\.?\d*)px/.exec(n),o=i&&+i[1]||E1,s=0;if(n.indexOf("mono")>=0)s=o*t.length;else for(var l=0;l<t.length;l++){var u=d6[t[l]];s+=u==null?o:u*o}return{width:s}}}(),loadImage:function(r,e,t){var n=new Image;return n.onload=e,n.onerror=t,n.src=r,n}},BI=Za(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(r,e){return r["[object "+e+"]"]=!0,r},{}),NI=Za(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(r,e){return r["[object "+e+"Array]"]=!0,r},{}),lu=Object.prototype.toString,cp=Array.prototype,p6=cp.forEach,g6=cp.filter,O1=cp.slice,y6=cp.map,m2=function(){}.constructor,Gf=m2?m2.prototype:null,B1="__proto__",m6=2311;function zI(){return m6++}function N1(){for(var r=[],e=0;e<arguments.length;e++)r[e]=arguments[e];typeof console<"u"&&console.error.apply(console,r)}function Gt(r){if(r==null||typeof r!="object")return r;var e=r,t=lu.call(r);if(t==="[object Array]"){if(!Pc(r)){e=[];for(var n=0,a=r.length;n<a;n++)e[n]=Gt(r[n])}}else if(NI[t]){if(!Pc(r)){var i=r.constructor;if(i.from)e=i.from(r);else{e=new i(r.length);for(var n=0,a=r.length;n<a;n++)e[n]=r[n]}}}else if(!BI[t]&&!Pc(r)&&!Kl(r)){e={};for(var o in r)r.hasOwnProperty(o)&&o!==B1&&(e[o]=Gt(r[o]))}return e}function qt(r,e,t){if(!Vt(e)||!Vt(r))return t?Gt(e):r;for(var n in e)if(e.hasOwnProperty(n)&&n!==B1){var a=r[n],i=e[n];Vt(i)&&Vt(a)&&!ht(i)&&!ht(a)&&!Kl(i)&&!Kl(a)&&!_2(i)&&!_2(a)&&!Pc(i)&&!Pc(a)?qt(a,i,t):(t||!(n in r))&&(r[n]=Gt(e[n]))}return r}function z1(r,e){for(var t=r[0],n=1,a=r.length;n<a;n++)t=qt(t,r[n],e);return t}function lt(r,e){if(Object.assign)Object.assign(r,e);else for(var t in e)e.hasOwnProperty(t)&&t!==B1&&(r[t]=e[t]);return r}function zt(r,e,t){for(var n=ue(e),a=0,i=n.length;a<i;a++){var o=n[a];(t?e[o]!=null:r[o]==null)&&(r[o]=e[o])}return r}function te(r,e){if(r){if(r.indexOf)return r.indexOf(e);for(var t=0,n=r.length;t<n;t++)if(r[t]===e)return t}return-1}function _6(r,e){var t=r.prototype;function n(){}n.prototype=e.prototype,r.prototype=new n;for(var a in t)t.hasOwnProperty(a)&&(r.prototype[a]=t[a]);r.prototype.constructor=r,r.superClass=e}function sr(r,e,t){if(r="prototype"in r?r.prototype:r,e="prototype"in e?e.prototype:e,Object.getOwnPropertyNames)for(var n=Object.getOwnPropertyNames(e),a=0;a<n.length;a++){var i=n[a];i!=="constructor"&&(t?e[i]!=null:r[i]==null)&&(r[i]=e[i])}else zt(r,e,t)}function Gr(r){return!r||typeof r=="string"?!1:typeof r.length=="number"}function B(r,e,t){if(r&&e)if(r.forEach&&r.forEach===p6)r.forEach(e,t);else if(r.length===+r.length)for(var n=0,a=r.length;n<a;n++)e.call(t,r[n],n,r);else for(var i in r)r.hasOwnProperty(i)&&e.call(t,r[i],i,r)}function ft(r,e,t){if(!r)return[];if(!e)return F1(r);if(r.map&&r.map===y6)return r.map(e,t);for(var n=[],a=0,i=r.length;a<i;a++)n.push(e.call(t,r[a],a,r));return n}function Za(r,e,t,n){if(r&&e){for(var a=0,i=r.length;a<i;a++)t=e.call(n,t,r[a],a,r);return t}}function Te(r,e,t){if(!r)return[];if(!e)return F1(r);if(r.filter&&r.filter===g6)return r.filter(e,t);for(var n=[],a=0,i=r.length;a<i;a++)e.call(t,r[a],a,r)&&n.push(r[a]);return n}function w6(r,e,t){if(r&&e){for(var n=0,a=r.length;n<a;n++)if(e.call(t,r[n],n,r))return r[n]}}function ue(r){if(!r)return[];if(Object.keys)return Object.keys(r);var e=[];for(var t in r)r.hasOwnProperty(t)&&e.push(t);return e}function x6(r,e){for(var t=[],n=2;n<arguments.length;n++)t[n-2]=arguments[n];return function(){return r.apply(e,t.concat(O1.call(arguments)))}}var Mt=Gf&&Nt(Gf.bind)?Gf.call.bind(Gf.bind):x6;function Xt(r){for(var e=[],t=1;t<arguments.length;t++)e[t-1]=arguments[t];return function(){return r.apply(this,e.concat(O1.call(arguments)))}}function ht(r){return Array.isArray?Array.isArray(r):lu.call(r)==="[object Array]"}function Nt(r){return typeof r=="function"}function Lt(r){return typeof r=="string"}function W0(r){return lu.call(r)==="[object String]"}function ye(r){return typeof r=="number"}function Vt(r){var e=typeof r;return e==="function"||!!r&&e==="object"}function _2(r){return!!BI[lu.call(r)]}function pn(r){return!!NI[lu.call(r)]}function Kl(r){return typeof r=="object"&&typeof r.nodeType=="number"&&typeof r.ownerDocument=="object"}function hp(r){return r.colorStops!=null}function b6(r){return r.image!=null}function S6(r){return lu.call(r)==="[object RegExp]"}function Xc(r){return r!==r}function Ar(){for(var r=[],e=0;e<arguments.length;e++)r[e]=arguments[e];for(var t=0,n=r.length;t<n;t++)if(r[t]!=null)return r[t]}function Zt(r,e){return r??e}function Ha(r,e,t){return r??e??t}function F1(r){for(var e=[],t=1;t<arguments.length;t++)e[t-1]=arguments[t];return O1.apply(r,e)}function V1(r){if(typeof r=="number")return[r,r,r,r];var e=r.length;return e===2?[r[0],r[1],r[0],r[1]]:e===3?[r[0],r[1],r[2],r[1]]:r}function Jr(r,e){if(!r)throw new Error(e)}function ga(r){return r==null?null:typeof r.trim=="function"?r.trim():r.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var FI="__ec_primitive__";function vd(r){r[FI]=!0}function Pc(r){return r[FI]}var A6=function(){function r(){this.data={}}return r.prototype.delete=function(e){var t=this.has(e);return t&&delete this.data[e],t},r.prototype.has=function(e){return this.data.hasOwnProperty(e)},r.prototype.get=function(e){return this.data[e]},r.prototype.set=function(e,t){return this.data[e]=t,this},r.prototype.keys=function(){return ue(this.data)},r.prototype.forEach=function(e){var t=this.data;for(var n in t)t.hasOwnProperty(n)&&e(t[n],n)},r}(),VI=typeof Map=="function";function T6(){return VI?new Map:new A6}var C6=function(){function r(e){var t=ht(e);this.data=T6();var n=this;e instanceof r?e.each(a):e&&B(e,a);function a(i,o){t?n.set(i,o):n.set(o,i)}}return r.prototype.hasKey=function(e){return this.data.has(e)},r.prototype.get=function(e){return this.data.get(e)},r.prototype.set=function(e,t){return this.data.set(e,t),t},r.prototype.each=function(e,t){this.data.forEach(function(n,a){e.call(t,n,a)})},r.prototype.keys=function(){var e=this.data.keys();return VI?Array.from(e):e},r.prototype.removeKey=function(e){this.data.delete(e)},r}();function Pt(r){return new C6(r)}function $c(r,e){for(var t=new r.constructor(r.length+e.length),n=0;n<r.length;n++)t[n]=r[n];for(var a=r.length,n=0;n<e.length;n++)t[n+a]=e[n];return t}function fp(r,e){var t;if(Object.create)t=Object.create(r);else{var n=function(){};n.prototype=r,t=new n}return e&&lt(t,e),t}function GI(r){var e=r.style;e.webkitUserSelect="none",e.userSelect="none",e.webkitTapHighlightColor="rgba(0,0,0,0)",e["-webkit-touch-callout"]="none"}function It(r,e){return r.hasOwnProperty(e)}function tr(){}var Uv=180/Math.PI;/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var H0=function(r,e){return H0=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var a in n)Object.prototype.hasOwnProperty.call(n,a)&&(t[a]=n[a])},H0(r,e)};function Ge(r,e){if(typeof e!="function"&&e!==null)throw new TypeError("Class extends value "+String(e)+" is not a constructor or null");H0(r,e);function t(){this.constructor=r}r.prototype=e===null?Object.create(e):(t.prototype=e.prototype,new t)}function Ws(r,e){return r==null&&(r=0),e==null&&(e=0),[r,e]}function Xr(r,e){return r[0]=e[0],r[1]=e[1],r}function mi(r){return[r[0],r[1]]}function L6(r,e,t){return r[0]=e,r[1]=t,r}function w2(r,e,t){return r[0]=e[0]+t[0],r[1]=e[1]+t[1],r}function U0(r,e,t,n){return r[0]=e[0]+t[0]*n,r[1]=e[1]+t[1]*n,r}function ms(r,e,t){return r[0]=e[0]-t[0],r[1]=e[1]-t[1],r}function Z0(r){return Math.sqrt(M6(r))}function M6(r){return r[0]*r[0]+r[1]*r[1]}function Zv(r,e,t){return r[0]=e[0]*t,r[1]=e[1]*t,r}function uu(r,e){var t=Z0(e);return t===0?(r[0]=0,r[1]=0):(r[0]=e[0]/t,r[1]=e[1]/t),r}function Y0(r,e){return Math.sqrt((r[0]-e[0])*(r[0]-e[0])+(r[1]-e[1])*(r[1]-e[1]))}var ao=Y0;function D6(r,e){return(r[0]-e[0])*(r[0]-e[0])+(r[1]-e[1])*(r[1]-e[1])}var Cs=D6;function Yv(r,e,t,n){return r[0]=e[0]+n*(t[0]-e[0]),r[1]=e[1]+n*(t[1]-e[1]),r}function Pr(r,e,t){var n=e[0],a=e[1];return r[0]=t[0]*n+t[2]*a+t[4],r[1]=t[1]*n+t[3]*a+t[5],r}function io(r,e,t){return r[0]=Math.min(e[0],t[0]),r[1]=Math.min(e[1],t[1]),r}function oo(r,e,t){return r[0]=Math.max(e[0],t[0]),r[1]=Math.max(e[1],t[1]),r}var fl=function(){function r(e,t){this.target=e,this.topTarget=t&&t.topTarget}return r}(),I6=function(){function r(e){this.handler=e,e.on("mousedown",this._dragStart,this),e.on("mousemove",this._drag,this),e.on("mouseup",this._dragEnd,this)}return r.prototype._dragStart=function(e){for(var t=e.target;t&&!t.draggable;)t=t.parent||t.__hostTarget;t&&(this._draggingTarget=t,t.dragging=!0,this._x=e.offsetX,this._y=e.offsetY,this.handler.dispatchToElement(new fl(t,e),"dragstart",e.event))},r.prototype._drag=function(e){var t=this._draggingTarget;if(t){var n=e.offsetX,a=e.offsetY,i=n-this._x,o=a-this._y;this._x=n,this._y=a,t.drift(i,o,e),this.handler.dispatchToElement(new fl(t,e),"drag",e.event);var s=this.handler.findHover(n,a,t).target,l=this._dropTarget;this._dropTarget=s,t!==s&&(l&&s!==l&&this.handler.dispatchToElement(new fl(l,e),"dragleave",e.event),s&&s!==l&&this.handler.dispatchToElement(new fl(s,e),"dragenter",e.event))}},r.prototype._dragEnd=function(e){var t=this._draggingTarget;t&&(t.dragging=!1),this.handler.dispatchToElement(new fl(t,e),"dragend",e.event),this._dropTarget&&this.handler.dispatchToElement(new fl(this._dropTarget,e),"drop",e.event),this._draggingTarget=null,this._dropTarget=null},r}(),ea=function(){function r(e){e&&(this._$eventProcessor=e)}return r.prototype.on=function(e,t,n,a){this._$handlers||(this._$handlers={});var i=this._$handlers;if(typeof t=="function"&&(a=n,n=t,t=null),!n||!e)return this;var o=this._$eventProcessor;t!=null&&o&&o.normalizeQuery&&(t=o.normalizeQuery(t)),i[e]||(i[e]=[]);for(var s=0;s<i[e].length;s++)if(i[e][s].h===n)return this;var l={h:n,query:t,ctx:a||this,callAtLast:n.zrEventfulCallAtLast},u=i[e].length-1,c=i[e][u];return c&&c.callAtLast?i[e].splice(u,0,l):i[e].push(l),this},r.prototype.isSilent=function(e){var t=this._$handlers;return!t||!t[e]||!t[e].length},r.prototype.off=function(e,t){var n=this._$handlers;if(!n)return this;if(!e)return this._$handlers={},this;if(t){if(n[e]){for(var a=[],i=0,o=n[e].length;i<o;i++)n[e][i].h!==t&&a.push(n[e][i]);n[e]=a}n[e]&&n[e].length===0&&delete n[e]}else delete n[e];return this},r.prototype.trigger=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(!this._$handlers)return this;var a=this._$handlers[e],i=this._$eventProcessor;if(a)for(var o=t.length,s=a.length,l=0;l<s;l++){var u=a[l];if(!(i&&i.filter&&u.query!=null&&!i.filter(e,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,t[0]);break;case 2:u.h.call(u.ctx,t[0],t[1]);break;default:u.h.apply(u.ctx,t);break}}return i&&i.afterTrigger&&i.afterTrigger(e),this},r.prototype.triggerWithContext=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];if(!this._$handlers)return this;var a=this._$handlers[e],i=this._$eventProcessor;if(a)for(var o=t.length,s=t[o-1],l=a.length,u=0;u<l;u++){var c=a[u];if(!(i&&i.filter&&c.query!=null&&!i.filter(e,c.query)))switch(o){case 0:c.h.call(s);break;case 1:c.h.call(s,t[0]);break;case 2:c.h.call(s,t[0],t[1]);break;default:c.h.apply(s,t.slice(1,o-1));break}}return i&&i.afterTrigger&&i.afterTrigger(e),this},r}(),P6=Math.log(2);function X0(r,e,t,n,a,i){var o=n+"-"+a,s=r.length;if(i.hasOwnProperty(o))return i[o];if(e===1){var l=Math.round(Math.log((1<<s)-1&~a)/P6);return r[t][l]}for(var u=n|1<<t,c=t+1;n&1<<c;)c++;for(var h=0,d=0,v=0;d<s;d++){var p=1<<d;p&a||(h+=(v%2?-1:1)*r[t][d]*X0(r,e-1,c,u,a|p,i),v++)}return i[o]=h,h}function x2(r,e){var t=[[r[0],r[1],1,0,0,0,-e[0]*r[0],-e[0]*r[1]],[0,0,0,r[0],r[1],1,-e[1]*r[0],-e[1]*r[1]],[r[2],r[3],1,0,0,0,-e[2]*r[2],-e[2]*r[3]],[0,0,0,r[2],r[3],1,-e[3]*r[2],-e[3]*r[3]],[r[4],r[5],1,0,0,0,-e[4]*r[4],-e[4]*r[5]],[0,0,0,r[4],r[5],1,-e[5]*r[4],-e[5]*r[5]],[r[6],r[7],1,0,0,0,-e[6]*r[6],-e[6]*r[7]],[0,0,0,r[6],r[7],1,-e[7]*r[6],-e[7]*r[7]]],n={},a=X0(t,8,0,0,0,n);if(a!==0){for(var i=[],o=0;o<8;o++)for(var s=0;s<8;s++)i[s]==null&&(i[s]=0),i[s]+=((o+s)%2?-1:1)*X0(t,7,o===0?1:0,1<<o,1<<s,n)/a*e[o];return function(l,u,c){var h=u*i[6]+c*i[7]+1;l[0]=(u*i[0]+c*i[1]+i[2])/h,l[1]=(u*i[3]+c*i[4]+i[5])/h}}}var b2="___zrEVENTSAVED",hy=[];function k6(r,e,t,n,a){return $0(hy,e,n,a,!0)&&$0(r,t,hy[0],hy[1])}function $0(r,e,t,n,a){if(e.getBoundingClientRect&&oe.domSupported&&!WI(e)){var i=e[b2]||(e[b2]={}),o=R6(e,i),s=E6(o,i,a);if(s)return s(r,t,n),!0}return!1}function R6(r,e){var t=e.markers;if(t)return t;t=e.markers=[];for(var n=["left","right"],a=["top","bottom"],i=0;i<4;i++){var o=document.createElement("div"),s=o.style,l=i%2,u=(i>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",n[l]+":0",a[u]+":0",n[1-l]+":auto",a[1-u]+":auto",""].join("!important;"),r.appendChild(o),t.push(o)}return t}function E6(r,e,t){for(var n=t?"invTrans":"trans",a=e[n],i=e.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var c=r[u].getBoundingClientRect(),h=2*u,d=c.left,v=c.top;o.push(d,v),l=l&&i&&d===i[h]&&v===i[h+1],s.push(r[u].offsetLeft,r[u].offsetTop)}return l&&a?a:(e.srcCoords=o,e[n]=t?x2(s,o):x2(o,s))}function WI(r){return r.nodeName.toUpperCase()==="CANVAS"}var O6=/([&<>"'])/g,B6={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function qr(r){return r==null?"":(r+"").replace(O6,function(e,t){return B6[t]})}var N6=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,fy=[],z6=oe.browser.firefox&&+oe.browser.version.split(".")[0]<39;function j0(r,e,t,n){return t=t||{},n?S2(r,e,t):z6&&e.layerX!=null&&e.layerX!==e.offsetX?(t.zrX=e.layerX,t.zrY=e.layerY):e.offsetX!=null?(t.zrX=e.offsetX,t.zrY=e.offsetY):S2(r,e,t),t}function S2(r,e,t){if(oe.domSupported&&r.getBoundingClientRect){var n=e.clientX,a=e.clientY;if(WI(r)){var i=r.getBoundingClientRect();t.zrX=n-i.left,t.zrY=a-i.top;return}else if($0(fy,r,n,a)){t.zrX=fy[0],t.zrY=fy[1];return}}t.zrX=t.zrY=0}function G1(r){return r||window.event}function Un(r,e,t){if(e=G1(e),e.zrX!=null)return e;var n=e.type,a=n&&n.indexOf("touch")>=0;if(a){var o=n!=="touchend"?e.targetTouches[0]:e.changedTouches[0];o&&j0(r,o,e,t)}else{j0(r,e,e,t);var i=F6(e);e.zrDelta=i?i/120:-(e.detail||0)/3}var s=e.button;return e.which==null&&s!==void 0&&N6.test(e.type)&&(e.which=s&1?1:s&2?3:s&4?2:0),e}function F6(r){var e=r.wheelDelta;if(e)return e;var t=r.deltaX,n=r.deltaY;if(t==null||n==null)return e;var a=Math.abs(n!==0?n:t),i=n>0?-1:n<0?1:t>0?-1:1;return 3*a*i}function q0(r,e,t,n){r.addEventListener(e,t,n)}function V6(r,e,t,n){r.removeEventListener(e,t,n)}var Si=function(r){r.preventDefault(),r.stopPropagation(),r.cancelBubble=!0};function A2(r){return r.which===2||r.which===3}var G6=function(){function r(){this._track=[]}return r.prototype.recognize=function(e,t,n){return this._doTrack(e,t,n),this._recognize(e)},r.prototype.clear=function(){return this._track.length=0,this},r.prototype._doTrack=function(e,t,n){var a=e.touches;if(a){for(var i={points:[],touches:[],target:t,event:e},o=0,s=a.length;o<s;o++){var l=a[o],u=j0(n,l,{});i.points.push([u.zrX,u.zrY]),i.touches.push(l)}this._track.push(i)}},r.prototype._recognize=function(e){for(var t in vy)if(vy.hasOwnProperty(t)){var n=vy[t](this._track,e);if(n)return n}},r}();function T2(r){var e=r[1][0]-r[0][0],t=r[1][1]-r[0][1];return Math.sqrt(e*e+t*t)}function W6(r){return[(r[0][0]+r[1][0])/2,(r[0][1]+r[1][1])/2]}var vy={pinch:function(r,e){var t=r.length;if(t){var n=(r[t-1]||{}).points,a=(r[t-2]||{}).points||n;if(a&&a.length>1&&n&&n.length>1){var i=T2(n)/T2(a);!isFinite(i)&&(i=1),e.pinchScale=i;var o=W6(n);return e.pinchX=o[0],e.pinchY=o[1],{type:"pinch",target:r[0].target,event:e}}}}};function Ln(){return[1,0,0,1,0,0]}function vp(r){return r[0]=1,r[1]=0,r[2]=0,r[3]=1,r[4]=0,r[5]=0,r}function W1(r,e){return r[0]=e[0],r[1]=e[1],r[2]=e[2],r[3]=e[3],r[4]=e[4],r[5]=e[5],r}function _i(r,e,t){var n=e[0]*t[0]+e[2]*t[1],a=e[1]*t[0]+e[3]*t[1],i=e[0]*t[2]+e[2]*t[3],o=e[1]*t[2]+e[3]*t[3],s=e[0]*t[4]+e[2]*t[5]+e[4],l=e[1]*t[4]+e[3]*t[5]+e[5];return r[0]=n,r[1]=a,r[2]=i,r[3]=o,r[4]=s,r[5]=l,r}function Ya(r,e,t){return r[0]=e[0],r[1]=e[1],r[2]=e[2],r[3]=e[3],r[4]=e[4]+t[0],r[5]=e[5]+t[1],r}function Hs(r,e,t,n){n===void 0&&(n=[0,0]);var a=e[0],i=e[2],o=e[4],s=e[1],l=e[3],u=e[5],c=Math.sin(t),h=Math.cos(t);return r[0]=a*h+s*c,r[1]=-a*c+s*h,r[2]=i*h+l*c,r[3]=-i*c+h*l,r[4]=h*(o-n[0])+c*(u-n[1])+n[0],r[5]=h*(u-n[1])-c*(o-n[0])+n[1],r}function H1(r,e,t){var n=t[0],a=t[1];return r[0]=e[0]*n,r[1]=e[1]*a,r[2]=e[2]*n,r[3]=e[3]*a,r[4]=e[4]*n,r[5]=e[5]*a,r}function cu(r,e){var t=e[0],n=e[2],a=e[4],i=e[1],o=e[3],s=e[5],l=t*o-i*n;return l?(l=1/l,r[0]=o*l,r[1]=-i*l,r[2]=-n*l,r[3]=t*l,r[4]=(n*s-o*a)*l,r[5]=(i*a-t*s)*l,r):null}function H6(r){var e=Ln();return W1(e,r),e}var Kt=function(){function r(e,t){this.x=e||0,this.y=t||0}return r.prototype.copy=function(e){return this.x=e.x,this.y=e.y,this},r.prototype.clone=function(){return new r(this.x,this.y)},r.prototype.set=function(e,t){return this.x=e,this.y=t,this},r.prototype.equal=function(e){return e.x===this.x&&e.y===this.y},r.prototype.add=function(e){return this.x+=e.x,this.y+=e.y,this},r.prototype.scale=function(e){this.x*=e,this.y*=e},r.prototype.scaleAndAdd=function(e,t){this.x+=e.x*t,this.y+=e.y*t},r.prototype.sub=function(e){return this.x-=e.x,this.y-=e.y,this},r.prototype.dot=function(e){return this.x*e.x+this.y*e.y},r.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},r.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},r.prototype.normalize=function(){var e=this.len();return this.x/=e,this.y/=e,this},r.prototype.distance=function(e){var t=this.x-e.x,n=this.y-e.y;return Math.sqrt(t*t+n*n)},r.prototype.distanceSquare=function(e){var t=this.x-e.x,n=this.y-e.y;return t*t+n*n},r.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},r.prototype.transform=function(e){if(e){var t=this.x,n=this.y;return this.x=e[0]*t+e[2]*n+e[4],this.y=e[1]*t+e[3]*n+e[5],this}},r.prototype.toArray=function(e){return e[0]=this.x,e[1]=this.y,e},r.prototype.fromArray=function(e){this.x=e[0],this.y=e[1]},r.set=function(e,t,n){e.x=t,e.y=n},r.copy=function(e,t){e.x=t.x,e.y=t.y},r.len=function(e){return Math.sqrt(e.x*e.x+e.y*e.y)},r.lenSquare=function(e){return e.x*e.x+e.y*e.y},r.dot=function(e,t){return e.x*t.x+e.y*t.y},r.add=function(e,t,n){e.x=t.x+n.x,e.y=t.y+n.y},r.sub=function(e,t,n){e.x=t.x-n.x,e.y=t.y-n.y},r.scale=function(e,t,n){e.x=t.x*n,e.y=t.y*n},r.scaleAndAdd=function(e,t,n,a){e.x=t.x+n.x*a,e.y=t.y+n.y*a},r.lerp=function(e,t,n,a){var i=1-a;e.x=i*t.x+a*n.x,e.y=i*t.y+a*n.y},r}(),Wf=Math.min,Hf=Math.max,zo=new Kt,Fo=new Kt,Vo=new Kt,Go=new Kt,Vu=new Kt,Gu=new Kt,Qt=function(){function r(e,t,n,a){n<0&&(e=e+n,n=-n),a<0&&(t=t+a,a=-a),this.x=e,this.y=t,this.width=n,this.height=a}return r.prototype.union=function(e){var t=Wf(e.x,this.x),n=Wf(e.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=Hf(e.x+e.width,this.x+this.width)-t:this.width=e.width,isFinite(this.y)&&isFinite(this.height)?this.height=Hf(e.y+e.height,this.y+this.height)-n:this.height=e.height,this.x=t,this.y=n},r.prototype.applyTransform=function(e){r.applyTransform(this,this,e)},r.prototype.calculateTransform=function(e){var t=this,n=e.width/t.width,a=e.height/t.height,i=Ln();return Ya(i,i,[-t.x,-t.y]),H1(i,i,[n,a]),Ya(i,i,[e.x,e.y]),i},r.prototype.intersect=function(e,t){if(!e)return!1;e instanceof r||(e=r.create(e));var n=this,a=n.x,i=n.x+n.width,o=n.y,s=n.y+n.height,l=e.x,u=e.x+e.width,c=e.y,h=e.y+e.height,d=!(i<l||u<a||s<c||h<o);if(t){var v=1/0,p=0,y=Math.abs(i-l),_=Math.abs(u-a),g=Math.abs(s-c),f=Math.abs(h-o),w=Math.min(y,_),x=Math.min(g,f);i<l||u<a?w>p&&(p=w,y<_?Kt.set(Gu,-y,0):Kt.set(Gu,_,0)):w<v&&(v=w,y<_?Kt.set(Vu,y,0):Kt.set(Vu,-_,0)),s<c||h<o?x>p&&(p=x,g<f?Kt.set(Gu,0,-g):Kt.set(Gu,0,f)):w<v&&(v=w,g<f?Kt.set(Vu,0,g):Kt.set(Vu,0,-f))}return t&&Kt.copy(t,d?Vu:Gu),d},r.prototype.contain=function(e,t){var n=this;return e>=n.x&&e<=n.x+n.width&&t>=n.y&&t<=n.y+n.height},r.prototype.clone=function(){return new r(this.x,this.y,this.width,this.height)},r.prototype.copy=function(e){r.copy(this,e)},r.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},r.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},r.prototype.isZero=function(){return this.width===0||this.height===0},r.create=function(e){return new r(e.x,e.y,e.width,e.height)},r.copy=function(e,t){e.x=t.x,e.y=t.y,e.width=t.width,e.height=t.height},r.applyTransform=function(e,t,n){if(!n){e!==t&&r.copy(e,t);return}if(n[1]<1e-5&&n[1]>-1e-5&&n[2]<1e-5&&n[2]>-1e-5){var a=n[0],i=n[3],o=n[4],s=n[5];e.x=t.x*a+o,e.y=t.y*i+s,e.width=t.width*a,e.height=t.height*i,e.width<0&&(e.x+=e.width,e.width=-e.width),e.height<0&&(e.y+=e.height,e.height=-e.height);return}zo.x=Vo.x=t.x,zo.y=Go.y=t.y,Fo.x=Go.x=t.x+t.width,Fo.y=Vo.y=t.y+t.height,zo.transform(n),Go.transform(n),Fo.transform(n),Vo.transform(n),e.x=Wf(zo.x,Fo.x,Vo.x,Go.x),e.y=Wf(zo.y,Fo.y,Vo.y,Go.y);var l=Hf(zo.x,Fo.x,Vo.x,Go.x),u=Hf(zo.y,Fo.y,Vo.y,Go.y);e.width=l-e.x,e.height=u-e.y},r}(),HI="silent";function U6(r,e,t){return{type:r,event:t,target:e.target,topTarget:e.topTarget,cancelBubble:!1,offsetX:t.zrX,offsetY:t.zrY,gestureEvent:t.gestureEvent,pinchX:t.pinchX,pinchY:t.pinchY,pinchScale:t.pinchScale,wheelDelta:t.zrDelta,zrByTouch:t.zrByTouch,which:t.which,stop:Z6}}function Z6(){Si(this.event)}var Y6=function(r){Ge(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.handler=null,t}return e.prototype.dispose=function(){},e.prototype.setCursor=function(){},e}(ea),Wu=function(){function r(e,t){this.x=e,this.y=t}return r}(),X6=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],dy=new Qt(0,0,0,0),UI=function(r){Ge(e,r);function e(t,n,a,i,o){var s=r.call(this)||this;return s._hovered=new Wu(0,0),s.storage=t,s.painter=n,s.painterRoot=i,s._pointerSize=o,a=a||new Y6,s.proxy=null,s.setHandlerProxy(a),s._draggingMgr=new I6(s),s}return e.prototype.setHandlerProxy=function(t){this.proxy&&this.proxy.dispose(),t&&(B(X6,function(n){t.on&&t.on(n,this[n],this)},this),t.handler=this),this.proxy=t},e.prototype.mousemove=function(t){var n=t.zrX,a=t.zrY,i=ZI(this,n,a),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=i?new Wu(n,a):this.findHover(n,a),u=l.target,c=this.proxy;c.setCursor&&c.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",t),this.dispatchToElement(l,"mousemove",t),u&&u!==s&&this.dispatchToElement(l,"mouseover",t)},e.prototype.mouseout=function(t){var n=t.zrEventControl;n!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",t),n!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:t})},e.prototype.resize=function(){this._hovered=new Wu(0,0)},e.prototype.dispatch=function(t,n){var a=this[t];a&&a.call(this,n)},e.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},e.prototype.setCursorStyle=function(t){var n=this.proxy;n.setCursor&&n.setCursor(t)},e.prototype.dispatchToElement=function(t,n,a){t=t||{};var i=t.target;if(!(i&&i.silent)){for(var o="on"+n,s=U6(n,t,a);i&&(i[o]&&(s.cancelBubble=!!i[o].call(i,s)),i.trigger(n,s),i=i.__hostTarget?i.__hostTarget:i.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(n,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(n,s)}))}},e.prototype.findHover=function(t,n,a){var i=this.storage.getDisplayList(),o=new Wu(t,n);if(C2(i,o,t,n,a),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,c=new Qt(t-u,n-u,l,l),h=i.length-1;h>=0;h--){var d=i[h];d!==a&&!d.ignore&&!d.ignoreCoarsePointer&&(!d.parent||!d.parent.ignoreCoarsePointer)&&(dy.copy(d.getBoundingRect()),d.transform&&dy.applyTransform(d.transform),dy.intersect(c)&&s.push(d))}if(s.length)for(var v=4,p=Math.PI/12,y=Math.PI*2,_=0;_<u;_+=v)for(var g=0;g<y;g+=p){var f=t+_*Math.cos(g),w=n+_*Math.sin(g);if(C2(s,o,f,w,a),o.target)return o}}return o},e.prototype.processGesture=function(t,n){this._gestureMgr||(this._gestureMgr=new G6);var a=this._gestureMgr;n==="start"&&a.clear();var i=a.recognize(t,this.findHover(t.zrX,t.zrY,null).target,this.proxy.dom);if(n==="end"&&a.clear(),i){var o=i.type;t.gestureEvent=o;var s=new Wu;s.target=i.target,this.dispatchToElement(s,o,i.event)}},e}(ea);B(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(r){UI.prototype[r]=function(e){var t=e.zrX,n=e.zrY,a=ZI(this,t,n),i,o;if((r!=="mouseup"||!a)&&(i=this.findHover(t,n),o=i.target),r==="mousedown")this._downEl=o,this._downPoint=[e.zrX,e.zrY],this._upEl=o;else if(r==="mouseup")this._upEl=o;else if(r==="click"){if(this._downEl!==this._upEl||!this._downPoint||ao(this._downPoint,[e.zrX,e.zrY])>4)return;this._downPoint=null}this.dispatchToElement(i,r,e)}});function $6(r,e,t){if(r[r.rectHover?"rectContain":"contain"](e,t)){for(var n=r,a=void 0,i=!1;n;){if(n.ignoreClip&&(i=!0),!i){var o=n.getClipPath();if(o&&!o.contain(e,t))return!1}n.silent&&(a=!0);var s=n.__hostTarget;n=s||n.parent}return a?HI:!0}return!1}function C2(r,e,t,n,a){for(var i=r.length-1;i>=0;i--){var o=r[i],s=void 0;if(o!==a&&!o.ignore&&(s=$6(o,t,n))&&(!e.topTarget&&(e.topTarget=o),s!==HI)){e.target=o;break}}}function ZI(r,e,t){var n=r.painter;return e<0||e>n.getWidth()||t<0||t>n.getHeight()}var YI=32,Hu=7;function j6(r){for(var e=0;r>=YI;)e|=r&1,r>>=1;return r+e}function L2(r,e,t,n){var a=e+1;if(a===t)return 1;if(n(r[a++],r[e])<0){for(;a<t&&n(r[a],r[a-1])<0;)a++;q6(r,e,a)}else for(;a<t&&n(r[a],r[a-1])>=0;)a++;return a-e}function q6(r,e,t){for(t--;e<t;){var n=r[e];r[e++]=r[t],r[t--]=n}}function M2(r,e,t,n,a){for(n===e&&n++;n<t;n++){for(var i=r[n],o=e,s=n,l;o<s;)l=o+s>>>1,a(i,r[l])<0?s=l:o=l+1;var u=n-o;switch(u){case 3:r[o+3]=r[o+2];case 2:r[o+2]=r[o+1];case 1:r[o+1]=r[o];break;default:for(;u>0;)r[o+u]=r[o+u-1],u--}r[o]=i}}function py(r,e,t,n,a,i){var o=0,s=0,l=1;if(i(r,e[t+a])>0){for(s=n-a;l<s&&i(r,e[t+a+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=a,l+=a}else{for(s=a+1;l<s&&i(r,e[t+a-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=a-l,l=a-u}for(o++;o<l;){var c=o+(l-o>>>1);i(r,e[t+c])>0?o=c+1:l=c}return l}function gy(r,e,t,n,a,i){var o=0,s=0,l=1;if(i(r,e[t+a])<0){for(s=a+1;l<s&&i(r,e[t+a-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=a-l,l=a-u}else{for(s=n-a;l<s&&i(r,e[t+a+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=a,l+=a}for(o++;o<l;){var c=o+(l-o>>>1);i(r,e[t+c])<0?l=c:o=c+1}return l}function K6(r,e){var t=Hu,n,a,i=0,o=[];n=[],a=[];function s(v,p){n[i]=v,a[i]=p,i+=1}function l(){for(;i>1;){var v=i-2;if(v>=1&&a[v-1]<=a[v]+a[v+1]||v>=2&&a[v-2]<=a[v]+a[v-1])a[v-1]<a[v+1]&&v--;else if(a[v]>a[v+1])break;c(v)}}function u(){for(;i>1;){var v=i-2;v>0&&a[v-1]<a[v+1]&&v--,c(v)}}function c(v){var p=n[v],y=a[v],_=n[v+1],g=a[v+1];a[v]=y+g,v===i-3&&(n[v+1]=n[v+2],a[v+1]=a[v+2]),i--;var f=gy(r[_],r,p,y,0,e);p+=f,y-=f,y!==0&&(g=py(r[p+y-1],r,_,g,g-1,e),g!==0&&(y<=g?h(p,y,_,g):d(p,y,_,g)))}function h(v,p,y,_){var g=0;for(g=0;g<p;g++)o[g]=r[v+g];var f=0,w=y,x=v;if(r[x++]=r[w++],--_===0){for(g=0;g<p;g++)r[x+g]=o[f+g];return}if(p===1){for(g=0;g<_;g++)r[x+g]=r[w+g];r[x+_]=o[f];return}for(var S=t,A,T,L;;){A=0,T=0,L=!1;do if(e(r[w],o[f])<0){if(r[x++]=r[w++],T++,A=0,--_===0){L=!0;break}}else if(r[x++]=o[f++],A++,T=0,--p===1){L=!0;break}while((A|T)<S);if(L)break;do{if(A=gy(r[w],o,f,p,0,e),A!==0){for(g=0;g<A;g++)r[x+g]=o[f+g];if(x+=A,f+=A,p-=A,p<=1){L=!0;break}}if(r[x++]=r[w++],--_===0){L=!0;break}if(T=py(o[f],r,w,_,0,e),T!==0){for(g=0;g<T;g++)r[x+g]=r[w+g];if(x+=T,w+=T,_-=T,_===0){L=!0;break}}if(r[x++]=o[f++],--p===1){L=!0;break}S--}while(A>=Hu||T>=Hu);if(L)break;S<0&&(S=0),S+=2}if(t=S,t<1&&(t=1),p===1){for(g=0;g<_;g++)r[x+g]=r[w+g];r[x+_]=o[f]}else{if(p===0)throw new Error;for(g=0;g<p;g++)r[x+g]=o[f+g]}}function d(v,p,y,_){var g=0;for(g=0;g<_;g++)o[g]=r[y+g];var f=v+p-1,w=_-1,x=y+_-1,S=0,A=0;if(r[x--]=r[f--],--p===0){for(S=x-(_-1),g=0;g<_;g++)r[S+g]=o[g];return}if(_===1){for(x-=p,f-=p,A=x+1,S=f+1,g=p-1;g>=0;g--)r[A+g]=r[S+g];r[x]=o[w];return}for(var T=t;;){var L=0,M=0,I=!1;do if(e(o[w],r[f])<0){if(r[x--]=r[f--],L++,M=0,--p===0){I=!0;break}}else if(r[x--]=o[w--],M++,L=0,--_===1){I=!0;break}while((L|M)<T);if(I)break;do{if(L=p-gy(o[w],r,v,p,p-1,e),L!==0){for(x-=L,f-=L,p-=L,A=x+1,S=f+1,g=L-1;g>=0;g--)r[A+g]=r[S+g];if(p===0){I=!0;break}}if(r[x--]=o[w--],--_===1){I=!0;break}if(M=_-py(r[f],o,0,_,_-1,e),M!==0){for(x-=M,w-=M,_-=M,A=x+1,S=w+1,g=0;g<M;g++)r[A+g]=o[S+g];if(_<=1){I=!0;break}}if(r[x--]=r[f--],--p===0){I=!0;break}T--}while(L>=Hu||M>=Hu);if(I)break;T<0&&(T=0),T+=2}if(t=T,t<1&&(t=1),_===1){for(x-=p,f-=p,A=x+1,S=f+1,g=p-1;g>=0;g--)r[A+g]=r[S+g];r[x]=o[w]}else{if(_===0)throw new Error;for(S=x-(_-1),g=0;g<_;g++)r[S+g]=o[g]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function Xv(r,e,t,n){t||(t=0),n||(n=r.length);var a=n-t;if(!(a<2)){var i=0;if(a<YI){i=L2(r,t,n,e),M2(r,t,n,t+i,e);return}var o=K6(r,e),s=j6(a);do{if(i=L2(r,t,n,e),i<s){var l=a;l>s&&(l=s),M2(r,t,t+l,t+i,e),i=l}o.pushRun(t,i),o.mergeRuns(),a-=i,t+=i}while(a!==0);o.forceMergeRuns()}}var Tn=1,mc=2,El=4,D2=!1;function yy(){D2||(D2=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function I2(r,e){return r.zlevel===e.zlevel?r.z===e.z?r.z2-e.z2:r.z-e.z:r.zlevel-e.zlevel}var Q6=function(){function r(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=I2}return r.prototype.traverse=function(e,t){for(var n=0;n<this._roots.length;n++)this._roots[n].traverse(e,t)},r.prototype.getDisplayList=function(e,t){t=t||!1;var n=this._displayList;return(e||!n.length)&&this.updateDisplayList(t),n},r.prototype.updateDisplayList=function(e){this._displayListLen=0;for(var t=this._roots,n=this._displayList,a=0,i=t.length;a<i;a++)this._updateAndAddDisplayable(t[a],null,e);n.length=this._displayListLen,Xv(n,I2)},r.prototype._updateAndAddDisplayable=function(e,t,n){if(!(e.ignore&&!n)){e.beforeUpdate(),e.update(),e.afterUpdate();var a=e.getClipPath();if(e.ignoreClip)t=null;else if(a){t?t=t.slice():t=[];for(var i=a,o=e;i;)i.parent=o,i.updateTransform(),t.push(i),o=i,i=i.getClipPath()}if(e.childrenRef){for(var s=e.childrenRef(),l=0;l<s.length;l++){var u=s[l];e.__dirty&&(u.__dirty|=Tn),this._updateAndAddDisplayable(u,t,n)}e.__dirty=0}else{var c=e;t&&t.length?c.__clipPaths=t:c.__clipPaths&&c.__clipPaths.length>0&&(c.__clipPaths=[]),isNaN(c.z)&&(yy(),c.z=0),isNaN(c.z2)&&(yy(),c.z2=0),isNaN(c.zlevel)&&(yy(),c.zlevel=0),this._displayList[this._displayListLen++]=c}var h=e.getDecalElement&&e.getDecalElement();h&&this._updateAndAddDisplayable(h,t,n);var d=e.getTextGuideLine();d&&this._updateAndAddDisplayable(d,t,n);var v=e.getTextContent();v&&this._updateAndAddDisplayable(v,t,n)}},r.prototype.addRoot=function(e){e.__zr&&e.__zr.storage===this||this._roots.push(e)},r.prototype.delRoot=function(e){if(e instanceof Array){for(var t=0,n=e.length;t<n;t++)this.delRoot(e[t]);return}var a=te(this._roots,e);a>=0&&this._roots.splice(a,1)},r.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},r.prototype.getRoots=function(){return this._roots},r.prototype.dispose=function(){this._displayList=null,this._roots=null},r}(),dd;dd=oe.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(r){return setTimeout(r,16)};var kc={linear:function(r){return r},quadraticIn:function(r){return r*r},quadraticOut:function(r){return r*(2-r)},quadraticInOut:function(r){return(r*=2)<1?.5*r*r:-.5*(--r*(r-2)-1)},cubicIn:function(r){return r*r*r},cubicOut:function(r){return--r*r*r+1},cubicInOut:function(r){return(r*=2)<1?.5*r*r*r:.5*((r-=2)*r*r+2)},quarticIn:function(r){return r*r*r*r},quarticOut:function(r){return 1- --r*r*r*r},quarticInOut:function(r){return(r*=2)<1?.5*r*r*r*r:-.5*((r-=2)*r*r*r-2)},quinticIn:function(r){return r*r*r*r*r},quinticOut:function(r){return--r*r*r*r*r+1},quinticInOut:function(r){return(r*=2)<1?.5*r*r*r*r*r:.5*((r-=2)*r*r*r*r+2)},sinusoidalIn:function(r){return 1-Math.cos(r*Math.PI/2)},sinusoidalOut:function(r){return Math.sin(r*Math.PI/2)},sinusoidalInOut:function(r){return .5*(1-Math.cos(Math.PI*r))},exponentialIn:function(r){return r===0?0:Math.pow(1024,r-1)},exponentialOut:function(r){return r===1?1:1-Math.pow(2,-10*r)},exponentialInOut:function(r){return r===0?0:r===1?1:(r*=2)<1?.5*Math.pow(1024,r-1):.5*(-Math.pow(2,-10*(r-1))+2)},circularIn:function(r){return 1-Math.sqrt(1-r*r)},circularOut:function(r){return Math.sqrt(1- --r*r)},circularInOut:function(r){return(r*=2)<1?-.5*(Math.sqrt(1-r*r)-1):.5*(Math.sqrt(1-(r-=2)*r)+1)},elasticIn:function(r){var e,t=.1,n=.4;return r===0?0:r===1?1:(!t||t<1?(t=1,e=n/4):e=n*Math.asin(1/t)/(2*Math.PI),-(t*Math.pow(2,10*(r-=1))*Math.sin((r-e)*(2*Math.PI)/n)))},elasticOut:function(r){var e,t=.1,n=.4;return r===0?0:r===1?1:(!t||t<1?(t=1,e=n/4):e=n*Math.asin(1/t)/(2*Math.PI),t*Math.pow(2,-10*r)*Math.sin((r-e)*(2*Math.PI)/n)+1)},elasticInOut:function(r){var e,t=.1,n=.4;return r===0?0:r===1?1:(!t||t<1?(t=1,e=n/4):e=n*Math.asin(1/t)/(2*Math.PI),(r*=2)<1?-.5*(t*Math.pow(2,10*(r-=1))*Math.sin((r-e)*(2*Math.PI)/n)):t*Math.pow(2,-10*(r-=1))*Math.sin((r-e)*(2*Math.PI)/n)*.5+1)},backIn:function(r){var e=1.70158;return r*r*((e+1)*r-e)},backOut:function(r){var e=1.70158;return--r*r*((e+1)*r+e)+1},backInOut:function(r){var e=2.5949095;return(r*=2)<1?.5*(r*r*((e+1)*r-e)):.5*((r-=2)*r*((e+1)*r+e)+2)},bounceIn:function(r){return 1-kc.bounceOut(1-r)},bounceOut:function(r){return r<1/2.75?7.5625*r*r:r<2/2.75?7.5625*(r-=1.5/2.75)*r+.75:r<2.5/2.75?7.5625*(r-=2.25/2.75)*r+.9375:7.5625*(r-=2.625/2.75)*r+.984375},bounceInOut:function(r){return r<.5?kc.bounceIn(r*2)*.5:kc.bounceOut(r*2-1)*.5+.5}},Uf=Math.pow,vo=Math.sqrt,pd=1e-8,XI=1e-4,P2=vo(3),Zf=1/3,Na=Ws(),$n=Ws(),Zl=Ws();function so(r){return r>-pd&&r<pd}function $I(r){return r>pd||r<-pd}function vr(r,e,t,n,a){var i=1-a;return i*i*(i*r+3*a*e)+a*a*(a*n+3*i*t)}function k2(r,e,t,n,a){var i=1-a;return 3*(((e-r)*i+2*(t-e)*a)*i+(n-t)*a*a)}function gd(r,e,t,n,a,i){var o=n+3*(e-t)-r,s=3*(t-e*2+r),l=3*(e-r),u=r-a,c=s*s-3*o*l,h=s*l-9*o*u,d=l*l-3*s*u,v=0;if(so(c)&&so(h))if(so(s))i[0]=0;else{var p=-l/s;p>=0&&p<=1&&(i[v++]=p)}else{var y=h*h-4*c*d;if(so(y)){var _=h/c,p=-s/o+_,g=-_/2;p>=0&&p<=1&&(i[v++]=p),g>=0&&g<=1&&(i[v++]=g)}else if(y>0){var f=vo(y),w=c*s+1.5*o*(-h+f),x=c*s+1.5*o*(-h-f);w<0?w=-Uf(-w,Zf):w=Uf(w,Zf),x<0?x=-Uf(-x,Zf):x=Uf(x,Zf);var p=(-s-(w+x))/(3*o);p>=0&&p<=1&&(i[v++]=p)}else{var S=(2*c*s-3*o*h)/(2*vo(c*c*c)),A=Math.acos(S)/3,T=vo(c),L=Math.cos(A),p=(-s-2*T*L)/(3*o),g=(-s+T*(L+P2*Math.sin(A)))/(3*o),M=(-s+T*(L-P2*Math.sin(A)))/(3*o);p>=0&&p<=1&&(i[v++]=p),g>=0&&g<=1&&(i[v++]=g),M>=0&&M<=1&&(i[v++]=M)}}return v}function jI(r,e,t,n,a){var i=6*t-12*e+6*r,o=9*e+3*n-3*r-9*t,s=3*e-3*r,l=0;if(so(o)){if($I(i)){var u=-s/i;u>=0&&u<=1&&(a[l++]=u)}}else{var c=i*i-4*o*s;if(so(c))a[0]=-i/(2*o);else if(c>0){var h=vo(c),u=(-i+h)/(2*o),d=(-i-h)/(2*o);u>=0&&u<=1&&(a[l++]=u),d>=0&&d<=1&&(a[l++]=d)}}return l}function wo(r,e,t,n,a,i){var o=(e-r)*a+r,s=(t-e)*a+e,l=(n-t)*a+t,u=(s-o)*a+o,c=(l-s)*a+s,h=(c-u)*a+u;i[0]=r,i[1]=o,i[2]=u,i[3]=h,i[4]=h,i[5]=c,i[6]=l,i[7]=n}function qI(r,e,t,n,a,i,o,s,l,u,c){var h,d=.005,v=1/0,p,y,_,g;Na[0]=l,Na[1]=u;for(var f=0;f<1;f+=.05)$n[0]=vr(r,t,a,o,f),$n[1]=vr(e,n,i,s,f),_=Cs(Na,$n),_<v&&(h=f,v=_);v=1/0;for(var w=0;w<32&&!(d<XI);w++)p=h-d,y=h+d,$n[0]=vr(r,t,a,o,p),$n[1]=vr(e,n,i,s,p),_=Cs($n,Na),p>=0&&_<v?(h=p,v=_):(Zl[0]=vr(r,t,a,o,y),Zl[1]=vr(e,n,i,s,y),g=Cs(Zl,Na),y<=1&&g<v?(h=y,v=g):d*=.5);return c&&(c[0]=vr(r,t,a,o,h),c[1]=vr(e,n,i,s,h)),vo(v)}function J6(r,e,t,n,a,i,o,s,l){for(var u=r,c=e,h=0,d=1/l,v=1;v<=l;v++){var p=v*d,y=vr(r,t,a,o,p),_=vr(e,n,i,s,p),g=y-u,f=_-c;h+=Math.sqrt(g*g+f*f),u=y,c=_}return h}function Sr(r,e,t,n){var a=1-n;return a*(a*r+2*n*e)+n*n*t}function K0(r,e,t,n){return 2*((1-n)*(e-r)+n*(t-e))}function t8(r,e,t,n,a){var i=r-2*e+t,o=2*(e-r),s=r-n,l=0;if(so(i)){if($I(o)){var u=-s/o;u>=0&&u<=1&&(a[l++]=u)}}else{var c=o*o-4*i*s;if(so(c)){var u=-o/(2*i);u>=0&&u<=1&&(a[l++]=u)}else if(c>0){var h=vo(c),u=(-o+h)/(2*i),d=(-o-h)/(2*i);u>=0&&u<=1&&(a[l++]=u),d>=0&&d<=1&&(a[l++]=d)}}return l}function KI(r,e,t){var n=r+t-2*e;return n===0?.5:(r-e)/n}function jc(r,e,t,n,a){var i=(e-r)*n+r,o=(t-e)*n+e,s=(o-i)*n+i;a[0]=r,a[1]=i,a[2]=s,a[3]=s,a[4]=o,a[5]=t}function QI(r,e,t,n,a,i,o,s,l){var u,c=.005,h=1/0;Na[0]=o,Na[1]=s;for(var d=0;d<1;d+=.05){$n[0]=Sr(r,t,a,d),$n[1]=Sr(e,n,i,d);var v=Cs(Na,$n);v<h&&(u=d,h=v)}h=1/0;for(var p=0;p<32&&!(c<XI);p++){var y=u-c,_=u+c;$n[0]=Sr(r,t,a,y),$n[1]=Sr(e,n,i,y);var v=Cs($n,Na);if(y>=0&&v<h)u=y,h=v;else{Zl[0]=Sr(r,t,a,_),Zl[1]=Sr(e,n,i,_);var g=Cs(Zl,Na);_<=1&&g<h?(u=_,h=g):c*=.5}}return l&&(l[0]=Sr(r,t,a,u),l[1]=Sr(e,n,i,u)),vo(h)}function e8(r,e,t,n,a,i,o){for(var s=r,l=e,u=0,c=1/o,h=1;h<=o;h++){var d=h*c,v=Sr(r,t,a,d),p=Sr(e,n,i,d),y=v-s,_=p-l;u+=Math.sqrt(y*y+_*_),s=v,l=p}return u}var r8=/cubic-bezier\(([0-9,\.e ]+)\)/;function U1(r){var e=r&&r8.exec(r);if(e){var t=e[1].split(","),n=+ga(t[0]),a=+ga(t[1]),i=+ga(t[2]),o=+ga(t[3]);if(isNaN(n+a+i+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:gd(0,n,i,1,l,s)&&vr(0,a,o,1,s[0])}}}var n8=function(){function r(e){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=e.life||1e3,this._delay=e.delay||0,this.loop=e.loop||!1,this.onframe=e.onframe||tr,this.ondestroy=e.ondestroy||tr,this.onrestart=e.onrestart||tr,e.easing&&this.setEasing(e.easing)}return r.prototype.step=function(e,t){if(this._inited||(this._startTime=e+this._delay,this._inited=!0),this._paused){this._pausedTime+=t;return}var n=this._life,a=e-this._startTime-this._pausedTime,i=a/n;i<0&&(i=0),i=Math.min(i,1);var o=this.easingFunc,s=o?o(i):i;if(this.onframe(s),i===1)if(this.loop){var l=a%n;this._startTime=e-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){this._paused=!1},r.prototype.setEasing=function(e){this.easing=e,this.easingFunc=Nt(e)?e:kc[e]||U1(e)},r}(),JI=function(){function r(e){this.value=e}return r}(),a8=function(){function r(){this._len=0}return r.prototype.insert=function(e){var t=new JI(e);return this.insertEntry(t),t},r.prototype.insertEntry=function(e){this.head?(this.tail.next=e,e.prev=this.tail,e.next=null,this.tail=e):this.head=this.tail=e,this._len++},r.prototype.remove=function(e){var t=e.prev,n=e.next;t?t.next=n:this.head=n,n?n.prev=t:this.tail=t,e.next=e.prev=null,this._len--},r.prototype.len=function(){return this._len},r.prototype.clear=function(){this.head=this.tail=null,this._len=0},r}(),Ah=function(){function r(e){this._list=new a8,this._maxSize=10,this._map={},this._maxSize=e}return r.prototype.put=function(e,t){var n=this._list,a=this._map,i=null;if(a[e]==null){var o=n.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=n.head;n.remove(l),delete a[l.key],i=l.value,this._lastRemovedEntry=l}s?s.value=t:s=new JI(t),s.key=e,n.insertEntry(s),a[e]=s}return i},r.prototype.get=function(e){var t=this._map[e],n=this._list;if(t!=null)return t!==n.tail&&(n.remove(t),n.insertEntry(t)),t.value},r.prototype.clear=function(){this._list.clear(),this._map={}},r.prototype.len=function(){return this._list.len()},r}(),R2={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function ma(r){return r=Math.round(r),r<0?0:r>255?255:r}function i8(r){return r=Math.round(r),r<0?0:r>360?360:r}function qc(r){return r<0?0:r>1?1:r}function my(r){var e=r;return e.length&&e.charAt(e.length-1)==="%"?ma(parseFloat(e)/100*255):ma(parseInt(e,10))}function Ls(r){var e=r;return e.length&&e.charAt(e.length-1)==="%"?qc(parseFloat(e)/100):qc(parseFloat(e))}function _y(r,e,t){return t<0?t+=1:t>1&&(t-=1),t*6<1?r+(e-r)*t*6:t*2<1?e:t*3<2?r+(e-r)*(2/3-t)*6:r}function lo(r,e,t){return r+(e-r)*t}function Hn(r,e,t,n,a){return r[0]=e,r[1]=t,r[2]=n,r[3]=a,r}function Q0(r,e){return r[0]=e[0],r[1]=e[1],r[2]=e[2],r[3]=e[3],r}var tP=new Ah(20),Yf=null;function vl(r,e){Yf&&Q0(Yf,e),Yf=tP.put(r,Yf||e.slice())}function Mn(r,e){if(r){e=e||[];var t=tP.get(r);if(t)return Q0(e,t);r=r+"";var n=r.replace(/ /g,"").toLowerCase();if(n in R2)return Q0(e,R2[n]),vl(r,e),e;var a=n.length;if(n.charAt(0)==="#"){if(a===4||a===5){var i=parseInt(n.slice(1,4),16);if(!(i>=0&&i<=4095)){Hn(e,0,0,0,1);return}return Hn(e,(i&3840)>>4|(i&3840)>>8,i&240|(i&240)>>4,i&15|(i&15)<<4,a===5?parseInt(n.slice(4),16)/15:1),vl(r,e),e}else if(a===7||a===9){var i=parseInt(n.slice(1,7),16);if(!(i>=0&&i<=16777215)){Hn(e,0,0,0,1);return}return Hn(e,(i&16711680)>>16,(i&65280)>>8,i&255,a===9?parseInt(n.slice(7),16)/255:1),vl(r,e),e}return}var o=n.indexOf("("),s=n.indexOf(")");if(o!==-1&&s+1===a){var l=n.substr(0,o),u=n.substr(o+1,s-(o+1)).split(","),c=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?Hn(e,+u[0],+u[1],+u[2],1):Hn(e,0,0,0,1);c=Ls(u.pop());case"rgb":if(u.length>=3)return Hn(e,my(u[0]),my(u[1]),my(u[2]),u.length===3?c:Ls(u[3])),vl(r,e),e;Hn(e,0,0,0,1);return;case"hsla":if(u.length!==4){Hn(e,0,0,0,1);return}return u[3]=Ls(u[3]),J0(u,e),vl(r,e),e;case"hsl":if(u.length!==3){Hn(e,0,0,0,1);return}return J0(u,e),vl(r,e),e;default:return}}Hn(e,0,0,0,1)}}function J0(r,e){var t=(parseFloat(r[0])%360+360)%360/360,n=Ls(r[1]),a=Ls(r[2]),i=a<=.5?a*(n+1):a+n-a*n,o=a*2-i;return e=e||[],Hn(e,ma(_y(o,i,t+1/3)*255),ma(_y(o,i,t)*255),ma(_y(o,i,t-1/3)*255),1),r.length===4&&(e[3]=r[3]),e}function o8(r){if(r){var e=r[0]/255,t=r[1]/255,n=r[2]/255,a=Math.min(e,t,n),i=Math.max(e,t,n),o=i-a,s=(i+a)/2,l,u;if(o===0)l=0,u=0;else{s<.5?u=o/(i+a):u=o/(2-i-a);var c=((i-e)/6+o/2)/o,h=((i-t)/6+o/2)/o,d=((i-n)/6+o/2)/o;e===i?l=d-h:t===i?l=1/3+c-d:n===i&&(l=2/3+h-c),l<0&&(l+=1),l>1&&(l-=1)}var v=[l*360,u,s];return r[3]!=null&&v.push(r[3]),v}}function t_(r,e){var t=Mn(r);if(t){for(var n=0;n<3;n++)e<0?t[n]=t[n]*(1-e)|0:t[n]=(255-t[n])*e+t[n]|0,t[n]>255?t[n]=255:t[n]<0&&(t[n]=0);return wi(t,t.length===4?"rgba":"rgb")}}function wy(r,e,t){if(!(!(e&&e.length)||!(r>=0&&r<=1))){t=t||[];var n=r*(e.length-1),a=Math.floor(n),i=Math.ceil(n),o=e[a],s=e[i],l=n-a;return t[0]=ma(lo(o[0],s[0],l)),t[1]=ma(lo(o[1],s[1],l)),t[2]=ma(lo(o[2],s[2],l)),t[3]=qc(lo(o[3],s[3],l)),t}}function s8(r,e,t){if(!(!(e&&e.length)||!(r>=0&&r<=1))){var n=r*(e.length-1),a=Math.floor(n),i=Math.ceil(n),o=Mn(e[a]),s=Mn(e[i]),l=n-a,u=wi([ma(lo(o[0],s[0],l)),ma(lo(o[1],s[1],l)),ma(lo(o[2],s[2],l)),qc(lo(o[3],s[3],l))],"rgba");return t?{color:u,leftIndex:a,rightIndex:i,value:n}:u}}function Rc(r,e,t,n){var a=Mn(r);if(r)return a=o8(a),e!=null&&(a[0]=i8(e)),t!=null&&(a[1]=Ls(t)),n!=null&&(a[2]=Ls(n)),wi(J0(a),"rgba")}function yd(r,e){var t=Mn(r);if(t&&e!=null)return t[3]=qc(e),wi(t,"rgba")}function wi(r,e){if(!(!r||!r.length)){var t=r[0]+","+r[1]+","+r[2];return(e==="rgba"||e==="hsva"||e==="hsla")&&(t+=","+r[3]),e+"("+t+")"}}function md(r,e){var t=Mn(r);return t?(.299*t[0]+.587*t[1]+.114*t[2])*t[3]/255+(1-t[3])*e:0}var E2=new Ah(100);function e_(r){if(Lt(r)){var e=E2.get(r);return e||(e=t_(r,-.1),E2.put(r,e)),e}else if(hp(r)){var t=lt({},r);return t.colorStops=ft(r.colorStops,function(n){return{offset:n.offset,color:t_(n.color,-.1)}}),t}return r}var _d=Math.round;function Kc(r){var e;if(!r||r==="transparent")r="none";else if(typeof r=="string"&&r.indexOf("rgba")>-1){var t=Mn(r);t&&(r="rgb("+t[0]+","+t[1]+","+t[2]+")",e=t[3])}return{color:r,opacity:e??1}}var O2=1e-4;function uo(r){return r<O2&&r>-O2}function Xf(r){return _d(r*1e3)/1e3}function r_(r){return _d(r*1e4)/1e4}function l8(r){return"matrix("+Xf(r[0])+","+Xf(r[1])+","+Xf(r[2])+","+Xf(r[3])+","+r_(r[4])+","+r_(r[5])+")"}var u8={left:"start",right:"end",center:"middle",middle:"middle"};function c8(r,e,t){return t==="top"?r+=e/2:t==="bottom"&&(r-=e/2),r}function h8(r){return r&&(r.shadowBlur||r.shadowOffsetX||r.shadowOffsetY)}function f8(r){var e=r.style,t=r.getGlobalScale();return[e.shadowColor,(e.shadowBlur||0).toFixed(2),(e.shadowOffsetX||0).toFixed(2),(e.shadowOffsetY||0).toFixed(2),t[0],t[1]].join(",")}function eP(r){return r&&!!r.image}function v8(r){return r&&!!r.svgElement}function Z1(r){return eP(r)||v8(r)}function rP(r){return r.type==="linear"}function nP(r){return r.type==="radial"}function aP(r){return r&&(r.type==="linear"||r.type==="radial")}function dp(r){return"url(#"+r+")"}function iP(r){var e=r.getGlobalScale(),t=Math.max(e[0],e[1]);return Math.max(Math.ceil(Math.log(t)/Math.log(10)),1)}function oP(r){var e=r.x||0,t=r.y||0,n=(r.rotation||0)*Uv,a=Zt(r.scaleX,1),i=Zt(r.scaleY,1),o=r.skewX||0,s=r.skewY||0,l=[];return(e||t)&&l.push("translate("+e+"px,"+t+"px)"),n&&l.push("rotate("+n+")"),(a!==1||i!==1)&&l.push("scale("+a+","+i+")"),(o||s)&&l.push("skew("+_d(o*Uv)+"deg, "+_d(s*Uv)+"deg)"),l.join(" ")}var d8=function(){return oe.hasGlobalWindow&&Nt(window.btoa)?function(r){return window.btoa(unescape(encodeURIComponent(r)))}:typeof Buffer<"u"?function(r){return Buffer.from(r).toString("base64")}:function(r){return null}}(),n_=Array.prototype.slice;function vi(r,e,t){return(e-r)*t+r}function xy(r,e,t,n){for(var a=e.length,i=0;i<a;i++)r[i]=vi(e[i],t[i],n);return r}function p8(r,e,t,n){for(var a=e.length,i=a&&e[0].length,o=0;o<a;o++){r[o]||(r[o]=[]);for(var s=0;s<i;s++)r[o][s]=vi(e[o][s],t[o][s],n)}return r}function $f(r,e,t,n){for(var a=e.length,i=0;i<a;i++)r[i]=e[i]+t[i]*n;return r}function B2(r,e,t,n){for(var a=e.length,i=a&&e[0].length,o=0;o<a;o++){r[o]||(r[o]=[]);for(var s=0;s<i;s++)r[o][s]=e[o][s]+t[o][s]*n}return r}function g8(r,e){for(var t=r.length,n=e.length,a=t>n?e:r,i=Math.min(t,n),o=a[i-1]||{color:[0,0,0,0],offset:0},s=i;s<Math.max(t,n);s++)a.push({offset:o.offset,color:o.color.slice()})}function y8(r,e,t){var n=r,a=e;if(!(!n.push||!a.push)){var i=n.length,o=a.length;if(i!==o){var s=i>o;if(s)n.length=o;else for(var l=i;l<o;l++)n.push(t===1?a[l]:n_.call(a[l]))}for(var u=n[0]&&n[0].length,l=0;l<n.length;l++)if(t===1)isNaN(n[l])&&(n[l]=a[l]);else for(var c=0;c<u;c++)isNaN(n[l][c])&&(n[l][c]=a[l][c])}}function Ec(r){if(Gr(r)){var e=r.length;if(Gr(r[0])){for(var t=[],n=0;n<e;n++)t.push(n_.call(r[n]));return t}return n_.call(r)}return r}function $v(r){return r[0]=Math.floor(r[0])||0,r[1]=Math.floor(r[1])||0,r[2]=Math.floor(r[2])||0,r[3]=r[3]==null?1:r[3],"rgba("+r.join(",")+")"}function m8(r){return Gr(r&&r[0])?2:1}var jf=0,jv=1,sP=2,_c=3,a_=4,i_=5,N2=6;function z2(r){return r===a_||r===i_}function qf(r){return r===jv||r===sP}var Uu=[0,0,0,0],_8=function(){function r(e){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=e}return r.prototype.isFinished=function(){return this._finished},r.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},r.prototype.needsAnimate=function(){return this.keyframes.length>=1},r.prototype.getAdditiveTrack=function(){return this._additiveTrack},r.prototype.addKeyframe=function(e,t,n){this._needsSort=!0;var a=this.keyframes,i=a.length,o=!1,s=N2,l=t;if(Gr(t)){var u=m8(t);s=u,(u===1&&!ye(t[0])||u===2&&!ye(t[0][0]))&&(o=!0)}else if(ye(t)&&!Xc(t))s=jf;else if(Lt(t))if(!isNaN(+t))s=jf;else{var c=Mn(t);c&&(l=c,s=_c)}else if(hp(t)){var h=lt({},l);h.colorStops=ft(t.colorStops,function(v){return{offset:v.offset,color:Mn(v.color)}}),rP(t)?s=a_:nP(t)&&(s=i_),l=h}i===0?this.valType=s:(s!==this.valType||s===N2)&&(o=!0),this.discrete=this.discrete||o;var d={time:e,value:l,rawValue:t,percent:0};return n&&(d.easing=n,d.easingFunc=Nt(n)?n:kc[n]||U1(n)),a.push(d),d},r.prototype.prepare=function(e,t){var n=this.keyframes;this._needsSort&&n.sort(function(y,_){return y.time-_.time});for(var a=this.valType,i=n.length,o=n[i-1],s=this.discrete,l=qf(a),u=z2(a),c=0;c<i;c++){var h=n[c],d=h.value,v=o.value;h.percent=h.time/e,s||(l&&c!==i-1?y8(d,v,a):u&&g8(d.colorStops,v.colorStops))}if(!s&&a!==i_&&t&&this.needsAnimate()&&t.needsAnimate()&&a===t.valType&&!t._finished){this._additiveTrack=t;for(var p=n[0].value,c=0;c<i;c++)a===jf?n[c].additiveValue=n[c].value-p:a===_c?n[c].additiveValue=$f([],n[c].value,p,-1):qf(a)&&(n[c].additiveValue=a===jv?$f([],n[c].value,p,-1):B2([],n[c].value,p,-1))}},r.prototype.step=function(e,t){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var n=this._additiveTrack!=null,a=n?"additiveValue":"value",i=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=i===_c,c,h=this._lastFr,d=Math.min,v,p;if(s===1)v=p=o[0];else{if(t<0)c=0;else if(t<this._lastFrP){var y=d(h+1,s-1);for(c=y;c>=0&&!(o[c].percent<=t);c--);c=d(c,s-2)}else{for(c=h;c<s&&!(o[c].percent>t);c++);c=d(c-1,s-2)}p=o[c+1],v=o[c]}if(v&&p){this._lastFr=c,this._lastFrP=t;var _=p.percent-v.percent,g=_===0?1:d((t-v.percent)/_,1);p.easingFunc&&(g=p.easingFunc(g));var f=n?this._additiveValue:u?Uu:e[l];if((qf(i)||u)&&!f&&(f=this._additiveValue=[]),this.discrete)e[l]=g<1?v.rawValue:p.rawValue;else if(qf(i))i===jv?xy(f,v[a],p[a],g):p8(f,v[a],p[a],g);else if(z2(i)){var w=v[a],x=p[a],S=i===a_;e[l]={type:S?"linear":"radial",x:vi(w.x,x.x,g),y:vi(w.y,x.y,g),colorStops:ft(w.colorStops,function(T,L){var M=x.colorStops[L];return{offset:vi(T.offset,M.offset,g),color:$v(xy([],T.color,M.color,g))}}),global:x.global},S?(e[l].x2=vi(w.x2,x.x2,g),e[l].y2=vi(w.y2,x.y2,g)):e[l].r=vi(w.r,x.r,g)}else if(u)xy(f,v[a],p[a],g),n||(e[l]=$v(f));else{var A=vi(v[a],p[a],g);n?this._additiveValue=A:e[l]=A}n&&this._addToTarget(e)}}},r.prototype._addToTarget=function(e){var t=this.valType,n=this.propName,a=this._additiveValue;t===jf?e[n]=e[n]+a:t===_c?(Mn(e[n],Uu),$f(Uu,Uu,a,1),e[n]=$v(Uu)):t===jv?$f(e[n],e[n],a,1):t===sP&&B2(e[n],e[n],a,1)},r}(),Y1=function(){function r(e,t,n,a){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=e,this._loop=t,t&&a){N1("Can' use additive animation on looped animation.");return}this._additiveAnimators=a,this._allowDiscrete=n}return r.prototype.getMaxTime=function(){return this._maxTime},r.prototype.getDelay=function(){return this._delay},r.prototype.getLoop=function(){return this._loop},r.prototype.getTarget=function(){return this._target},r.prototype.changeTarget=function(e){this._target=e},r.prototype.when=function(e,t,n){return this.whenWithKeys(e,t,ue(t),n)},r.prototype.whenWithKeys=function(e,t,n,a){for(var i=this._tracks,o=0;o<n.length;o++){var s=n[o],l=i[s];if(!l){l=i[s]=new _8(s);var u=void 0,c=this._getAdditiveTrack(s);if(c){var h=c.keyframes,d=h[h.length-1];u=d&&d.value,c.valType===_c&&u&&(u=$v(u))}else u=this._target[s];if(u==null)continue;e>0&&l.addKeyframe(0,Ec(u),a),this._trackKeys.push(s)}l.addKeyframe(e,Ec(t[s]),a)}return this._maxTime=Math.max(this._maxTime,e),this},r.prototype.pause=function(){this._clip.pause(),this._paused=!0},r.prototype.resume=function(){this._clip.resume(),this._paused=!1},r.prototype.isPaused=function(){return!!this._paused},r.prototype.duration=function(e){return this._maxTime=e,this._force=!0,this},r.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var e=this._doneCbs;if(e)for(var t=e.length,n=0;n<t;n++)e[n].call(this)},r.prototype._abortedCallback=function(){this._setTracksFinished();var e=this.animation,t=this._abortedCbs;if(e&&e.removeClip(this._clip),this._clip=null,t)for(var n=0;n<t.length;n++)t[n].call(this)},r.prototype._setTracksFinished=function(){for(var e=this._tracks,t=this._trackKeys,n=0;n<t.length;n++)e[t[n]].setFinished()},r.prototype._getAdditiveTrack=function(e){var t,n=this._additiveAnimators;if(n)for(var a=0;a<n.length;a++){var i=n[a].getTrack(e);i&&(t=i)}return t},r.prototype.start=function(e){if(!(this._started>0)){this._started=1;for(var t=this,n=[],a=this._maxTime||0,i=0;i<this._trackKeys.length;i++){var o=this._trackKeys[i],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,c=u.length;if(s.prepare(a,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var h=u[c-1];h&&(t._target[s.propName]=h.rawValue),s.setFinished()}else n.push(s)}if(n.length||this._force){var d=new n8({life:a,loop:this._loop,delay:this._delay||0,onframe:function(v){t._started=2;var p=t._additiveAnimators;if(p){for(var y=!1,_=0;_<p.length;_++)if(p[_]._clip){y=!0;break}y||(t._additiveAnimators=null)}for(var _=0;_<n.length;_++)n[_].step(t._target,v);var g=t._onframeCbs;if(g)for(var _=0;_<g.length;_++)g[_](t._target,v)},ondestroy:function(){t._doneCallback()}});this._clip=d,this.animation&&this.animation.addClip(d),e&&d.setEasing(e)}else this._doneCallback();return this}},r.prototype.stop=function(e){if(this._clip){var t=this._clip;e&&t.onframe(1),this._abortedCallback()}},r.prototype.delay=function(e){return this._delay=e,this},r.prototype.during=function(e){return e&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(e)),this},r.prototype.done=function(e){return e&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(e)),this},r.prototype.aborted=function(e){return e&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(e)),this},r.prototype.getClip=function(){return this._clip},r.prototype.getTrack=function(e){return this._tracks[e]},r.prototype.getTracks=function(){var e=this;return ft(this._trackKeys,function(t){return e._tracks[t]})},r.prototype.stopTracks=function(e,t){if(!e.length||!this._clip)return!0;for(var n=this._tracks,a=this._trackKeys,i=0;i<e.length;i++){var o=n[e[i]];o&&!o.isFinished()&&(t?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,i=0;i<a.length;i++)if(!n[a[i]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},r.prototype.saveTo=function(e,t,n){if(e){t=t||this._trackKeys;for(var a=0;a<t.length;a++){var i=t[a],o=this._tracks[i];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[n?0:s.length-1];l&&(e[i]=Ec(l.rawValue))}}}},r.prototype.__changeFinalValue=function(e,t){t=t||ue(e);for(var n=0;n<t.length;n++){var a=t[n],i=this._tracks[a];if(i){var o=i.keyframes;if(o.length>1){var s=o.pop();i.addKeyframe(s.time,e[a]),i.prepare(this._maxTime,i.getAdditiveTrack())}}}},r}();function Fl(){return new Date().getTime()}var w8=function(r){Ge(e,r);function e(t){var n=r.call(this)||this;return n._running=!1,n._time=0,n._pausedTime=0,n._pauseStart=0,n._paused=!1,t=t||{},n.stage=t.stage||{},n}return e.prototype.addClip=function(t){t.animation&&this.removeClip(t),this._head?(this._tail.next=t,t.prev=this._tail,t.next=null,this._tail=t):this._head=this._tail=t,t.animation=this},e.prototype.addAnimator=function(t){t.animation=this;var n=t.getClip();n&&this.addClip(n)},e.prototype.removeClip=function(t){if(t.animation){var n=t.prev,a=t.next;n?n.next=a:this._head=a,a?a.prev=n:this._tail=n,t.next=t.prev=t.animation=null}},e.prototype.removeAnimator=function(t){var n=t.getClip();n&&this.removeClip(n),t.animation=null},e.prototype.update=function(t){for(var n=Fl()-this._pausedTime,a=n-this._time,i=this._head;i;){var o=i.next,s=i.step(n,a);s&&(i.ondestroy(),this.removeClip(i)),i=o}this._time=n,t||(this.trigger("frame",a),this.stage.update&&this.stage.update())},e.prototype._startLoop=function(){var t=this;this._running=!0;function n(){t._running&&(dd(n),!t._paused&&t.update())}dd(n)},e.prototype.start=function(){this._running||(this._time=Fl(),this._pausedTime=0,this._startLoop())},e.prototype.stop=function(){this._running=!1},e.prototype.pause=function(){this._paused||(this._pauseStart=Fl(),this._paused=!0)},e.prototype.resume=function(){this._paused&&(this._pausedTime+=Fl()-this._pauseStart,this._paused=!1)},e.prototype.clear=function(){for(var t=this._head;t;){var n=t.next;t.prev=t.next=t.animation=null,t=n}this._head=this._tail=null},e.prototype.isFinished=function(){return this._head==null},e.prototype.animate=function(t,n){n=n||{},this.start();var a=new Y1(t,n.loop);return this.addAnimator(a),a},e}(ea),x8=300,by=oe.domSupported,Sy=function(){var r=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],e=["touchstart","touchend","touchmove"],t={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},n=ft(r,function(a){var i=a.replace("mouse","pointer");return t.hasOwnProperty(i)?i:a});return{mouse:r,touch:e,pointer:n}}(),F2={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},V2=!1;function o_(r){var e=r.pointerType;return e==="pen"||e==="touch"}function b8(r){r.touching=!0,r.touchTimer!=null&&(clearTimeout(r.touchTimer),r.touchTimer=null),r.touchTimer=setTimeout(function(){r.touching=!1,r.touchTimer=null},700)}function Ay(r){r&&(r.zrByTouch=!0)}function S8(r,e){return Un(r.dom,new A8(r,e),!0)}function lP(r,e){for(var t=e,n=!1;t&&t.nodeType!==9&&!(n=t.domBelongToZr||t!==e&&t===r.painterRoot);)t=t.parentNode;return n}var A8=function(){function r(e,t){this.stopPropagation=tr,this.stopImmediatePropagation=tr,this.preventDefault=tr,this.type=t.type,this.target=this.currentTarget=e.dom,this.pointerType=t.pointerType,this.clientX=t.clientX,this.clientY=t.clientY}return r}(),fa={mousedown:function(r){r=Un(this.dom,r),this.__mayPointerCapture=[r.zrX,r.zrY],this.trigger("mousedown",r)},mousemove:function(r){r=Un(this.dom,r);var e=this.__mayPointerCapture;e&&(r.zrX!==e[0]||r.zrY!==e[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",r)},mouseup:function(r){r=Un(this.dom,r),this.__togglePointerCapture(!1),this.trigger("mouseup",r)},mouseout:function(r){r=Un(this.dom,r);var e=r.toElement||r.relatedTarget;lP(this,e)||(this.__pointerCapturing&&(r.zrEventControl="no_globalout"),this.trigger("mouseout",r))},wheel:function(r){V2=!0,r=Un(this.dom,r),this.trigger("mousewheel",r)},mousewheel:function(r){V2||(r=Un(this.dom,r),this.trigger("mousewheel",r))},touchstart:function(r){r=Un(this.dom,r),Ay(r),this.__lastTouchMoment=new Date,this.handler.processGesture(r,"start"),fa.mousemove.call(this,r),fa.mousedown.call(this,r)},touchmove:function(r){r=Un(this.dom,r),Ay(r),this.handler.processGesture(r,"change"),fa.mousemove.call(this,r)},touchend:function(r){r=Un(this.dom,r),Ay(r),this.handler.processGesture(r,"end"),fa.mouseup.call(this,r),+new Date-+this.__lastTouchMoment<x8&&fa.click.call(this,r)},pointerdown:function(r){fa.mousedown.call(this,r)},pointermove:function(r){o_(r)||fa.mousemove.call(this,r)},pointerup:function(r){fa.mouseup.call(this,r)},pointerout:function(r){o_(r)||fa.mouseout.call(this,r)}};B(["click","dblclick","contextmenu"],function(r){fa[r]=function(e){e=Un(this.dom,e),this.trigger(r,e)}});var s_={pointermove:function(r){o_(r)||s_.mousemove.call(this,r)},pointerup:function(r){s_.mouseup.call(this,r)},mousemove:function(r){this.trigger("mousemove",r)},mouseup:function(r){var e=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",r),e&&(r.zrEventControl="only_globalout",this.trigger("mouseout",r))}};function T8(r,e){var t=e.domHandlers;oe.pointerEventsSupported?B(Sy.pointer,function(n){qv(e,n,function(a){t[n].call(r,a)})}):(oe.touchEventsSupported&&B(Sy.touch,function(n){qv(e,n,function(a){t[n].call(r,a),b8(e)})}),B(Sy.mouse,function(n){qv(e,n,function(a){a=G1(a),e.touching||t[n].call(r,a)})}))}function C8(r,e){oe.pointerEventsSupported?B(F2.pointer,t):oe.touchEventsSupported||B(F2.mouse,t);function t(n){function a(i){i=G1(i),lP(r,i.target)||(i=S8(r,i),e.domHandlers[n].call(r,i))}qv(e,n,a,{capture:!0})}}function qv(r,e,t,n){r.mounted[e]=t,r.listenerOpts[e]=n,q0(r.domTarget,e,t,n)}function Ty(r){var e=r.mounted;for(var t in e)e.hasOwnProperty(t)&&V6(r.domTarget,t,e[t],r.listenerOpts[t]);r.mounted={}}var G2=function(){function r(e,t){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=e,this.domHandlers=t}return r}(),L8=function(r){Ge(e,r);function e(t,n){var a=r.call(this)||this;return a.__pointerCapturing=!1,a.dom=t,a.painterRoot=n,a._localHandlerScope=new G2(t,fa),by&&(a._globalHandlerScope=new G2(document,s_)),T8(a,a._localHandlerScope),a}return e.prototype.dispose=function(){Ty(this._localHandlerScope),by&&Ty(this._globalHandlerScope)},e.prototype.setCursor=function(t){this.dom.style&&(this.dom.style.cursor=t||"default")},e.prototype.__togglePointerCapture=function(t){if(this.__mayPointerCapture=null,by&&+this.__pointerCapturing^+t){this.__pointerCapturing=t;var n=this._globalHandlerScope;t?C8(this,n):Ty(n)}},e}(ea),uP=1;oe.hasGlobalWindow&&(uP=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var wd=uP,l_=.4,u_="#333",c_="#ccc",M8="#eee",W2=vp,H2=5e-5;function Wo(r){return r>H2||r<-H2}var Ho=[],dl=[],Cy=Ln(),Ly=Math.abs,gi=function(){function r(){}return r.prototype.getLocalTransform=function(e){return r.getLocalTransform(this,e)},r.prototype.setPosition=function(e){this.x=e[0],this.y=e[1]},r.prototype.setScale=function(e){this.scaleX=e[0],this.scaleY=e[1]},r.prototype.setSkew=function(e){this.skewX=e[0],this.skewY=e[1]},r.prototype.setOrigin=function(e){this.originX=e[0],this.originY=e[1]},r.prototype.needLocalTransform=function(){return Wo(this.rotation)||Wo(this.x)||Wo(this.y)||Wo(this.scaleX-1)||Wo(this.scaleY-1)||Wo(this.skewX)||Wo(this.skewY)},r.prototype.updateTransform=function(){var e=this.parent&&this.parent.transform,t=this.needLocalTransform(),n=this.transform;if(!(t||e)){n&&(W2(n),this.invTransform=null);return}n=n||Ln(),t?this.getLocalTransform(n):W2(n),e&&(t?_i(n,e,n):W1(n,e)),this.transform=n,this._resolveGlobalScaleRatio(n)},r.prototype._resolveGlobalScaleRatio=function(e){var t=this.globalScaleRatio;if(t!=null&&t!==1){this.getGlobalScale(Ho);var n=Ho[0]<0?-1:1,a=Ho[1]<0?-1:1,i=((Ho[0]-n)*t+n)/Ho[0]||0,o=((Ho[1]-a)*t+a)/Ho[1]||0;e[0]*=i,e[1]*=i,e[2]*=o,e[3]*=o}this.invTransform=this.invTransform||Ln(),cu(this.invTransform,e)},r.prototype.getComputedTransform=function(){for(var e=this,t=[];e;)t.push(e),e=e.parent;for(;e=t.pop();)e.updateTransform();return this.transform},r.prototype.setLocalTransform=function(e){if(e){var t=e[0]*e[0]+e[1]*e[1],n=e[2]*e[2]+e[3]*e[3],a=Math.atan2(e[1],e[0]),i=Math.PI/2+a-Math.atan2(e[3],e[2]);n=Math.sqrt(n)*Math.cos(i),t=Math.sqrt(t),this.skewX=i,this.skewY=0,this.rotation=-a,this.x=+e[4],this.y=+e[5],this.scaleX=t,this.scaleY=n,this.originX=0,this.originY=0}},r.prototype.decomposeTransform=function(){if(this.transform){var e=this.parent,t=this.transform;e&&e.transform&&(e.invTransform=e.invTransform||Ln(),_i(dl,e.invTransform,t),t=dl);var n=this.originX,a=this.originY;(n||a)&&(Cy[4]=n,Cy[5]=a,_i(dl,t,Cy),dl[4]-=n,dl[5]-=a,t=dl),this.setLocalTransform(t)}},r.prototype.getGlobalScale=function(e){var t=this.transform;return e=e||[],t?(e[0]=Math.sqrt(t[0]*t[0]+t[1]*t[1]),e[1]=Math.sqrt(t[2]*t[2]+t[3]*t[3]),t[0]<0&&(e[0]=-e[0]),t[3]<0&&(e[1]=-e[1]),e):(e[0]=1,e[1]=1,e)},r.prototype.transformCoordToLocal=function(e,t){var n=[e,t],a=this.invTransform;return a&&Pr(n,n,a),n},r.prototype.transformCoordToGlobal=function(e,t){var n=[e,t],a=this.transform;return a&&Pr(n,n,a),n},r.prototype.getLineScale=function(){var e=this.transform;return e&&Ly(e[0]-1)>1e-10&&Ly(e[3]-1)>1e-10?Math.sqrt(Ly(e[0]*e[3]-e[2]*e[1])):1},r.prototype.copyTransform=function(e){cP(this,e)},r.getLocalTransform=function(e,t){t=t||[];var n=e.originX||0,a=e.originY||0,i=e.scaleX,o=e.scaleY,s=e.anchorX,l=e.anchorY,u=e.rotation||0,c=e.x,h=e.y,d=e.skewX?Math.tan(e.skewX):0,v=e.skewY?Math.tan(-e.skewY):0;if(n||a||s||l){var p=n+s,y=a+l;t[4]=-p*i-d*y*o,t[5]=-y*o-v*p*i}else t[4]=t[5]=0;return t[0]=i,t[3]=o,t[1]=v*i,t[2]=d*o,u&&Hs(t,t,u),t[4]+=n+c,t[5]+=a+h,t},r.initDefaultProps=function(){var e=r.prototype;e.scaleX=e.scaleY=e.globalScaleRatio=1,e.x=e.y=e.originX=e.originY=e.skewX=e.skewY=e.rotation=e.anchorX=e.anchorY=0}(),r}(),Xa=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function cP(r,e){for(var t=0;t<Xa.length;t++){var n=Xa[t];r[n]=e[n]}}var U2={};function Dn(r,e){e=e||mo;var t=U2[e];t||(t=U2[e]=new Ah(500));var n=t.get(r);return n==null&&(n=_o.measureText(r,e).width,t.put(r,n)),n}function Z2(r,e,t,n){var a=Dn(r,e),i=pp(e),o=wc(0,a,t),s=Ol(0,i,n),l=new Qt(o,s,a,i);return l}function Th(r,e,t,n){var a=((r||"")+"").split(`
`),i=a.length;if(i===1)return Z2(a[0],e,t,n);for(var o=new Qt(0,0,0,0),s=0;s<a.length;s++){var l=Z2(a[s],e,t,n);s===0?o.copy(l):o.union(l)}return o}function wc(r,e,t){return t==="right"?r-=e:t==="center"&&(r-=e/2),r}function Ol(r,e,t){return t==="middle"?r-=e/2:t==="bottom"&&(r-=e),r}function pp(r){return Dn("国",r)}function wa(r,e){return typeof r=="string"?r.lastIndexOf("%")>=0?parseFloat(r)/100*e:parseFloat(r):r}function xd(r,e,t){var n=e.position||"inside",a=e.distance!=null?e.distance:5,i=t.height,o=t.width,s=i/2,l=t.x,u=t.y,c="left",h="top";if(n instanceof Array)l+=wa(n[0],t.width),u+=wa(n[1],t.height),c=null,h=null;else switch(n){case"left":l-=a,u+=s,c="right",h="middle";break;case"right":l+=a+o,u+=s,h="middle";break;case"top":l+=o/2,u-=a,c="center",h="bottom";break;case"bottom":l+=o/2,u+=i+a,c="center";break;case"inside":l+=o/2,u+=s,c="center",h="middle";break;case"insideLeft":l+=a,u+=s,h="middle";break;case"insideRight":l+=o-a,u+=s,c="right",h="middle";break;case"insideTop":l+=o/2,u+=a,c="center";break;case"insideBottom":l+=o/2,u+=i-a,c="center",h="bottom";break;case"insideTopLeft":l+=a,u+=a;break;case"insideTopRight":l+=o-a,u+=a,c="right";break;case"insideBottomLeft":l+=a,u+=i-a,h="bottom";break;case"insideBottomRight":l+=o-a,u+=i-a,c="right",h="bottom";break}return r=r||{},r.x=l,r.y=u,r.align=c,r.verticalAlign=h,r}var My="__zr_normal__",Dy=Xa.concat(["ignore"]),D8=Za(Xa,function(r,e){return r[e]=!0,r},{ignore:!1}),pl={},I8=new Qt(0,0,0,0),gp=function(){function r(e){this.id=zI(),this.animators=[],this.currentStates=[],this.states={},this._init(e)}return r.prototype._init=function(e){this.attr(e)},r.prototype.drift=function(e,t,n){switch(this.draggable){case"horizontal":t=0;break;case"vertical":e=0;break}var a=this.transform;a||(a=this.transform=[1,0,0,1,0,0]),a[4]+=e,a[5]+=t,this.decomposeTransform(),this.markRedraw()},r.prototype.beforeUpdate=function(){},r.prototype.afterUpdate=function(){},r.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},r.prototype.updateInnerText=function(e){var t=this._textContent;if(t&&(!t.ignore||e)){this.textConfig||(this.textConfig={});var n=this.textConfig,a=n.local,i=t.innerTransformable,o=void 0,s=void 0,l=!1;i.parent=a?this:null;var u=!1;if(i.copyTransform(t),n.position!=null){var c=I8;n.layoutRect?c.copy(n.layoutRect):c.copy(this.getBoundingRect()),a||c.applyTransform(this.transform),this.calculateTextPosition?this.calculateTextPosition(pl,n,c):xd(pl,n,c),i.x=pl.x,i.y=pl.y,o=pl.align,s=pl.verticalAlign;var h=n.origin;if(h&&n.rotation!=null){var d=void 0,v=void 0;h==="center"?(d=c.width*.5,v=c.height*.5):(d=wa(h[0],c.width),v=wa(h[1],c.height)),u=!0,i.originX=-i.x+d+(a?0:c.x),i.originY=-i.y+v+(a?0:c.y)}}n.rotation!=null&&(i.rotation=n.rotation);var p=n.offset;p&&(i.x+=p[0],i.y+=p[1],u||(i.originX=-p[0],i.originY=-p[1]));var y=n.inside==null?typeof n.position=="string"&&n.position.indexOf("inside")>=0:n.inside,_=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={}),g=void 0,f=void 0,w=void 0;y&&this.canBeInsideText()?(g=n.insideFill,f=n.insideStroke,(g==null||g==="auto")&&(g=this.getInsideTextFill()),(f==null||f==="auto")&&(f=this.getInsideTextStroke(g),w=!0)):(g=n.outsideFill,f=n.outsideStroke,(g==null||g==="auto")&&(g=this.getOutsideFill()),(f==null||f==="auto")&&(f=this.getOutsideStroke(g),w=!0)),g=g||"#000",(g!==_.fill||f!==_.stroke||w!==_.autoStroke||o!==_.align||s!==_.verticalAlign)&&(l=!0,_.fill=g,_.stroke=f,_.autoStroke=w,_.align=o,_.verticalAlign=s,t.setDefaultTextStyle(_)),t.__dirty|=Tn,l&&t.dirtyStyle(!0)}},r.prototype.canBeInsideText=function(){return!0},r.prototype.getInsideTextFill=function(){return"#fff"},r.prototype.getInsideTextStroke=function(e){return"#000"},r.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?c_:u_},r.prototype.getOutsideStroke=function(e){var t=this.__zr&&this.__zr.getBackgroundColor(),n=typeof t=="string"&&Mn(t);n||(n=[255,255,255,1]);for(var a=n[3],i=this.__zr.isDarkMode(),o=0;o<3;o++)n[o]=n[o]*a+(i?0:255)*(1-a);return n[3]=1,wi(n,"rgba")},r.prototype.traverse=function(e,t){},r.prototype.attrKV=function(e,t){e==="textConfig"?this.setTextConfig(t):e==="textContent"?this.setTextContent(t):e==="clipPath"?this.setClipPath(t):e==="extra"?(this.extra=this.extra||{},lt(this.extra,t)):this[e]=t},r.prototype.hide=function(){this.ignore=!0,this.markRedraw()},r.prototype.show=function(){this.ignore=!1,this.markRedraw()},r.prototype.attr=function(e,t){if(typeof e=="string")this.attrKV(e,t);else if(Vt(e))for(var n=e,a=ue(n),i=0;i<a.length;i++){var o=a[i];this.attrKV(o,e[o])}return this.markRedraw(),this},r.prototype.saveCurrentToNormalState=function(e){this._innerSaveToNormal(e);for(var t=this._normalState,n=0;n<this.animators.length;n++){var a=this.animators[n],i=a.__fromStateTransition;if(!(a.getLoop()||i&&i!==My)){var o=a.targetName,s=o?t[o]:t;a.saveTo(s)}}},r.prototype._innerSaveToNormal=function(e){var t=this._normalState;t||(t=this._normalState={}),e.textConfig&&!t.textConfig&&(t.textConfig=this.textConfig),this._savePrimaryToNormal(e,t,Dy)},r.prototype._savePrimaryToNormal=function(e,t,n){for(var a=0;a<n.length;a++){var i=n[a];e[i]!=null&&!(i in t)&&(t[i]=this[i])}},r.prototype.hasState=function(){return this.currentStates.length>0},r.prototype.getState=function(e){return this.states[e]},r.prototype.ensureState=function(e){var t=this.states;return t[e]||(t[e]={}),t[e]},r.prototype.clearStates=function(e){this.useState(My,!1,e)},r.prototype.useState=function(e,t,n,a){var i=e===My,o=this.hasState();if(!(!o&&i)){var s=this.currentStates,l=this.stateTransition;if(!(te(s,e)>=0&&(t||s.length===1))){var u;if(this.stateProxy&&!i&&(u=this.stateProxy(e)),u||(u=this.states&&this.states[e]),!u&&!i){N1("State "+e+" not exists.");return}i||this.saveCurrentToNormalState(u);var c=!!(u&&u.hoverLayer||a);c&&this._toggleHoverLayerFlag(!0),this._applyStateObj(e,u,this._normalState,t,!n&&!this.__inHover&&l&&l.duration>0,l);var h=this._textContent,d=this._textGuide;return h&&h.useState(e,t,n,c),d&&d.useState(e,t,n,c),i?(this.currentStates=[],this._normalState={}):t?this.currentStates.push(e):this.currentStates=[e],this._updateAnimationTargets(),this.markRedraw(),!c&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~Tn),u}}},r.prototype.useStates=function(e,t,n){if(!e.length)this.clearStates();else{var a=[],i=this.currentStates,o=e.length,s=o===i.length;if(s){for(var l=0;l<o;l++)if(e[l]!==i[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=e[l],c=void 0;this.stateProxy&&(c=this.stateProxy(u,e)),c||(c=this.states[u]),c&&a.push(c)}var h=a[o-1],d=!!(h&&h.hoverLayer||n);d&&this._toggleHoverLayerFlag(!0);var v=this._mergeStates(a),p=this.stateTransition;this.saveCurrentToNormalState(v),this._applyStateObj(e.join(","),v,this._normalState,!1,!t&&!this.__inHover&&p&&p.duration>0,p);var y=this._textContent,_=this._textGuide;y&&y.useStates(e,t,d),_&&_.useStates(e,t,d),this._updateAnimationTargets(),this.currentStates=e.slice(),this.markRedraw(),!d&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~Tn)}},r.prototype.isSilent=function(){for(var e=this.silent,t=this.parent;!e&&t;){if(t.silent){e=!0;break}t=t.parent}return e},r.prototype._updateAnimationTargets=function(){for(var e=0;e<this.animators.length;e++){var t=this.animators[e];t.targetName&&t.changeTarget(this[t.targetName])}},r.prototype.removeState=function(e){var t=te(this.currentStates,e);if(t>=0){var n=this.currentStates.slice();n.splice(t,1),this.useStates(n)}},r.prototype.replaceState=function(e,t,n){var a=this.currentStates.slice(),i=te(a,e),o=te(a,t)>=0;i>=0?o?a.splice(i,1):a[i]=t:n&&!o&&a.push(t),this.useStates(a)},r.prototype.toggleState=function(e,t){t?this.useState(e,!0):this.removeState(e)},r.prototype._mergeStates=function(e){for(var t={},n,a=0;a<e.length;a++){var i=e[a];lt(t,i),i.textConfig&&(n=n||{},lt(n,i.textConfig))}return n&&(t.textConfig=n),t},r.prototype._applyStateObj=function(e,t,n,a,i,o){var s=!(t&&a);t&&t.textConfig?(this.textConfig=lt({},a?this.textConfig:n.textConfig),lt(this.textConfig,t.textConfig)):s&&n.textConfig&&(this.textConfig=n.textConfig);for(var l={},u=!1,c=0;c<Dy.length;c++){var h=Dy[c],d=i&&D8[h];t&&t[h]!=null?d?(u=!0,l[h]=t[h]):this[h]=t[h]:s&&n[h]!=null&&(d?(u=!0,l[h]=n[h]):this[h]=n[h])}if(!i)for(var c=0;c<this.animators.length;c++){var v=this.animators[c],p=v.targetName;v.getLoop()||v.__changeFinalValue(p?(t||n)[p]:t||n)}u&&this._transitionState(e,l,o)},r.prototype._attachComponent=function(e){if(!(e.__zr&&!e.__hostTarget)&&e!==this){var t=this.__zr;t&&e.addSelfToZr(t),e.__zr=t,e.__hostTarget=this}},r.prototype._detachComponent=function(e){e.__zr&&e.removeSelfFromZr(e.__zr),e.__zr=null,e.__hostTarget=null},r.prototype.getClipPath=function(){return this._clipPath},r.prototype.setClipPath=function(e){this._clipPath&&this._clipPath!==e&&this.removeClipPath(),this._attachComponent(e),this._clipPath=e,this.markRedraw()},r.prototype.removeClipPath=function(){var e=this._clipPath;e&&(this._detachComponent(e),this._clipPath=null,this.markRedraw())},r.prototype.getTextContent=function(){return this._textContent},r.prototype.setTextContent=function(e){var t=this._textContent;t!==e&&(t&&t!==e&&this.removeTextContent(),e.innerTransformable=new gi,this._attachComponent(e),this._textContent=e,this.markRedraw())},r.prototype.setTextConfig=function(e){this.textConfig||(this.textConfig={}),lt(this.textConfig,e),this.markRedraw()},r.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},r.prototype.removeTextContent=function(){var e=this._textContent;e&&(e.innerTransformable=null,this._detachComponent(e),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},r.prototype.getTextGuideLine=function(){return this._textGuide},r.prototype.setTextGuideLine=function(e){this._textGuide&&this._textGuide!==e&&this.removeTextGuideLine(),this._attachComponent(e),this._textGuide=e,this.markRedraw()},r.prototype.removeTextGuideLine=function(){var e=this._textGuide;e&&(this._detachComponent(e),this._textGuide=null,this.markRedraw())},r.prototype.markRedraw=function(){this.__dirty|=Tn;var e=this.__zr;e&&(this.__inHover?e.refreshHover():e.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},r.prototype.dirty=function(){this.markRedraw()},r.prototype._toggleHoverLayerFlag=function(e){this.__inHover=e;var t=this._textContent,n=this._textGuide;t&&(t.__inHover=e),n&&(n.__inHover=e)},r.prototype.addSelfToZr=function(e){if(this.__zr!==e){this.__zr=e;var t=this.animators;if(t)for(var n=0;n<t.length;n++)e.animation.addAnimator(t[n]);this._clipPath&&this._clipPath.addSelfToZr(e),this._textContent&&this._textContent.addSelfToZr(e),this._textGuide&&this._textGuide.addSelfToZr(e)}},r.prototype.removeSelfFromZr=function(e){if(this.__zr){this.__zr=null;var t=this.animators;if(t)for(var n=0;n<t.length;n++)e.animation.removeAnimator(t[n]);this._clipPath&&this._clipPath.removeSelfFromZr(e),this._textContent&&this._textContent.removeSelfFromZr(e),this._textGuide&&this._textGuide.removeSelfFromZr(e)}},r.prototype.animate=function(e,t,n){var a=e?this[e]:this,i=new Y1(a,t,n);return e&&(i.targetName=e),this.addAnimator(i,e),i},r.prototype.addAnimator=function(e,t){var n=this.__zr,a=this;e.during(function(){a.updateDuringAnimation(t)}).done(function(){var i=a.animators,o=te(i,e);o>=0&&i.splice(o,1)}),this.animators.push(e),n&&n.animation.addAnimator(e),n&&n.wakeUp()},r.prototype.updateDuringAnimation=function(e){this.markRedraw()},r.prototype.stopAnimation=function(e,t){for(var n=this.animators,a=n.length,i=[],o=0;o<a;o++){var s=n[o];!e||e===s.scope?s.stop(t):i.push(s)}return this.animators=i,this},r.prototype.animateTo=function(e,t,n){Iy(this,e,t,n)},r.prototype.animateFrom=function(e,t,n){Iy(this,e,t,n,!0)},r.prototype._transitionState=function(e,t,n,a){for(var i=Iy(this,t,n,a),o=0;o<i.length;o++)i[o].__fromStateTransition=e},r.prototype.getBoundingRect=function(){return null},r.prototype.getPaintRect=function(){return null},r.initDefaultProps=function(){var e=r.prototype;e.type="element",e.name="",e.ignore=e.silent=e.isGroup=e.draggable=e.dragging=e.ignoreClip=e.__inHover=!1,e.__dirty=Tn;function t(n,a,i,o){Object.defineProperty(e,n,{get:function(){if(!this[a]){var l=this[a]=[];s(this,l)}return this[a]},set:function(l){this[i]=l[0],this[o]=l[1],this[a]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[i]},set:function(c){l[i]=c}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(c){l[o]=c}})}}Object.defineProperty&&(t("position","_legacyPos","x","y"),t("scale","_legacyScale","scaleX","scaleY"),t("origin","_legacyOrigin","originX","originY"))}(),r}();sr(gp,ea);sr(gp,gi);function Iy(r,e,t,n,a){t=t||{};var i=[];hP(r,"",r,e,t,n,i,a);var o=i.length,s=!1,l=t.done,u=t.aborted,c=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},h=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),i.length>0&&t.during&&i[0].during(function(p,y){t.during(y)});for(var d=0;d<i.length;d++){var v=i[d];c&&v.done(c),h&&v.aborted(h),t.force&&v.duration(t.duration),v.start(t.easing)}return i}function Py(r,e,t){for(var n=0;n<t;n++)r[n]=e[n]}function P8(r){return Gr(r[0])}function k8(r,e,t){if(Gr(e[t]))if(Gr(r[t])||(r[t]=[]),pn(e[t])){var n=e[t].length;r[t].length!==n&&(r[t]=new e[t].constructor(n),Py(r[t],e[t],n))}else{var a=e[t],i=r[t],o=a.length;if(P8(a))for(var s=a[0].length,l=0;l<o;l++)i[l]?Py(i[l],a[l],s):i[l]=Array.prototype.slice.call(a[l]);else Py(i,a,o);i.length=a.length}else r[t]=e[t]}function R8(r,e){return r===e||Gr(r)&&Gr(e)&&E8(r,e)}function E8(r,e){var t=r.length;if(t!==e.length)return!1;for(var n=0;n<t;n++)if(r[n]!==e[n])return!1;return!0}function hP(r,e,t,n,a,i,o,s){for(var l=ue(n),u=a.duration,c=a.delay,h=a.additive,d=a.setToFinal,v=!Vt(i),p=r.animators,y=[],_=0;_<l.length;_++){var g=l[_],f=n[g];if(f!=null&&t[g]!=null&&(v||i[g]))if(Vt(f)&&!Gr(f)&&!hp(f)){if(e){s||(t[g]=f,r.updateDuringAnimation(e));continue}hP(r,g,t[g],f,a,i&&i[g],o,s)}else y.push(g);else s||(t[g]=f,r.updateDuringAnimation(e),y.push(g))}var w=y.length;if(!h&&w)for(var x=0;x<p.length;x++){var S=p[x];if(S.targetName===e){var A=S.stopTracks(y);if(A){var T=te(p,S);p.splice(T,1)}}}if(a.force||(y=Te(y,function(R){return!R8(n[R],t[R])}),w=y.length),w>0||a.force&&!o.length){var L=void 0,M=void 0,I=void 0;if(s){M={},d&&(L={});for(var x=0;x<w;x++){var g=y[x];M[g]=t[g],d?L[g]=n[g]:t[g]=n[g]}}else if(d){I={};for(var x=0;x<w;x++){var g=y[x];I[g]=Ec(t[g]),k8(t,n,g)}}var S=new Y1(t,!1,!1,h?Te(p,function(P){return P.targetName===e}):null);S.targetName=e,a.scope&&(S.scope=a.scope),d&&L&&S.whenWithKeys(0,L,y),I&&S.whenWithKeys(0,I,y),S.whenWithKeys(u??500,s?M:n,y).delay(c||0),r.addAnimator(S,e),o.push(S)}}var Wt=function(r){Ge(e,r);function e(t){var n=r.call(this)||this;return n.isGroup=!0,n._children=[],n.attr(t),n}return e.prototype.childrenRef=function(){return this._children},e.prototype.children=function(){return this._children.slice()},e.prototype.childAt=function(t){return this._children[t]},e.prototype.childOfName=function(t){for(var n=this._children,a=0;a<n.length;a++)if(n[a].name===t)return n[a]},e.prototype.childCount=function(){return this._children.length},e.prototype.add=function(t){return t&&t!==this&&t.parent!==this&&(this._children.push(t),this._doAdd(t)),this},e.prototype.addBefore=function(t,n){if(t&&t!==this&&t.parent!==this&&n&&n.parent===this){var a=this._children,i=a.indexOf(n);i>=0&&(a.splice(i,0,t),this._doAdd(t))}return this},e.prototype.replace=function(t,n){var a=te(this._children,t);return a>=0&&this.replaceAt(n,a),this},e.prototype.replaceAt=function(t,n){var a=this._children,i=a[n];if(t&&t!==this&&t.parent!==this&&t!==i){a[n]=t,i.parent=null;var o=this.__zr;o&&i.removeSelfFromZr(o),this._doAdd(t)}return this},e.prototype._doAdd=function(t){t.parent&&t.parent.remove(t),t.parent=this;var n=this.__zr;n&&n!==t.__zr&&t.addSelfToZr(n),n&&n.refresh()},e.prototype.remove=function(t){var n=this.__zr,a=this._children,i=te(a,t);return i<0?this:(a.splice(i,1),t.parent=null,n&&t.removeSelfFromZr(n),n&&n.refresh(),this)},e.prototype.removeAll=function(){for(var t=this._children,n=this.__zr,a=0;a<t.length;a++){var i=t[a];n&&i.removeSelfFromZr(n),i.parent=null}return t.length=0,this},e.prototype.eachChild=function(t,n){for(var a=this._children,i=0;i<a.length;i++){var o=a[i];t.call(n,o,i)}return this},e.prototype.traverse=function(t,n){for(var a=0;a<this._children.length;a++){var i=this._children[a],o=t.call(n,i);i.isGroup&&!o&&i.traverse(t,n)}return this},e.prototype.addSelfToZr=function(t){r.prototype.addSelfToZr.call(this,t);for(var n=0;n<this._children.length;n++){var a=this._children[n];a.addSelfToZr(t)}},e.prototype.removeSelfFromZr=function(t){r.prototype.removeSelfFromZr.call(this,t);for(var n=0;n<this._children.length;n++){var a=this._children[n];a.removeSelfFromZr(t)}},e.prototype.getBoundingRect=function(t){for(var n=new Qt(0,0,0,0),a=t||this._children,i=[],o=null,s=0;s<a.length;s++){var l=a[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),c=l.getLocalTransform(i);c?(Qt.applyTransform(n,u,c),o=o||n.clone(),o.union(n)):(o=o||u.clone(),o.union(u))}}return o||n},e}(gp);Wt.prototype.type="group";/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var Kv={},fP={};function O8(r){delete fP[r]}function B8(r){if(!r)return!1;if(typeof r=="string")return md(r,1)<l_;if(r.colorStops){for(var e=r.colorStops,t=0,n=e.length,a=0;a<n;a++)t+=md(e[a].color,1);return t/=n,t<l_}return!1}var N8=function(){function r(e,t,n){var a=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,n=n||{},this.dom=t,this.id=e;var i=new Q6,o=n.renderer||"canvas";Kv[o]||(o=ue(Kv)[0]),n.useDirtyRect=n.useDirtyRect==null?!1:n.useDirtyRect;var s=new Kv[o](t,i,n,e),l=n.ssr||s.ssrOnly;this.storage=i,this.painter=s;var u=!oe.node&&!oe.worker&&!l?new L8(s.getViewportRoot(),s.root):null,c=n.useCoarsePointer,h=c==null||c==="auto"?oe.touchEventsSupported:!!c,d=44,v;h&&(v=Zt(n.pointerSize,d)),this.handler=new UI(i,s,u,s.root,v),this.animation=new w8({stage:{update:l?null:function(){return a._flush(!0)}}}),l||this.animation.start()}return r.prototype.add=function(e){this._disposed||!e||(this.storage.addRoot(e),e.addSelfToZr(this),this.refresh())},r.prototype.remove=function(e){this._disposed||!e||(this.storage.delRoot(e),e.removeSelfFromZr(this),this.refresh())},r.prototype.configLayer=function(e,t){this._disposed||(this.painter.configLayer&&this.painter.configLayer(e,t),this.refresh())},r.prototype.setBackgroundColor=function(e){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(e),this.refresh(),this._backgroundColor=e,this._darkMode=B8(e))},r.prototype.getBackgroundColor=function(){return this._backgroundColor},r.prototype.setDarkMode=function(e){this._darkMode=e},r.prototype.isDarkMode=function(){return this._darkMode},r.prototype.refreshImmediately=function(e){this._disposed||(e||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},r.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},r.prototype.flush=function(){this._disposed||this._flush(!1)},r.prototype._flush=function(e){var t,n=Fl();this._needsRefresh&&(t=!0,this.refreshImmediately(e)),this._needsRefreshHover&&(t=!0,this.refreshHoverImmediately());var a=Fl();t?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:a-n})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},r.prototype.setSleepAfterStill=function(e){this._sleepAfterStill=e},r.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},r.prototype.refreshHover=function(){this._needsRefreshHover=!0},r.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},r.prototype.resize=function(e){this._disposed||(e=e||{},this.painter.resize(e.width,e.height),this.handler.resize())},r.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},r.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},r.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},r.prototype.setCursorStyle=function(e){this._disposed||this.handler.setCursorStyle(e)},r.prototype.findHover=function(e,t){if(!this._disposed)return this.handler.findHover(e,t)},r.prototype.on=function(e,t,n){return this._disposed||this.handler.on(e,t,n),this},r.prototype.off=function(e,t){this._disposed||this.handler.off(e,t)},r.prototype.trigger=function(e,t){this._disposed||this.handler.trigger(e,t)},r.prototype.clear=function(){if(!this._disposed){for(var e=this.storage.getRoots(),t=0;t<e.length;t++)e[t]instanceof Wt&&e[t].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},r.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,O8(this.id))},r}();function Y2(r,e){var t=new N8(zI(),r,e);return fP[t.id]=t,t}function z8(r,e){Kv[r]=e}var h_;function F8(r){if(typeof h_=="function")return h_(r)}function V8(r){h_=r}var X2=1e-4,vP=20;function G8(r){return r.replace(/^\s+|\s+$/g,"")}function Me(r,e,t,n){var a=e[0],i=e[1],o=t[0],s=t[1],l=i-a,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(n)if(l>0){if(r<=a)return o;if(r>=i)return s}else{if(r>=a)return o;if(r<=i)return s}else{if(r===a)return o;if(r===i)return s}return(r-a)/l*u+o}function At(r,e){switch(r){case"center":case"middle":r="50%";break;case"left":case"top":r="0%";break;case"right":case"bottom":r="100%";break}return Lt(r)?G8(r).match(/%$/)?parseFloat(r)/100*e:parseFloat(r):r==null?NaN:+r}function qe(r,e,t){return e==null&&(e=10),e=Math.min(Math.max(0,e),vP),r=(+r).toFixed(e),t?r:+r}function Qn(r){return r.sort(function(e,t){return e-t}),r}function Fa(r){if(r=+r,isNaN(r))return 0;if(r>1e-14){for(var e=1,t=0;t<15;t++,e*=10)if(Math.round(r*e)/e===r)return t}return W8(r)}function W8(r){var e=r.toString().toLowerCase(),t=e.indexOf("e"),n=t>0?+e.slice(t+1):0,a=t>0?t:e.length,i=e.indexOf("."),o=i<0?0:a-1-i;return Math.max(0,o-n)}function dP(r,e){var t=Math.log,n=Math.LN10,a=Math.floor(t(r[1]-r[0])/n),i=Math.round(t(Math.abs(e[1]-e[0]))/n),o=Math.min(Math.max(-a+i,0),20);return isFinite(o)?o:20}function H8(r,e){var t=Za(r,function(v,p){return v+(isNaN(p)?0:p)},0);if(t===0)return[];for(var n=Math.pow(10,e),a=ft(r,function(v){return(isNaN(v)?0:v)/t*n*100}),i=n*100,o=ft(a,function(v){return Math.floor(v)}),s=Za(o,function(v,p){return v+p},0),l=ft(a,function(v,p){return v-o[p]});s<i;){for(var u=Number.NEGATIVE_INFINITY,c=null,h=0,d=l.length;h<d;++h)l[h]>u&&(u=l[h],c=h);++o[c],l[c]=0,++s}return ft(o,function(v){return v/n})}function U8(r,e){var t=Math.max(Fa(r),Fa(e)),n=r+e;return t>vP?n:qe(n,t)}var $2=9007199254740991;function pP(r){var e=Math.PI*2;return(r%e+e)%e}function Qc(r){return r>-X2&&r<X2}var Z8=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function $a(r){if(r instanceof Date)return r;if(Lt(r)){var e=Z8.exec(r);if(!e)return new Date(NaN);if(e[8]){var t=+e[4]||0;return e[8].toUpperCase()!=="Z"&&(t-=+e[8].slice(0,3)),new Date(Date.UTC(+e[1],+(e[2]||1)-1,+e[3]||1,t,+(e[5]||0),+e[6]||0,e[7]?+e[7].substring(0,3):0))}else return new Date(+e[1],+(e[2]||1)-1,+e[3]||1,+e[4]||0,+(e[5]||0),+e[6]||0,e[7]?+e[7].substring(0,3):0)}else if(r==null)return new Date(NaN);return new Date(Math.round(r))}function Y8(r){return Math.pow(10,X1(r))}function X1(r){if(r===0)return 0;var e=Math.floor(Math.log(r)/Math.LN10);return r/Math.pow(10,e)>=10&&e++,e}function gP(r,e){var t=X1(r),n=Math.pow(10,t),a=r/n,i;return a<1.5?i=1:a<2.5?i=2:a<4?i=3:a<7?i=5:i=10,r=i*n,t>=-20?+r.toFixed(t<0?-t:0):r}function ky(r,e){var t=(r.length-1)*e+1,n=Math.floor(t),a=+r[n-1],i=t-n;return i?a+i*(r[n]-a):a}function j2(r){r.sort(function(l,u){return s(l,u,0)?-1:1});for(var e=-1/0,t=1,n=0;n<r.length;){for(var a=r[n].interval,i=r[n].close,o=0;o<2;o++)a[o]<=e&&(a[o]=e,i[o]=o?1:1-t),e=a[o],t=i[o];a[0]===a[1]&&i[0]*i[1]!==1?r.splice(n,1):n++}return r;function s(l,u,c){return l.interval[c]<u.interval[c]||l.interval[c]===u.interval[c]&&(l.close[c]-u.close[c]===(c?-1:1)||!c&&s(l,u,1))}}function Ai(r){var e=parseFloat(r);return e==r&&(e!==0||!Lt(r)||r.indexOf("x")<=0)?e:NaN}function yP(r){return!isNaN(Ai(r))}function mP(){return Math.round(Math.random()*9)}function _P(r,e){return e===0?r:_P(e,r%e)}function q2(r,e){return r==null?e:e==null?r:r*e/_P(r,e)}function Ae(r){throw new Error(r)}function K2(r,e,t){return(e-r)*t+r}var wP="series\0",xP="\0_ec_\0";function Ie(r){return r instanceof Array?r:r==null?[]:[r]}function Os(r,e,t){if(r){r[e]=r[e]||{},r.emphasis=r.emphasis||{},r.emphasis[e]=r.emphasis[e]||{};for(var n=0,a=t.length;n<a;n++){var i=t[n];!r.emphasis[e].hasOwnProperty(i)&&r[e].hasOwnProperty(i)&&(r.emphasis[e][i]=r[e][i])}}}var Q2=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function hu(r){return Vt(r)&&!ht(r)&&!(r instanceof Date)?r.value:r}function X8(r){return Vt(r)&&!(r instanceof Array)}function bP(r,e,t){var n=t==="normalMerge",a=t==="replaceMerge",i=t==="replaceAll";r=r||[],e=(e||[]).slice();var o=Pt();B(e,function(l,u){if(!Vt(l)){e[u]=null;return}});var s=$8(r,o,t);return(n||a)&&j8(s,r,o,e),n&&q8(s,e),n||a?K8(s,e,a):i&&Q8(s,e),J8(s),s}function $8(r,e,t){var n=[];if(t==="replaceAll")return n;for(var a=0;a<r.length;a++){var i=r[a];i&&i.id!=null&&e.set(i.id,a),n.push({existing:t==="replaceMerge"||Jc(i)?null:i,newOption:null,keyInfo:null,brandNew:null})}return n}function j8(r,e,t,n){B(n,function(a,i){if(!(!a||a.id==null)){var o=Oc(a.id),s=t.get(o);if(s!=null){var l=r[s];Jr(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=a,l.existing=e[s],n[i]=null}}})}function q8(r,e){B(e,function(t,n){if(!(!t||t.name==null))for(var a=0;a<r.length;a++){var i=r[a].existing;if(!r[a].newOption&&i&&(i.id==null||t.id==null)&&!Jc(t)&&!Jc(i)&&SP("name",i,t)){r[a].newOption=t,e[n]=null;return}}})}function K8(r,e,t){B(e,function(n){if(n){for(var a,i=0;(a=r[i])&&(a.newOption||Jc(a.existing)||a.existing&&n.id!=null&&!SP("id",n,a.existing));)i++;a?(a.newOption=n,a.brandNew=t):r.push({newOption:n,brandNew:t,existing:null,keyInfo:null}),i++}})}function Q8(r,e){B(e,function(t){r.push({newOption:t,brandNew:!0,existing:null,keyInfo:null})})}function J8(r){var e=Pt();B(r,function(t){var n=t.existing;n&&e.set(n.id,t)}),B(r,function(t){var n=t.newOption;Jr(!n||n.id==null||!e.get(n.id)||e.get(n.id)===t,"id duplicates: "+(n&&n.id)),n&&n.id!=null&&e.set(n.id,t),!t.keyInfo&&(t.keyInfo={})}),B(r,function(t,n){var a=t.existing,i=t.newOption,o=t.keyInfo;if(Vt(i)){if(o.name=i.name!=null?Oc(i.name):a?a.name:wP+n,a)o.id=Oc(a.id);else if(i.id!=null)o.id=Oc(i.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(e.get(o.id))}e.set(o.id,t)}})}function SP(r,e,t){var n=ur(e[r],null),a=ur(t[r],null);return n!=null&&a!=null&&n===a}function Oc(r){return ur(r,"")}function ur(r,e){return r==null?e:Lt(r)?r:ye(r)||W0(r)?r+"":e}function $1(r){var e=r.name;return!!(e&&e.indexOf(wP))}function Jc(r){return r&&r.id!=null&&Oc(r.id).indexOf(xP)===0}function tW(r){return xP+r}function eW(r,e,t){B(r,function(n){var a=n.newOption;Vt(a)&&(n.keyInfo.mainType=e,n.keyInfo.subType=rW(e,a,n.existing,t))})}function rW(r,e,t,n){var a=e.type?e.type:t?t.subType:n.determineSubType(r,e);return a}function nW(r,e){var t={},n={};return a(r||[],t),a(e||[],n,t),[i(t),i(n)];function a(o,s,l){for(var u=0,c=o.length;u<c;u++){var h=ur(o[u].seriesId,null);if(h==null)return;for(var d=Ie(o[u].dataIndex),v=l&&l[h],p=0,y=d.length;p<y;p++){var _=d[p];v&&v[_]?v[_]=null:(s[h]||(s[h]={}))[_]=1}}}function i(o,s){var l=[];for(var u in o)if(o.hasOwnProperty(u)&&o[u]!=null)if(s)l.push(+u);else{var c=i(o[u],!0);c.length&&l.push({seriesId:u,dataIndex:c})}return l}}function Bs(r,e){if(e.dataIndexInside!=null)return e.dataIndexInside;if(e.dataIndex!=null)return ht(e.dataIndex)?ft(e.dataIndex,function(t){return r.indexOfRawIndex(t)}):r.indexOfRawIndex(e.dataIndex);if(e.name!=null)return ht(e.name)?ft(e.name,function(t){return r.indexOfName(t)}):r.indexOfName(e.name)}function ve(){var r="__ec_inner_"+aW++;return function(e){return e[r]||(e[r]={})}}var aW=mP();function Bc(r,e,t){var n=j1(e,t),a=n.mainTypeSpecified,i=n.queryOptionMap,o=n.others,s=o,l=t?t.defaultMainType:null;return!a&&l&&i.set(l,{}),i.each(function(u,c){var h=Ch(r,c,u,{useDefault:l===c,enableAll:t&&t.enableAll!=null?t.enableAll:!0,enableNone:t&&t.enableNone!=null?t.enableNone:!0});s[c+"Models"]=h.models,s[c+"Model"]=h.models[0]}),s}function j1(r,e){var t;if(Lt(r)){var n={};n[r+"Index"]=0,t=n}else t=r;var a=Pt(),i={},o=!1;return B(t,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){i[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],c=u[1],h=(u[2]||"").toLowerCase();if(!(!c||!h||e&&e.includeMainTypes&&te(e.includeMainTypes,c)<0)){o=o||!!c;var d=a.get(c)||a.set(c,{});d[h]=s}}),{mainTypeSpecified:o,queryOptionMap:a,others:i}}var ir={useDefault:!0,enableAll:!1,enableNone:!1},iW={useDefault:!1,enableAll:!0,enableNone:!0};function Ch(r,e,t,n){n=n||ir;var a=t.index,i=t.id,o=t.name,s={models:null,specified:a!=null||i!=null||o!=null};if(!s.specified){var l=void 0;return s.models=n.useDefault&&(l=r.getComponent(e))?[l]:[],s}return a==="none"||a===!1?(Jr(n.enableNone,'`"none"` or `false` is not a valid value on index option.'),s.models=[],s):(a==="all"&&(Jr(n.enableAll,'`"all"` is not a valid value on index option.'),a=i=o=null),s.models=r.queryComponents({mainType:e,index:a,id:i,name:o}),s)}function AP(r,e,t){r.setAttribute?r.setAttribute(e,t):r[e]=t}function oW(r,e){return r.getAttribute?r.getAttribute(e):r[e]}function sW(r){return r==="auto"?oe.domSupported?"html":"richText":r||"html"}function f_(r,e){var t=Pt(),n=[];return B(r,function(a){var i=e(a);(t.get(i)||(n.push(i),t.set(i,[]))).push(a)}),{keys:n,buckets:t}}function TP(r,e,t,n,a){var i=e==null||e==="auto";if(n==null)return n;if(ye(n)){var o=K2(t||0,n,a);return qe(o,i?Math.max(Fa(t||0),Fa(n)):e)}else{if(Lt(n))return a<1?t:n;for(var s=[],l=t,u=n,c=Math.max(l?l.length:0,u.length),h=0;h<c;++h){var d=r.getDimensionInfo(h);if(d&&d.type==="ordinal")s[h]=(a<1&&l?l:u)[h];else{var v=l&&l[h]?l[h]:0,p=u[h],o=K2(v,p,a);s[h]=qe(o,i?Math.max(Fa(v),Fa(p)):e)}}return s}}var lW=".",Uo="___EC__COMPONENT__CONTAINER___",CP="___EC__EXTENDED_CLASS___";function Va(r){var e={main:"",sub:""};if(r){var t=r.split(lW);e.main=t[0]||"",e.sub=t[1]||""}return e}function uW(r){Jr(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(r),'componentType "'+r+'" illegal')}function cW(r){return!!(r&&r[CP])}function q1(r,e){r.$constructor=r,r.extend=function(t){var n=this,a;return hW(n)?a=function(i){rt(o,i);function o(){return i.apply(this,arguments)||this}return o}(n):(a=function(){(t.$constructor||n).apply(this,arguments)},_6(a,this)),lt(a.prototype,t),a[CP]=!0,a.extend=this.extend,a.superCall=dW,a.superApply=pW,a.superClass=n,a}}function hW(r){return Nt(r)&&/^class\s/.test(Function.prototype.toString.call(r))}function LP(r,e){r.extend=e.extend}var fW=Math.round(Math.random()*10);function vW(r){var e=["__\0is_clz",fW++].join("_");r.prototype[e]=!0,r.isInstance=function(t){return!!(t&&t[e])}}function dW(r,e){for(var t=[],n=2;n<arguments.length;n++)t[n-2]=arguments[n];return this.superClass.prototype[e].apply(r,t)}function pW(r,e,t){return this.superClass.prototype[e].apply(r,t)}function yp(r){var e={};r.registerClass=function(n){var a=n.type||n.prototype.type;if(a){uW(a),n.prototype.type=a;var i=Va(a);if(!i.sub)e[i.main]=n;else if(i.sub!==Uo){var o=t(i);o[i.sub]=n}}return n},r.getClass=function(n,a,i){var o=e[n];if(o&&o[Uo]&&(o=a?o[a]:null),i&&!o)throw new Error(a?"Component "+n+"."+(a||"")+" is used but not imported.":n+".type should be specified.");return o},r.getClassesByMainType=function(n){var a=Va(n),i=[],o=e[a.main];return o&&o[Uo]?B(o,function(s,l){l!==Uo&&i.push(s)}):i.push(o),i},r.hasClass=function(n){var a=Va(n);return!!e[a.main]},r.getAllClassMainTypes=function(){var n=[];return B(e,function(a,i){n.push(i)}),n},r.hasSubTypes=function(n){var a=Va(n),i=e[a.main];return i&&i[Uo]};function t(n){var a=e[n.main];return(!a||!a[Uo])&&(a=e[n.main]={},a[Uo]=!0),a}}function Ns(r,e){for(var t=0;t<r.length;t++)r[t][1]||(r[t][1]=r[t][0]);return e=e||!1,function(n,a,i){for(var o={},s=0;s<r.length;s++){var l=r[s][1];if(!(a&&te(a,l)>=0||i&&te(i,l)<0)){var u=n.getShallow(l,e);u!=null&&(o[r[s][0]]=u)}}return o}}var gW=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],yW=Ns(gW),mW=function(){function r(){}return r.prototype.getAreaStyle=function(e,t){return yW(this,e,t)},r}(),v_=new Ah(50);function _W(r){if(typeof r=="string"){var e=v_.get(r);return e&&e.image}else return r}function K1(r,e,t,n,a){if(r)if(typeof r=="string"){if(e&&e.__zrImageSrc===r||!t)return e;var i=v_.get(r),o={hostEl:t,cb:n,cbPayload:a};return i?(e=i.image,!mp(e)&&i.pending.push(o)):(e=_o.loadImage(r,J2,J2),e.__zrImageSrc=r,v_.put(r,e.__cachedImgObj={image:e,pending:[o]})),e}else return r;else return e}function J2(){var r=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var e=0;e<r.pending.length;e++){var t=r.pending[e],n=t.cb;n&&n(this,t.cbPayload),t.hostEl.dirty()}r.pending.length=0}function mp(r){return r&&r.width&&r.height}var Ry=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function wW(r,e,t,n,a,i){if(!t){r.text="",r.isTruncated=!1;return}var o=(e+"").split(`
`);i=MP(t,n,a,i);for(var s=!1,l={},u=0,c=o.length;u<c;u++)DP(l,o[u],i),o[u]=l.textLine,s=s||l.isTruncated;r.text=o.join(`
`),r.isTruncated=s}function MP(r,e,t,n){n=n||{};var a=lt({},n);a.font=e,t=Zt(t,"..."),a.maxIterations=Zt(n.maxIterations,2);var i=a.minChar=Zt(n.minChar,0);a.cnCharWidth=Dn("国",e);var o=a.ascCharWidth=Dn("a",e);a.placeholder=Zt(n.placeholder,"");for(var s=r=Math.max(0,r-1),l=0;l<i&&s>=o;l++)s-=o;var u=Dn(t,e);return u>s&&(t="",u=0),s=r-u,a.ellipsis=t,a.ellipsisWidth=u,a.contentWidth=s,a.containerWidth=r,a}function DP(r,e,t){var n=t.containerWidth,a=t.font,i=t.contentWidth;if(!n){r.textLine="",r.isTruncated=!1;return}var o=Dn(e,a);if(o<=n){r.textLine=e,r.isTruncated=!1;return}for(var s=0;;s++){if(o<=i||s>=t.maxIterations){e+=t.ellipsis;break}var l=s===0?xW(e,i,t.ascCharWidth,t.cnCharWidth):o>0?Math.floor(e.length*i/o):0;e=e.substr(0,l),o=Dn(e,a)}e===""&&(e=t.placeholder),r.textLine=e,r.isTruncated=!0}function xW(r,e,t,n){for(var a=0,i=0,o=r.length;i<o&&a<e;i++){var s=r.charCodeAt(i);a+=0<=s&&s<=127?t:n}return i}function bW(r,e){r!=null&&(r+="");var t=e.overflow,n=e.padding,a=e.font,i=t==="truncate",o=pp(a),s=Zt(e.lineHeight,o),l=!!e.backgroundColor,u=e.lineOverflow==="truncate",c=!1,h=e.width,d;h!=null&&(t==="break"||t==="breakAll")?d=r?IP(r,e.font,h,t==="breakAll",0).lines:[]:d=r?r.split(`
`):[];var v=d.length*s,p=Zt(e.height,v);if(v>p&&u){var y=Math.floor(p/s);c=c||d.length>y,d=d.slice(0,y)}if(r&&i&&h!=null)for(var _=MP(h,a,e.ellipsis,{minChar:e.truncateMinChar,placeholder:e.placeholder}),g={},f=0;f<d.length;f++)DP(g,d[f],_),d[f]=g.textLine,c=c||g.isTruncated;for(var w=p,x=0,f=0;f<d.length;f++)x=Math.max(Dn(d[f],a),x);h==null&&(h=x);var S=x;return n&&(w+=n[0]+n[2],S+=n[1]+n[3],h+=n[1]+n[3]),l&&(S=h),{lines:d,height:p,outerWidth:S,outerHeight:w,lineHeight:s,calculatedLineHeight:o,contentWidth:x,contentHeight:v,width:h,isTruncated:c}}var SW=function(){function r(){}return r}(),tA=function(){function r(e){this.tokens=[],e&&(this.tokens=e)}return r}(),AW=function(){function r(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[],this.isTruncated=!1}return r}();function TW(r,e){var t=new AW;if(r!=null&&(r+=""),!r)return t;for(var n=e.width,a=e.height,i=e.overflow,o=(i==="break"||i==="breakAll")&&n!=null?{width:n,accumWidth:0,breakAll:i==="breakAll"}:null,s=Ry.lastIndex=0,l;(l=Ry.exec(r))!=null;){var u=l.index;u>s&&Ey(t,r.substring(s,u),e,o),Ey(t,l[2],e,o,l[1]),s=Ry.lastIndex}s<r.length&&Ey(t,r.substring(s,r.length),e,o);var c=[],h=0,d=0,v=e.padding,p=i==="truncate",y=e.lineOverflow==="truncate",_={};function g(K,U,j){K.width=U,K.lineHeight=j,h+=j,d=Math.max(d,U)}t:for(var f=0;f<t.lines.length;f++){for(var w=t.lines[f],x=0,S=0,A=0;A<w.tokens.length;A++){var T=w.tokens[A],L=T.styleName&&e.rich[T.styleName]||{},M=T.textPadding=L.padding,I=M?M[1]+M[3]:0,R=T.font=L.font||e.font;T.contentHeight=pp(R);var P=Zt(L.height,T.contentHeight);if(T.innerHeight=P,M&&(P+=M[0]+M[2]),T.height=P,T.lineHeight=Ha(L.lineHeight,e.lineHeight,P),T.align=L&&L.align||e.align,T.verticalAlign=L&&L.verticalAlign||"middle",y&&a!=null&&h+T.lineHeight>a){var E=t.lines.length;A>0?(w.tokens=w.tokens.slice(0,A),g(w,S,x),t.lines=t.lines.slice(0,f+1)):t.lines=t.lines.slice(0,f),t.isTruncated=t.isTruncated||t.lines.length<E;break t}var D=L.width,N=D==null||D==="auto";if(typeof D=="string"&&D.charAt(D.length-1)==="%")T.percentWidth=D,c.push(T),T.contentWidth=Dn(T.text,R);else{if(N){var V=L.backgroundColor,W=V&&V.image;W&&(W=_W(W),mp(W)&&(T.width=Math.max(T.width,W.width*P/W.height)))}var $=p&&n!=null?n-S:null;$!=null&&$<T.width?!N||$<I?(T.text="",T.width=T.contentWidth=0):(wW(_,T.text,$-I,R,e.ellipsis,{minChar:e.truncateMinChar}),T.text=_.text,t.isTruncated=t.isTruncated||_.isTruncated,T.width=T.contentWidth=Dn(T.text,R)):T.contentWidth=Dn(T.text,R)}T.width+=I,S+=T.width,L&&(x=Math.max(x,T.lineHeight))}g(w,S,x)}t.outerWidth=t.width=Zt(n,d),t.outerHeight=t.height=Zt(a,h),t.contentHeight=h,t.contentWidth=d,v&&(t.outerWidth+=v[1]+v[3],t.outerHeight+=v[0]+v[2]);for(var f=0;f<c.length;f++){var T=c[f],H=T.percentWidth;T.width=parseInt(H,10)/100*t.width}return t}function Ey(r,e,t,n,a){var i=e==="",o=a&&t.rich[a]||{},s=r.lines,l=o.font||t.font,u=!1,c,h;if(n){var d=o.padding,v=d?d[1]+d[3]:0;if(o.width!=null&&o.width!=="auto"){var p=wa(o.width,n.width)+v;s.length>0&&p+n.accumWidth>n.width&&(c=e.split(`
`),u=!0),n.accumWidth=p}else{var y=IP(e,l,n.width,n.breakAll,n.accumWidth);n.accumWidth=y.accumWidth+v,h=y.linesWidths,c=y.lines}}else c=e.split(`
`);for(var _=0;_<c.length;_++){var g=c[_],f=new SW;if(f.styleName=a,f.text=g,f.isLineHolder=!g&&!i,typeof o.width=="number"?f.width=o.width:f.width=h?h[_]:Dn(g,l),!_&&!u){var w=(s[s.length-1]||(s[0]=new tA)).tokens,x=w.length;x===1&&w[0].isLineHolder?w[0]=f:(g||!x||i)&&w.push(f)}else s.push(new tA([f]))}}function CW(r){var e=r.charCodeAt(0);return e>=32&&e<=591||e>=880&&e<=4351||e>=4608&&e<=5119||e>=7680&&e<=8303}var LW=Za(",&?/;] ".split(""),function(r,e){return r[e]=!0,r},{});function MW(r){return CW(r)?!!LW[r]:!0}function IP(r,e,t,n,a){for(var i=[],o=[],s="",l="",u=0,c=0,h=0;h<r.length;h++){var d=r.charAt(h);if(d===`
`){l&&(s+=l,c+=u),i.push(s),o.push(c),s="",l="",u=0,c=0;continue}var v=Dn(d,e),p=n?!1:!MW(d);if(i.length?c+v>t:a+c+v>t){c?(s||l)&&(p?(s||(s=l,l="",u=0,c=u),i.push(s),o.push(c-u),l+=d,u+=v,s="",c=u):(l&&(s+=l,l="",u=0),i.push(s),o.push(c),s=d,c=v)):p?(i.push(l),o.push(u),l=d,u=v):(i.push(d),o.push(v));continue}c+=v,p?(l+=d,u+=v):(l&&(s+=l,l="",u=0),s+=d)}return!i.length&&!s&&(s=r,l="",u=0),l&&(s+=l),s&&(i.push(s),o.push(c)),i.length===1&&(c+=a),{accumWidth:c,lines:i,linesWidths:o}}var d_="__zr_style_"+Math.round(Math.random()*10),Ms={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},_p={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};Ms[d_]=!0;var eA=["z","z2","invisible"],DW=["invisible"],ta=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype._init=function(t){for(var n=ue(t),a=0;a<n.length;a++){var i=n[a];i==="style"?this.useStyle(t[i]):r.prototype.attrKV.call(this,i,t[i])}this.style||this.useStyle({})},e.prototype.beforeBrush=function(){},e.prototype.afterBrush=function(){},e.prototype.innerBeforeBrush=function(){},e.prototype.innerAfterBrush=function(){},e.prototype.shouldBePainted=function(t,n,a,i){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&IW(this,t,n)||o&&!o[0]&&!o[3])return!1;if(a&&this.__clipPaths){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(i&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},e.prototype.contain=function(t,n){return this.rectContain(t,n)},e.prototype.traverse=function(t,n){t.call(n,this)},e.prototype.rectContain=function(t,n){var a=this.transformCoordToLocal(t,n),i=this.getBoundingRect();return i.contain(a[0],a[1])},e.prototype.getPaintRect=function(){var t=this._paintRect;if(!this._paintRect||this.__dirty){var n=this.transform,a=this.getBoundingRect(),i=this.style,o=i.shadowBlur||0,s=i.shadowOffsetX||0,l=i.shadowOffsetY||0;t=this._paintRect||(this._paintRect=new Qt(0,0,0,0)),n?Qt.applyTransform(t,a,n):t.copy(a),(o||s||l)&&(t.width+=o*2+Math.abs(s),t.height+=o*2+Math.abs(l),t.x=Math.min(t.x,t.x+s-o),t.y=Math.min(t.y,t.y+l-o));var u=this.dirtyRectTolerance;t.isZero()||(t.x=Math.floor(t.x-u),t.y=Math.floor(t.y-u),t.width=Math.ceil(t.width+1+u*2),t.height=Math.ceil(t.height+1+u*2))}return t},e.prototype.setPrevPaintRect=function(t){t?(this._prevPaintRect=this._prevPaintRect||new Qt(0,0,0,0),this._prevPaintRect.copy(t)):this._prevPaintRect=null},e.prototype.getPrevPaintRect=function(){return this._prevPaintRect},e.prototype.animateStyle=function(t){return this.animate("style",t)},e.prototype.updateDuringAnimation=function(t){t==="style"?this.dirtyStyle():this.markRedraw()},e.prototype.attrKV=function(t,n){t!=="style"?r.prototype.attrKV.call(this,t,n):this.style?this.setStyle(n):this.useStyle(n)},e.prototype.setStyle=function(t,n){return typeof t=="string"?this.style[t]=n:lt(this.style,t),this.dirtyStyle(),this},e.prototype.dirtyStyle=function(t){t||this.markRedraw(),this.__dirty|=mc,this._rect&&(this._rect=null)},e.prototype.dirty=function(){this.dirtyStyle()},e.prototype.styleChanged=function(){return!!(this.__dirty&mc)},e.prototype.styleUpdated=function(){this.__dirty&=~mc},e.prototype.createStyle=function(t){return fp(Ms,t)},e.prototype.useStyle=function(t){t[d_]||(t=this.createStyle(t)),this.__inHover?this.__hoverStyle=t:this.style=t,this.dirtyStyle()},e.prototype.isStyleObject=function(t){return t[d_]},e.prototype._innerSaveToNormal=function(t){r.prototype._innerSaveToNormal.call(this,t);var n=this._normalState;t.style&&!n.style&&(n.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(t,n,eA)},e.prototype._applyStateObj=function(t,n,a,i,o,s){r.prototype._applyStateObj.call(this,t,n,a,i,o,s);var l=!(n&&i),u;if(n&&n.style?o?i?u=n.style:(u=this._mergeStyle(this.createStyle(),a.style),this._mergeStyle(u,n.style)):(u=this._mergeStyle(this.createStyle(),i?this.style:a.style),this._mergeStyle(u,n.style)):l&&(u=a.style),u)if(o){var c=this.style;if(this.style=this.createStyle(l?{}:c),l)for(var h=ue(c),d=0;d<h.length;d++){var v=h[d];v in u&&(u[v]=u[v],this.style[v]=c[v])}for(var p=ue(u),d=0;d<p.length;d++){var v=p[d];this.style[v]=this.style[v]}this._transitionState(t,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var y=this.__inHover?DW:eA,d=0;d<y.length;d++){var v=y[d];n&&n[v]!=null?this[v]=n[v]:l&&a[v]!=null&&(this[v]=a[v])}},e.prototype._mergeStates=function(t){for(var n=r.prototype._mergeStates.call(this,t),a,i=0;i<t.length;i++){var o=t[i];o.style&&(a=a||{},this._mergeStyle(a,o.style))}return a&&(n.style=a),n},e.prototype._mergeStyle=function(t,n){return lt(t,n),t},e.prototype.getAnimationStyleProps=function(){return _p},e.initDefaultProps=function(){var t=e.prototype;t.type="displayable",t.invisible=!1,t.z=0,t.z2=0,t.zlevel=0,t.culling=!1,t.cursor="pointer",t.rectHover=!1,t.incremental=!1,t._rect=null,t.dirtyRectTolerance=0,t.__dirty=Tn|mc}(),e}(gp),Oy=new Qt(0,0,0,0),By=new Qt(0,0,0,0);function IW(r,e,t){return Oy.copy(r.getBoundingRect()),r.transform&&Oy.applyTransform(r.transform),By.width=e,By.height=t,!Oy.intersect(By)}var fn=Math.min,vn=Math.max,Ny=Math.sin,zy=Math.cos,Zo=Math.PI*2,Kf=Ws(),Qf=Ws(),Jf=Ws();function wp(r,e,t){if(r.length!==0){for(var n=r[0],a=n[0],i=n[0],o=n[1],s=n[1],l=1;l<r.length;l++)n=r[l],a=fn(a,n[0]),i=vn(i,n[0]),o=fn(o,n[1]),s=vn(s,n[1]);e[0]=a,e[1]=o,t[0]=i,t[1]=s}}function rA(r,e,t,n,a,i){a[0]=fn(r,t),a[1]=fn(e,n),i[0]=vn(r,t),i[1]=vn(e,n)}var nA=[],aA=[];function PW(r,e,t,n,a,i,o,s,l,u){var c=jI,h=vr,d=c(r,t,a,o,nA);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var v=0;v<d;v++){var p=h(r,t,a,o,nA[v]);l[0]=fn(p,l[0]),u[0]=vn(p,u[0])}d=c(e,n,i,s,aA);for(var v=0;v<d;v++){var y=h(e,n,i,s,aA[v]);l[1]=fn(y,l[1]),u[1]=vn(y,u[1])}l[0]=fn(r,l[0]),u[0]=vn(r,u[0]),l[0]=fn(o,l[0]),u[0]=vn(o,u[0]),l[1]=fn(e,l[1]),u[1]=vn(e,u[1]),l[1]=fn(s,l[1]),u[1]=vn(s,u[1])}function kW(r,e,t,n,a,i,o,s){var l=KI,u=Sr,c=vn(fn(l(r,t,a),1),0),h=vn(fn(l(e,n,i),1),0),d=u(r,t,a,c),v=u(e,n,i,h);o[0]=fn(r,a,d),o[1]=fn(e,i,v),s[0]=vn(r,a,d),s[1]=vn(e,i,v)}function RW(r,e,t,n,a,i,o,s,l){var u=io,c=oo,h=Math.abs(a-i);if(h%Zo<1e-4&&h>1e-4){s[0]=r-t,s[1]=e-n,l[0]=r+t,l[1]=e+n;return}if(Kf[0]=zy(a)*t+r,Kf[1]=Ny(a)*n+e,Qf[0]=zy(i)*t+r,Qf[1]=Ny(i)*n+e,u(s,Kf,Qf),c(l,Kf,Qf),a=a%Zo,a<0&&(a=a+Zo),i=i%Zo,i<0&&(i=i+Zo),a>i&&!o?i+=Zo:a<i&&o&&(a+=Zo),o){var d=i;i=a,a=d}for(var v=0;v<i;v+=Math.PI/2)v>a&&(Jf[0]=zy(v)*t+r,Jf[1]=Ny(v)*n+e,u(s,Jf,s),c(l,Jf,l))}var Oe={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},Yo=[],Xo=[],Ma=[],Ui=[],Da=[],Ia=[],Fy=Math.min,Vy=Math.max,$o=Math.cos,jo=Math.sin,ui=Math.abs,p_=Math.PI,Ji=p_*2,Gy=typeof Float32Array<"u",Zu=[];function Wy(r){var e=Math.round(r/p_*1e8)/1e8;return e%2*p_}function Q1(r,e){var t=Wy(r[0]);t<0&&(t+=Ji);var n=t-r[0],a=r[1];a+=n,!e&&a-t>=Ji?a=t+Ji:e&&t-a>=Ji?a=t-Ji:!e&&t>a?a=t+(Ji-Wy(t-a)):e&&t<a&&(a=t-(Ji-Wy(a-t))),r[0]=t,r[1]=a}var ja=function(){function r(e){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,e&&(this._saveData=!1),this._saveData&&(this.data=[])}return r.prototype.increaseVersion=function(){this._version++},r.prototype.getVersion=function(){return this._version},r.prototype.setScale=function(e,t,n){n=n||0,n>0&&(this._ux=ui(n/wd/e)||0,this._uy=ui(n/wd/t)||0)},r.prototype.setDPR=function(e){this.dpr=e},r.prototype.setContext=function(e){this._ctx=e},r.prototype.getContext=function(){return this._ctx},r.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},r.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},r.prototype.moveTo=function(e,t){return this._drawPendingPt(),this.addData(Oe.M,e,t),this._ctx&&this._ctx.moveTo(e,t),this._x0=e,this._y0=t,this._xi=e,this._yi=t,this},r.prototype.lineTo=function(e,t){var n=ui(e-this._xi),a=ui(t-this._yi),i=n>this._ux||a>this._uy;if(this.addData(Oe.L,e,t),this._ctx&&i&&this._ctx.lineTo(e,t),i)this._xi=e,this._yi=t,this._pendingPtDist=0;else{var o=n*n+a*a;o>this._pendingPtDist&&(this._pendingPtX=e,this._pendingPtY=t,this._pendingPtDist=o)}return this},r.prototype.bezierCurveTo=function(e,t,n,a,i,o){return this._drawPendingPt(),this.addData(Oe.C,e,t,n,a,i,o),this._ctx&&this._ctx.bezierCurveTo(e,t,n,a,i,o),this._xi=i,this._yi=o,this},r.prototype.quadraticCurveTo=function(e,t,n,a){return this._drawPendingPt(),this.addData(Oe.Q,e,t,n,a),this._ctx&&this._ctx.quadraticCurveTo(e,t,n,a),this._xi=n,this._yi=a,this},r.prototype.arc=function(e,t,n,a,i,o){this._drawPendingPt(),Zu[0]=a,Zu[1]=i,Q1(Zu,o),a=Zu[0],i=Zu[1];var s=i-a;return this.addData(Oe.A,e,t,n,n,a,s,0,o?0:1),this._ctx&&this._ctx.arc(e,t,n,a,i,o),this._xi=$o(i)*n+e,this._yi=jo(i)*n+t,this},r.prototype.arcTo=function(e,t,n,a,i){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(e,t,n,a,i),this},r.prototype.rect=function(e,t,n,a){return this._drawPendingPt(),this._ctx&&this._ctx.rect(e,t,n,a),this.addData(Oe.R,e,t,n,a),this},r.prototype.closePath=function(){this._drawPendingPt(),this.addData(Oe.Z);var e=this._ctx,t=this._x0,n=this._y0;return e&&e.closePath(),this._xi=t,this._yi=n,this},r.prototype.fill=function(e){e&&e.fill(),this.toStatic()},r.prototype.stroke=function(e){e&&e.stroke(),this.toStatic()},r.prototype.len=function(){return this._len},r.prototype.setData=function(e){var t=e.length;!(this.data&&this.data.length===t)&&Gy&&(this.data=new Float32Array(t));for(var n=0;n<t;n++)this.data[n]=e[n];this._len=t},r.prototype.appendPath=function(e){e instanceof Array||(e=[e]);for(var t=e.length,n=0,a=this._len,i=0;i<t;i++)n+=e[i].len();Gy&&this.data instanceof Float32Array&&(this.data=new Float32Array(a+n));for(var i=0;i<t;i++)for(var o=e[i].data,s=0;s<o.length;s++)this.data[a++]=o[s];this._len=a},r.prototype.addData=function(e,t,n,a,i,o,s,l,u){if(this._saveData){var c=this.data;this._len+arguments.length>c.length&&(this._expandData(),c=this.data);for(var h=0;h<arguments.length;h++)c[this._len++]=arguments[h]}},r.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},r.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var e=[],t=0;t<this._len;t++)e[t]=this.data[t];this.data=e}},r.prototype.toStatic=function(){if(this._saveData){this._drawPendingPt();var e=this.data;e instanceof Array&&(e.length=this._len,Gy&&this._len>11&&(this.data=new Float32Array(e)))}},r.prototype.getBoundingRect=function(){Ma[0]=Ma[1]=Da[0]=Da[1]=Number.MAX_VALUE,Ui[0]=Ui[1]=Ia[0]=Ia[1]=-Number.MAX_VALUE;var e=this.data,t=0,n=0,a=0,i=0,o;for(o=0;o<this._len;){var s=e[o++],l=o===1;switch(l&&(t=e[o],n=e[o+1],a=t,i=n),s){case Oe.M:t=a=e[o++],n=i=e[o++],Da[0]=a,Da[1]=i,Ia[0]=a,Ia[1]=i;break;case Oe.L:rA(t,n,e[o],e[o+1],Da,Ia),t=e[o++],n=e[o++];break;case Oe.C:PW(t,n,e[o++],e[o++],e[o++],e[o++],e[o],e[o+1],Da,Ia),t=e[o++],n=e[o++];break;case Oe.Q:kW(t,n,e[o++],e[o++],e[o],e[o+1],Da,Ia),t=e[o++],n=e[o++];break;case Oe.A:var u=e[o++],c=e[o++],h=e[o++],d=e[o++],v=e[o++],p=e[o++]+v;o+=1;var y=!e[o++];l&&(a=$o(v)*h+u,i=jo(v)*d+c),RW(u,c,h,d,v,p,y,Da,Ia),t=$o(p)*h+u,n=jo(p)*d+c;break;case Oe.R:a=t=e[o++],i=n=e[o++];var _=e[o++],g=e[o++];rA(a,i,a+_,i+g,Da,Ia);break;case Oe.Z:t=a,n=i;break}io(Ma,Ma,Da),oo(Ui,Ui,Ia)}return o===0&&(Ma[0]=Ma[1]=Ui[0]=Ui[1]=0),new Qt(Ma[0],Ma[1],Ui[0]-Ma[0],Ui[1]-Ma[1])},r.prototype._calculateLength=function(){var e=this.data,t=this._len,n=this._ux,a=this._uy,i=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,c=0,h=0,d=0;d<t;){var v=e[d++],p=d===1;p&&(i=e[d],o=e[d+1],s=i,l=o);var y=-1;switch(v){case Oe.M:i=s=e[d++],o=l=e[d++];break;case Oe.L:{var _=e[d++],g=e[d++],f=_-i,w=g-o;(ui(f)>n||ui(w)>a||d===t-1)&&(y=Math.sqrt(f*f+w*w),i=_,o=g);break}case Oe.C:{var x=e[d++],S=e[d++],_=e[d++],g=e[d++],A=e[d++],T=e[d++];y=J6(i,o,x,S,_,g,A,T,10),i=A,o=T;break}case Oe.Q:{var x=e[d++],S=e[d++],_=e[d++],g=e[d++];y=e8(i,o,x,S,_,g,10),i=_,o=g;break}case Oe.A:var L=e[d++],M=e[d++],I=e[d++],R=e[d++],P=e[d++],E=e[d++],D=E+P;d+=1,p&&(s=$o(P)*I+L,l=jo(P)*R+M),y=Vy(I,R)*Fy(Ji,Math.abs(E)),i=$o(D)*I+L,o=jo(D)*R+M;break;case Oe.R:{s=i=e[d++],l=o=e[d++];var N=e[d++],V=e[d++];y=N*2+V*2;break}case Oe.Z:{var f=s-i,w=l-o;y=Math.sqrt(f*f+w*w),i=s,o=l;break}}y>=0&&(u[h++]=y,c+=y)}return this._pathLen=c,c},r.prototype.rebuildPath=function(e,t){var n=this.data,a=this._ux,i=this._uy,o=this._len,s,l,u,c,h,d,v=t<1,p,y,_=0,g=0,f,w=0,x,S;if(!(v&&(this._pathSegLen||this._calculateLength(),p=this._pathSegLen,y=this._pathLen,f=t*y,!f)))t:for(var A=0;A<o;){var T=n[A++],L=A===1;switch(L&&(u=n[A],c=n[A+1],s=u,l=c),T!==Oe.L&&w>0&&(e.lineTo(x,S),w=0),T){case Oe.M:s=u=n[A++],l=c=n[A++],e.moveTo(u,c);break;case Oe.L:{h=n[A++],d=n[A++];var M=ui(h-u),I=ui(d-c);if(M>a||I>i){if(v){var R=p[g++];if(_+R>f){var P=(f-_)/R;e.lineTo(u*(1-P)+h*P,c*(1-P)+d*P);break t}_+=R}e.lineTo(h,d),u=h,c=d,w=0}else{var E=M*M+I*I;E>w&&(x=h,S=d,w=E)}break}case Oe.C:{var D=n[A++],N=n[A++],V=n[A++],W=n[A++],$=n[A++],H=n[A++];if(v){var R=p[g++];if(_+R>f){var P=(f-_)/R;wo(u,D,V,$,P,Yo),wo(c,N,W,H,P,Xo),e.bezierCurveTo(Yo[1],Xo[1],Yo[2],Xo[2],Yo[3],Xo[3]);break t}_+=R}e.bezierCurveTo(D,N,V,W,$,H),u=$,c=H;break}case Oe.Q:{var D=n[A++],N=n[A++],V=n[A++],W=n[A++];if(v){var R=p[g++];if(_+R>f){var P=(f-_)/R;jc(u,D,V,P,Yo),jc(c,N,W,P,Xo),e.quadraticCurveTo(Yo[1],Xo[1],Yo[2],Xo[2]);break t}_+=R}e.quadraticCurveTo(D,N,V,W),u=V,c=W;break}case Oe.A:var K=n[A++],U=n[A++],j=n[A++],ut=n[A++],ot=n[A++],it=n[A++],Et=n[A++],jt=!n[A++],bt=j>ut?j:ut,wt=ui(j-ut)>.001,Ot=ot+it,xt=!1;if(v){var R=p[g++];_+R>f&&(Ot=ot+it*(f-_)/R,xt=!0),_+=R}if(wt&&e.ellipse?e.ellipse(K,U,j,ut,Et,ot,Ot,jt):e.arc(K,U,bt,ot,Ot,jt),xt)break t;L&&(s=$o(ot)*j+K,l=jo(ot)*ut+U),u=$o(Ot)*j+K,c=jo(Ot)*ut+U;break;case Oe.R:s=u=n[A],l=c=n[A+1],h=n[A++],d=n[A++];var kt=n[A++],ae=n[A++];if(v){var R=p[g++];if(_+R>f){var O=f-_;e.moveTo(h,d),e.lineTo(h+Fy(O,kt),d),O-=kt,O>0&&e.lineTo(h+kt,d+Fy(O,ae)),O-=ae,O>0&&e.lineTo(h+Vy(kt-O,0),d+ae),O-=kt,O>0&&e.lineTo(h,d+Vy(ae-O,0));break t}_+=R}e.rect(h,d,kt,ae);break;case Oe.Z:if(v){var R=p[g++];if(_+R>f){var P=(f-_)/R;e.lineTo(u*(1-P)+s*P,c*(1-P)+l*P);break t}_+=R}e.closePath(),u=s,c=l}}},r.prototype.clone=function(){var e=new r,t=this.data;return e.data=t.slice?t.slice():Array.prototype.slice.call(t),e._len=this._len,e},r.CMD=Oe,r.initDefaultProps=function(){var e=r.prototype;e._saveData=!0,e._ux=0,e._uy=0,e._pendingPtDist=0,e._version=0}(),r}();function eo(r,e,t,n,a,i,o){if(a===0)return!1;var s=a,l=0,u=r;if(o>e+s&&o>n+s||o<e-s&&o<n-s||i>r+s&&i>t+s||i<r-s&&i<t-s)return!1;if(r!==t)l=(e-n)/(r-t),u=(r*n-t*e)/(r-t);else return Math.abs(i-r)<=s/2;var c=l*i-o+u,h=c*c/(l*l+1);return h<=s/2*s/2}function EW(r,e,t,n,a,i,o,s,l,u,c){if(l===0)return!1;var h=l;if(c>e+h&&c>n+h&&c>i+h&&c>s+h||c<e-h&&c<n-h&&c<i-h&&c<s-h||u>r+h&&u>t+h&&u>a+h&&u>o+h||u<r-h&&u<t-h&&u<a-h&&u<o-h)return!1;var d=qI(r,e,t,n,a,i,o,s,u,c,null);return d<=h/2}function PP(r,e,t,n,a,i,o,s,l){if(o===0)return!1;var u=o;if(l>e+u&&l>n+u&&l>i+u||l<e-u&&l<n-u&&l<i-u||s>r+u&&s>t+u&&s>a+u||s<r-u&&s<t-u&&s<a-u)return!1;var c=QI(r,e,t,n,a,i,s,l,null);return c<=u/2}var iA=Math.PI*2;function Cn(r){return r%=iA,r<0&&(r+=iA),r}var Yu=Math.PI*2;function OW(r,e,t,n,a,i,o,s,l){if(o===0)return!1;var u=o;s-=r,l-=e;var c=Math.sqrt(s*s+l*l);if(c-u>t||c+u<t)return!1;if(Math.abs(n-a)%Yu<1e-4)return!0;if(i){var h=n;n=Cn(a),a=Cn(h)}else n=Cn(n),a=Cn(a);n>a&&(a+=Yu);var d=Math.atan2(l,s);return d<0&&(d+=Yu),d>=n&&d<=a||d+Yu>=n&&d+Yu<=a}function di(r,e,t,n,a,i){if(i>e&&i>n||i<e&&i<n||n===e)return 0;var o=(i-e)/(n-e),s=n<e?1:-1;(o===1||o===0)&&(s=n<e?.5:-.5);var l=o*(t-r)+r;return l===a?1/0:l>a?s:0}var Zi=ja.CMD,qo=Math.PI*2,BW=1e-4;function NW(r,e){return Math.abs(r-e)<BW}var $r=[-1,-1,-1],Yn=[-1,-1];function zW(){var r=Yn[0];Yn[0]=Yn[1],Yn[1]=r}function FW(r,e,t,n,a,i,o,s,l,u){if(u>e&&u>n&&u>i&&u>s||u<e&&u<n&&u<i&&u<s)return 0;var c=gd(e,n,i,s,u,$r);if(c===0)return 0;for(var h=0,d=-1,v=void 0,p=void 0,y=0;y<c;y++){var _=$r[y],g=_===0||_===1?.5:1,f=vr(r,t,a,o,_);f<l||(d<0&&(d=jI(e,n,i,s,Yn),Yn[1]<Yn[0]&&d>1&&zW(),v=vr(e,n,i,s,Yn[0]),d>1&&(p=vr(e,n,i,s,Yn[1]))),d===2?_<Yn[0]?h+=v<e?g:-g:_<Yn[1]?h+=p<v?g:-g:h+=s<p?g:-g:_<Yn[0]?h+=v<e?g:-g:h+=s<v?g:-g)}return h}function VW(r,e,t,n,a,i,o,s){if(s>e&&s>n&&s>i||s<e&&s<n&&s<i)return 0;var l=t8(e,n,i,s,$r);if(l===0)return 0;var u=KI(e,n,i);if(u>=0&&u<=1){for(var c=0,h=Sr(e,n,i,u),d=0;d<l;d++){var v=$r[d]===0||$r[d]===1?.5:1,p=Sr(r,t,a,$r[d]);p<o||($r[d]<u?c+=h<e?v:-v:c+=i<h?v:-v)}return c}else{var v=$r[0]===0||$r[0]===1?.5:1,p=Sr(r,t,a,$r[0]);return p<o?0:i<e?v:-v}}function GW(r,e,t,n,a,i,o,s){if(s-=e,s>t||s<-t)return 0;var l=Math.sqrt(t*t-s*s);$r[0]=-l,$r[1]=l;var u=Math.abs(n-a);if(u<1e-4)return 0;if(u>=qo-1e-4){n=0,a=qo;var c=i?1:-1;return o>=$r[0]+r&&o<=$r[1]+r?c:0}if(n>a){var h=n;n=a,a=h}n<0&&(n+=qo,a+=qo);for(var d=0,v=0;v<2;v++){var p=$r[v];if(p+r>o){var y=Math.atan2(s,p),c=i?1:-1;y<0&&(y=qo+y),(y>=n&&y<=a||y+qo>=n&&y+qo<=a)&&(y>Math.PI/2&&y<Math.PI*1.5&&(c=-c),d+=c)}}return d}function kP(r,e,t,n,a){for(var i=r.data,o=r.len(),s=0,l=0,u=0,c=0,h=0,d,v,p=0;p<o;){var y=i[p++],_=p===1;switch(y===Zi.M&&p>1&&(t||(s+=di(l,u,c,h,n,a))),_&&(l=i[p],u=i[p+1],c=l,h=u),y){case Zi.M:c=i[p++],h=i[p++],l=c,u=h;break;case Zi.L:if(t){if(eo(l,u,i[p],i[p+1],e,n,a))return!0}else s+=di(l,u,i[p],i[p+1],n,a)||0;l=i[p++],u=i[p++];break;case Zi.C:if(t){if(EW(l,u,i[p++],i[p++],i[p++],i[p++],i[p],i[p+1],e,n,a))return!0}else s+=FW(l,u,i[p++],i[p++],i[p++],i[p++],i[p],i[p+1],n,a)||0;l=i[p++],u=i[p++];break;case Zi.Q:if(t){if(PP(l,u,i[p++],i[p++],i[p],i[p+1],e,n,a))return!0}else s+=VW(l,u,i[p++],i[p++],i[p],i[p+1],n,a)||0;l=i[p++],u=i[p++];break;case Zi.A:var g=i[p++],f=i[p++],w=i[p++],x=i[p++],S=i[p++],A=i[p++];p+=1;var T=!!(1-i[p++]);d=Math.cos(S)*w+g,v=Math.sin(S)*x+f,_?(c=d,h=v):s+=di(l,u,d,v,n,a);var L=(n-g)*x/w+g;if(t){if(OW(g,f,x,S,S+A,T,e,L,a))return!0}else s+=GW(g,f,x,S,S+A,T,L,a);l=Math.cos(S+A)*w+g,u=Math.sin(S+A)*x+f;break;case Zi.R:c=l=i[p++],h=u=i[p++];var M=i[p++],I=i[p++];if(d=c+M,v=h+I,t){if(eo(c,h,d,h,e,n,a)||eo(d,h,d,v,e,n,a)||eo(d,v,c,v,e,n,a)||eo(c,v,c,h,e,n,a))return!0}else s+=di(d,h,d,v,n,a),s+=di(c,v,c,h,n,a);break;case Zi.Z:if(t){if(eo(l,u,c,h,e,n,a))return!0}else s+=di(l,u,c,h,n,a);l=c,u=h;break}}return!t&&!NW(u,h)&&(s+=di(l,u,c,h,n,a)||0),s!==0}function WW(r,e,t){return kP(r,0,!1,e,t)}function HW(r,e,t,n){return kP(r,e,!0,t,n)}var bd=zt({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},Ms),UW={style:zt({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},_p.style)},Hy=Xa.concat(["invisible","culling","z","z2","zlevel","parent"]),ie=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.update=function(){var t=this;r.prototype.update.call(this);var n=this.style;if(n.decal){var a=this._decalEl=this._decalEl||new e;a.buildPath===e.prototype.buildPath&&(a.buildPath=function(l){t.buildPath(l,t.shape)}),a.silent=!0;var i=a.style;for(var o in n)i[o]!==n[o]&&(i[o]=n[o]);i.fill=n.fill?n.decal:null,i.decal=null,i.shadowColor=null,n.strokeFirst&&(i.stroke=null);for(var s=0;s<Hy.length;++s)a[Hy[s]]=this[Hy[s]];a.__dirty|=Tn}else this._decalEl&&(this._decalEl=null)},e.prototype.getDecalElement=function(){return this._decalEl},e.prototype._init=function(t){var n=ue(t);this.shape=this.getDefaultShape();var a=this.getDefaultStyle();a&&this.useStyle(a);for(var i=0;i<n.length;i++){var o=n[i],s=t[o];o==="style"?this.style?lt(this.style,s):this.useStyle(s):o==="shape"?lt(this.shape,s):r.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},e.prototype.getDefaultStyle=function(){return null},e.prototype.getDefaultShape=function(){return{}},e.prototype.canBeInsideText=function(){return this.hasFill()},e.prototype.getInsideTextFill=function(){var t=this.style.fill;if(t!=="none"){if(Lt(t)){var n=md(t,0);return n>.5?u_:n>.2?M8:c_}else if(t)return c_}return u_},e.prototype.getInsideTextStroke=function(t){var n=this.style.fill;if(Lt(n)){var a=this.__zr,i=!!(a&&a.isDarkMode()),o=md(t,0)<l_;if(i===o)return n}},e.prototype.buildPath=function(t,n,a){},e.prototype.pathUpdated=function(){this.__dirty&=~El},e.prototype.getUpdatedPathProxy=function(t){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,t),this.path},e.prototype.createPathProxy=function(){this.path=new ja(!1)},e.prototype.hasStroke=function(){var t=this.style,n=t.stroke;return!(n==null||n==="none"||!(t.lineWidth>0))},e.prototype.hasFill=function(){var t=this.style,n=t.fill;return n!=null&&n!=="none"},e.prototype.getBoundingRect=function(){var t=this._rect,n=this.style,a=!t;if(a){var i=!1;this.path||(i=!0,this.createPathProxy());var o=this.path;(i||this.__dirty&El)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),t=o.getBoundingRect()}if(this._rect=t,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=t.clone());if(this.__dirty||a){s.copy(t);var l=n.strokeNoScale?this.getLineScale():1,u=n.lineWidth;if(!this.hasFill()){var c=this.strokeContainThreshold;u=Math.max(u,c??4)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return t},e.prototype.contain=function(t,n){var a=this.transformCoordToLocal(t,n),i=this.getBoundingRect(),o=this.style;if(t=a[0],n=a[1],i.contain(t,n)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),HW(s,l/u,t,n)))return!0}if(this.hasFill())return WW(s,t,n)}return!1},e.prototype.dirtyShape=function(){this.__dirty|=El,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},e.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},e.prototype.animateShape=function(t){return this.animate("shape",t)},e.prototype.updateDuringAnimation=function(t){t==="style"?this.dirtyStyle():t==="shape"?this.dirtyShape():this.markRedraw()},e.prototype.attrKV=function(t,n){t==="shape"?this.setShape(n):r.prototype.attrKV.call(this,t,n)},e.prototype.setShape=function(t,n){var a=this.shape;return a||(a=this.shape={}),typeof t=="string"?a[t]=n:lt(a,t),this.dirtyShape(),this},e.prototype.shapeChanged=function(){return!!(this.__dirty&El)},e.prototype.createStyle=function(t){return fp(bd,t)},e.prototype._innerSaveToNormal=function(t){r.prototype._innerSaveToNormal.call(this,t);var n=this._normalState;t.shape&&!n.shape&&(n.shape=lt({},this.shape))},e.prototype._applyStateObj=function(t,n,a,i,o,s){r.prototype._applyStateObj.call(this,t,n,a,i,o,s);var l=!(n&&i),u;if(n&&n.shape?o?i?u=n.shape:(u=lt({},a.shape),lt(u,n.shape)):(u=lt({},i?this.shape:a.shape),lt(u,n.shape)):l&&(u=a.shape),u)if(o){this.shape=lt({},this.shape);for(var c={},h=ue(u),d=0;d<h.length;d++){var v=h[d];typeof u[v]=="object"?this.shape[v]=u[v]:c[v]=u[v]}this._transitionState(t,{shape:c},s)}else this.shape=u,this.dirtyShape()},e.prototype._mergeStates=function(t){for(var n=r.prototype._mergeStates.call(this,t),a,i=0;i<t.length;i++){var o=t[i];o.shape&&(a=a||{},this._mergeStyle(a,o.shape))}return a&&(n.shape=a),n},e.prototype.getAnimationStyleProps=function(){return UW},e.prototype.isZeroArea=function(){return!1},e.extend=function(t){var n=function(i){Ge(o,i);function o(s){var l=i.call(this,s)||this;return t.init&&t.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return Gt(t.style)},o.prototype.getDefaultShape=function(){return Gt(t.shape)},o}(e);for(var a in t)typeof t[a]=="function"&&(n.prototype[a]=t[a]);return n},e.initDefaultProps=function(){var t=e.prototype;t.type="path",t.strokeContainThreshold=5,t.segmentIgnoreThreshold=0,t.subPixelOptimize=!1,t.autoBatch=!1,t.__dirty=Tn|mc|El}(),e}(ta),ZW=zt({strokeFirst:!0,font:mo,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},bd),Ql=function(r){Ge(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.hasStroke=function(){var t=this.style,n=t.stroke;return n!=null&&n!=="none"&&t.lineWidth>0},e.prototype.hasFill=function(){var t=this.style,n=t.fill;return n!=null&&n!=="none"},e.prototype.createStyle=function(t){return fp(ZW,t)},e.prototype.setBoundingRect=function(t){this._rect=t},e.prototype.getBoundingRect=function(){var t=this.style;if(!this._rect){var n=t.text;n!=null?n+="":n="";var a=Th(n,t.font,t.textAlign,t.textBaseline);if(a.x+=t.x||0,a.y+=t.y||0,this.hasStroke()){var i=t.lineWidth;a.x-=i/2,a.y-=i/2,a.width+=i,a.height+=i}this._rect=a}return this._rect},e.initDefaultProps=function(){var t=e.prototype;t.dirtyRectTolerance=10}(),e}(ta);Ql.prototype.type="tspan";var YW=zt({x:0,y:0},Ms),XW={style:zt({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},_p.style)};function $W(r){return!!(r&&typeof r!="string"&&r.width&&r.height)}var Tr=function(r){Ge(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.createStyle=function(t){return fp(YW,t)},e.prototype._getSize=function(t){var n=this.style,a=n[t];if(a!=null)return a;var i=$W(n.image)?n.image:this.__image;if(!i)return 0;var o=t==="width"?"height":"width",s=n[o];return s==null?i[t]:i[t]/i[o]*s},e.prototype.getWidth=function(){return this._getSize("width")},e.prototype.getHeight=function(){return this._getSize("height")},e.prototype.getAnimationStyleProps=function(){return XW},e.prototype.getBoundingRect=function(){var t=this.style;return this._rect||(this._rect=new Qt(t.x||0,t.y||0,this.getWidth(),this.getHeight())),this._rect},e}(ta);Tr.prototype.type="image";function jW(r,e){var t=e.x,n=e.y,a=e.width,i=e.height,o=e.r,s,l,u,c;a<0&&(t=t+a,a=-a),i<0&&(n=n+i,i=-i),typeof o=="number"?s=l=u=c=o:o instanceof Array?o.length===1?s=l=u=c=o[0]:o.length===2?(s=u=o[0],l=c=o[1]):o.length===3?(s=o[0],l=c=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],c=o[3]):s=l=u=c=0;var h;s+l>a&&(h=s+l,s*=a/h,l*=a/h),u+c>a&&(h=u+c,u*=a/h,c*=a/h),l+u>i&&(h=l+u,l*=i/h,u*=i/h),s+c>i&&(h=s+c,s*=i/h,c*=i/h),r.moveTo(t+s,n),r.lineTo(t+a-l,n),l!==0&&r.arc(t+a-l,n+l,l,-Math.PI/2,0),r.lineTo(t+a,n+i-u),u!==0&&r.arc(t+a-u,n+i-u,u,0,Math.PI/2),r.lineTo(t+c,n+i),c!==0&&r.arc(t+c,n+i-c,c,Math.PI/2,Math.PI),r.lineTo(t,n+s),s!==0&&r.arc(t+s,n+s,s,Math.PI,Math.PI*1.5)}var Vl=Math.round;function RP(r,e,t){if(e){var n=e.x1,a=e.x2,i=e.y1,o=e.y2;r.x1=n,r.x2=a,r.y1=i,r.y2=o;var s=t&&t.lineWidth;return s&&(Vl(n*2)===Vl(a*2)&&(r.x1=r.x2=_s(n,s,!0)),Vl(i*2)===Vl(o*2)&&(r.y1=r.y2=_s(i,s,!0))),r}}function EP(r,e,t){if(e){var n=e.x,a=e.y,i=e.width,o=e.height;r.x=n,r.y=a,r.width=i,r.height=o;var s=t&&t.lineWidth;return s&&(r.x=_s(n,s,!0),r.y=_s(a,s,!0),r.width=Math.max(_s(n+i,s,!1)-r.x,i===0?0:1),r.height=Math.max(_s(a+o,s,!1)-r.y,o===0?0:1)),r}}function _s(r,e,t){if(!e)return r;var n=Vl(r*2);return(n+Vl(e))%2===0?n/2:(n+(t?1:-1))/2}var qW=function(){function r(){this.x=0,this.y=0,this.width=0,this.height=0}return r}(),KW={},fe=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new qW},e.prototype.buildPath=function(t,n){var a,i,o,s;if(this.subPixelOptimize){var l=EP(KW,n,this.style);a=l.x,i=l.y,o=l.width,s=l.height,l.r=n.r,n=l}else a=n.x,i=n.y,o=n.width,s=n.height;n.r?jW(t,n):t.rect(a,i,o,s)},e.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},e}(ie);fe.prototype.type="rect";var oA={fill:"#000"},sA=2,QW={style:zt({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},_p.style)},pe=function(r){Ge(e,r);function e(t){var n=r.call(this)||this;return n.type="text",n._children=[],n._defaultStyle=oA,n.attr(t),n}return e.prototype.childrenRef=function(){return this._children},e.prototype.update=function(){r.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var t=0;t<this._children.length;t++){var n=this._children[t];n.zlevel=this.zlevel,n.z=this.z,n.z2=this.z2,n.culling=this.culling,n.cursor=this.cursor,n.invisible=this.invisible}},e.prototype.updateTransform=function(){var t=this.innerTransformable;t?(t.updateTransform(),t.transform&&(this.transform=t.transform)):r.prototype.updateTransform.call(this)},e.prototype.getLocalTransform=function(t){var n=this.innerTransformable;return n?n.getLocalTransform(t):r.prototype.getLocalTransform.call(this,t)},e.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),r.prototype.getComputedTransform.call(this)},e.prototype._updateSubTexts=function(){this._childCursor=0,eH(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},e.prototype.addSelfToZr=function(t){r.prototype.addSelfToZr.call(this,t);for(var n=0;n<this._children.length;n++)this._children[n].__zr=t},e.prototype.removeSelfFromZr=function(t){r.prototype.removeSelfFromZr.call(this,t);for(var n=0;n<this._children.length;n++)this._children[n].__zr=null},e.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var t=new Qt(0,0,0,0),n=this._children,a=[],i=null,o=0;o<n.length;o++){var s=n[o],l=s.getBoundingRect(),u=s.getLocalTransform(a);u?(t.copy(l),t.applyTransform(u),i=i||t.clone(),i.union(t)):(i=i||l.clone(),i.union(l))}this._rect=i||t}return this._rect},e.prototype.setDefaultTextStyle=function(t){this._defaultStyle=t||oA},e.prototype.setTextContent=function(t){},e.prototype._mergeStyle=function(t,n){if(!n)return t;var a=n.rich,i=t.rich||a&&{};return lt(t,n),a&&i?(this._mergeRich(i,a),t.rich=i):i&&(t.rich=i),t},e.prototype._mergeRich=function(t,n){for(var a=ue(n),i=0;i<a.length;i++){var o=a[i];t[o]=t[o]||{},lt(t[o],n[o])}},e.prototype.getAnimationStyleProps=function(){return QW},e.prototype._getOrCreateChild=function(t){var n=this._children[this._childCursor];return(!n||!(n instanceof t))&&(n=new t),this._children[this._childCursor++]=n,n.__zr=this.__zr,n.parent=this,n},e.prototype._updatePlainTexts=function(){var t=this.style,n=t.font||mo,a=t.padding,i=dA(t),o=bW(i,t),s=Uy(t),l=!!t.backgroundColor,u=o.outerHeight,c=o.outerWidth,h=o.contentWidth,d=o.lines,v=o.lineHeight,p=this._defaultStyle;this.isTruncated=!!o.isTruncated;var y=t.x||0,_=t.y||0,g=t.align||p.align||"left",f=t.verticalAlign||p.verticalAlign||"top",w=y,x=Ol(_,o.contentHeight,f);if(s||a){var S=wc(y,c,g),A=Ol(_,u,f);s&&this._renderBackground(t,t,S,A,c,u)}x+=v/2,a&&(w=vA(y,g,a),f==="top"?x+=a[0]:f==="bottom"&&(x-=a[2]));for(var T=0,L=!1,M=fA("fill"in t?t.fill:(L=!0,p.fill)),I=hA("stroke"in t?t.stroke:!l&&(!p.autoStroke||L)?(T=sA,p.stroke):null),R=t.textShadowBlur>0,P=t.width!=null&&(t.overflow==="truncate"||t.overflow==="break"||t.overflow==="breakAll"),E=o.calculatedLineHeight,D=0;D<d.length;D++){var N=this._getOrCreateChild(Ql),V=N.createStyle();N.useStyle(V),V.text=d[D],V.x=w,V.y=x,V.textAlign=g,V.textBaseline="middle",V.opacity=t.opacity,V.strokeFirst=!0,R&&(V.shadowBlur=t.textShadowBlur||0,V.shadowColor=t.textShadowColor||"transparent",V.shadowOffsetX=t.textShadowOffsetX||0,V.shadowOffsetY=t.textShadowOffsetY||0),V.stroke=I,V.fill=M,I&&(V.lineWidth=t.lineWidth||T,V.lineDash=t.lineDash,V.lineDashOffset=t.lineDashOffset||0),V.font=n,uA(V,t),x+=v,P&&N.setBoundingRect(new Qt(wc(V.x,h,V.textAlign),Ol(V.y,E,V.textBaseline),h,E))}},e.prototype._updateRichTexts=function(){var t=this.style,n=dA(t),a=TW(n,t),i=a.width,o=a.outerWidth,s=a.outerHeight,l=t.padding,u=t.x||0,c=t.y||0,h=this._defaultStyle,d=t.align||h.align,v=t.verticalAlign||h.verticalAlign;this.isTruncated=!!a.isTruncated;var p=wc(u,o,d),y=Ol(c,s,v),_=p,g=y;l&&(_+=l[3],g+=l[0]);var f=_+i;Uy(t)&&this._renderBackground(t,t,p,y,o,s);for(var w=!!t.backgroundColor,x=0;x<a.lines.length;x++){for(var S=a.lines[x],A=S.tokens,T=A.length,L=S.lineHeight,M=S.width,I=0,R=_,P=f,E=T-1,D=void 0;I<T&&(D=A[I],!D.align||D.align==="left");)this._placeToken(D,t,L,g,R,"left",w),M-=D.width,R+=D.width,I++;for(;E>=0&&(D=A[E],D.align==="right");)this._placeToken(D,t,L,g,P,"right",w),M-=D.width,P-=D.width,E--;for(R+=(i-(R-_)-(f-P)-M)/2;I<=E;)D=A[I],this._placeToken(D,t,L,g,R+D.width/2,"center",w),R+=D.width,I++;g+=L}},e.prototype._placeToken=function(t,n,a,i,o,s,l){var u=n.rich[t.styleName]||{};u.text=t.text;var c=t.verticalAlign,h=i+a/2;c==="top"?h=i+t.height/2:c==="bottom"&&(h=i+a-t.height/2);var d=!t.isLineHolder&&Uy(u);d&&this._renderBackground(u,n,s==="right"?o-t.width:s==="center"?o-t.width/2:o,h-t.height/2,t.width,t.height);var v=!!u.backgroundColor,p=t.textPadding;p&&(o=vA(o,s,p),h-=t.height/2-p[0]-t.innerHeight/2);var y=this._getOrCreateChild(Ql),_=y.createStyle();y.useStyle(_);var g=this._defaultStyle,f=!1,w=0,x=fA("fill"in u?u.fill:"fill"in n?n.fill:(f=!0,g.fill)),S=hA("stroke"in u?u.stroke:"stroke"in n?n.stroke:!v&&!l&&(!g.autoStroke||f)?(w=sA,g.stroke):null),A=u.textShadowBlur>0||n.textShadowBlur>0;_.text=t.text,_.x=o,_.y=h,A&&(_.shadowBlur=u.textShadowBlur||n.textShadowBlur||0,_.shadowColor=u.textShadowColor||n.textShadowColor||"transparent",_.shadowOffsetX=u.textShadowOffsetX||n.textShadowOffsetX||0,_.shadowOffsetY=u.textShadowOffsetY||n.textShadowOffsetY||0),_.textAlign=s,_.textBaseline="middle",_.font=t.font||mo,_.opacity=Ha(u.opacity,n.opacity,1),uA(_,u),S&&(_.lineWidth=Ha(u.lineWidth,n.lineWidth,w),_.lineDash=Zt(u.lineDash,n.lineDash),_.lineDashOffset=n.lineDashOffset||0,_.stroke=S),x&&(_.fill=x);var T=t.contentWidth,L=t.contentHeight;y.setBoundingRect(new Qt(wc(_.x,T,_.textAlign),Ol(_.y,L,_.textBaseline),T,L))},e.prototype._renderBackground=function(t,n,a,i,o,s){var l=t.backgroundColor,u=t.borderWidth,c=t.borderColor,h=l&&l.image,d=l&&!h,v=t.borderRadius,p=this,y,_;if(d||t.lineHeight||u&&c){y=this._getOrCreateChild(fe),y.useStyle(y.createStyle()),y.style.fill=null;var g=y.shape;g.x=a,g.y=i,g.width=o,g.height=s,g.r=v,y.dirtyShape()}if(d){var f=y.style;f.fill=l||null,f.fillOpacity=Zt(t.fillOpacity,1)}else if(h){_=this._getOrCreateChild(Tr),_.onload=function(){p.dirtyStyle()};var w=_.style;w.image=l.image,w.x=a,w.y=i,w.width=o,w.height=s}if(u&&c){var f=y.style;f.lineWidth=u,f.stroke=c,f.strokeOpacity=Zt(t.strokeOpacity,1),f.lineDash=t.borderDash,f.lineDashOffset=t.borderDashOffset||0,y.strokeContainThreshold=0,y.hasFill()&&y.hasStroke()&&(f.strokeFirst=!0,f.lineWidth*=2)}var x=(y||_).style;x.shadowBlur=t.shadowBlur||0,x.shadowColor=t.shadowColor||"transparent",x.shadowOffsetX=t.shadowOffsetX||0,x.shadowOffsetY=t.shadowOffsetY||0,x.opacity=Ha(t.opacity,n.opacity,1)},e.makeFont=function(t){var n="";return BP(t)&&(n=[t.fontStyle,t.fontWeight,OP(t.fontSize),t.fontFamily||"sans-serif"].join(" ")),n&&ga(n)||t.textFont||t.font},e}(ta),JW={left:!0,right:1,center:1},tH={top:1,bottom:1,middle:1},lA=["fontStyle","fontWeight","fontSize","fontFamily"];function OP(r){return typeof r=="string"&&(r.indexOf("px")!==-1||r.indexOf("rem")!==-1||r.indexOf("em")!==-1)?r:isNaN(+r)?E1+"px":r+"px"}function uA(r,e){for(var t=0;t<lA.length;t++){var n=lA[t],a=e[n];a!=null&&(r[n]=a)}}function BP(r){return r.fontSize!=null||r.fontFamily||r.fontWeight}function eH(r){return cA(r),B(r.rich,cA),r}function cA(r){if(r){r.font=pe.makeFont(r);var e=r.align;e==="middle"&&(e="center"),r.align=e==null||JW[e]?e:"left";var t=r.verticalAlign;t==="center"&&(t="middle"),r.verticalAlign=t==null||tH[t]?t:"top";var n=r.padding;n&&(r.padding=V1(r.padding))}}function hA(r,e){return r==null||e<=0||r==="transparent"||r==="none"?null:r.image||r.colorStops?"#000":r}function fA(r){return r==null||r==="none"?null:r.image||r.colorStops?"#000":r}function vA(r,e,t){return e==="right"?r-t[1]:e==="center"?r+t[3]/2-t[1]/2:r+t[3]}function dA(r){var e=r.text;return e!=null&&(e+=""),e}function Uy(r){return!!(r.backgroundColor||r.lineHeight||r.borderWidth&&r.borderColor)}var Ht=ve(),g_=function(r,e,t,n){if(n){var a=Ht(n);a.dataIndex=t,a.dataType=e,a.seriesIndex=r,a.ssrType="chart",n.type==="group"&&n.traverse(function(i){var o=Ht(i);o.seriesIndex=r,o.dataIndex=t,o.dataType=e,o.ssrType="chart"})}},pA=1,gA={},NP=ve(),J1=ve(),tw=0,Lh=1,xp=2,tn=["emphasis","blur","select"],th=["normal","emphasis","blur","select"],fu=10,rH=9,Ds="highlight",Qv="downplay",Nc="select",Jv="unselect",zc="toggleSelect";function gl(r){return r!=null&&r!=="none"}function bp(r,e,t){r.onHoverStateChange&&(r.hoverState||0)!==t&&r.onHoverStateChange(e),r.hoverState=t}function zP(r){bp(r,"emphasis",xp)}function FP(r){r.hoverState===xp&&bp(r,"normal",tw)}function ew(r){bp(r,"blur",Lh)}function VP(r){r.hoverState===Lh&&bp(r,"normal",tw)}function nH(r){r.selected=!0}function aH(r){r.selected=!1}function yA(r,e,t){e(r,t)}function Pi(r,e,t){yA(r,e,t),r.isGroup&&r.traverse(function(n){yA(n,e,t)})}function Sd(r,e){switch(e){case"emphasis":r.hoverState=xp;break;case"normal":r.hoverState=tw;break;case"blur":r.hoverState=Lh;break;case"select":r.selected=!0}}function iH(r,e,t,n){for(var a=r.style,i={},o=0;o<e.length;o++){var s=e[o],l=a[s];i[s]=l??(n&&n[s])}for(var o=0;o<r.animators.length;o++){var u=r.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(t)<0&&u.targetName==="style"&&u.saveTo(i,e)}return i}function oH(r,e,t,n){var a=t&&te(t,"select")>=0,i=!1;if(r instanceof ie){var o=NP(r),s=a&&o.selectFill||o.normalFill,l=a&&o.selectStroke||o.normalStroke;if(gl(s)||gl(l)){n=n||{};var u=n.style||{};u.fill==="inherit"?(i=!0,n=lt({},n),u=lt({},u),u.fill=s):!gl(u.fill)&&gl(s)?(i=!0,n=lt({},n),u=lt({},u),u.fill=e_(s)):!gl(u.stroke)&&gl(l)&&(i||(n=lt({},n),u=lt({},u)),u.stroke=e_(l)),n.style=u}}if(n&&n.z2==null){i||(n=lt({},n));var c=r.z2EmphasisLift;n.z2=r.z2+(c??fu)}return n}function sH(r,e,t){if(t&&t.z2==null){t=lt({},t);var n=r.z2SelectLift;t.z2=r.z2+(n??rH)}return t}function lH(r,e,t){var n=te(r.currentStates,e)>=0,a=r.style.opacity,i=n?null:iH(r,["opacity"],e,{opacity:1});t=t||{};var o=t.style||{};return o.opacity==null&&(t=lt({},t),o=lt({opacity:n?a:i.opacity*.1},o),t.style=o),t}function Zy(r,e){var t=this.states[r];if(this.style){if(r==="emphasis")return oH(this,r,e,t);if(r==="blur")return lH(this,r,t);if(r==="select")return sH(this,r,t)}return t}function zs(r){r.stateProxy=Zy;var e=r.getTextContent(),t=r.getTextGuideLine();e&&(e.stateProxy=Zy),t&&(t.stateProxy=Zy)}function mA(r,e){!UP(r,e)&&!r.__highByOuter&&Pi(r,zP)}function _A(r,e){!UP(r,e)&&!r.__highByOuter&&Pi(r,FP)}function Ti(r,e){r.__highByOuter|=1<<(e||0),Pi(r,zP)}function Ci(r,e){!(r.__highByOuter&=~(1<<(e||0)))&&Pi(r,FP)}function GP(r){Pi(r,ew)}function rw(r){Pi(r,VP)}function WP(r){Pi(r,nH)}function HP(r){Pi(r,aH)}function UP(r,e){return r.__highDownSilentOnTouch&&e.zrByTouch}function ZP(r){var e=r.getModel(),t=[],n=[];e.eachComponent(function(a,i){var o=J1(i),s=a==="series",l=s?r.getViewOfSeriesModel(i):r.getViewOfComponentModel(i);!s&&n.push(l),o.isBlured&&(l.group.traverse(function(u){VP(u)}),s&&t.push(i)),o.isBlured=!1}),B(n,function(a){a&&a.toggleBlurSeries&&a.toggleBlurSeries(t,!1,e)})}function y_(r,e,t,n){var a=n.getModel();t=t||"coordinateSystem";function i(u,c){for(var h=0;h<c.length;h++){var d=u.getItemGraphicEl(c[h]);d&&rw(d)}}if(r!=null&&!(!e||e==="none")){var o=a.getSeriesByIndex(r),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];a.eachSeries(function(u){var c=o===u,h=u.coordinateSystem;h&&h.master&&(h=h.master);var d=h&&s?h===s:c;if(!(t==="series"&&!c||t==="coordinateSystem"&&!d||e==="series"&&c)){var v=n.getViewOfSeriesModel(u);if(v.group.traverse(function(_){_.__highByOuter&&c&&e==="self"||ew(_)}),Gr(e))i(u.getData(),e);else if(Vt(e))for(var p=ue(e),y=0;y<p.length;y++)i(u.getData(p[y]),e[p[y]]);l.push(u),J1(u).isBlured=!0}}),a.eachComponent(function(u,c){if(u!=="series"){var h=n.getViewOfComponentModel(c);h&&h.toggleBlurSeries&&h.toggleBlurSeries(l,!0,a)}})}}function m_(r,e,t){if(!(r==null||e==null)){var n=t.getModel().getComponent(r,e);if(n){J1(n).isBlured=!0;var a=t.getViewOfComponentModel(n);!a||!a.focusBlurEnabled||a.group.traverse(function(i){ew(i)})}}}function uH(r,e,t){var n=r.seriesIndex,a=r.getData(e.dataType);if(a){var i=Bs(a,e);i=(ht(i)?i[0]:i)||0;var o=a.getItemGraphicEl(i);if(!o)for(var s=a.count(),l=0;!o&&l<s;)o=a.getItemGraphicEl(l++);if(o){var u=Ht(o);y_(n,u.focus,u.blurScope,t)}else{var c=r.get(["emphasis","focus"]),h=r.get(["emphasis","blurScope"]);c!=null&&y_(n,c,h,t)}}}function nw(r,e,t,n){var a={focusSelf:!1,dispatchers:null};if(r==null||r==="series"||e==null||t==null)return a;var i=n.getModel().getComponent(r,e);if(!i)return a;var o=n.getViewOfComponentModel(i);if(!o||!o.findHighDownDispatchers)return a;for(var s=o.findHighDownDispatchers(t),l,u=0;u<s.length;u++)if(Ht(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function cH(r,e,t){var n=Ht(r),a=nw(n.componentMainType,n.componentIndex,n.componentHighDownName,t),i=a.dispatchers,o=a.focusSelf;i?(o&&m_(n.componentMainType,n.componentIndex,t),B(i,function(s){return mA(s,e)})):(y_(n.seriesIndex,n.focus,n.blurScope,t),n.focus==="self"&&m_(n.componentMainType,n.componentIndex,t),mA(r,e))}function hH(r,e,t){ZP(t);var n=Ht(r),a=nw(n.componentMainType,n.componentIndex,n.componentHighDownName,t).dispatchers;a?B(a,function(i){return _A(i,e)}):_A(r,e)}function fH(r,e,t){if(w_(e)){var n=e.dataType,a=r.getData(n),i=Bs(a,e);ht(i)||(i=[i]),r[e.type===zc?"toggleSelect":e.type===Nc?"select":"unselect"](i,n)}}function wA(r){var e=r.getAllData();B(e,function(t){var n=t.data,a=t.type;n.eachItemGraphicEl(function(i,o){r.isSelected(o,a)?WP(i):HP(i)})})}function vH(r){var e=[];return r.eachSeries(function(t){var n=t.getAllData();B(n,function(a){a.data;var i=a.type,o=t.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:t.seriesIndex};i!=null&&(s.dataType=i),e.push(s)}})}),e}function Is(r,e,t){ws(r,!0),Pi(r,zs),__(r,e,t)}function dH(r){ws(r,!1)}function Xe(r,e,t,n){n?dH(r):Is(r,e,t)}function __(r,e,t){var n=Ht(r);e!=null?(n.focus=e,n.blurScope=t):n.focus&&(n.focus=null)}var xA=["emphasis","blur","select"],pH={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function kr(r,e,t,n){t=t||"itemStyle";for(var a=0;a<xA.length;a++){var i=xA[a],o=e.getModel([i,t]),s=r.ensureState(i);s.style=n?n(o):o[pH[t]]()}}function ws(r,e){var t=e===!1,n=r;r.highDownSilentOnTouch&&(n.__highDownSilentOnTouch=r.highDownSilentOnTouch),(!t||n.__highDownDispatcher)&&(n.__highByOuter=n.__highByOuter||0,n.__highDownDispatcher=!t)}function eh(r){return!!(r&&r.__highDownDispatcher)}function gH(r,e,t){var n=Ht(r);n.componentMainType=e.mainType,n.componentIndex=e.componentIndex,n.componentHighDownName=t}function yH(r){var e=gA[r];return e==null&&pA<=32&&(e=gA[r]=pA++),e}function w_(r){var e=r.type;return e===Nc||e===Jv||e===zc}function bA(r){var e=r.type;return e===Ds||e===Qv}function mH(r){var e=NP(r);e.normalFill=r.style.fill,e.normalStroke=r.style.stroke;var t=r.states.select||{};e.selectFill=t.style&&t.style.fill||null,e.selectStroke=t.style&&t.style.stroke||null}var yl=ja.CMD,_H=[[],[],[]],SA=Math.sqrt,wH=Math.atan2;function YP(r,e){if(e){var t=r.data,n=r.len(),a,i,o,s,l,u,c=yl.M,h=yl.C,d=yl.L,v=yl.R,p=yl.A,y=yl.Q;for(o=0,s=0;o<n;){switch(a=t[o++],s=o,i=0,a){case c:i=1;break;case d:i=1;break;case h:i=3;break;case y:i=2;break;case p:var _=e[4],g=e[5],f=SA(e[0]*e[0]+e[1]*e[1]),w=SA(e[2]*e[2]+e[3]*e[3]),x=wH(-e[1]/w,e[0]/f);t[o]*=f,t[o++]+=_,t[o]*=w,t[o++]+=g,t[o++]*=f,t[o++]*=w,t[o++]+=x,t[o++]+=x,o+=2,s=o;break;case v:u[0]=t[o++],u[1]=t[o++],Pr(u,u,e),t[s++]=u[0],t[s++]=u[1],u[0]+=t[o++],u[1]+=t[o++],Pr(u,u,e),t[s++]=u[0],t[s++]=u[1]}for(l=0;l<i;l++){var S=_H[l];S[0]=t[o++],S[1]=t[o++],Pr(S,S,e),t[s++]=S[0],t[s++]=S[1]}}r.increaseVersion()}}var Yy=Math.sqrt,tv=Math.sin,ev=Math.cos,Xu=Math.PI;function AA(r){return Math.sqrt(r[0]*r[0]+r[1]*r[1])}function x_(r,e){return(r[0]*e[0]+r[1]*e[1])/(AA(r)*AA(e))}function TA(r,e){return(r[0]*e[1]<r[1]*e[0]?-1:1)*Math.acos(x_(r,e))}function CA(r,e,t,n,a,i,o,s,l,u,c){var h=l*(Xu/180),d=ev(h)*(r-t)/2+tv(h)*(e-n)/2,v=-1*tv(h)*(r-t)/2+ev(h)*(e-n)/2,p=d*d/(o*o)+v*v/(s*s);p>1&&(o*=Yy(p),s*=Yy(p));var y=(a===i?-1:1)*Yy((o*o*(s*s)-o*o*(v*v)-s*s*(d*d))/(o*o*(v*v)+s*s*(d*d)))||0,_=y*o*v/s,g=y*-s*d/o,f=(r+t)/2+ev(h)*_-tv(h)*g,w=(e+n)/2+tv(h)*_+ev(h)*g,x=TA([1,0],[(d-_)/o,(v-g)/s]),S=[(d-_)/o,(v-g)/s],A=[(-1*d-_)/o,(-1*v-g)/s],T=TA(S,A);if(x_(S,A)<=-1&&(T=Xu),x_(S,A)>=1&&(T=0),T<0){var L=Math.round(T/Xu*1e6)/1e6;T=Xu*2+L%2*Xu}c.addData(u,f,w,o,s,x,T,h,i)}var xH=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,bH=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function SH(r){var e=new ja;if(!r)return e;var t=0,n=0,a=t,i=n,o,s=ja.CMD,l=r.match(xH);if(!l)return e;for(var u=0;u<l.length;u++){for(var c=l[u],h=c.charAt(0),d=void 0,v=c.match(bH)||[],p=v.length,y=0;y<p;y++)v[y]=parseFloat(v[y]);for(var _=0;_<p;){var g=void 0,f=void 0,w=void 0,x=void 0,S=void 0,A=void 0,T=void 0,L=t,M=n,I=void 0,R=void 0;switch(h){case"l":t+=v[_++],n+=v[_++],d=s.L,e.addData(d,t,n);break;case"L":t=v[_++],n=v[_++],d=s.L,e.addData(d,t,n);break;case"m":t+=v[_++],n+=v[_++],d=s.M,e.addData(d,t,n),a=t,i=n,h="l";break;case"M":t=v[_++],n=v[_++],d=s.M,e.addData(d,t,n),a=t,i=n,h="L";break;case"h":t+=v[_++],d=s.L,e.addData(d,t,n);break;case"H":t=v[_++],d=s.L,e.addData(d,t,n);break;case"v":n+=v[_++],d=s.L,e.addData(d,t,n);break;case"V":n=v[_++],d=s.L,e.addData(d,t,n);break;case"C":d=s.C,e.addData(d,v[_++],v[_++],v[_++],v[_++],v[_++],v[_++]),t=v[_-2],n=v[_-1];break;case"c":d=s.C,e.addData(d,v[_++]+t,v[_++]+n,v[_++]+t,v[_++]+n,v[_++]+t,v[_++]+n),t+=v[_-2],n+=v[_-1];break;case"S":g=t,f=n,I=e.len(),R=e.data,o===s.C&&(g+=t-R[I-4],f+=n-R[I-3]),d=s.C,L=v[_++],M=v[_++],t=v[_++],n=v[_++],e.addData(d,g,f,L,M,t,n);break;case"s":g=t,f=n,I=e.len(),R=e.data,o===s.C&&(g+=t-R[I-4],f+=n-R[I-3]),d=s.C,L=t+v[_++],M=n+v[_++],t+=v[_++],n+=v[_++],e.addData(d,g,f,L,M,t,n);break;case"Q":L=v[_++],M=v[_++],t=v[_++],n=v[_++],d=s.Q,e.addData(d,L,M,t,n);break;case"q":L=v[_++]+t,M=v[_++]+n,t+=v[_++],n+=v[_++],d=s.Q,e.addData(d,L,M,t,n);break;case"T":g=t,f=n,I=e.len(),R=e.data,o===s.Q&&(g+=t-R[I-4],f+=n-R[I-3]),t=v[_++],n=v[_++],d=s.Q,e.addData(d,g,f,t,n);break;case"t":g=t,f=n,I=e.len(),R=e.data,o===s.Q&&(g+=t-R[I-4],f+=n-R[I-3]),t+=v[_++],n+=v[_++],d=s.Q,e.addData(d,g,f,t,n);break;case"A":w=v[_++],x=v[_++],S=v[_++],A=v[_++],T=v[_++],L=t,M=n,t=v[_++],n=v[_++],d=s.A,CA(L,M,t,n,A,T,w,x,S,d,e);break;case"a":w=v[_++],x=v[_++],S=v[_++],A=v[_++],T=v[_++],L=t,M=n,t+=v[_++],n+=v[_++],d=s.A,CA(L,M,t,n,A,T,w,x,S,d,e);break}}(h==="z"||h==="Z")&&(d=s.Z,e.addData(d),t=a,n=i),o=d}return e.toStatic(),e}var XP=function(r){Ge(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.applyTransform=function(t){},e}(ie);function $P(r){return r.setData!=null}function jP(r,e){var t=SH(r),n=lt({},e);return n.buildPath=function(a){if($P(a)){a.setData(t.data);var i=a.getContext();i&&a.rebuildPath(i,1)}else{var i=a;t.rebuildPath(i,1)}},n.applyTransform=function(a){YP(t,a),this.dirtyShape()},n}function qP(r,e){return new XP(jP(r,e))}function AH(r,e){var t=jP(r,e),n=function(a){Ge(i,a);function i(o){var s=a.call(this,o)||this;return s.applyTransform=t.applyTransform,s.buildPath=t.buildPath,s}return i}(XP);return n}function TH(r,e){for(var t=[],n=r.length,a=0;a<n;a++){var i=r[a];t.push(i.getUpdatedPathProxy(!0))}var o=new ie(e);return o.createPathProxy(),o.buildPath=function(s){if($P(s)){s.appendPath(t);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}function aw(r,e){e=e||{};var t=new ie;return r.shape&&t.setShape(r.shape),t.setStyle(r.style),e.bakeTransform?YP(t.path,r.getComputedTransform()):e.toLocal?t.setLocalTransform(r.getComputedTransform()):t.copyTransform(r),t.buildPath=r.buildPath,t.applyTransform=t.applyTransform,t.z=r.z,t.z2=r.z2,t.zlevel=r.zlevel,t}var CH=function(){function r(){this.cx=0,this.cy=0,this.r=0}return r}(),ki=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new CH},e.prototype.buildPath=function(t,n){t.moveTo(n.cx+n.r,n.cy),t.arc(n.cx,n.cy,n.r,0,Math.PI*2)},e}(ie);ki.prototype.type="circle";var LH=function(){function r(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return r}(),Sp=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new LH},e.prototype.buildPath=function(t,n){var a=.5522848,i=n.cx,o=n.cy,s=n.rx,l=n.ry,u=s*a,c=l*a;t.moveTo(i-s,o),t.bezierCurveTo(i-s,o-c,i-u,o-l,i,o-l),t.bezierCurveTo(i+u,o-l,i+s,o-c,i+s,o),t.bezierCurveTo(i+s,o+c,i+u,o+l,i,o+l),t.bezierCurveTo(i-u,o+l,i-s,o+c,i-s,o),t.closePath()},e}(ie);Sp.prototype.type="ellipse";var KP=Math.PI,Xy=KP*2,Ko=Math.sin,ml=Math.cos,MH=Math.acos,Br=Math.atan2,LA=Math.abs,Fc=Math.sqrt,xc=Math.max,Pa=Math.min,ha=1e-4;function DH(r,e,t,n,a,i,o,s){var l=t-r,u=n-e,c=o-a,h=s-i,d=h*l-c*u;if(!(d*d<ha))return d=(c*(e-i)-h*(r-a))/d,[r+d*l,e+d*u]}function rv(r,e,t,n,a,i,o){var s=r-t,l=e-n,u=(o?i:-i)/Fc(s*s+l*l),c=u*l,h=-u*s,d=r+c,v=e+h,p=t+c,y=n+h,_=(d+p)/2,g=(v+y)/2,f=p-d,w=y-v,x=f*f+w*w,S=a-i,A=d*y-p*v,T=(w<0?-1:1)*Fc(xc(0,S*S*x-A*A)),L=(A*w-f*T)/x,M=(-A*f-w*T)/x,I=(A*w+f*T)/x,R=(-A*f+w*T)/x,P=L-_,E=M-g,D=I-_,N=R-g;return P*P+E*E>D*D+N*N&&(L=I,M=R),{cx:L,cy:M,x0:-c,y0:-h,x1:L*(a/S-1),y1:M*(a/S-1)}}function IH(r){var e;if(ht(r)){var t=r.length;if(!t)return r;t===1?e=[r[0],r[0],0,0]:t===2?e=[r[0],r[0],r[1],r[1]]:t===3?e=r.concat(r[2]):e=r}else e=[r,r,r,r];return e}function PH(r,e){var t,n=xc(e.r,0),a=xc(e.r0||0,0),i=n>0,o=a>0;if(!(!i&&!o)){if(i||(n=a,a=0),a>n){var s=n;n=a,a=s}var l=e.startAngle,u=e.endAngle;if(!(isNaN(l)||isNaN(u))){var c=e.cx,h=e.cy,d=!!e.clockwise,v=LA(u-l),p=v>Xy&&v%Xy;if(p>ha&&(v=p),!(n>ha))r.moveTo(c,h);else if(v>Xy-ha)r.moveTo(c+n*ml(l),h+n*Ko(l)),r.arc(c,h,n,l,u,!d),a>ha&&(r.moveTo(c+a*ml(u),h+a*Ko(u)),r.arc(c,h,a,u,l,d));else{var y=void 0,_=void 0,g=void 0,f=void 0,w=void 0,x=void 0,S=void 0,A=void 0,T=void 0,L=void 0,M=void 0,I=void 0,R=void 0,P=void 0,E=void 0,D=void 0,N=n*ml(l),V=n*Ko(l),W=a*ml(u),$=a*Ko(u),H=v>ha;if(H){var K=e.cornerRadius;K&&(t=IH(K),y=t[0],_=t[1],g=t[2],f=t[3]);var U=LA(n-a)/2;if(w=Pa(U,g),x=Pa(U,f),S=Pa(U,y),A=Pa(U,_),M=T=xc(w,x),I=L=xc(S,A),(T>ha||L>ha)&&(R=n*ml(u),P=n*Ko(u),E=a*ml(l),D=a*Ko(l),v<KP)){var j=DH(N,V,E,D,R,P,W,$);if(j){var ut=N-j[0],ot=V-j[1],it=R-j[0],Et=P-j[1],jt=1/Ko(MH((ut*it+ot*Et)/(Fc(ut*ut+ot*ot)*Fc(it*it+Et*Et)))/2),bt=Fc(j[0]*j[0]+j[1]*j[1]);M=Pa(T,(n-bt)/(jt+1)),I=Pa(L,(a-bt)/(jt-1))}}}if(!H)r.moveTo(c+N,h+V);else if(M>ha){var wt=Pa(g,M),Ot=Pa(f,M),xt=rv(E,D,N,V,n,wt,d),kt=rv(R,P,W,$,n,Ot,d);r.moveTo(c+xt.cx+xt.x0,h+xt.cy+xt.y0),M<T&&wt===Ot?r.arc(c+xt.cx,h+xt.cy,M,Br(xt.y0,xt.x0),Br(kt.y0,kt.x0),!d):(wt>0&&r.arc(c+xt.cx,h+xt.cy,wt,Br(xt.y0,xt.x0),Br(xt.y1,xt.x1),!d),r.arc(c,h,n,Br(xt.cy+xt.y1,xt.cx+xt.x1),Br(kt.cy+kt.y1,kt.cx+kt.x1),!d),Ot>0&&r.arc(c+kt.cx,h+kt.cy,Ot,Br(kt.y1,kt.x1),Br(kt.y0,kt.x0),!d))}else r.moveTo(c+N,h+V),r.arc(c,h,n,l,u,!d);if(!(a>ha)||!H)r.lineTo(c+W,h+$);else if(I>ha){var wt=Pa(y,I),Ot=Pa(_,I),xt=rv(W,$,R,P,a,-Ot,d),kt=rv(N,V,E,D,a,-wt,d);r.lineTo(c+xt.cx+xt.x0,h+xt.cy+xt.y0),I<L&&wt===Ot?r.arc(c+xt.cx,h+xt.cy,I,Br(xt.y0,xt.x0),Br(kt.y0,kt.x0),!d):(Ot>0&&r.arc(c+xt.cx,h+xt.cy,Ot,Br(xt.y0,xt.x0),Br(xt.y1,xt.x1),!d),r.arc(c,h,a,Br(xt.cy+xt.y1,xt.cx+xt.x1),Br(kt.cy+kt.y1,kt.cx+kt.x1),d),wt>0&&r.arc(c+kt.cx,h+kt.cy,wt,Br(kt.y1,kt.x1),Br(kt.y0,kt.x0),!d))}else r.lineTo(c+W,h+$),r.arc(c,h,a,u,l,d)}r.closePath()}}}var kH=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return r}(),en=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new kH},e.prototype.buildPath=function(t,n){PH(t,n)},e.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},e}(ie);en.prototype.type="sector";var RH=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return r}(),Mh=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new RH},e.prototype.buildPath=function(t,n){var a=n.cx,i=n.cy,o=Math.PI*2;t.moveTo(a+n.r,i),t.arc(a,i,n.r,0,o,!1),t.moveTo(a+n.r0,i),t.arc(a,i,n.r0,0,o,!0)},e}(ie);Mh.prototype.type="ring";function EH(r,e,t,n){var a=[],i=[],o=[],s=[],l,u,c,h;if(n){c=[1/0,1/0],h=[-1/0,-1/0];for(var d=0,v=r.length;d<v;d++)io(c,c,r[d]),oo(h,h,r[d]);io(c,c,n[0]),oo(h,h,n[1])}for(var d=0,v=r.length;d<v;d++){var p=r[d];if(t)l=r[d?d-1:v-1],u=r[(d+1)%v];else if(d===0||d===v-1){a.push(mi(r[d]));continue}else l=r[d-1],u=r[d+1];ms(i,u,l),Zv(i,i,e);var y=Y0(p,l),_=Y0(p,u),g=y+_;g!==0&&(y/=g,_/=g),Zv(o,i,-y),Zv(s,i,_);var f=w2([],p,o),w=w2([],p,s);n&&(oo(f,f,c),io(f,f,h),oo(w,w,c),io(w,w,h)),a.push(f),a.push(w)}return t&&a.push(a.shift()),a}function QP(r,e,t){var n=e.smooth,a=e.points;if(a&&a.length>=2){if(n){var i=EH(a,n,t,e.smoothConstraint);r.moveTo(a[0][0],a[0][1]);for(var o=a.length,s=0;s<(t?o:o-1);s++){var l=i[s*2],u=i[s*2+1],c=a[(s+1)%o];r.bezierCurveTo(l[0],l[1],u[0],u[1],c[0],c[1])}}else{r.moveTo(a[0][0],a[0][1]);for(var s=1,h=a.length;s<h;s++)r.lineTo(a[s][0],a[s][1])}t&&r.closePath()}}var OH=function(){function r(){this.points=null,this.smooth=0,this.smoothConstraint=null}return r}(),rn=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new OH},e.prototype.buildPath=function(t,n){QP(t,n,!0)},e}(ie);rn.prototype.type="polygon";var BH=function(){function r(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return r}(),nn=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new BH},e.prototype.buildPath=function(t,n){QP(t,n,!1)},e}(ie);nn.prototype.type="polyline";var NH={},zH=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}(),gr=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new zH},e.prototype.buildPath=function(t,n){var a,i,o,s;if(this.subPixelOptimize){var l=RP(NH,n,this.style);a=l.x1,i=l.y1,o=l.x2,s=l.y2}else a=n.x1,i=n.y1,o=n.x2,s=n.y2;var u=n.percent;u!==0&&(t.moveTo(a,i),u<1&&(o=a*(1-u)+o*u,s=i*(1-u)+s*u),t.lineTo(o,s))},e.prototype.pointAt=function(t){var n=this.shape;return[n.x1*(1-t)+n.x2*t,n.y1*(1-t)+n.y2*t]},e}(ie);gr.prototype.type="line";var un=[],FH=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return r}();function MA(r,e,t){var n=r.cpx2,a=r.cpy2;return n!=null||a!=null?[(t?k2:vr)(r.x1,r.cpx1,r.cpx2,r.x2,e),(t?k2:vr)(r.y1,r.cpy1,r.cpy2,r.y2,e)]:[(t?K0:Sr)(r.x1,r.cpx1,r.x2,e),(t?K0:Sr)(r.y1,r.cpy1,r.y2,e)]}var Dh=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new FH},e.prototype.buildPath=function(t,n){var a=n.x1,i=n.y1,o=n.x2,s=n.y2,l=n.cpx1,u=n.cpy1,c=n.cpx2,h=n.cpy2,d=n.percent;d!==0&&(t.moveTo(a,i),c==null||h==null?(d<1&&(jc(a,l,o,d,un),l=un[1],o=un[2],jc(i,u,s,d,un),u=un[1],s=un[2]),t.quadraticCurveTo(l,u,o,s)):(d<1&&(wo(a,l,c,o,d,un),l=un[1],c=un[2],o=un[3],wo(i,u,h,s,d,un),u=un[1],h=un[2],s=un[3]),t.bezierCurveTo(l,u,c,h,o,s)))},e.prototype.pointAt=function(t){return MA(this.shape,t,!1)},e.prototype.tangentAt=function(t){var n=MA(this.shape,t,!0);return uu(n,n)},e}(ie);Dh.prototype.type="bezier-curve";var VH=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),Ap=function(r){Ge(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new VH},e.prototype.buildPath=function(t,n){var a=n.cx,i=n.cy,o=Math.max(n.r,0),s=n.startAngle,l=n.endAngle,u=n.clockwise,c=Math.cos(s),h=Math.sin(s);t.moveTo(c*o+a,h*o+i),t.arc(a,i,o,s,l,!u)},e}(ie);Ap.prototype.type="arc";var iw=function(r){Ge(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="compound",t}return e.prototype._updatePathDirty=function(){for(var t=this.shape.paths,n=this.shapeChanged(),a=0;a<t.length;a++)n=n||t[a].shapeChanged();n&&this.dirtyShape()},e.prototype.beforeBrush=function(){this._updatePathDirty();for(var t=this.shape.paths||[],n=this.getGlobalScale(),a=0;a<t.length;a++)t[a].path||t[a].createPathProxy(),t[a].path.setScale(n[0],n[1],t[a].segmentIgnoreThreshold)},e.prototype.buildPath=function(t,n){for(var a=n.paths||[],i=0;i<a.length;i++)a[i].buildPath(t,a[i].shape,!0)},e.prototype.afterBrush=function(){for(var t=this.shape.paths||[],n=0;n<t.length;n++)t[n].pathUpdated()},e.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),ie.prototype.getBoundingRect.call(this)},e}(ie),JP=function(){function r(e){this.colorStops=e||[]}return r.prototype.addColorStop=function(e,t){this.colorStops.push({offset:e,color:t})},r}(),Ih=function(r){Ge(e,r);function e(t,n,a,i,o,s){var l=r.call(this,o)||this;return l.x=t??0,l.y=n??0,l.x2=a??1,l.y2=i??0,l.type="linear",l.global=s||!1,l}return e}(JP),tk=function(r){Ge(e,r);function e(t,n,a,i,o){var s=r.call(this,i)||this;return s.x=t??.5,s.y=n??.5,s.r=a??.5,s.type="radial",s.global=o||!1,s}return e}(JP),Qo=[0,0],Jo=[0,0],nv=new Kt,av=new Kt,Ad=function(){function r(e,t){this._corners=[],this._axes=[],this._origin=[0,0];for(var n=0;n<4;n++)this._corners[n]=new Kt;for(var n=0;n<2;n++)this._axes[n]=new Kt;e&&this.fromBoundingRect(e,t)}return r.prototype.fromBoundingRect=function(e,t){var n=this._corners,a=this._axes,i=e.x,o=e.y,s=i+e.width,l=o+e.height;if(n[0].set(i,o),n[1].set(s,o),n[2].set(s,l),n[3].set(i,l),t)for(var u=0;u<4;u++)n[u].transform(t);Kt.sub(a[0],n[1],n[0]),Kt.sub(a[1],n[3],n[0]),a[0].normalize(),a[1].normalize();for(var u=0;u<2;u++)this._origin[u]=a[u].dot(n[0])},r.prototype.intersect=function(e,t){var n=!0,a=!t;return nv.set(1/0,1/0),av.set(0,0),!this._intersectCheckOneSide(this,e,nv,av,a,1)&&(n=!1,a)||!this._intersectCheckOneSide(e,this,nv,av,a,-1)&&(n=!1,a)||a||Kt.copy(t,n?nv:av),n},r.prototype._intersectCheckOneSide=function(e,t,n,a,i,o){for(var s=!0,l=0;l<2;l++){var u=this._axes[l];if(this._getProjMinMaxOnAxis(l,e._corners,Qo),this._getProjMinMaxOnAxis(l,t._corners,Jo),Qo[1]<Jo[0]||Qo[0]>Jo[1]){if(s=!1,i)return s;var c=Math.abs(Jo[0]-Qo[1]),h=Math.abs(Qo[0]-Jo[1]);Math.min(c,h)>a.len()&&(c<h?Kt.scale(a,u,-c*o):Kt.scale(a,u,h*o))}else if(n){var c=Math.abs(Jo[0]-Qo[1]),h=Math.abs(Qo[0]-Jo[1]);Math.min(c,h)<n.len()&&(c<h?Kt.scale(n,u,c*o):Kt.scale(n,u,-h*o))}}return s},r.prototype._getProjMinMaxOnAxis=function(e,t,n){for(var a=this._axes[e],i=this._origin,o=t[0].dot(a)+i[e],s=o,l=o,u=1;u<t.length;u++){var c=t[u].dot(a)+i[e];s=Math.min(c,s),l=Math.max(c,l)}n[0]=s,n[1]=l},r}(),GH=[],WH=function(r){Ge(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.notClear=!0,t.incremental=!0,t._displayables=[],t._temporaryDisplayables=[],t._cursor=0,t}return e.prototype.traverse=function(t,n){t.call(n,this)},e.prototype.useStyle=function(){this.style={}},e.prototype.getCursor=function(){return this._cursor},e.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},e.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},e.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},e.prototype.addDisplayable=function(t,n){n?this._temporaryDisplayables.push(t):this._displayables.push(t),this.markRedraw()},e.prototype.addDisplayables=function(t,n){n=n||!1;for(var a=0;a<t.length;a++)this.addDisplayable(t[a],n)},e.prototype.getDisplayables=function(){return this._displayables},e.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},e.prototype.eachPendingDisplayable=function(t){for(var n=this._cursor;n<this._displayables.length;n++)t&&t(this._displayables[n]);for(var n=0;n<this._temporaryDisplayables.length;n++)t&&t(this._temporaryDisplayables[n])},e.prototype.update=function(){this.updateTransform();for(var t=this._cursor;t<this._displayables.length;t++){var n=this._displayables[t];n.parent=this,n.update(),n.parent=null}for(var t=0;t<this._temporaryDisplayables.length;t++){var n=this._temporaryDisplayables[t];n.parent=this,n.update(),n.parent=null}},e.prototype.getBoundingRect=function(){if(!this._rect){for(var t=new Qt(1/0,1/0,-1/0,-1/0),n=0;n<this._displayables.length;n++){var a=this._displayables[n],i=a.getBoundingRect().clone();a.needLocalTransform()&&i.applyTransform(a.getLocalTransform(GH)),t.union(i)}this._rect=t}return this._rect},e.prototype.contain=function(t,n){var a=this.transformCoordToLocal(t,n),i=this.getBoundingRect();if(i.contain(a[0],a[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(t,n))return!0}return!1},e}(ta),ek=ve();function vu(r,e,t,n,a){var i;if(e&&e.ecModel){var o=e.ecModel.getUpdatePayload();i=o&&o.animation}var s=e&&e.isAnimationEnabled(),l=r==="update";if(s){var u=void 0,c=void 0,h=void 0;n?(u=Zt(n.duration,200),c=Zt(n.easing,"cubicOut"),h=0):(u=e.getShallow(l?"animationDurationUpdate":"animationDuration"),c=e.getShallow(l?"animationEasingUpdate":"animationEasing"),h=e.getShallow(l?"animationDelayUpdate":"animationDelay")),i&&(i.duration!=null&&(u=i.duration),i.easing!=null&&(c=i.easing),i.delay!=null&&(h=i.delay)),Nt(h)&&(h=h(t,a)),Nt(u)&&(u=u(t));var d={duration:u||0,delay:h,easing:c};return d}else return null}function ow(r,e,t,n,a,i,o){var s=!1,l;Nt(a)?(o=i,i=a,a=null):Vt(a)&&(i=a.cb,o=a.during,s=a.isFrom,l=a.removeOpt,a=a.dataIndex);var u=r==="leave";u||e.stopAnimation("leave");var c=vu(r,n,a,u?l||{}:null,n&&n.getAnimationDelayParams?n.getAnimationDelayParams(e,a):null);if(c&&c.duration>0){var h=c.duration,d=c.delay,v=c.easing,p={duration:h,delay:d||0,easing:v,done:i,force:!!i||!!o,setToFinal:!u,scope:r,during:o};s?e.animateFrom(t,p):e.animateTo(t,p)}else e.stopAnimation(),!s&&e.attr(t),o&&o(1),i&&i()}function _e(r,e,t,n,a,i){ow("update",r,e,t,n,a,i)}function He(r,e,t,n,a,i){ow("enter",r,e,t,n,a,i)}function Yl(r){if(!r.__zr)return!0;for(var e=0;e<r.animators.length;e++){var t=r.animators[e];if(t.scope==="leave")return!0}return!1}function xo(r,e,t,n,a,i){Yl(r)||ow("leave",r,e,t,n,a,i)}function DA(r,e,t,n){r.removeTextContent(),r.removeTextGuideLine(),xo(r,{style:{opacity:0}},e,t,n)}function rh(r,e,t){function n(){r.parent&&r.parent.remove(r)}r.isGroup?r.traverse(function(a){a.isGroup||DA(a,e,t,n)}):DA(r,e,t,n)}function xa(r){ek(r).oldStyle=r.style}function HH(r){return ek(r).oldStyle}var Td=Math.max,Cd=Math.min,b_={};function UH(r){return ie.extend(r)}var ZH=AH;function YH(r,e){return ZH(r,e)}function ba(r,e){b_[r]=e}function sw(r){if(b_.hasOwnProperty(r))return b_[r]}function Tp(r,e,t,n){var a=qP(r,e);return t&&(n==="center"&&(t=nk(t,a.getBoundingRect())),ak(a,t)),a}function rk(r,e,t){var n=new Tr({style:{image:r,x:e.x,y:e.y,width:e.width,height:e.height},onload:function(a){if(t==="center"){var i={width:a.width,height:a.height};n.setStyle(nk(e,i))}}});return n}function nk(r,e){var t=e.width/e.height,n=r.height*t,a;n<=r.width?a=r.height:(n=r.width,a=n/t);var i=r.x+r.width/2,o=r.y+r.height/2;return{x:i-n/2,y:o-a/2,width:n,height:a}}var qn=TH;function ak(r,e){if(r.applyTransform){var t=r.getBoundingRect(),n=t.calculateTransform(e);r.applyTransform(n)}}function Jl(r,e){return RP(r,r,{lineWidth:e}),r}function XH(r){return EP(r.shape,r.shape,r.style),r}var td=_s;function Ps(r,e){for(var t=vp([]);r&&r!==e;)_i(t,r.getLocalTransform(),t),r=r.parent;return t}function _a(r,e,t){return e&&!Gr(e)&&(e=gi.getLocalTransform(e)),t&&(e=cu([],e)),Pr([],r,e)}function Cp(r,e,t){var n=e[4]===0||e[5]===0||e[0]===0?1:Math.abs(2*e[4]/e[0]),a=e[4]===0||e[5]===0||e[2]===0?1:Math.abs(2*e[4]/e[2]),i=[r==="left"?-n:r==="right"?n:0,r==="top"?-a:r==="bottom"?a:0];return i=_a(i,e,t),Math.abs(i[0])>Math.abs(i[1])?i[0]>0?"right":"left":i[1]>0?"bottom":"top"}function IA(r){return!r.isGroup}function $H(r){return r.shape!=null}function Ph(r,e,t){if(!r||!e)return;function n(o){var s={};return o.traverse(function(l){IA(l)&&l.anid&&(s[l.anid]=l)}),s}function a(o){var s={x:o.x,y:o.y,rotation:o.rotation};return $H(o)&&(s.shape=lt({},o.shape)),s}var i=n(r);e.traverse(function(o){if(IA(o)&&o.anid){var s=i[o.anid];if(s){var l=a(o);o.attr(a(s)),_e(o,l,t,Ht(o).dataIndex)}}})}function ik(r,e){return ft(r,function(t){var n=t[0];n=Td(n,e.x),n=Cd(n,e.x+e.width);var a=t[1];return a=Td(a,e.y),a=Cd(a,e.y+e.height),[n,a]})}function jH(r,e){var t=Td(r.x,e.x),n=Cd(r.x+r.width,e.x+e.width),a=Td(r.y,e.y),i=Cd(r.y+r.height,e.y+e.height);if(n>=t&&i>=a)return{x:t,y:a,width:n-t,height:i-a}}function kh(r,e,t){var n=lt({rectHover:!0},e),a=n.style={strokeNoScale:!0};if(t=t||{x:-1,y:-1,width:2,height:2},r)return r.indexOf("image://")===0?(a.image=r.slice(8),zt(a,t),new Tr(n)):Tp(r.replace("path://",""),n,t,"center")}function bc(r,e,t,n,a){for(var i=0,o=a[a.length-1];i<a.length;i++){var s=a[i];if(ok(r,e,t,n,s[0],s[1],o[0],o[1]))return!0;o=s}}function ok(r,e,t,n,a,i,o,s){var l=t-r,u=n-e,c=o-a,h=s-i,d=$y(c,h,l,u);if(qH(d))return!1;var v=r-a,p=e-i,y=$y(v,p,l,u)/d;if(y<0||y>1)return!1;var _=$y(v,p,c,h)/d;return!(_<0||_>1)}function $y(r,e,t,n){return r*n-t*e}function qH(r){return r<=1e-6&&r>=-1e-6}function Us(r){var e=r.itemTooltipOption,t=r.componentModel,n=r.itemName,a=Lt(e)?{formatter:e}:e,i=t.mainType,o=t.componentIndex,s={componentType:i,name:n,$vars:["name"]};s[i+"Index"]=o;var l=r.formatterParamsExtra;l&&B(ue(l),function(c){It(s,c)||(s[c]=l[c],s.$vars.push(c))});var u=Ht(r.el);u.componentMainType=i,u.componentIndex=o,u.tooltipConfig={name:n,option:zt({content:n,encodeHTMLContent:!0,formatterParams:s},a)}}function PA(r,e){var t;r.isGroup&&(t=e(r)),t||r.traverse(e)}function Co(r,e){if(r)if(ht(r))for(var t=0;t<r.length;t++)PA(r[t],e);else PA(r,e)}ba("circle",ki);ba("ellipse",Sp);ba("sector",en);ba("ring",Mh);ba("polygon",rn);ba("polyline",nn);ba("rect",fe);ba("line",gr);ba("bezierCurve",Dh);ba("arc",Ap);const Zs=Object.freeze(Object.defineProperty({__proto__:null,Arc:Ap,BezierCurve:Dh,BoundingRect:Qt,Circle:ki,CompoundPath:iw,Ellipse:Sp,Group:Wt,Image:Tr,IncrementalDisplayable:WH,Line:gr,LinearGradient:Ih,OrientedBoundingRect:Ad,Path:ie,Point:Kt,Polygon:rn,Polyline:nn,RadialGradient:tk,Rect:fe,Ring:Mh,Sector:en,Text:pe,applyTransform:_a,clipPointsByRect:ik,clipRectByRect:jH,createIcon:kh,extendPath:YH,extendShape:UH,getShapeClass:sw,getTransform:Ps,groupTransition:Ph,initProps:He,isElementRemoved:Yl,lineLineIntersect:ok,linePolygonIntersect:bc,makeImage:rk,makePath:Tp,mergePath:qn,registerShape:ba,removeElement:xo,removeElementWithFadeOut:rh,resizePath:ak,setTooltipConfig:Us,subPixelOptimize:td,subPixelOptimizeLine:Jl,subPixelOptimizeRect:XH,transformDirection:Cp,traverseElements:Co,updateProps:_e},Symbol.toStringTag,{value:"Module"}));var Lp={};function sk(r,e){for(var t=0;t<tn.length;t++){var n=tn[t],a=e[n],i=r.ensureState(n);i.style=i.style||{},i.style.text=a}var o=r.currentStates.slice();r.clearStates(!0),r.setStyle({text:e.normal}),r.useStates(o,!0)}function S_(r,e,t){var n=r.labelFetcher,a=r.labelDataIndex,i=r.labelDimIndex,o=e.normal,s;n&&(s=n.getFormattedLabel(a,"normal",null,i,o&&o.get("formatter"),t!=null?{interpolatedValue:t}:null)),s==null&&(s=Nt(r.defaultText)?r.defaultText(a,r,t):r.defaultText);for(var l={normal:s},u=0;u<tn.length;u++){var c=tn[u],h=e[c];l[c]=Zt(n?n.getFormattedLabel(a,c,null,i,h&&h.get("formatter")):null,s)}return l}function Rr(r,e,t,n){t=t||Lp;for(var a=r instanceof pe,i=!1,o=0;o<th.length;o++){var s=e[th[o]];if(s&&s.getShallow("show")){i=!0;break}}var l=a?r:r.getTextContent();if(i){a||(l||(l=new pe,r.setTextContent(l)),r.stateProxy&&(l.stateProxy=r.stateProxy));var u=S_(t,e),c=e.normal,h=!!c.getShallow("show"),d=Fe(c,n&&n.normal,t,!1,!a);d.text=u.normal,a||r.setTextConfig(Ld(c,t,!1));for(var o=0;o<tn.length;o++){var v=tn[o],s=e[v];if(s){var p=l.ensureState(v),y=!!Zt(s.getShallow("show"),h);if(y!==h&&(p.ignore=!y),p.style=Fe(s,n&&n[v],t,!0,!a),p.style.text=u[v],!a){var _=r.ensureState(v);_.textConfig=Ld(s,t,!0)}}}l.silent=!!c.getShallow("silent"),l.style.x!=null&&(d.x=l.style.x),l.style.y!=null&&(d.y=l.style.y),l.ignore=!h,l.useStyle(d),l.dirty(),t.enableTextSetter&&(du(l).setLabelText=function(g){var f=S_(t,e,g);sk(l,f)})}else l&&(l.ignore=!0);r.dirty()}function _r(r,e){e=e||"label";for(var t={normal:r.getModel(e)},n=0;n<tn.length;n++){var a=tn[n];t[a]=r.getModel([a,e])}return t}function Fe(r,e,t,n,a){var i={};return KH(i,r,t,n,a),e&&lt(i,e),i}function Ld(r,e,t){e=e||{};var n={},a,i=r.getShallow("rotate"),o=Zt(r.getShallow("distance"),t?null:5),s=r.getShallow("offset");return a=r.getShallow("position")||(t?null:"inside"),a==="outside"&&(a=e.defaultOutsidePosition||"top"),a!=null&&(n.position=a),s!=null&&(n.offset=s),i!=null&&(i*=Math.PI/180,n.rotation=i),o!=null&&(n.distance=o),n.outsideFill=r.get("color")==="inherit"?e.inheritColor||null:"auto",n}function KH(r,e,t,n,a){t=t||Lp;var i=e.ecModel,o=i&&i.option.textStyle,s=QH(e),l;if(s){l={};for(var u in s)if(s.hasOwnProperty(u)){var c=e.getModel(["rich",u]);OA(l[u]={},c,o,t,n,a,!1,!0)}}l&&(r.rich=l);var h=e.get("overflow");h&&(r.overflow=h);var d=e.get("minMargin");d!=null&&(r.margin=d),OA(r,e,o,t,n,a,!0,!1)}function QH(r){for(var e;r&&r!==r.ecModel;){var t=(r.option||Lp).rich;if(t){e=e||{};for(var n=ue(t),a=0;a<n.length;a++){var i=n[a];e[i]=1}}r=r.parentModel}return e}var kA=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],RA=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],EA=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function OA(r,e,t,n,a,i,o,s){t=!a&&t||Lp;var l=n&&n.inheritColor,u=e.getShallow("color"),c=e.getShallow("textBorderColor"),h=Zt(e.getShallow("opacity"),t.opacity);(u==="inherit"||u==="auto")&&(l?u=l:u=null),(c==="inherit"||c==="auto")&&(l?c=l:c=null),i||(u=u||t.color,c=c||t.textBorderColor),u!=null&&(r.fill=u),c!=null&&(r.stroke=c);var d=Zt(e.getShallow("textBorderWidth"),t.textBorderWidth);d!=null&&(r.lineWidth=d);var v=Zt(e.getShallow("textBorderType"),t.textBorderType);v!=null&&(r.lineDash=v);var p=Zt(e.getShallow("textBorderDashOffset"),t.textBorderDashOffset);p!=null&&(r.lineDashOffset=p),!a&&h==null&&!s&&(h=n&&n.defaultOpacity),h!=null&&(r.opacity=h),!a&&!i&&r.fill==null&&n.inheritColor&&(r.fill=n.inheritColor);for(var y=0;y<kA.length;y++){var _=kA[y],g=Zt(e.getShallow(_),t[_]);g!=null&&(r[_]=g)}for(var y=0;y<RA.length;y++){var _=RA[y],g=e.getShallow(_);g!=null&&(r[_]=g)}if(r.verticalAlign==null){var f=e.getShallow("baseline");f!=null&&(r.verticalAlign=f)}if(!o||!n.disableBox){for(var y=0;y<EA.length;y++){var _=EA[y],g=e.getShallow(_);g!=null&&(r[_]=g)}var w=e.getShallow("borderType");w!=null&&(r.borderDash=w),(r.backgroundColor==="auto"||r.backgroundColor==="inherit")&&l&&(r.backgroundColor=l),(r.borderColor==="auto"||r.borderColor==="inherit")&&l&&(r.borderColor=l)}}function lw(r,e){var t=e&&e.getModel("textStyle");return ga([r.fontStyle||t&&t.getShallow("fontStyle")||"",r.fontWeight||t&&t.getShallow("fontWeight")||"",(r.fontSize||t&&t.getShallow("fontSize")||12)+"px",r.fontFamily||t&&t.getShallow("fontFamily")||"sans-serif"].join(" "))}var du=ve();function lk(r,e,t,n){if(r){var a=du(r);a.prevValue=a.value,a.value=t;var i=e.normal;a.valueAnimation=i.get("valueAnimation"),a.valueAnimation&&(a.precision=i.get("precision"),a.defaultInterpolatedText=n,a.statesModels=e)}}function uk(r,e,t,n,a){var i=du(r);if(!i.valueAnimation||i.prevValue===i.value)return;var o=i.defaultInterpolatedText,s=Zt(i.interpolatedValue,i.prevValue),l=i.value;function u(c){var h=TP(t,i.precision,s,l,c);i.interpolatedValue=c===1?null:h;var d=S_({labelDataIndex:e,labelFetcher:a,defaultText:o?o(h):h+""},i.statesModels,h);sk(r,d)}r.percent=0,(i.prevValue==null?He:_e)(r,{percent:1},n,e,null,u)}var JH=["textStyle","color"],jy=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],qy=new pe,tU=function(){function r(){}return r.prototype.getTextColor=function(e){var t=this.ecModel;return this.getShallow("color")||(!e&&t?t.get(JH):null)},r.prototype.getFont=function(){return lw({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},r.prototype.getTextRect=function(e){for(var t={text:e,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},n=0;n<jy.length;n++)t[jy[n]]=this.getShallow(jy[n]);return qy.useStyle(t),qy.update(),qy.getBoundingRect()},r}(),ck=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],eU=Ns(ck),rU=function(){function r(){}return r.prototype.getLineStyle=function(e){return eU(this,e)},r}(),hk=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],nU=Ns(hk),aU=function(){function r(){}return r.prototype.getItemStyle=function(e,t){return nU(this,e,t)},r}(),De=function(){function r(e,t,n){this.parentModel=t,this.ecModel=n,this.option=e}return r.prototype.init=function(e,t,n){},r.prototype.mergeOption=function(e,t){qt(this.option,e,!0)},r.prototype.get=function(e,t){return e==null?this.option:this._doGet(this.parsePath(e),!t&&this.parentModel)},r.prototype.getShallow=function(e,t){var n=this.option,a=n==null?n:n[e];if(a==null&&!t){var i=this.parentModel;i&&(a=i.getShallow(e))}return a},r.prototype.getModel=function(e,t){var n=e!=null,a=n?this.parsePath(e):null,i=n?this._doGet(a):this.option;return t=t||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(a)),new r(i,t,this.ecModel)},r.prototype.isEmpty=function(){return this.option==null},r.prototype.restoreData=function(){},r.prototype.clone=function(){var e=this.constructor;return new e(Gt(this.option))},r.prototype.parsePath=function(e){return typeof e=="string"?e.split("."):e},r.prototype.resolveParentPath=function(e){return e},r.prototype.isAnimationEnabled=function(){if(!oe.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},r.prototype._doGet=function(e,t){var n=this.option;if(!e)return n;for(var a=0;a<e.length&&!(e[a]&&(n=n&&typeof n=="object"?n[e[a]]:null,n==null));a++);return n==null&&t&&(n=t._doGet(this.resolveParentPath(e),t.parentModel)),n},r}();q1(De);vW(De);sr(De,rU);sr(De,aU);sr(De,mW);sr(De,tU);var iU=Math.round(Math.random()*10);function pu(r){return[r||"",iU++].join("_")}function oU(r){var e={};r.registerSubTypeDefaulter=function(t,n){var a=Va(t);e[a.main]=n},r.determineSubType=function(t,n){var a=n.type;if(!a){var i=Va(t).main;r.hasSubTypes(t)&&e[i]&&(a=e[i](n))}return a}}function sU(r,e){r.topologicalTravel=function(i,o,s,l){if(!i.length)return;var u=t(o),c=u.graph,h=u.noEntryList,d={};for(B(i,function(f){d[f]=!0});h.length;){var v=h.pop(),p=c[v],y=!!d[v];y&&(s.call(l,v,p.originalDeps.slice()),delete d[v]),B(p.successor,y?g:_)}B(d,function(){var f="";throw new Error(f)});function _(f){c[f].entryCount--,c[f].entryCount===0&&h.push(f)}function g(f){d[f]=!0,_(f)}};function t(i){var o={},s=[];return B(i,function(l){var u=n(o,l),c=u.originalDeps=e(l),h=a(c,i);u.entryCount=h.length,u.entryCount===0&&s.push(l),B(h,function(d){te(u.predecessor,d)<0&&u.predecessor.push(d);var v=n(o,d);te(v.successor,d)<0&&v.successor.push(l)})}),{graph:o,noEntryList:s}}function n(i,o){return i[o]||(i[o]={predecessor:[],successor:[]}),i[o]}function a(i,o){var s=[];return B(i,function(l){te(o,l)>=0&&s.push(l)}),s}}function Lo(r,e){return qt(qt({},r,!0),e,!0)}const lU={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},uU={time:{month:["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],monthAbbr:["1月","2月","3月","4月","5月","6月","7月","8月","9月","10月","11月","12月"],dayOfWeek:["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],dayOfWeekAbbr:["日","一","二","三","四","五","六"]},legend:{selector:{all:"全选",inverse:"反选"}},toolbox:{brush:{title:{rect:"矩形选择",polygon:"圈选",lineX:"横向选择",lineY:"纵向选择",keep:"保持选择",clear:"清除选择"}},dataView:{title:"数据视图",lang:["数据视图","关闭","刷新"]},dataZoom:{title:{zoom:"区域缩放",back:"区域缩放还原"}},magicType:{title:{line:"切换为折线图",bar:"切换为柱状图",stack:"切换为堆叠",tiled:"切换为平铺"}},restore:{title:"还原"},saveAsImage:{title:"保存为图片",lang:["右键另存为图片"]}},series:{typeNames:{pie:"饼图",bar:"柱状图",line:"折线图",scatter:"散点图",effectScatter:"涟漪散点图",radar:"雷达图",tree:"树图",treemap:"矩形树图",boxplot:"箱型图",candlestick:"K线图",k:"K线图",heatmap:"热力图",map:"地图",parallel:"平行坐标图",lines:"线图",graph:"关系图",sankey:"桑基图",funnel:"漏斗图",gauge:"仪表盘图",pictorialBar:"象形柱图",themeRiver:"主题河流图",sunburst:"旭日图",custom:"自定义图表",chart:"图表"}},aria:{general:{withTitle:"这是一个关于“{title}”的图表。",withoutTitle:"这是一个图表，"},series:{single:{prefix:"",withName:"图表类型是{seriesType}，表示{seriesName}。",withoutName:"图表类型是{seriesType}。"},multiple:{prefix:"它由{seriesCount}个图表系列组成。",withName:"第{seriesId}个系列是一个表示{seriesName}的{seriesType}，",withoutName:"第{seriesId}个系列是一个{seriesType}，",separator:{middle:"；",end:"。"}}},data:{allData:"其数据是——",partialData:"其中，前{displayCnt}项是——",withName:"{name}的数据是{value}",withoutName:"{value}",separator:{middle:"，",end:""}}}};var Md="ZH",uw="EN",Xl=uw,ed={},cw={},fk=oe.domSupported?function(){var r=(document.documentElement.lang||navigator.language||navigator.browserLanguage||Xl).toUpperCase();return r.indexOf(Md)>-1?Md:Xl}():Xl;function vk(r,e){r=r.toUpperCase(),cw[r]=new De(e),ed[r]=e}function cU(r){if(Lt(r)){var e=ed[r.toUpperCase()]||{};return r===Md||r===uw?Gt(e):qt(Gt(e),Gt(ed[Xl]),!1)}else return qt(Gt(r),Gt(ed[Xl]),!1)}function A_(r){return cw[r]}function hU(){return cw[Xl]}vk(uw,lU);vk(Md,uU);var hw=1e3,fw=hw*60,Vc=fw*60,Kn=Vc*24,BA=Kn*365,Sc={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}",none:"{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}"},iv="{yyyy}-{MM}-{dd}",NA={year:"{yyyy}",month:"{yyyy}-{MM}",day:iv,hour:iv+" "+Sc.hour,minute:iv+" "+Sc.minute,second:iv+" "+Sc.second,millisecond:Sc.none},Ky=["year","month","day","hour","minute","second","millisecond"],dk=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function Yi(r,e){return r+="","0000".substr(0,e-r.length)+r}function $l(r){switch(r){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return r}}function fU(r){return r===$l(r)}function vU(r){switch(r){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function Mp(r,e,t,n){var a=$a(r),i=a[vw(t)](),o=a[jl(t)]()+1,s=Math.floor((o-1)/3)+1,l=a[Dp(t)](),u=a["get"+(t?"UTC":"")+"Day"](),c=a[nh(t)](),h=(c-1)%12+1,d=a[Ip(t)](),v=a[Pp(t)](),p=a[kp(t)](),y=c>=12?"pm":"am",_=y.toUpperCase(),g=n instanceof De?n:A_(n||fk)||hU(),f=g.getModel("time"),w=f.get("month"),x=f.get("monthAbbr"),S=f.get("dayOfWeek"),A=f.get("dayOfWeekAbbr");return(e||"").replace(/{a}/g,y+"").replace(/{A}/g,_+"").replace(/{yyyy}/g,i+"").replace(/{yy}/g,Yi(i%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,w[o-1]).replace(/{MMM}/g,x[o-1]).replace(/{MM}/g,Yi(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,Yi(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,S[u]).replace(/{ee}/g,A[u]).replace(/{e}/g,u+"").replace(/{HH}/g,Yi(c,2)).replace(/{H}/g,c+"").replace(/{hh}/g,Yi(h+"",2)).replace(/{h}/g,h+"").replace(/{mm}/g,Yi(d,2)).replace(/{m}/g,d+"").replace(/{ss}/g,Yi(v,2)).replace(/{s}/g,v+"").replace(/{SSS}/g,Yi(p,3)).replace(/{S}/g,p+"")}function dU(r,e,t,n,a){var i=null;if(Lt(t))i=t;else if(Nt(t))i=t(r.value,e,{level:r.level});else{var o=lt({},Sc);if(r.level>0)for(var s=0;s<Ky.length;++s)o[Ky[s]]="{primary|"+o[Ky[s]]+"}";var l=t?t.inherit===!1?t:zt(t,o):o,u=pk(r.value,a);if(l[u])i=l[u];else if(l.inherit){for(var c=dk.indexOf(u),s=c-1;s>=0;--s)if(l[u]){i=l[u];break}i=i||o.none}if(ht(i)){var h=r.level==null?0:r.level>=0?r.level:i.length+r.level;h=Math.min(h,i.length-1),i=i[h]}}return Mp(new Date(r.value),i,a,n)}function pk(r,e){var t=$a(r),n=t[jl(e)]()+1,a=t[Dp(e)](),i=t[nh(e)](),o=t[Ip(e)](),s=t[Pp(e)](),l=t[kp(e)](),u=l===0,c=u&&s===0,h=c&&o===0,d=h&&i===0,v=d&&a===1,p=v&&n===1;return p?"year":v?"month":d?"day":h?"hour":c?"minute":u?"second":"millisecond"}function zA(r,e,t){var n=ye(r)?$a(r):r;switch(e=e||pk(r,t),e){case"year":return n[vw(t)]();case"half-year":return n[jl(t)]()>=6?1:0;case"quarter":return Math.floor((n[jl(t)]()+1)/4);case"month":return n[jl(t)]();case"day":return n[Dp(t)]();case"half-day":return n[nh(t)]()/24;case"hour":return n[nh(t)]();case"minute":return n[Ip(t)]();case"second":return n[Pp(t)]();case"millisecond":return n[kp(t)]()}}function vw(r){return r?"getUTCFullYear":"getFullYear"}function jl(r){return r?"getUTCMonth":"getMonth"}function Dp(r){return r?"getUTCDate":"getDate"}function nh(r){return r?"getUTCHours":"getHours"}function Ip(r){return r?"getUTCMinutes":"getMinutes"}function Pp(r){return r?"getUTCSeconds":"getSeconds"}function kp(r){return r?"getUTCMilliseconds":"getMilliseconds"}function pU(r){return r?"setUTCFullYear":"setFullYear"}function gk(r){return r?"setUTCMonth":"setMonth"}function yk(r){return r?"setUTCDate":"setDate"}function mk(r){return r?"setUTCHours":"setHours"}function _k(r){return r?"setUTCMinutes":"setMinutes"}function wk(r){return r?"setUTCSeconds":"setSeconds"}function xk(r){return r?"setUTCMilliseconds":"setMilliseconds"}function bk(r){if(!yP(r))return Lt(r)?r:"-";var e=(r+"").split(".");return e[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(e.length>1?"."+e[1]:"")}function Sk(r,e){return r=(r||"").toLowerCase().replace(/-(.)/g,function(t,n){return n.toUpperCase()}),e&&r&&(r=r.charAt(0).toUpperCase()+r.slice(1)),r}var gu=V1;function T_(r,e,t){var n="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function a(c){return c&&ga(c)?c:"-"}function i(c){return!!(c!=null&&!isNaN(c)&&isFinite(c))}var o=e==="time",s=r instanceof Date;if(o||s){var l=o?$a(r):r;if(isNaN(+l)){if(s)return"-"}else return Mp(l,n,t)}if(e==="ordinal")return W0(r)?a(r):ye(r)&&i(r)?r+"":"-";var u=Ai(r);return i(u)?bk(u):W0(r)?a(r):typeof r=="boolean"?r+"":"-"}var FA=["a","b","c","d","e","f","g"],Qy=function(r,e){return"{"+r+(e??"")+"}"};function Ak(r,e,t){ht(e)||(e=[e]);var n=e.length;if(!n)return"";for(var a=e[0].$vars||[],i=0;i<a.length;i++){var o=FA[i];r=r.replace(Qy(o),Qy(o,0))}for(var s=0;s<n;s++)for(var l=0;l<a.length;l++){var u=e[s][a[l]];r=r.replace(Qy(FA[l],s),t?qr(u):u)}return r}function gU(r,e,t){return B(e,function(n,a){r=r.replace("{"+a+"}",n)}),r}function yU(r,e){var t=Lt(r)?{color:r,extraCssText:e}:r||{},n=t.color,a=t.type;e=t.extraCssText;var i=t.renderMode||"html";if(!n)return"";if(i==="html")return a==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+qr(n)+";"+(e||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+qr(n)+";"+(e||"")+'"></span>';var o=t.markerId||"markerX";return{renderMode:i,content:"{"+o+"|}  ",style:a==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:n}:{width:10,height:10,borderRadius:5,backgroundColor:n}}}function Fs(r,e){return e=e||"transparent",Lt(r)?r:Vt(r)&&r.colorStops&&(r.colorStops[0]||{}).color||e}function Dd(r,e){if(e==="_blank"||e==="blank"){var t=window.open();t.opener=null,t.location.href=r}else window.open(r,e)}var rd=B,Tk=["left","right","top","bottom","width","height"],xs=[["width","left","right"],["height","top","bottom"]];function dw(r,e,t,n,a){var i=0,o=0;n==null&&(n=1/0),a==null&&(a=1/0);var s=0;e.eachChild(function(l,u){var c=l.getBoundingRect(),h=e.childAt(u+1),d=h&&h.getBoundingRect(),v,p;if(r==="horizontal"){var y=c.width+(d?-d.x+c.x:0);v=i+y,v>n||l.newline?(i=0,v=y,o+=s+t,s=c.height):s=Math.max(s,c.height)}else{var _=c.height+(d?-d.y+c.y:0);p=o+_,p>a||l.newline?(i+=s+t,o=0,p=_,s=c.width):s=Math.max(s,c.width)}l.newline||(l.x=i,l.y=o,l.markRedraw(),r==="horizontal"?i=v+t:o=p+t)})}var ks=dw;Xt(dw,"vertical");Xt(dw,"horizontal");function mU(r,e,t){var n=e.width,a=e.height,i=At(r.left,n),o=At(r.top,a),s=At(r.right,n),l=At(r.bottom,a);return(isNaN(i)||isNaN(parseFloat(r.left)))&&(i=0),(isNaN(s)||isNaN(parseFloat(r.right)))&&(s=n),(isNaN(o)||isNaN(parseFloat(r.top)))&&(o=0),(isNaN(l)||isNaN(parseFloat(r.bottom)))&&(l=a),t=gu(t||0),{width:Math.max(s-i-t[1]-t[3],0),height:Math.max(l-o-t[0]-t[2],0)}}function cr(r,e,t){t=gu(t||0);var n=e.width,a=e.height,i=At(r.left,n),o=At(r.top,a),s=At(r.right,n),l=At(r.bottom,a),u=At(r.width,n),c=At(r.height,a),h=t[2]+t[0],d=t[1]+t[3],v=r.aspect;switch(isNaN(u)&&(u=n-s-d-i),isNaN(c)&&(c=a-l-h-o),v!=null&&(isNaN(u)&&isNaN(c)&&(v>n/a?u=n*.8:c=a*.8),isNaN(u)&&(u=v*c),isNaN(c)&&(c=u/v)),isNaN(i)&&(i=n-s-u-d),isNaN(o)&&(o=a-l-c-h),r.left||r.right){case"center":i=n/2-u/2-t[3];break;case"right":i=n-u-d;break}switch(r.top||r.bottom){case"middle":case"center":o=a/2-c/2-t[0];break;case"bottom":o=a-c-h;break}i=i||0,o=o||0,isNaN(u)&&(u=n-d-i-(s||0)),isNaN(c)&&(c=a-h-o-(l||0));var p=new Qt(i+t[3],o+t[0],u,c);return p.margin=t,p}function Rp(r,e,t,n,a,i){var o=!a||!a.hv||a.hv[0],s=!a||!a.hv||a.hv[1],l=a&&a.boundingMode||"all";if(i=i||r,i.x=r.x,i.y=r.y,!o&&!s)return!1;var u;if(l==="raw")u=r.type==="group"?new Qt(0,0,+e.width||0,+e.height||0):r.getBoundingRect();else if(u=r.getBoundingRect(),r.needLocalTransform()){var c=r.getLocalTransform();u=u.clone(),u.applyTransform(c)}var h=cr(zt({width:u.width,height:u.height},e),t,n),d=o?h.x-u.x:0,v=s?h.y-u.y:0;return l==="raw"?(i.x=d,i.y=v):(i.x+=d,i.y+=v),i===r&&r.markRedraw(),!0}function _U(r,e){return r[xs[e][0]]!=null||r[xs[e][1]]!=null&&r[xs[e][2]]!=null}function ah(r){var e=r.layoutMode||r.constructor.layoutMode;return Vt(e)?e:e?{type:e}:null}function bo(r,e,t){var n=t&&t.ignoreSize;!ht(n)&&(n=[n,n]);var a=o(xs[0],0),i=o(xs[1],1);u(xs[0],r,a),u(xs[1],r,i);function o(c,h){var d={},v=0,p={},y=0,_=2;if(rd(c,function(w){p[w]=r[w]}),rd(c,function(w){s(e,w)&&(d[w]=p[w]=e[w]),l(d,w)&&v++,l(p,w)&&y++}),n[h])return l(e,c[1])?p[c[2]]=null:l(e,c[2])&&(p[c[1]]=null),p;if(y===_||!v)return p;if(v>=_)return d;for(var g=0;g<c.length;g++){var f=c[g];if(!s(d,f)&&s(r,f)){d[f]=r[f];break}}return d}function s(c,h){return c.hasOwnProperty(h)}function l(c,h){return c[h]!=null&&c[h]!=="auto"}function u(c,h,d){rd(c,function(v){h[v]=d[v]})}}function yu(r){return Ck({},r)}function Ck(r,e){return e&&r&&rd(Tk,function(t){e.hasOwnProperty(t)&&(r[t]=e[t])}),r}var wU=ve(),le=function(r){rt(e,r);function e(t,n,a){var i=r.call(this,t,n,a)||this;return i.uid=pu("ec_cpt_model"),i}return e.prototype.init=function(t,n,a){this.mergeDefaultAndTheme(t,a)},e.prototype.mergeDefaultAndTheme=function(t,n){var a=ah(this),i=a?yu(t):{},o=n.getTheme();qt(t,o.get(this.mainType)),qt(t,this.getDefaultOption()),a&&bo(t,i,a)},e.prototype.mergeOption=function(t,n){qt(this.option,t,!0);var a=ah(this);a&&bo(this.option,t,a)},e.prototype.optionUpdated=function(t,n){},e.prototype.getDefaultOption=function(){var t=this.constructor;if(!cW(t))return t.defaultOption;var n=wU(this);if(!n.defaultOption){for(var a=[],i=t;i;){var o=i.prototype.defaultOption;o&&a.push(o),i=i.superClass}for(var s={},l=a.length-1;l>=0;l--)s=qt(s,a[l],!0);n.defaultOption=s}return n.defaultOption},e.prototype.getReferringComponents=function(t,n){var a=t+"Index",i=t+"Id";return Ch(this.ecModel,t,{index:this.get(a,!0),id:this.get(i,!0)},n)},e.prototype.getBoxLayoutParams=function(){var t=this;return{left:t.get("left"),top:t.get("top"),right:t.get("right"),bottom:t.get("bottom"),width:t.get("width"),height:t.get("height")}},e.prototype.getZLevelKey=function(){return""},e.prototype.setZLevel=function(t){this.option.zlevel=t},e.protoInitialize=function(){var t=e.prototype;t.type="component",t.id="",t.name="",t.mainType="",t.subType="",t.componentIndex=0}(),e}(De);LP(le,De);yp(le);oU(le);sU(le,xU);function xU(r){var e=[];return B(le.getClassesByMainType(r),function(t){e=e.concat(t.dependencies||t.prototype.dependencies||[])}),e=ft(e,function(t){return Va(t).main}),r!=="dataset"&&te(e,"dataset")<=0&&e.unshift("dataset"),e}var Lk="";typeof navigator<"u"&&(Lk=navigator.platform||"");var _l="rgba(0, 0, 0, 0.2)";const bU={darkMode:"auto",colorBy:"series",color:["#5470c6","#91cc75","#fac858","#ee6666","#73c0de","#3ba272","#fc8452","#9a60b4","#ea7ccc"],gradientColor:["#f6efa6","#d88273","#bf444c"],aria:{decal:{decals:[{color:_l,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:_l,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:_l,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:_l,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:_l,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:_l,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:Lk.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var Mk=Pt(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),ra="original",Wr="arrayRows",na="objectRows",Ka="keyedColumns",po="typedArray",Dk="unknown",Ua="column",mu="row",Ir={Must:1,Might:2,Not:3},Ik=ve();function SU(r){Ik(r).datasetMap=Pt()}function Pk(r,e,t){var n={},a=gw(e);if(!a||!r)return n;var i=[],o=[],s=e.ecModel,l=Ik(s).datasetMap,u=a.uid+"_"+t.seriesLayoutBy,c,h;r=r.slice(),B(r,function(y,_){var g=Vt(y)?y:r[_]={name:y};g.type==="ordinal"&&c==null&&(c=_,h=p(g)),n[g.name]=[]});var d=l.get(u)||l.set(u,{categoryWayDim:h,valueWayDim:0});B(r,function(y,_){var g=y.name,f=p(y);if(c==null){var w=d.valueWayDim;v(n[g],w,f),v(o,w,f),d.valueWayDim+=f}else if(c===_)v(n[g],0,f),v(i,0,f);else{var w=d.categoryWayDim;v(n[g],w,f),v(o,w,f),d.categoryWayDim+=f}});function v(y,_,g){for(var f=0;f<g;f++)y.push(_+f)}function p(y){var _=y.dimsDef;return _?_.length:1}return i.length&&(n.itemName=i),o.length&&(n.seriesName=o),n}function pw(r,e,t){var n={},a=gw(r);if(!a)return n;var i=e.sourceFormat,o=e.dimensionsDefine,s;(i===na||i===Ka)&&B(o,function(c,h){(Vt(c)?c.name:c)==="name"&&(s=h)});var l=function(){for(var c={},h={},d=[],v=0,p=Math.min(5,t);v<p;v++){var y=Rk(e.data,i,e.seriesLayoutBy,o,e.startIndex,v);d.push(y);var _=y===Ir.Not;if(_&&c.v==null&&v!==s&&(c.v=v),(c.n==null||c.n===c.v||!_&&d[c.n]===Ir.Not)&&(c.n=v),g(c)&&d[c.n]!==Ir.Not)return c;_||(y===Ir.Might&&h.v==null&&v!==s&&(h.v=v),(h.n==null||h.n===h.v)&&(h.n=v))}function g(f){return f.v!=null&&f.n!=null}return g(c)?c:g(h)?h:null}();if(l){n.value=[l.v];var u=s??l.n;n.itemName=[u],n.seriesName=[u]}return n}function gw(r){var e=r.get("data",!0);if(!e)return Ch(r.ecModel,"dataset",{index:r.get("datasetIndex",!0),id:r.get("datasetId",!0)},ir).models[0]}function AU(r){return!r.get("transform",!0)&&!r.get("fromTransformResult",!0)?[]:Ch(r.ecModel,"dataset",{index:r.get("fromDatasetIndex",!0),id:r.get("fromDatasetId",!0)},ir).models}function kk(r,e){return Rk(r.data,r.sourceFormat,r.seriesLayoutBy,r.dimensionsDefine,r.startIndex,e)}function Rk(r,e,t,n,a,i){var o,s=5;if(pn(r))return Ir.Not;var l,u;if(n){var c=n[i];Vt(c)?(l=c.name,u=c.type):Lt(c)&&(l=c)}if(u!=null)return u==="ordinal"?Ir.Must:Ir.Not;if(e===Wr){var h=r;if(t===mu){for(var d=h[i],v=0;v<(d||[]).length&&v<s;v++)if((o=x(d[a+v]))!=null)return o}else for(var v=0;v<h.length&&v<s;v++){var p=h[a+v];if(p&&(o=x(p[i]))!=null)return o}}else if(e===na){var y=r;if(!l)return Ir.Not;for(var v=0;v<y.length&&v<s;v++){var _=y[v];if(_&&(o=x(_[l]))!=null)return o}}else if(e===Ka){var g=r;if(!l)return Ir.Not;var d=g[l];if(!d||pn(d))return Ir.Not;for(var v=0;v<d.length&&v<s;v++)if((o=x(d[v]))!=null)return o}else if(e===ra)for(var f=r,v=0;v<f.length&&v<s;v++){var _=f[v],w=hu(_);if(!ht(w))return Ir.Not;if((o=x(w[i]))!=null)return o}function x(S){var A=Lt(S);if(S!=null&&Number.isFinite(Number(S))&&S!=="")return A?Ir.Might:Ir.Not;if(A&&S!=="-")return Ir.Must}return Ir.Not}var C_=Pt();function TU(r,e){Jr(C_.get(r)==null&&e),C_.set(r,e)}function CU(r,e,t){var n=C_.get(e);if(!n)return t;var a=n(r);return a?t.concat(a):t}var VA=ve(),LU=ve(),yw=function(){function r(){}return r.prototype.getColorFromPalette=function(e,t,n){var a=Ie(this.get("color",!0)),i=this.get("colorLayer",!0);return Ek(this,VA,a,i,e,t,n)},r.prototype.clearColorPalette=function(){DU(this,VA)},r}();function L_(r,e,t,n){var a=Ie(r.get(["aria","decal","decals"]));return Ek(r,LU,a,null,e,t,n)}function MU(r,e){for(var t=r.length,n=0;n<t;n++)if(r[n].length>e)return r[n];return r[t-1]}function Ek(r,e,t,n,a,i,o){i=i||r;var s=e(i),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(a))return u[a];var c=o==null||!n?t:MU(n,o);if(c=c||t,!(!c||!c.length)){var h=c[l];return a&&(u[a]=h),s.paletteIdx=(l+1)%c.length,h}}function DU(r,e){e(r).paletteIdx=0,e(r).paletteNameMap={}}var ov,$u,GA,WA="\0_ec_inner",IU=1,mw=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.init=function(t,n,a,i,o,s){i=i||{},this.option=null,this._theme=new De(i),this._locale=new De(o),this._optionManager=s},e.prototype.setOption=function(t,n,a){var i=ZA(n);this._optionManager.setOption(t,a,i),this._resetOption(null,i)},e.prototype.resetOption=function(t,n){return this._resetOption(t,ZA(n))},e.prototype._resetOption=function(t,n){var a=!1,i=this._optionManager;if(!t||t==="recreate"){var o=i.mountOption(t==="recreate");!this.option||t==="recreate"?GA(this,o):(this.restoreData(),this._mergeOption(o,n)),a=!0}if((t==="timeline"||t==="media")&&this.restoreData(),!t||t==="recreate"||t==="timeline"){var s=i.getTimelineOption(this);s&&(a=!0,this._mergeOption(s,n))}if(!t||t==="recreate"||t==="media"){var l=i.getMediaOption(this);l.length&&B(l,function(u){a=!0,this._mergeOption(u,n)},this)}return a},e.prototype.mergeOption=function(t){this._mergeOption(t,null)},e.prototype._mergeOption=function(t,n){var a=this.option,i=this._componentsMap,o=this._componentsCount,s=[],l=Pt(),u=n&&n.replaceMergeMainTypeMap;SU(this),B(t,function(h,d){h!=null&&(le.hasClass(d)?d&&(s.push(d),l.set(d,!0)):a[d]=a[d]==null?Gt(h):qt(a[d],h,!0))}),u&&u.each(function(h,d){le.hasClass(d)&&!l.get(d)&&(s.push(d),l.set(d,!0))}),le.topologicalTravel(s,le.getAllClassMainTypes(),c,this);function c(h){var d=CU(this,h,Ie(t[h])),v=i.get(h),p=v?u&&u.get(h)?"replaceMerge":"normalMerge":"replaceAll",y=bP(v,d,p);eW(y,h,le),a[h]=null,i.set(h,null),o.set(h,0);var _=[],g=[],f=0,w;B(y,function(x,S){var A=x.existing,T=x.newOption;if(!T)A&&(A.mergeOption({},this),A.optionUpdated({},!1));else{var L=h==="series",M=le.getClass(h,x.keyInfo.subType,!L);if(!M)return;if(h==="tooltip"){if(w)return;w=!0}if(A&&A.constructor===M)A.name=x.keyInfo.name,A.mergeOption(T,this),A.optionUpdated(T,!1);else{var I=lt({componentIndex:S},x.keyInfo);A=new M(T,this,this,I),lt(A,I),x.brandNew&&(A.__requireNewView=!0),A.init(T,this,this),A.optionUpdated(null,!0)}}A?(_.push(A.option),g.push(A),f++):(_.push(void 0),g.push(void 0))},this),a[h]=_,i.set(h,g),o.set(h,f),h==="series"&&ov(this)}this._seriesIndices||ov(this)},e.prototype.getOption=function(){var t=Gt(this.option);return B(t,function(n,a){if(le.hasClass(a)){for(var i=Ie(n),o=i.length,s=!1,l=o-1;l>=0;l--)i[l]&&!Jc(i[l])?s=!0:(i[l]=null,!s&&o--);i.length=o,t[a]=i}}),delete t[WA],t},e.prototype.getTheme=function(){return this._theme},e.prototype.getLocaleModel=function(){return this._locale},e.prototype.setUpdatePayload=function(t){this._payload=t},e.prototype.getUpdatePayload=function(){return this._payload},e.prototype.getComponent=function(t,n){var a=this._componentsMap.get(t);if(a){var i=a[n||0];if(i)return i;if(n==null){for(var o=0;o<a.length;o++)if(a[o])return a[o]}}},e.prototype.queryComponents=function(t){var n=t.mainType;if(!n)return[];var a=t.index,i=t.id,o=t.name,s=this._componentsMap.get(n);if(!s||!s.length)return[];var l;return a!=null?(l=[],B(Ie(a),function(u){s[u]&&l.push(s[u])})):i!=null?l=HA("id",i,s):o!=null?l=HA("name",o,s):l=Te(s,function(u){return!!u}),UA(l,t)},e.prototype.findComponents=function(t){var n=t.query,a=t.mainType,i=s(n),o=i?this.queryComponents(i):Te(this._componentsMap.get(a),function(u){return!!u});return l(UA(o,t));function s(u){var c=a+"Index",h=a+"Id",d=a+"Name";return u&&(u[c]!=null||u[h]!=null||u[d]!=null)?{mainType:a,index:u[c],id:u[h],name:u[d]}:null}function l(u){return t.filter?Te(u,t.filter):u}},e.prototype.eachComponent=function(t,n,a){var i=this._componentsMap;if(Nt(t)){var o=n,s=t;i.each(function(h,d){for(var v=0;h&&v<h.length;v++){var p=h[v];p&&s.call(o,d,p,p.componentIndex)}})}else for(var l=Lt(t)?i.get(t):Vt(t)?this.findComponents(t):null,u=0;l&&u<l.length;u++){var c=l[u];c&&n.call(a,c,c.componentIndex)}},e.prototype.getSeriesByName=function(t){var n=ur(t,null);return Te(this._componentsMap.get("series"),function(a){return!!a&&n!=null&&a.name===n})},e.prototype.getSeriesByIndex=function(t){return this._componentsMap.get("series")[t]},e.prototype.getSeriesByType=function(t){return Te(this._componentsMap.get("series"),function(n){return!!n&&n.subType===t})},e.prototype.getSeries=function(){return Te(this._componentsMap.get("series"),function(t){return!!t})},e.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},e.prototype.eachSeries=function(t,n){$u(this),B(this._seriesIndices,function(a){var i=this._componentsMap.get("series")[a];t.call(n,i,a)},this)},e.prototype.eachRawSeries=function(t,n){B(this._componentsMap.get("series"),function(a){a&&t.call(n,a,a.componentIndex)})},e.prototype.eachSeriesByType=function(t,n,a){$u(this),B(this._seriesIndices,function(i){var o=this._componentsMap.get("series")[i];o.subType===t&&n.call(a,o,i)},this)},e.prototype.eachRawSeriesByType=function(t,n,a){return B(this.getSeriesByType(t),n,a)},e.prototype.isSeriesFiltered=function(t){return $u(this),this._seriesIndicesMap.get(t.componentIndex)==null},e.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},e.prototype.filterSeries=function(t,n){$u(this);var a=[];B(this._seriesIndices,function(i){var o=this._componentsMap.get("series")[i];t.call(n,o,i)&&a.push(i)},this),this._seriesIndices=a,this._seriesIndicesMap=Pt(a)},e.prototype.restoreData=function(t){ov(this);var n=this._componentsMap,a=[];n.each(function(i,o){le.hasClass(o)&&a.push(o)}),le.topologicalTravel(a,le.getAllClassMainTypes(),function(i){B(n.get(i),function(o){o&&(i!=="series"||!PU(o,t))&&o.restoreData()})})},e.internalField=function(){ov=function(t){var n=t._seriesIndices=[];B(t._componentsMap.get("series"),function(a){a&&n.push(a.componentIndex)}),t._seriesIndicesMap=Pt(n)},$u=function(t){},GA=function(t,n){t.option={},t.option[WA]=IU,t._componentsMap=Pt({series:[]}),t._componentsCount=Pt();var a=n.aria;Vt(a)&&a.enabled==null&&(a.enabled=!0),kU(n,t._theme.option),qt(n,bU,!1),t._mergeOption(n,null)}}(),e}(De);function PU(r,e){if(e){var t=e.seriesIndex,n=e.seriesId,a=e.seriesName;return t!=null&&r.componentIndex!==t||n!=null&&r.id!==n||a!=null&&r.name!==a}}function kU(r,e){var t=r.color&&!r.colorLayer;B(e,function(n,a){a==="colorLayer"&&t||le.hasClass(a)||(typeof n=="object"?r[a]=r[a]?qt(r[a],n,!1):Gt(n):r[a]==null&&(r[a]=n))})}function HA(r,e,t){if(ht(e)){var n=Pt();return B(e,function(i){if(i!=null){var o=ur(i,null);o!=null&&n.set(i,!0)}}),Te(t,function(i){return i&&n.get(i[r])})}else{var a=ur(e,null);return Te(t,function(i){return i&&a!=null&&i[r]===a})}}function UA(r,e){return e.hasOwnProperty("subType")?Te(r,function(t){return t&&t.subType===e.subType}):r}function ZA(r){var e=Pt();return r&&B(Ie(r.replaceMerge),function(t){e.set(t,!0)}),{replaceMergeMainTypeMap:e}}sr(mw,yw);var RU=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],Ok=function(){function r(e){B(RU,function(t){this[t]=Mt(e[t],e)},this)}return r}(),Jy={},Rh=function(){function r(){this._coordinateSystems=[]}return r.prototype.create=function(e,t){var n=[];B(Jy,function(a,i){var o=a.create(e,t);n=n.concat(o||[])}),this._coordinateSystems=n},r.prototype.update=function(e,t){B(this._coordinateSystems,function(n){n.update&&n.update(e,t)})},r.prototype.getCoordinateSystems=function(){return this._coordinateSystems.slice()},r.register=function(e,t){Jy[e]=t},r.get=function(e){return Jy[e]},r}(),EU=/^(min|max)?(.+)$/,OU=function(){function r(e){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=e}return r.prototype.setOption=function(e,t,n){e&&(B(Ie(e.series),function(o){o&&o.data&&pn(o.data)&&vd(o.data)}),B(Ie(e.dataset),function(o){o&&o.source&&pn(o.source)&&vd(o.source)})),e=Gt(e);var a=this._optionBackup,i=BU(e,t,!a);this._newBaseOption=i.baseOption,a?(i.timelineOptions.length&&(a.timelineOptions=i.timelineOptions),i.mediaList.length&&(a.mediaList=i.mediaList),i.mediaDefault&&(a.mediaDefault=i.mediaDefault)):this._optionBackup=i},r.prototype.mountOption=function(e){var t=this._optionBackup;return this._timelineOptions=t.timelineOptions,this._mediaList=t.mediaList,this._mediaDefault=t.mediaDefault,this._currentMediaIndices=[],Gt(e?t.baseOption:this._newBaseOption)},r.prototype.getTimelineOption=function(e){var t,n=this._timelineOptions;if(n.length){var a=e.getComponent("timeline");a&&(t=Gt(n[a.getCurrentIndex()]))}return t},r.prototype.getMediaOption=function(e){var t=this._api.getWidth(),n=this._api.getHeight(),a=this._mediaList,i=this._mediaDefault,o=[],s=[];if(!a.length&&!i)return s;for(var l=0,u=a.length;l<u;l++)NU(a[l].query,t,n)&&o.push(l);return!o.length&&i&&(o=[-1]),o.length&&!FU(o,this._currentMediaIndices)&&(s=ft(o,function(c){return Gt(c===-1?i.option:a[c].option)})),this._currentMediaIndices=o,s},r}();function BU(r,e,t){var n=[],a,i,o=r.baseOption,s=r.timeline,l=r.options,u=r.media,c=!!r.media,h=!!(l||s||o&&o.timeline);o?(i=o,i.timeline||(i.timeline=s)):((h||c)&&(r.options=r.media=null),i=r),c&&ht(u)&&B(u,function(v){v&&v.option&&(v.query?n.push(v):a||(a=v))}),d(i),B(l,function(v){return d(v)}),B(n,function(v){return d(v.option)});function d(v){B(e,function(p){p(v,t)})}return{baseOption:i,timelineOptions:l||[],mediaDefault:a,mediaList:n}}function NU(r,e,t){var n={width:e,height:t,aspectratio:e/t},a=!0;return B(r,function(i,o){var s=o.match(EU);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();zU(n[u],i,l)||(a=!1)}}),a}function zU(r,e,t){return t==="min"?r>=e:t==="max"?r<=e:r===e}function FU(r,e){return r.join(",")===e.join(",")}var ua=B,ih=Vt,YA=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function tm(r){var e=r&&r.itemStyle;if(e)for(var t=0,n=YA.length;t<n;t++){var a=YA[t],i=e.normal,o=e.emphasis;i&&i[a]&&(r[a]=r[a]||{},r[a].normal?qt(r[a].normal,i[a]):r[a].normal=i[a],i[a]=null),o&&o[a]&&(r[a]=r[a]||{},r[a].emphasis?qt(r[a].emphasis,o[a]):r[a].emphasis=o[a],o[a]=null)}}function Vr(r,e,t){if(r&&r[e]&&(r[e].normal||r[e].emphasis)){var n=r[e].normal,a=r[e].emphasis;n&&(t?(r[e].normal=r[e].emphasis=null,zt(r[e],n)):r[e]=n),a&&(r.emphasis=r.emphasis||{},r.emphasis[e]=a,a.focus&&(r.emphasis.focus=a.focus),a.blurScope&&(r.emphasis.blurScope=a.blurScope))}}function Ac(r){Vr(r,"itemStyle"),Vr(r,"lineStyle"),Vr(r,"areaStyle"),Vr(r,"label"),Vr(r,"labelLine"),Vr(r,"upperLabel"),Vr(r,"edgeLabel")}function ar(r,e){var t=ih(r)&&r[e],n=ih(t)&&t.textStyle;if(n)for(var a=0,i=Q2.length;a<i;a++){var o=Q2[a];n.hasOwnProperty(o)&&(t[o]=n[o])}}function Zn(r){r&&(Ac(r),ar(r,"label"),r.emphasis&&ar(r.emphasis,"label"))}function VU(r){if(ih(r)){tm(r),Ac(r),ar(r,"label"),ar(r,"upperLabel"),ar(r,"edgeLabel"),r.emphasis&&(ar(r.emphasis,"label"),ar(r.emphasis,"upperLabel"),ar(r.emphasis,"edgeLabel"));var e=r.markPoint;e&&(tm(e),Zn(e));var t=r.markLine;t&&(tm(t),Zn(t));var n=r.markArea;n&&Zn(n);var a=r.data;if(r.type==="graph"){a=a||r.nodes;var i=r.links||r.edges;if(i&&!pn(i))for(var o=0;o<i.length;o++)Zn(i[o]);B(r.categories,function(u){Ac(u)})}if(a&&!pn(a))for(var o=0;o<a.length;o++)Zn(a[o]);if(e=r.markPoint,e&&e.data)for(var s=e.data,o=0;o<s.length;o++)Zn(s[o]);if(t=r.markLine,t&&t.data)for(var l=t.data,o=0;o<l.length;o++)ht(l[o])?(Zn(l[o][0]),Zn(l[o][1])):Zn(l[o]);r.type==="gauge"?(ar(r,"axisLabel"),ar(r,"title"),ar(r,"detail")):r.type==="treemap"?(Vr(r.breadcrumb,"itemStyle"),B(r.levels,function(u){Ac(u)})):r.type==="tree"&&Ac(r.leaves)}}function ci(r){return ht(r)?r:r?[r]:[]}function XA(r){return(ht(r)?r[0]:r)||{}}function GU(r,e){ua(ci(r.series),function(n){ih(n)&&VU(n)});var t=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];e&&t.push("valueAxis","categoryAxis","logAxis","timeAxis"),ua(t,function(n){ua(ci(r[n]),function(a){a&&(ar(a,"axisLabel"),ar(a.axisPointer,"label"))})}),ua(ci(r.parallel),function(n){var a=n&&n.parallelAxisDefault;ar(a,"axisLabel"),ar(a&&a.axisPointer,"label")}),ua(ci(r.calendar),function(n){Vr(n,"itemStyle"),ar(n,"dayLabel"),ar(n,"monthLabel"),ar(n,"yearLabel")}),ua(ci(r.radar),function(n){ar(n,"name"),n.name&&n.axisName==null&&(n.axisName=n.name,delete n.name),n.nameGap!=null&&n.axisNameGap==null&&(n.axisNameGap=n.nameGap,delete n.nameGap)}),ua(ci(r.geo),function(n){ih(n)&&(Zn(n),ua(ci(n.regions),function(a){Zn(a)}))}),ua(ci(r.timeline),function(n){Zn(n),Vr(n,"label"),Vr(n,"itemStyle"),Vr(n,"controlStyle",!0);var a=n.data;ht(a)&&B(a,function(i){Vt(i)&&(Vr(i,"label"),Vr(i,"itemStyle"))})}),ua(ci(r.toolbox),function(n){Vr(n,"iconStyle"),ua(n.feature,function(a){Vr(a,"iconStyle")})}),ar(XA(r.axisPointer),"label"),ar(XA(r.tooltip).axisPointer,"label")}function WU(r,e){for(var t=e.split(","),n=r,a=0;a<t.length&&(n=n&&n[t[a]],n!=null);a++);return n}function HU(r,e,t,n){for(var a=e.split(","),i=r,o,s=0;s<a.length-1;s++)o=a[s],i[o]==null&&(i[o]={}),i=i[o];i[a[s]]==null&&(i[a[s]]=t)}function $A(r){r&&B(UU,function(e){e[0]in r&&!(e[1]in r)&&(r[e[1]]=r[e[0]])})}var UU=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],ZU=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],em=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function ju(r){var e=r&&r.itemStyle;if(e)for(var t=0;t<em.length;t++){var n=em[t][1],a=em[t][0];e[n]!=null&&(e[a]=e[n])}}function jA(r){r&&r.alignTo==="edge"&&r.margin!=null&&r.edgeDistance==null&&(r.edgeDistance=r.margin)}function qA(r){r&&r.downplay&&!r.blur&&(r.blur=r.downplay)}function YU(r){r&&r.focusNodeAdjacency!=null&&(r.emphasis=r.emphasis||{},r.emphasis.focus==null&&(r.emphasis.focus="adjacency"))}function Bk(r,e){if(r)for(var t=0;t<r.length;t++)e(r[t]),r[t]&&Bk(r[t].children,e)}function Nk(r,e){GU(r,e),r.series=Ie(r.series),B(r.series,function(t){if(Vt(t)){var n=t.type;if(n==="line")t.clipOverflow!=null&&(t.clip=t.clipOverflow);else if(n==="pie"||n==="gauge"){t.clockWise!=null&&(t.clockwise=t.clockWise),jA(t.label);var a=t.data;if(a&&!pn(a))for(var i=0;i<a.length;i++)jA(a[i]);t.hoverOffset!=null&&(t.emphasis=t.emphasis||{},(t.emphasis.scaleSize=null)&&(t.emphasis.scaleSize=t.hoverOffset))}else if(n==="gauge"){var o=WU(t,"pointer.color");o!=null&&HU(t,"itemStyle.color",o)}else if(n==="bar"){ju(t),ju(t.backgroundStyle),ju(t.emphasis);var a=t.data;if(a&&!pn(a))for(var i=0;i<a.length;i++)typeof a[i]=="object"&&(ju(a[i]),ju(a[i]&&a[i].emphasis))}else if(n==="sunburst"){var s=t.highlightPolicy;s&&(t.emphasis=t.emphasis||{},t.emphasis.focus||(t.emphasis.focus=s)),qA(t),Bk(t.data,qA)}else n==="graph"||n==="sankey"?YU(t):n==="map"&&(t.mapType&&!t.map&&(t.map=t.mapType),t.mapLocation&&zt(t,t.mapLocation));t.hoverAnimation!=null&&(t.emphasis=t.emphasis||{},t.emphasis&&t.emphasis.scale==null&&(t.emphasis.scale=t.hoverAnimation)),$A(t)}}),r.dataRange&&(r.visualMap=r.dataRange),B(ZU,function(t){var n=r[t];n&&(ht(n)||(n=[n]),B(n,function(a){$A(a)}))})}function XU(r){var e=Pt();r.eachSeries(function(t){var n=t.get("stack");if(n){var a=e.get(n)||e.set(n,[]),i=t.getData(),o={stackResultDimension:i.getCalculationInfo("stackResultDimension"),stackedOverDimension:i.getCalculationInfo("stackedOverDimension"),stackedDimension:i.getCalculationInfo("stackedDimension"),stackedByDimension:i.getCalculationInfo("stackedByDimension"),isStackedByIndex:i.getCalculationInfo("isStackedByIndex"),data:i,seriesModel:t};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;a.length&&i.setCalculationInfo("stackedOnSeries",a[a.length-1].seriesModel),a.push(o)}}),e.each($U)}function $U(r){B(r,function(e,t){var n=[],a=[NaN,NaN],i=[e.stackResultDimension,e.stackedOverDimension],o=e.data,s=e.isStackedByIndex,l=e.seriesModel.get("stackStrategy")||"samesign";o.modify(i,function(u,c,h){var d=o.get(e.stackedDimension,h);if(isNaN(d))return a;var v,p;s?p=o.getRawIndex(h):v=o.get(e.stackedByDimension,h);for(var y=NaN,_=t-1;_>=0;_--){var g=r[_];if(s||(p=g.data.rawIndexOf(g.stackedByDimension,v)),p>=0){var f=g.data.getByRawIndex(g.stackResultDimension,p);if(l==="all"||l==="positive"&&f>0||l==="negative"&&f<0||l==="samesign"&&d>=0&&f>0||l==="samesign"&&d<=0&&f<0){d=U8(d,f),y=f;break}}}return n[0]=d,n[1]=y,n})})}var Ep=function(){function r(e){this.data=e.data||(e.sourceFormat===Ka?{}:[]),this.sourceFormat=e.sourceFormat||Dk,this.seriesLayoutBy=e.seriesLayoutBy||Ua,this.startIndex=e.startIndex||0,this.dimensionsDetectedCount=e.dimensionsDetectedCount,this.metaRawOption=e.metaRawOption;var t=this.dimensionsDefine=e.dimensionsDefine;if(t)for(var n=0;n<t.length;n++){var a=t[n];a.type==null&&kk(this,n)===Ir.Must&&(a.type="ordinal")}}return r}();function _w(r){return r instanceof Ep}function M_(r,e,t){t=t||zk(r);var n=e.seriesLayoutBy,a=qU(r,t,n,e.sourceHeader,e.dimensions),i=new Ep({data:r,sourceFormat:t,seriesLayoutBy:n,dimensionsDefine:a.dimensionsDefine,startIndex:a.startIndex,dimensionsDetectedCount:a.dimensionsDetectedCount,metaRawOption:Gt(e)});return i}function ww(r){return new Ep({data:r,sourceFormat:pn(r)?po:ra})}function jU(r){return new Ep({data:r.data,sourceFormat:r.sourceFormat,seriesLayoutBy:r.seriesLayoutBy,dimensionsDefine:Gt(r.dimensionsDefine),startIndex:r.startIndex,dimensionsDetectedCount:r.dimensionsDetectedCount})}function zk(r){var e=Dk;if(pn(r))e=po;else if(ht(r)){r.length===0&&(e=Wr);for(var t=0,n=r.length;t<n;t++){var a=r[t];if(a!=null){if(ht(a)||pn(a)){e=Wr;break}else if(Vt(a)){e=na;break}}}}else if(Vt(r)){for(var i in r)if(It(r,i)&&Gr(r[i])){e=Ka;break}}return e}function qU(r,e,t,n,a){var i,o;if(!r)return{dimensionsDefine:KA(a),startIndex:o,dimensionsDetectedCount:i};if(e===Wr){var s=r;n==="auto"||n==null?QA(function(u){u!=null&&u!=="-"&&(Lt(u)?o==null&&(o=1):o=0)},t,s,10):o=ye(n)?n:n?1:0,!a&&o===1&&(a=[],QA(function(u,c){a[c]=u!=null?u+"":""},t,s,1/0)),i=a?a.length:t===mu?s.length:s[0]?s[0].length:null}else if(e===na)a||(a=KU(r));else if(e===Ka)a||(a=[],B(r,function(u,c){a.push(c)}));else if(e===ra){var l=hu(r[0]);i=ht(l)&&l.length||1}return{startIndex:o,dimensionsDefine:KA(a),dimensionsDetectedCount:i}}function KU(r){for(var e=0,t;e<r.length&&!(t=r[e++]););if(t)return ue(t)}function KA(r){if(r){var e=Pt();return ft(r,function(t,n){t=Vt(t)?t:{name:t};var a={name:t.name,displayName:t.displayName,type:t.type};if(a.name==null)return a;a.name+="",a.displayName==null&&(a.displayName=a.name);var i=e.get(a.name);return i?a.name+="-"+i.count++:e.set(a.name,{count:1}),a})}}function QA(r,e,t,n){if(e===mu)for(var a=0;a<t.length&&a<n;a++)r(t[a]?t[a][0]:null,a);else for(var i=t[0]||[],a=0;a<i.length&&a<n;a++)r(i[a],a)}function Fk(r){var e=r.sourceFormat;return e===na||e===Ka}var ts,es,rs,JA,tT,Vk=function(){function r(e,t){var n=_w(e)?e:ww(e);this._source=n;var a=this._data=n.data;n.sourceFormat===po&&(this._offset=0,this._dimSize=t,this._data=a),tT(this,a,n)}return r.prototype.getSource=function(){return this._source},r.prototype.count=function(){return 0},r.prototype.getItem=function(e,t){},r.prototype.appendData=function(e){},r.prototype.clean=function(){},r.protoInitialize=function(){var e=r.prototype;e.pure=!1,e.persistent=!0}(),r.internalField=function(){var e;tT=function(o,s,l){var u=l.sourceFormat,c=l.seriesLayoutBy,h=l.startIndex,d=l.dimensionsDefine,v=JA[xw(u,c)];if(lt(o,v),u===po)o.getItem=t,o.count=a,o.fillStorage=n;else{var p=Gk(u,c);o.getItem=Mt(p,null,s,h,d);var y=Wk(u,c);o.count=Mt(y,null,s,h,d)}};var t=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,c=u*o,h=0;h<u;h++)s[h]=l[c+h];return s},n=function(o,s,l,u){for(var c=this._data,h=this._dimSize,d=0;d<h;d++){for(var v=u[d],p=v[0]==null?1/0:v[0],y=v[1]==null?-1/0:v[1],_=s-o,g=l[d],f=0;f<_;f++){var w=c[f*h+d];g[o+f]=w,w<p&&(p=w),w>y&&(y=w)}v[0]=p,v[1]=y}},a=function(){return this._data?this._data.length/this._dimSize:0};JA=(e={},e[Wr+"_"+Ua]={pure:!0,appendData:i},e[Wr+"_"+mu]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},e[na]={pure:!0,appendData:i},e[Ka]={pure:!0,appendData:function(o){var s=this._data;B(o,function(l,u){for(var c=s[u]||(s[u]=[]),h=0;h<(l||[]).length;h++)c.push(l[h])})}},e[ra]={appendData:i},e[po]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},e);function i(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}}(),r}(),eT=function(r,e,t,n){return r[n]},QU=(ts={},ts[Wr+"_"+Ua]=function(r,e,t,n){return r[n+e]},ts[Wr+"_"+mu]=function(r,e,t,n,a){n+=e;for(var i=a||[],o=r,s=0;s<o.length;s++){var l=o[s];i[s]=l?l[n]:null}return i},ts[na]=eT,ts[Ka]=function(r,e,t,n,a){for(var i=a||[],o=0;o<t.length;o++){var s=t[o].name,l=r[s];i[o]=l?l[n]:null}return i},ts[ra]=eT,ts);function Gk(r,e){var t=QU[xw(r,e)];return t}var rT=function(r,e,t){return r.length},JU=(es={},es[Wr+"_"+Ua]=function(r,e,t){return Math.max(0,r.length-e)},es[Wr+"_"+mu]=function(r,e,t){var n=r[0];return n?Math.max(0,n.length-e):0},es[na]=rT,es[Ka]=function(r,e,t){var n=t[0].name,a=r[n];return a?a.length:0},es[ra]=rT,es);function Wk(r,e){var t=JU[xw(r,e)];return t}var rm=function(r,e,t){return r[e]},t7=(rs={},rs[Wr]=rm,rs[na]=function(r,e,t){return r[t]},rs[Ka]=rm,rs[ra]=function(r,e,t){var n=hu(r);return n instanceof Array?n[e]:n},rs[po]=rm,rs);function Hk(r){var e=t7[r];return e}function xw(r,e){return r===Wr?r+"_"+e:r}function tu(r,e,t){if(r){var n=r.getRawDataItem(e);if(n!=null){var a=r.getStore(),i=a.getSource().sourceFormat;if(t!=null){var o=r.getDimensionIndex(t),s=a.getDimensionProperty(o);return Hk(i)(n,o,s)}else{var l=n;return i===ra&&(l=hu(n)),l}}}}var e7=/\{@(.+?)\}/g,Op=function(){function r(){}return r.prototype.getDataParams=function(e,t){var n=this.getData(t),a=this.getRawValue(e,t),i=n.getRawIndex(e),o=n.getName(e),s=n.getRawDataItem(e),l=n.getItemVisual(e,"style"),u=l&&l[n.getItemVisual(e,"drawType")||"fill"],c=l&&l.stroke,h=this.mainType,d=h==="series",v=n.userOutput&&n.userOutput.get();return{componentType:h,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:d?this.subType:null,seriesIndex:this.seriesIndex,seriesId:d?this.id:null,seriesName:d?this.name:null,name:o,dataIndex:i,data:s,dataType:t,value:a,color:u,borderColor:c,dimensionNames:v?v.fullDimensions:null,encode:v?v.encode:null,$vars:["seriesName","name","value"]}},r.prototype.getFormattedLabel=function(e,t,n,a,i,o){t=t||"normal";var s=this.getData(n),l=this.getDataParams(e,n);if(o&&(l.value=o.interpolatedValue),a!=null&&ht(l.value)&&(l.value=l.value[a]),!i){var u=s.getItemModel(e);i=u.get(t==="normal"?["label","formatter"]:[t,"label","formatter"])}if(Nt(i))return l.status=t,l.dimensionIndex=a,i(l);if(Lt(i)){var c=Ak(i,l);return c.replace(e7,function(h,d){var v=d.length,p=d;p.charAt(0)==="["&&p.charAt(v-1)==="]"&&(p=+p.slice(1,v-1));var y=tu(s,e,p);if(o&&ht(o.interpolatedValue)){var _=s.getDimensionIndex(p);_>=0&&(y=o.interpolatedValue[_])}return y!=null?y+"":""})}},r.prototype.getRawValue=function(e,t){return tu(this.getData(t),e)},r.prototype.formatTooltip=function(e,t,n){},r}();function nT(r){var e,t;return Vt(r)?r.type&&(t=r):e=r,{text:e,frag:t}}function Gc(r){return new r7(r)}var r7=function(){function r(e){e=e||{},this._reset=e.reset,this._plan=e.plan,this._count=e.count,this._onDirty=e.onDirty,this._dirty=!0}return r.prototype.perform=function(e){var t=this._upstream,n=e&&e.skip;if(this._dirty&&t){var a=this.context;a.data=a.outputData=t.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var i;this._plan&&!n&&(i=this._plan(this.context));var o=c(this._modBy),s=this._modDataCount||0,l=c(e&&e.modBy),u=e&&e.modDataCount||0;(o!==l||s!==u)&&(i="reset");function c(f){return!(f>=1)&&(f=1),f}var h;(this._dirty||i==="reset")&&(this._dirty=!1,h=this._doReset(n)),this._modBy=l,this._modDataCount=u;var d=e&&e.step;if(t?this._dueEnd=t._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var v=this._dueIndex,p=Math.min(d!=null?this._dueIndex+d:1/0,this._dueEnd);if(!n&&(h||v<p)){var y=this._progress;if(ht(y))for(var _=0;_<y.length;_++)this._doProgress(y[_],v,p,l,u);else this._doProgress(y,v,p,l,u)}this._dueIndex=p;var g=this._settedOutputEnd!=null?this._settedOutputEnd:p;this._outputDueEnd=g}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},r.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},r.prototype._doProgress=function(e,t,n,a,i){aT.reset(t,n,a,i),this._callingProgress=e,this._callingProgress({start:t,end:n,count:n-t,next:aT.next},this.context)},r.prototype._doReset=function(e){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var t,n;!e&&this._reset&&(t=this._reset(this.context),t&&t.progress&&(n=t.forceFirstProgress,t=t.progress),ht(t)&&!t.length&&(t=null)),this._progress=t,this._modBy=this._modDataCount=null;var a=this._downstream;return a&&a.dirty(),n},r.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},r.prototype.pipe=function(e){(this._downstream!==e||this._dirty)&&(this._downstream=e,e._upstream=this,e.dirty())},r.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},r.prototype.getUpstream=function(){return this._upstream},r.prototype.getDownstream=function(){return this._downstream},r.prototype.setOutputEnd=function(e){this._outputDueEnd=this._settedOutputEnd=e},r}(),aT=function(){var r,e,t,n,a,i={reset:function(l,u,c,h){e=l,r=u,t=c,n=h,a=Math.ceil(n/t),i.next=t>1&&n>0?s:o}};return i;function o(){return e<r?e++:null}function s(){var l=e%a*t+Math.ceil(e/a),u=e>=r?null:l<n?l:e;return e++,u}}();function go(r,e){var t=e&&e.type;return t==="ordinal"?r:(t==="time"&&!ye(r)&&r!=null&&r!=="-"&&(r=+$a(r)),r==null||r===""?NaN:Number(r))}var n7=Pt({number:function(r){return parseFloat(r)},time:function(r){return+$a(r)},trim:function(r){return Lt(r)?ga(r):r}});function Uk(r){return n7.get(r)}var Zk={lt:function(r,e){return r<e},lte:function(r,e){return r<=e},gt:function(r,e){return r>e},gte:function(r,e){return r>=e}},a7=function(){function r(e,t){if(!ye(t)){var n="";Ae(n)}this._opFn=Zk[e],this._rvalFloat=Ai(t)}return r.prototype.evaluate=function(e){return ye(e)?this._opFn(e,this._rvalFloat):this._opFn(Ai(e),this._rvalFloat)},r}(),Yk=function(){function r(e,t){var n=e==="desc";this._resultLT=n?1:-1,t==null&&(t=n?"min":"max"),this._incomparable=t==="min"?-1/0:1/0}return r.prototype.evaluate=function(e,t){var n=ye(e)?e:Ai(e),a=ye(t)?t:Ai(t),i=isNaN(n),o=isNaN(a);if(i&&(n=this._incomparable),o&&(a=this._incomparable),i&&o){var s=Lt(e),l=Lt(t);s&&(n=l?e:0),l&&(a=s?t:0)}return n<a?this._resultLT:n>a?-this._resultLT:0},r}(),i7=function(){function r(e,t){this._rval=t,this._isEQ=e,this._rvalTypeof=typeof t,this._rvalFloat=Ai(t)}return r.prototype.evaluate=function(e){var t=e===this._rval;if(!t){var n=typeof e;n!==this._rvalTypeof&&(n==="number"||this._rvalTypeof==="number")&&(t=Ai(e)===this._rvalFloat)}return this._isEQ?t:!t},r}();function o7(r,e){return r==="eq"||r==="ne"?new i7(r==="eq",e):It(Zk,r)?new a7(r,e):null}var s7=function(){function r(){}return r.prototype.getRawData=function(){throw new Error("not supported")},r.prototype.getRawDataItem=function(e){throw new Error("not supported")},r.prototype.cloneRawData=function(){},r.prototype.getDimensionInfo=function(e){},r.prototype.cloneAllDimensionInfo=function(){},r.prototype.count=function(){},r.prototype.retrieveValue=function(e,t){},r.prototype.retrieveValueFromItem=function(e,t){},r.prototype.convertValue=function(e,t){return go(e,t)},r}();function l7(r,e){var t=new s7,n=r.data,a=t.sourceFormat=r.sourceFormat,i=r.startIndex,o="";r.seriesLayoutBy!==Ua&&Ae(o);var s=[],l={},u=r.dimensionsDefine;if(u)B(u,function(y,_){var g=y.name,f={index:_,name:g,displayName:y.displayName};if(s.push(f),g!=null){var w="";It(l,g)&&Ae(w),l[g]=f}});else for(var c=0;c<r.dimensionsDetectedCount;c++)s.push({index:c});var h=Gk(a,Ua);e.__isBuiltIn&&(t.getRawDataItem=function(y){return h(n,i,s,y)},t.getRawData=Mt(u7,null,r)),t.cloneRawData=Mt(c7,null,r);var d=Wk(a,Ua);t.count=Mt(d,null,n,i,s);var v=Hk(a);t.retrieveValue=function(y,_){var g=h(n,i,s,y);return p(g,_)};var p=t.retrieveValueFromItem=function(y,_){if(y!=null){var g=s[_];if(g)return v(y,_,g.name)}};return t.getDimensionInfo=Mt(h7,null,s,l),t.cloneAllDimensionInfo=Mt(f7,null,s),t}function u7(r){var e=r.sourceFormat;if(!bw(e)){var t="";Ae(t)}return r.data}function c7(r){var e=r.sourceFormat,t=r.data;if(!bw(e)){var n="";Ae(n)}if(e===Wr){for(var a=[],i=0,o=t.length;i<o;i++)a.push(t[i].slice());return a}else if(e===na){for(var a=[],i=0,o=t.length;i<o;i++)a.push(lt({},t[i]));return a}}function h7(r,e,t){if(t!=null){if(ye(t)||!isNaN(t)&&!It(e,t))return r[t];if(It(e,t))return e[t]}}function f7(r){return Gt(r)}var Xk=Pt();function v7(r){r=Gt(r);var e=r.type,t="";e||Ae(t);var n=e.split(":");n.length!==2&&Ae(t);var a=!1;n[0]==="echarts"&&(e=n[1],a=!0),r.__isBuiltIn=a,Xk.set(e,r)}function d7(r,e,t){var n=Ie(r),a=n.length,i="";a||Ae(i);for(var o=0,s=a;o<s;o++){var l=n[o];e=p7(l,e),o!==s-1&&(e.length=Math.max(e.length,1))}return e}function p7(r,e,t,n){var a="";e.length||Ae(a),Vt(r)||Ae(a);var i=r.type,o=Xk.get(i);o||Ae(a);var s=ft(e,function(u){return l7(u,o)}),l=Ie(o.transform({upstream:s[0],upstreamList:s,config:Gt(r.config)}));return ft(l,function(u,c){var h="";Vt(u)||Ae(h),u.data||Ae(h);var d=zk(u.data);bw(d)||Ae(h);var v,p=e[0];if(p&&c===0&&!u.dimensions){var y=p.startIndex;y&&(u.data=p.data.slice(0,y).concat(u.data)),v={seriesLayoutBy:Ua,sourceHeader:y,dimensions:p.metaRawOption.dimensions}}else v={seriesLayoutBy:Ua,sourceHeader:0,dimensions:u.dimensions};return M_(u.data,v,null)})}function bw(r){return r===Wr||r===na}var Bp="undefined",g7=typeof Uint32Array===Bp?Array:Uint32Array,y7=typeof Uint16Array===Bp?Array:Uint16Array,$k=typeof Int32Array===Bp?Array:Int32Array,iT=typeof Float64Array===Bp?Array:Float64Array,jk={float:iT,int:$k,ordinal:Array,number:Array,time:iT},nm;function wl(r){return r>65535?g7:y7}function xl(){return[1/0,-1/0]}function m7(r){var e=r.constructor;return e===Array?r.slice():new e(r)}function oT(r,e,t,n,a){var i=jk[t||"float"];if(a){var o=r[e],s=o&&o.length;if(s!==n){for(var l=new i(n),u=0;u<s;u++)l[u]=o[u];r[e]=l}}else r[e]=new i(n)}var D_=function(){function r(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=Pt()}return r.prototype.initData=function(e,t,n){this._provider=e,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var a=e.getSource(),i=this.defaultDimValueGetter=nm[a.sourceFormat];this._dimValueGetter=n||i,this._rawExtent=[],Fk(a),this._dimensions=ft(t,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,e.count())},r.prototype.getProvider=function(){return this._provider},r.prototype.getSource=function(){return this._provider.getSource()},r.prototype.ensureCalculationDimension=function(e,t){var n=this._calcDimNameToIdx,a=this._dimensions,i=n.get(e);if(i!=null){if(a[i].type===t)return i}else i=a.length;return a[i]={type:t},n.set(e,i),this._chunks[i]=new jk[t||"float"](this._rawCount),this._rawExtent[i]=xl(),i},r.prototype.collectOrdinalMeta=function(e,t){var n=this._chunks[e],a=this._dimensions[e],i=this._rawExtent,o=a.ordinalOffset||0,s=n.length;o===0&&(i[e]=xl());for(var l=i[e],u=o;u<s;u++){var c=n[u]=t.parseAndCollect(n[u]);isNaN(c)||(l[0]=Math.min(c,l[0]),l[1]=Math.max(c,l[1]))}a.ordinalMeta=t,a.ordinalOffset=s,a.type="ordinal"},r.prototype.getOrdinalMeta=function(e){var t=this._dimensions[e],n=t.ordinalMeta;return n},r.prototype.getDimensionProperty=function(e){var t=this._dimensions[e];return t&&t.property},r.prototype.appendData=function(e){var t=this._provider,n=this.count();t.appendData(e);var a=t.count();return t.persistent||(a+=n),n<a&&this._initDataFromProvider(n,a,!0),[n,a]},r.prototype.appendValues=function(e,t){for(var n=this._chunks,a=this._dimensions,i=a.length,o=this._rawExtent,s=this.count(),l=s+Math.max(e.length,t||0),u=0;u<i;u++){var c=a[u];oT(n,u,c.type,l,!0)}for(var h=[],d=s;d<l;d++)for(var v=d-s,p=0;p<i;p++){var c=a[p],y=nm.arrayRows.call(this,e[v]||h,c.property,v,p);n[p][d]=y;var _=o[p];y<_[0]&&(_[0]=y),y>_[1]&&(_[1]=y)}return this._rawCount=this._count=l,{start:s,end:l}},r.prototype._initDataFromProvider=function(e,t,n){for(var a=this._provider,i=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=ft(o,function(f){return f.property}),c=0;c<s;c++){var h=o[c];l[c]||(l[c]=xl()),oT(i,c,h.type,t,n)}if(a.fillStorage)a.fillStorage(e,t,i,l);else for(var d=[],v=e;v<t;v++){d=a.getItem(v,d);for(var p=0;p<s;p++){var y=i[p],_=this._dimValueGetter(d,u[p],v,p);y[v]=_;var g=l[p];_<g[0]&&(g[0]=_),_>g[1]&&(g[1]=_)}}!a.persistent&&a.clean&&a.clean(),this._rawCount=this._count=t,this._extent=[]},r.prototype.count=function(){return this._count},r.prototype.get=function(e,t){if(!(t>=0&&t<this._count))return NaN;var n=this._chunks[e];return n?n[this.getRawIndex(t)]:NaN},r.prototype.getValues=function(e,t){var n=[],a=[];if(t==null){t=e,e=[];for(var i=0;i<this._dimensions.length;i++)a.push(i)}else a=e;for(var i=0,o=a.length;i<o;i++)n.push(this.get(a[i],t));return n},r.prototype.getByRawIndex=function(e,t){if(!(t>=0&&t<this._rawCount))return NaN;var n=this._chunks[e];return n?n[t]:NaN},r.prototype.getSum=function(e){var t=this._chunks[e],n=0;if(t)for(var a=0,i=this.count();a<i;a++){var o=this.get(e,a);isNaN(o)||(n+=o)}return n},r.prototype.getMedian=function(e){var t=[];this.each([e],function(i){isNaN(i)||t.push(i)});var n=t.sort(function(i,o){return i-o}),a=this.count();return a===0?0:a%2===1?n[(a-1)/2]:(n[a/2]+n[a/2-1])/2},r.prototype.indexOfRawIndex=function(e){if(e>=this._rawCount||e<0)return-1;if(!this._indices)return e;var t=this._indices,n=t[e];if(n!=null&&n<this._count&&n===e)return e;for(var a=0,i=this._count-1;a<=i;){var o=(a+i)/2|0;if(t[o]<e)a=o+1;else if(t[o]>e)i=o-1;else return o}return-1},r.prototype.indicesOfNearest=function(e,t,n){var a=this._chunks,i=a[e],o=[];if(!i)return o;n==null&&(n=1/0);for(var s=1/0,l=-1,u=0,c=0,h=this.count();c<h;c++){var d=this.getRawIndex(c),v=t-i[d],p=Math.abs(v);p<=n&&((p<s||p===s&&v>=0&&l<0)&&(s=p,l=v,u=0),v===l&&(o[u++]=c))}return o.length=u,o},r.prototype.getIndices=function(){var e,t=this._indices;if(t){var n=t.constructor,a=this._count;if(n===Array){e=new n(a);for(var i=0;i<a;i++)e[i]=t[i]}else e=new n(t.buffer,0,a)}else{var n=wl(this._rawCount);e=new n(this.count());for(var i=0;i<e.length;i++)e[i]=i}return e},r.prototype.filter=function(e,t){if(!this._count)return this;for(var n=this.clone(),a=n.count(),i=wl(n._rawCount),o=new i(a),s=[],l=e.length,u=0,c=e[0],h=n._chunks,d=0;d<a;d++){var v=void 0,p=n.getRawIndex(d);if(l===0)v=t(d);else if(l===1){var y=h[c][p];v=t(y,d)}else{for(var _=0;_<l;_++)s[_]=h[e[_]][p];s[_]=d,v=t.apply(null,s)}v&&(o[u++]=p)}return u<a&&(n._indices=o),n._count=u,n._extent=[],n._updateGetRawIdx(),n},r.prototype.selectRange=function(e){var t=this.clone(),n=t._count;if(!n)return this;var a=ue(e),i=a.length;if(!i)return this;var o=t.count(),s=wl(t._rawCount),l=new s(o),u=0,c=a[0],h=e[c][0],d=e[c][1],v=t._chunks,p=!1;if(!t._indices){var y=0;if(i===1){for(var _=v[a[0]],g=0;g<n;g++){var f=_[g];(f>=h&&f<=d||isNaN(f))&&(l[u++]=y),y++}p=!0}else if(i===2){for(var _=v[a[0]],w=v[a[1]],x=e[a[1]][0],S=e[a[1]][1],g=0;g<n;g++){var f=_[g],A=w[g];(f>=h&&f<=d||isNaN(f))&&(A>=x&&A<=S||isNaN(A))&&(l[u++]=y),y++}p=!0}}if(!p)if(i===1)for(var g=0;g<o;g++){var T=t.getRawIndex(g),f=v[a[0]][T];(f>=h&&f<=d||isNaN(f))&&(l[u++]=T)}else for(var g=0;g<o;g++){for(var L=!0,T=t.getRawIndex(g),M=0;M<i;M++){var I=a[M],f=v[I][T];(f<e[I][0]||f>e[I][1])&&(L=!1)}L&&(l[u++]=t.getRawIndex(g))}return u<o&&(t._indices=l),t._count=u,t._extent=[],t._updateGetRawIdx(),t},r.prototype.map=function(e,t){var n=this.clone(e);return this._updateDims(n,e,t),n},r.prototype.modify=function(e,t){this._updateDims(this,e,t)},r.prototype._updateDims=function(e,t,n){for(var a=e._chunks,i=[],o=t.length,s=e.count(),l=[],u=e._rawExtent,c=0;c<t.length;c++)u[t[c]]=xl();for(var h=0;h<s;h++){for(var d=e.getRawIndex(h),v=0;v<o;v++)l[v]=a[t[v]][d];l[o]=h;var p=n&&n.apply(null,l);if(p!=null){typeof p!="object"&&(i[0]=p,p=i);for(var c=0;c<p.length;c++){var y=t[c],_=p[c],g=u[y],f=a[y];f&&(f[d]=_),_<g[0]&&(g[0]=_),_>g[1]&&(g[1]=_)}}}},r.prototype.lttbDownSample=function(e,t){var n=this.clone([e],!0),a=n._chunks,i=a[e],o=this.count(),s=0,l=Math.floor(1/t),u=this.getRawIndex(0),c,h,d,v=new(wl(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));v[s++]=u;for(var p=1;p<o-1;p+=l){for(var y=Math.min(p+l,o-1),_=Math.min(p+l*2,o),g=(_+y)/2,f=0,w=y;w<_;w++){var x=this.getRawIndex(w),S=i[x];isNaN(S)||(f+=S)}f/=_-y;var A=p,T=Math.min(p+l,o),L=p-1,M=i[u];c=-1,d=A;for(var I=-1,R=0,w=A;w<T;w++){var x=this.getRawIndex(w),S=i[x];if(isNaN(S)){R++,I<0&&(I=x);continue}h=Math.abs((L-g)*(S-M)-(L-w)*(f-M)),h>c&&(c=h,d=x)}R>0&&R<T-A&&(v[s++]=Math.min(I,d),d=Math.max(I,d)),v[s++]=d,u=d}return v[s++]=this.getRawIndex(o-1),n._count=s,n._indices=v,n.getRawIndex=this._getRawIdx,n},r.prototype.minmaxDownSample=function(e,t){for(var n=this.clone([e],!0),a=n._chunks,i=Math.floor(1/t),o=a[e],s=this.count(),l=new(wl(this._rawCount))(Math.ceil(s/i)*2),u=0,c=0;c<s;c+=i){var h=c,d=o[this.getRawIndex(h)],v=c,p=o[this.getRawIndex(v)],y=i;c+i>s&&(y=s-c);for(var _=0;_<y;_++){var g=this.getRawIndex(c+_),f=o[g];f<d&&(d=f,h=c+_),f>p&&(p=f,v=c+_)}var w=this.getRawIndex(h),x=this.getRawIndex(v);h<v?(l[u++]=w,l[u++]=x):(l[u++]=x,l[u++]=w)}return n._count=u,n._indices=l,n._updateGetRawIdx(),n},r.prototype.downSample=function(e,t,n,a){for(var i=this.clone([e],!0),o=i._chunks,s=[],l=Math.floor(1/t),u=o[e],c=this.count(),h=i._rawExtent[e]=xl(),d=new(wl(this._rawCount))(Math.ceil(c/l)),v=0,p=0;p<c;p+=l){l>c-p&&(l=c-p,s.length=l);for(var y=0;y<l;y++){var _=this.getRawIndex(p+y);s[y]=u[_]}var g=n(s),f=this.getRawIndex(Math.min(p+a(s,g)||0,c-1));u[f]=g,g<h[0]&&(h[0]=g),g>h[1]&&(h[1]=g),d[v++]=f}return i._count=v,i._indices=d,i._updateGetRawIdx(),i},r.prototype.each=function(e,t){if(this._count)for(var n=e.length,a=this._chunks,i=0,o=this.count();i<o;i++){var s=this.getRawIndex(i);switch(n){case 0:t(i);break;case 1:t(a[e[0]][s],i);break;case 2:t(a[e[0]][s],a[e[1]][s],i);break;default:for(var l=0,u=[];l<n;l++)u[l]=a[e[l]][s];u[l]=i,t.apply(null,u)}}},r.prototype.getDataExtent=function(e){var t=this._chunks[e],n=xl();if(!t)return n;var a=this.count(),i=!this._indices,o;if(i)return this._rawExtent[e].slice();if(o=this._extent[e],o)return o.slice();o=n;for(var s=o[0],l=o[1],u=0;u<a;u++){var c=this.getRawIndex(u),h=t[c];h<s&&(s=h),h>l&&(l=h)}return o=[s,l],this._extent[e]=o,o},r.prototype.getRawDataItem=function(e){var t=this.getRawIndex(e);if(this._provider.persistent)return this._provider.getItem(t);for(var n=[],a=this._chunks,i=0;i<a.length;i++)n.push(a[i][t]);return n},r.prototype.clone=function(e,t){var n=new r,a=this._chunks,i=e&&Za(e,function(s,l){return s[l]=!0,s},{});if(i)for(var o=0;o<a.length;o++)n._chunks[o]=i[o]?m7(a[o]):a[o];else n._chunks=a;return this._copyCommonProps(n),t||(n._indices=this._cloneIndices()),n._updateGetRawIdx(),n},r.prototype._copyCommonProps=function(e){e._count=this._count,e._rawCount=this._rawCount,e._provider=this._provider,e._dimensions=this._dimensions,e._extent=Gt(this._extent),e._rawExtent=Gt(this._rawExtent)},r.prototype._cloneIndices=function(){if(this._indices){var e=this._indices.constructor,t=void 0;if(e===Array){var n=this._indices.length;t=new e(n);for(var a=0;a<n;a++)t[a]=this._indices[a]}else t=new e(this._indices);return t}return null},r.prototype._getRawIdxIdentity=function(e){return e},r.prototype._getRawIdx=function(e){return e<this._count&&e>=0?this._indices[e]:-1},r.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},r.internalField=function(){function e(t,n,a,i){return go(t[i],this._dimensions[i])}nm={arrayRows:e,objectRows:function(t,n,a,i){return go(t[n],this._dimensions[i])},keyedColumns:e,original:function(t,n,a,i){var o=t&&(t.value==null?t:t.value);return go(o instanceof Array?o[i]:o,this._dimensions[i])},typedArray:function(t,n,a,i){return t[i]}}}(),r}(),qk=function(){function r(e){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=e}return r.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},r.prototype._setLocalSource=function(e,t){this._sourceList=e,this._upstreamSignList=t,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},r.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},r.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},r.prototype._createSource=function(){this._setLocalSource([],[]);var e=this._sourceHost,t=this._getUpstreamSourceManagers(),n=!!t.length,a,i;if(sv(e)){var o=e,s=void 0,l=void 0,u=void 0;if(n){var c=t[0];c.prepareSource(),u=c.getSource(),s=u.data,l=u.sourceFormat,i=[c._getVersionSign()]}else s=o.get("data",!0),l=pn(s)?po:ra,i=[];var h=this._getSourceMetaRawOption()||{},d=u&&u.metaRawOption||{},v=Zt(h.seriesLayoutBy,d.seriesLayoutBy)||null,p=Zt(h.sourceHeader,d.sourceHeader),y=Zt(h.dimensions,d.dimensions),_=v!==d.seriesLayoutBy||!!p!=!!d.sourceHeader||y;a=_?[M_(s,{seriesLayoutBy:v,sourceHeader:p,dimensions:y},l)]:[]}else{var g=e;if(n){var f=this._applyTransform(t);a=f.sourceList,i=f.upstreamSignList}else{var w=g.get("source",!0);a=[M_(w,this._getSourceMetaRawOption(),null)],i=[]}}this._setLocalSource(a,i)},r.prototype._applyTransform=function(e){var t=this._sourceHost,n=t.get("transform",!0),a=t.get("fromTransformResult",!0);if(a!=null){var i="";e.length!==1&&lT(i)}var o,s=[],l=[];return B(e,function(u){u.prepareSource();var c=u.getSource(a||0),h="";a!=null&&!c&&lT(h),s.push(c),l.push(u._getVersionSign())}),n?o=d7(n,s,{datasetIndex:t.componentIndex}):a!=null&&(o=[jU(s[0])]),{sourceList:o,upstreamSignList:l}},r.prototype._isDirty=function(){if(this._dirty)return!0;for(var e=this._getUpstreamSourceManagers(),t=0;t<e.length;t++){var n=e[t];if(n._isDirty()||this._upstreamSignList[t]!==n._getVersionSign())return!0}},r.prototype.getSource=function(e){e=e||0;var t=this._sourceList[e];if(!t){var n=this._getUpstreamSourceManagers();return n[0]&&n[0].getSource(e)}return t},r.prototype.getSharedDataStore=function(e){var t=e.makeStoreSchema();return this._innerGetDataStore(t.dimensions,e.source,t.hash)},r.prototype._innerGetDataStore=function(e,t,n){var a=0,i=this._storeList,o=i[a];o||(o=i[a]={});var s=o[n];if(!s){var l=this._getUpstreamSourceManagers()[0];sv(this._sourceHost)&&l?s=l._innerGetDataStore(e,t,n):(s=new D_,s.initData(new Vk(t,e.length),e)),o[n]=s}return s},r.prototype._getUpstreamSourceManagers=function(){var e=this._sourceHost;if(sv(e)){var t=gw(e);return t?[t.getSourceManager()]:[]}else return ft(AU(e),function(n){return n.getSourceManager()})},r.prototype._getSourceMetaRawOption=function(){var e=this._sourceHost,t,n,a;if(sv(e))t=e.get("seriesLayoutBy",!0),n=e.get("sourceHeader",!0),a=e.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var i=e;t=i.get("seriesLayoutBy",!0),n=i.get("sourceHeader",!0),a=i.get("dimensions",!0)}return{seriesLayoutBy:t,sourceHeader:n,dimensions:a}},r}();function sT(r){var e=r.option.transform;e&&vd(r.option.transform)}function sv(r){return r.mainType==="series"}function lT(r){throw new Error(r)}var _7="line-height:1";function Kk(r){var e=r.lineHeight;return e==null?_7:"line-height:"+qr(e+"")+"px"}function Qk(r,e){var t=r.color||"#6e7079",n=r.fontSize||12,a=r.fontWeight||"400",i=r.color||"#464646",o=r.fontSize||14,s=r.fontWeight||"900";return e==="html"?{nameStyle:"font-size:"+qr(n+"")+"px;color:"+qr(t)+";font-weight:"+qr(a+""),valueStyle:"font-size:"+qr(o+"")+"px;color:"+qr(i)+";font-weight:"+qr(s+"")}:{nameStyle:{fontSize:n,fill:t,fontWeight:a},valueStyle:{fontSize:o,fill:i,fontWeight:s}}}var w7=[0,10,20,30],x7=["",`
`,`

`,`


`];function wr(r,e){return e.type=r,e}function I_(r){return r.type==="section"}function Jk(r){return I_(r)?b7:S7}function tR(r){if(I_(r)){var e=0,t=r.blocks.length,n=t>1||t>0&&!r.noHeader;return B(r.blocks,function(a){var i=tR(a);i>=e&&(e=i+ +(n&&(!i||I_(a)&&!a.noHeader)))}),e}return 0}function b7(r,e,t,n){var a=e.noHeader,i=A7(tR(e)),o=[],s=e.blocks||[];Jr(!s||ht(s)),s=s||[];var l=r.orderMode;if(e.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(It(u,l)){var c=new Yk(u[l],null);s.sort(function(y,_){return c.evaluate(y.sortParam,_.sortParam)})}else l==="seriesDesc"&&s.reverse()}B(s,function(y,_){var g=e.valueFormatter,f=Jk(y)(g?lt(lt({},r),{valueFormatter:g}):r,y,_>0?i.html:0,n);f!=null&&o.push(f)});var h=r.renderMode==="richText"?o.join(i.richText):P_(n,o.join(""),a?t:i.html);if(a)return h;var d=T_(e.header,"ordinal",r.useUTC),v=Qk(n,r.renderMode).nameStyle,p=Kk(n);return r.renderMode==="richText"?eR(r,d,v)+i.richText+h:P_(n,'<div style="'+v+";"+p+';">'+qr(d)+"</div>"+h,t)}function S7(r,e,t,n){var a=r.renderMode,i=e.noName,o=e.noValue,s=!e.markerType,l=e.name,u=r.useUTC,c=e.valueFormatter||r.valueFormatter||function(x){return x=ht(x)?x:[x],ft(x,function(S,A){return T_(S,ht(v)?v[A]:v,u)})};if(!(i&&o)){var h=s?"":r.markupStyleCreator.makeTooltipMarker(e.markerType,e.markerColor||"#333",a),d=i?"":T_(l,"ordinal",u),v=e.valueType,p=o?[]:c(e.value,e.dataIndex),y=!s||!i,_=!s&&i,g=Qk(n,a),f=g.nameStyle,w=g.valueStyle;return a==="richText"?(s?"":h)+(i?"":eR(r,d,f))+(o?"":L7(r,p,y,_,w)):P_(n,(s?"":h)+(i?"":T7(d,!s,f))+(o?"":C7(p,y,_,w)),t)}}function uT(r,e,t,n,a,i){if(r){var o=Jk(r),s={useUTC:a,renderMode:t,orderMode:n,markupStyleCreator:e,valueFormatter:r.valueFormatter};return o(s,r,0,i)}}function A7(r){return{html:w7[r],richText:x7[r]}}function P_(r,e,t){var n='<div style="clear:both"></div>',a="margin: "+t+"px 0 0",i=Kk(r);return'<div style="'+a+";"+i+';">'+e+n+"</div>"}function T7(r,e,t){var n=e?"margin-left:2px":"";return'<span style="'+t+";"+n+'">'+qr(r)+"</span>"}function C7(r,e,t,n){var a=t?"10px":"20px",i=e?"float:right;margin-left:"+a:"";return r=ht(r)?r:[r],'<span style="'+i+";"+n+'">'+ft(r,function(o){return qr(o)}).join("&nbsp;&nbsp;")+"</span>"}function eR(r,e,t){return r.markupStyleCreator.wrapRichTextStyle(e,t)}function L7(r,e,t,n,a){var i=[a],o=n?10:20;return t&&i.push({padding:[0,0,0,o],align:"right"}),r.markupStyleCreator.wrapRichTextStyle(ht(e)?e.join("  "):e,i)}function rR(r,e){var t=r.getData().getItemVisual(e,"style"),n=t[r.visualDrawType];return Fs(n)}function nR(r,e){var t=r.get("padding");return t??(e==="richText"?[8,10]:10)}var am=function(){function r(){this.richTextStyles={},this._nextStyleNameId=mP()}return r.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},r.prototype.makeTooltipMarker=function(e,t,n){var a=n==="richText"?this._generateStyleName():null,i=yU({color:t,type:e,renderMode:n,markerId:a});return Lt(i)?i:(this.richTextStyles[a]=i.style,i.content)},r.prototype.wrapRichTextStyle=function(e,t){var n={};ht(t)?B(t,function(i){return lt(n,i)}):lt(n,t);var a=this._generateStyleName();return this.richTextStyles[a]=n,"{"+a+"|"+e+"}"},r}();function aR(r){var e=r.series,t=r.dataIndex,n=r.multipleSeries,a=e.getData(),i=a.mapDimensionsAll("defaultedTooltip"),o=i.length,s=e.getRawValue(t),l=ht(s),u=rR(e,t),c,h,d,v;if(o>1||l&&!o){var p=M7(s,e,t,i,u);c=p.inlineValues,h=p.inlineValueTypes,d=p.blocks,v=p.inlineValues[0]}else if(o){var y=a.getDimensionInfo(i[0]);v=c=tu(a,t,i[0]),h=y.type}else v=c=l?s[0]:s;var _=$1(e),g=_&&e.name||"",f=a.getName(t),w=n?g:f;return wr("section",{header:g,noHeader:n||!_,sortParam:v,blocks:[wr("nameValue",{markerType:"item",markerColor:u,name:w,noName:!ga(w),value:c,valueType:h,dataIndex:t})].concat(d||[])})}function M7(r,e,t,n,a){var i=e.getData(),o=Za(r,function(h,d,v){var p=i.getDimensionInfo(v);return h=h||p&&p.tooltip!==!1&&p.displayName!=null},!1),s=[],l=[],u=[];n.length?B(n,function(h){c(tu(i,t,h),h)}):B(r,c);function c(h,d){var v=i.getDimensionInfo(d);!v||v.otherDims.tooltip===!1||(o?u.push(wr("nameValue",{markerType:"subItem",markerColor:a,name:v.displayName,value:h,valueType:v.type})):(s.push(h),l.push(v.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var Xi=ve();function lv(r,e){return r.getName(e)||r.getId(e)}var nd="__universalTransitionEnabled",Ve=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t._selectedDataIndicesMap={},t}return e.prototype.init=function(t,n,a){this.seriesIndex=this.componentIndex,this.dataTask=Gc({count:I7,reset:P7}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(t,a);var i=Xi(this).sourceManager=new qk(this);i.prepareSource();var o=this.getInitialData(t,a);hT(o,this),this.dataTask.context.data=o,Xi(this).dataBeforeProcessed=o,cT(this),this._initSelectedMapFromData(o)},e.prototype.mergeDefaultAndTheme=function(t,n){var a=ah(this),i=a?yu(t):{},o=this.subType;le.hasClass(o)&&(o+="Series"),qt(t,n.getTheme().get(this.subType)),qt(t,this.getDefaultOption()),Os(t,"label",["show"]),this.fillDataTextStyle(t.data),a&&bo(t,i,a)},e.prototype.mergeOption=function(t,n){t=qt(this.option,t,!0),this.fillDataTextStyle(t.data);var a=ah(this);a&&bo(this.option,t,a);var i=Xi(this).sourceManager;i.dirty(),i.prepareSource();var o=this.getInitialData(t,n);hT(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,Xi(this).dataBeforeProcessed=o,cT(this),this._initSelectedMapFromData(o)},e.prototype.fillDataTextStyle=function(t){if(t&&!pn(t))for(var n=["show"],a=0;a<t.length;a++)t[a]&&t[a].label&&Os(t[a],"label",n)},e.prototype.getInitialData=function(t,n){},e.prototype.appendData=function(t){var n=this.getRawData();n.appendData(t.data)},e.prototype.getData=function(t){var n=k_(this);if(n){var a=n.context.data;return t==null||!a.getLinkedData?a:a.getLinkedData(t)}else return Xi(this).data},e.prototype.getAllData=function(){var t=this.getData();return t&&t.getLinkedDataAll?t.getLinkedDataAll():[{data:t}]},e.prototype.setData=function(t){var n=k_(this);if(n){var a=n.context;a.outputData=t,n!==this.dataTask&&(a.data=t)}Xi(this).data=t},e.prototype.getEncode=function(){var t=this.get("encode",!0);if(t)return Pt(t)},e.prototype.getSourceManager=function(){return Xi(this).sourceManager},e.prototype.getSource=function(){return this.getSourceManager().getSource()},e.prototype.getRawData=function(){return Xi(this).dataBeforeProcessed},e.prototype.getColorBy=function(){var t=this.get("colorBy");return t||"series"},e.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},e.prototype.getBaseAxis=function(){var t=this.coordinateSystem;return t&&t.getBaseAxis&&t.getBaseAxis()},e.prototype.formatTooltip=function(t,n,a){return aR({series:this,dataIndex:t,multipleSeries:n})},e.prototype.isAnimationEnabled=function(){var t=this.ecModel;if(oe.node&&!(t&&t.ssr))return!1;var n=this.getShallow("animation");return n&&this.getData().count()>this.getShallow("animationThreshold")&&(n=!1),!!n},e.prototype.restoreData=function(){this.dataTask.dirty()},e.prototype.getColorFromPalette=function(t,n,a){var i=this.ecModel,o=yw.prototype.getColorFromPalette.call(this,t,n,a);return o||(o=i.getColorFromPalette(t,n,a)),o},e.prototype.coordDimToDataDim=function(t){return this.getRawData().mapDimensionsAll(t)},e.prototype.getProgressive=function(){return this.get("progressive")},e.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},e.prototype.select=function(t,n){this._innerSelect(this.getData(n),t)},e.prototype.unselect=function(t,n){var a=this.option.selectedMap;if(a){var i=this.option.selectedMode,o=this.getData(n);if(i==="series"||a==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<t.length;s++){var l=t[s],u=lv(o,l);a[u]=!1,this._selectedDataIndicesMap[u]=-1}}},e.prototype.toggleSelect=function(t,n){for(var a=[],i=0;i<t.length;i++)a[0]=t[i],this.isSelected(t[i],n)?this.unselect(a,n):this.select(a,n)},e.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var t=this._selectedDataIndicesMap,n=ue(t),a=[],i=0;i<n.length;i++){var o=t[n[i]];o>=0&&a.push(o)}return a},e.prototype.isSelected=function(t,n){var a=this.option.selectedMap;if(!a)return!1;var i=this.getData(n);return(a==="all"||a[lv(i,t)])&&!i.getItemModel(t).get(["select","disabled"])},e.prototype.isUniversalTransitionEnabled=function(){if(this[nd])return!0;var t=this.option.universalTransition;return t?t===!0?!0:t&&t.enabled:!1},e.prototype._innerSelect=function(t,n){var a,i,o=this.option,s=o.selectedMode,l=n.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){Vt(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,c=0;c<l;c++){var h=n[c],d=lv(t,h);u[d]=!0,this._selectedDataIndicesMap[d]=t.getRawIndex(h)}}else if(s==="single"||s===!0){var v=n[l-1],d=lv(t,v);o.selectedMap=(a={},a[d]=!0,a),this._selectedDataIndicesMap=(i={},i[d]=t.getRawIndex(v),i)}}},e.prototype._initSelectedMapFromData=function(t){if(!this.option.selectedMap){var n=[];t.hasItemOption&&t.each(function(a){var i=t.getRawDataItem(a);i&&i.selected&&n.push(a)}),n.length>0&&this._innerSelect(t,n)}},e.registerClass=function(t){return le.registerClass(t)},e.protoInitialize=function(){var t=e.prototype;t.type="series.__base__",t.seriesIndex=0,t.ignoreStyleOnData=!1,t.hasSymbolVisual=!1,t.defaultSymbol="circle",t.visualStyleAccessPath="itemStyle",t.visualDrawType="fill"}(),e}(le);sr(Ve,Op);sr(Ve,yw);LP(Ve,le);function cT(r){var e=r.name;$1(r)||(r.name=D7(r)||e)}function D7(r){var e=r.getRawData(),t=e.mapDimensionsAll("seriesName"),n=[];return B(t,function(a){var i=e.getDimensionInfo(a);i.displayName&&n.push(i.displayName)}),n.join(" ")}function I7(r){return r.model.getRawData().count()}function P7(r){var e=r.model;return e.setData(e.getRawData().cloneShallow()),k7}function k7(r,e){e.outputData&&r.end>e.outputData.count()&&e.model.getRawData().cloneShallow(e.outputData)}function hT(r,e){B($c(r.CHANGABLE_METHODS,r.DOWNSAMPLE_METHODS),function(t){r.wrapMethod(t,Xt(R7,e))})}function R7(r,e){var t=k_(r);return t&&t.setOutputEnd((e||this).count()),e}function k_(r){var e=(r.ecModel||{}).scheduler,t=e&&e.getPipeline(r.uid);if(t){var n=t.currentTask;if(n){var a=n.agentStubMap;a&&(n=a.get(r.uid))}return n}}var Ze=function(){function r(){this.group=new Wt,this.uid=pu("viewComponent")}return r.prototype.init=function(e,t){},r.prototype.render=function(e,t,n,a){},r.prototype.dispose=function(e,t){},r.prototype.updateView=function(e,t,n,a){},r.prototype.updateLayout=function(e,t,n,a){},r.prototype.updateVisual=function(e,t,n,a){},r.prototype.toggleBlurSeries=function(e,t,n){},r.prototype.eachRendered=function(e){var t=this.group;t&&t.traverse(e)},r}();q1(Ze);yp(Ze);function _u(){var r=ve();return function(e){var t=r(e),n=e.pipelineContext,a=!!t.large,i=!!t.progressiveRender,o=t.large=!!(n&&n.large),s=t.progressiveRender=!!(n&&n.progressiveRender);return(a!==o||i!==s)&&"reset"}}var iR=ve(),E7=_u(),Re=function(){function r(){this.group=new Wt,this.uid=pu("viewChart"),this.renderTask=Gc({plan:O7,reset:B7}),this.renderTask.context={view:this}}return r.prototype.init=function(e,t){},r.prototype.render=function(e,t,n,a){},r.prototype.highlight=function(e,t,n,a){var i=e.getData(a&&a.dataType);i&&vT(i,a,"emphasis")},r.prototype.downplay=function(e,t,n,a){var i=e.getData(a&&a.dataType);i&&vT(i,a,"normal")},r.prototype.remove=function(e,t){this.group.removeAll()},r.prototype.dispose=function(e,t){},r.prototype.updateView=function(e,t,n,a){this.render(e,t,n,a)},r.prototype.updateLayout=function(e,t,n,a){this.render(e,t,n,a)},r.prototype.updateVisual=function(e,t,n,a){this.render(e,t,n,a)},r.prototype.eachRendered=function(e){Co(this.group,e)},r.markUpdateMethod=function(e,t){iR(e).updateMethod=t},r.protoInitialize=function(){var e=r.prototype;e.type="chart"}(),r}();function fT(r,e,t){r&&eh(r)&&(e==="emphasis"?Ti:Ci)(r,t)}function vT(r,e,t){var n=Bs(r,e),a=e&&e.highlightKey!=null?yH(e.highlightKey):null;n!=null?B(Ie(n),function(i){fT(r.getItemGraphicEl(i),t,a)}):r.eachItemGraphicEl(function(i){fT(i,t,a)})}q1(Re);yp(Re);function O7(r){return E7(r.model)}function B7(r){var e=r.model,t=r.ecModel,n=r.api,a=r.payload,i=e.pipelineContext.progressiveRender,o=r.view,s=a&&iR(a).updateMethod,l=i?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](e,t,n,a),N7[l]}var N7={incrementalPrepareRender:{progress:function(r,e){e.view.incrementalRender(r,e.model,e.ecModel,e.api,e.payload)}},render:{forceFirstProgress:!0,progress:function(r,e){e.view.render(e.model,e.ecModel,e.api,e.payload)}}},Id="\0__throttleOriginMethod",dT="\0__throttleRate",pT="\0__throttleType";function Sw(r,e,t){var n,a=0,i=0,o=null,s,l,u,c;e=e||0;function h(){i=new Date().getTime(),o=null,r.apply(l,u||[])}var d=function(){for(var v=[],p=0;p<arguments.length;p++)v[p]=arguments[p];n=new Date().getTime(),l=this,u=v;var y=c||e,_=c||t;c=null,s=n-(_?a:i)-y,clearTimeout(o),_?o=setTimeout(h,y):s>=0?h():o=setTimeout(h,-s),a=n};return d.clear=function(){o&&(clearTimeout(o),o=null)},d.debounceNextCall=function(v){c=v},d}function wu(r,e,t,n){var a=r[e];if(a){var i=a[Id]||a,o=a[pT],s=a[dT];if(s!==t||o!==n){if(t==null||!n)return r[e]=i;a=r[e]=Sw(i,t,n==="debounce"),a[Id]=i,a[pT]=n,a[dT]=t}return a}}function oh(r,e){var t=r[e];t&&t[Id]&&(t.clear&&t.clear(),r[e]=t[Id])}var gT=ve(),yT={itemStyle:Ns(hk,!0),lineStyle:Ns(ck,!0)},z7={lineStyle:"stroke",itemStyle:"fill"};function oR(r,e){var t=r.visualStyleMapper||yT[e];return t||(console.warn("Unknown style type '"+e+"'."),yT.itemStyle)}function sR(r,e){var t=r.visualDrawType||z7[e];return t||(console.warn("Unknown style type '"+e+"'."),"fill")}var F7={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){var t=r.getData(),n=r.visualStyleAccessPath||"itemStyle",a=r.getModel(n),i=oR(r,n),o=i(a),s=a.getShallow("decal");s&&(t.setVisual("decal",s),s.dirty=!0);var l=sR(r,n),u=o[l],c=Nt(u)?u:null,h=o.fill==="auto"||o.stroke==="auto";if(!o[l]||c||h){var d=r.getColorFromPalette(r.name,null,e.getSeriesCount());o[l]||(o[l]=d,t.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||Nt(o.fill)?d:o.fill,o.stroke=o.stroke==="auto"||Nt(o.stroke)?d:o.stroke}if(t.setVisual("style",o),t.setVisual("drawType",l),!e.isSeriesFiltered(r)&&c)return t.setVisual("colorFromPalette",!1),{dataEach:function(v,p){var y=r.getDataParams(p),_=lt({},o);_[l]=c(y),v.setItemVisual(p,"style",_)}}}},qu=new De,V7={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){if(!(r.ignoreStyleOnData||e.isSeriesFiltered(r))){var t=r.getData(),n=r.visualStyleAccessPath||"itemStyle",a=oR(r,n),i=t.getVisual("drawType");return{dataEach:t.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[n]){qu.option=l[n];var u=a(qu),c=o.ensureUniqueItemVisual(s,"style");lt(c,u),qu.option.decal&&(o.setItemVisual(s,"decal",qu.option.decal),qu.option.decal.dirty=!0),i in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},G7={performRawSeries:!0,overallReset:function(r){var e=Pt();r.eachSeries(function(t){var n=t.getColorBy();if(!t.isColorBySeries()){var a=t.type+"-"+n,i=e.get(a);i||(i={},e.set(a,i)),gT(t).scope=i}}),r.eachSeries(function(t){if(!(t.isColorBySeries()||r.isSeriesFiltered(t))){var n=t.getRawData(),a={},i=t.getData(),o=gT(t).scope,s=t.visualStyleAccessPath||"itemStyle",l=sR(t,s);i.each(function(u){var c=i.getRawIndex(u);a[c]=u}),n.each(function(u){var c=a[u],h=i.getItemVisual(c,"colorFromPalette");if(h){var d=i.ensureUniqueItemVisual(c,"style"),v=n.getName(u)||u+"",p=n.count();d[l]=t.getColorFromPalette(v,o,p)}})}})}},uv=Math.PI;function W7(r,e){e=e||{},zt(e,{text:"loading",textColor:"#000",fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255, 255, 255, 0.8)",showSpinner:!0,color:"#5470c6",spinnerRadius:10,lineWidth:5,zlevel:0});var t=new Wt,n=new fe({style:{fill:e.maskColor},zlevel:e.zlevel,z:1e4});t.add(n);var a=new pe({style:{text:e.text,fill:e.textColor,fontSize:e.fontSize,fontWeight:e.fontWeight,fontStyle:e.fontStyle,fontFamily:e.fontFamily},zlevel:e.zlevel,z:10001}),i=new fe({style:{fill:"none"},textContent:a,textConfig:{position:"right",distance:10},zlevel:e.zlevel,z:10001});t.add(i);var o;return e.showSpinner&&(o=new Ap({shape:{startAngle:-uv/2,endAngle:-uv/2+.1,r:e.spinnerRadius},style:{stroke:e.color,lineCap:"round",lineWidth:e.lineWidth},zlevel:e.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:uv*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:uv*3/2}).delay(300).start("circularInOut"),t.add(o)),t.resize=function(){var s=a.getBoundingRect().width,l=e.showSpinner?e.spinnerRadius:0,u=(r.getWidth()-l*2-(e.showSpinner&&s?10:0)-s)/2-(e.showSpinner&&s?0:5+s/2)+(e.showSpinner?0:s/2)+(s?0:l),c=r.getHeight()/2;e.showSpinner&&o.setShape({cx:u,cy:c}),i.setShape({x:u-l,y:c-l,width:l*2,height:l*2}),n.setShape({x:0,y:0,width:r.getWidth(),height:r.getHeight()})},t.resize(),t}var lR=function(){function r(e,t,n,a){this._stageTaskMap=Pt(),this.ecInstance=e,this.api=t,n=this._dataProcessorHandlers=n.slice(),a=this._visualHandlers=a.slice(),this._allHandlers=n.concat(a)}return r.prototype.restoreData=function(e,t){e.restoreData(t),this._stageTaskMap.each(function(n){var a=n.overallTask;a&&a.dirty()})},r.prototype.getPerformArgs=function(e,t){if(e.__pipeline){var n=this._pipelineMap.get(e.__pipeline.id),a=n.context,i=!t&&n.progressiveEnabled&&(!a||a.progressiveRender)&&e.__idxInPipeline>n.blockIndex,o=i?n.step:null,s=a&&a.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},r.prototype.getPipeline=function(e){return this._pipelineMap.get(e)},r.prototype.updateStreamModes=function(e,t){var n=this._pipelineMap.get(e.uid),a=e.getData(),i=a.count(),o=n.progressiveEnabled&&t.incrementalPrepareRender&&i>=n.threshold,s=e.get("large")&&i>=e.get("largeThreshold"),l=e.get("progressiveChunkMode")==="mod"?i:null;e.pipelineContext=n.context={progressiveRender:o,modDataCount:l,large:s}},r.prototype.restorePipelines=function(e){var t=this,n=t._pipelineMap=Pt();e.eachSeries(function(a){var i=a.getProgressive(),o=a.uid;n.set(o,{id:o,head:null,tail:null,threshold:a.getProgressiveThreshold(),progressiveEnabled:i&&!(a.preventIncremental&&a.preventIncremental()),blockIndex:-1,step:Math.round(i||700),count:0}),t._pipe(a,a.dataTask)})},r.prototype.prepareStageTasks=function(){var e=this._stageTaskMap,t=this.api.getModel(),n=this.api;B(this._allHandlers,function(a){var i=e.get(a.uid)||e.set(a.uid,{}),o="";Jr(!(a.reset&&a.overallReset),o),a.reset&&this._createSeriesStageTask(a,i,t,n),a.overallReset&&this._createOverallStageTask(a,i,t,n)},this)},r.prototype.prepareView=function(e,t,n,a){var i=e.renderTask,o=i.context;o.model=t,o.ecModel=n,o.api=a,i.__block=!e.incrementalPrepareRender,this._pipe(t,i)},r.prototype.performDataProcessorTasks=function(e,t){this._performStageTasks(this._dataProcessorHandlers,e,t,{block:!0})},r.prototype.performVisualTasks=function(e,t,n){this._performStageTasks(this._visualHandlers,e,t,n)},r.prototype._performStageTasks=function(e,t,n,a){a=a||{};var i=!1,o=this;B(e,function(l,u){if(!(a.visualType&&a.visualType!==l.visualType)){var c=o._stageTaskMap.get(l.uid),h=c.seriesTaskMap,d=c.overallTask;if(d){var v,p=d.agentStubMap;p.each(function(_){s(a,_)&&(_.dirty(),v=!0)}),v&&d.dirty(),o.updatePayload(d,n);var y=o.getPerformArgs(d,a.block);p.each(function(_){_.perform(y)}),d.perform(y)&&(i=!0)}else h&&h.each(function(_,g){s(a,_)&&_.dirty();var f=o.getPerformArgs(_,a.block);f.skip=!l.performRawSeries&&t.isSeriesFiltered(_.context.model),o.updatePayload(_,n),_.perform(f)&&(i=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=i||this.unfinished},r.prototype.performSeriesTasks=function(e){var t;e.eachSeries(function(n){t=n.dataTask.perform()||t}),this.unfinished=t||this.unfinished},r.prototype.plan=function(){this._pipelineMap.each(function(e){var t=e.tail;do{if(t.__block){e.blockIndex=t.__idxInPipeline;break}t=t.getUpstream()}while(t)})},r.prototype.updatePayload=function(e,t){t!=="remain"&&(e.context.payload=t)},r.prototype._createSeriesStageTask=function(e,t,n,a){var i=this,o=t.seriesTaskMap,s=t.seriesTaskMap=Pt(),l=e.seriesType,u=e.getTargetSeries;e.createOnAllSeries?n.eachRawSeries(c):l?n.eachRawSeriesByType(l,c):u&&u(n,a).each(c);function c(h){var d=h.uid,v=s.set(d,o&&o.get(d)||Gc({plan:X7,reset:$7,count:q7}));v.context={model:h,ecModel:n,api:a,useClearVisual:e.isVisual&&!e.isLayout,plan:e.plan,reset:e.reset,scheduler:i},i._pipe(h,v)}},r.prototype._createOverallStageTask=function(e,t,n,a){var i=this,o=t.overallTask=t.overallTask||Gc({reset:H7});o.context={ecModel:n,api:a,overallReset:e.overallReset,scheduler:i};var s=o.agentStubMap,l=o.agentStubMap=Pt(),u=e.seriesType,c=e.getTargetSeries,h=!0,d=!1,v="";Jr(!e.createOnAllSeries,v),u?n.eachRawSeriesByType(u,p):c?c(n,a).each(p):(h=!1,B(n.getSeries(),p));function p(y){var _=y.uid,g=l.set(_,s&&s.get(_)||(d=!0,Gc({reset:U7,onDirty:Y7})));g.context={model:y,overallProgress:h},g.agent=o,g.__block=h,i._pipe(y,g)}d&&o.dirty()},r.prototype._pipe=function(e,t){var n=e.uid,a=this._pipelineMap.get(n);!a.head&&(a.head=t),a.tail&&a.tail.pipe(t),a.tail=t,t.__idxInPipeline=a.count++,t.__pipeline=a},r.wrapStageHandler=function(e,t){return Nt(e)&&(e={overallReset:e,seriesType:K7(e)}),e.uid=pu("stageHandler"),t&&(e.visualType=t),e},r}();function H7(r){r.overallReset(r.ecModel,r.api,r.payload)}function U7(r){return r.overallProgress&&Z7}function Z7(){this.agent.dirty(),this.getDownstream().dirty()}function Y7(){this.agent&&this.agent.dirty()}function X7(r){return r.plan?r.plan(r.model,r.ecModel,r.api,r.payload):null}function $7(r){r.useClearVisual&&r.data.clearAllVisual();var e=r.resetDefines=Ie(r.reset(r.model,r.ecModel,r.api,r.payload));return e.length>1?ft(e,function(t,n){return uR(n)}):j7}var j7=uR(0);function uR(r){return function(e,t){var n=t.data,a=t.resetDefines[r];if(a&&a.dataEach)for(var i=e.start;i<e.end;i++)a.dataEach(n,i);else a&&a.progress&&a.progress(e,n)}}function q7(r){return r.data.count()}function K7(r){Pd=null;try{r(sh,cR)}catch{}return Pd}var sh={},cR={},Pd;hR(sh,mw);hR(cR,Ok);sh.eachSeriesByType=sh.eachRawSeriesByType=function(r){Pd=r};sh.eachComponent=function(r){r.mainType==="series"&&r.subType&&(Pd=r.subType)};function hR(r,e){for(var t in e.prototype)r[t]=tr}var mT=["#37A2DA","#32C5E9","#67E0E3","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#E062AE","#E690D1","#e7bcf3","#9d96f5","#8378EA","#96BFFF"];const Q7={color:mT,colorLayer:[["#37A2DA","#ffd85c","#fd7b5f"],["#37A2DA","#67E0E3","#FFDB5C","#ff9f7f","#E062AE","#9d96f5"],["#37A2DA","#32C5E9","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#e7bcf3","#8378EA","#96BFFF"],mT]};var Fr="#B9B8CE",_T="#100C2A",cv=function(){return{axisLine:{lineStyle:{color:Fr}},splitLine:{lineStyle:{color:"#484753"}},splitArea:{areaStyle:{color:["rgba(255,255,255,0.02)","rgba(255,255,255,0.05)"]}},minorSplitLine:{lineStyle:{color:"#20203B"}}}},wT=["#4992ff","#7cffb2","#fddd60","#ff6e76","#58d9f9","#05c091","#ff8a45","#8d48e3","#dd79ff"],fR={darkMode:!0,color:wT,backgroundColor:_T,axisPointer:{lineStyle:{color:"#817f91"},crossStyle:{color:"#817f91"},label:{color:"#fff"}},legend:{textStyle:{color:Fr},pageTextStyle:{color:Fr}},textStyle:{color:Fr},title:{textStyle:{color:"#EEF1FA"},subtextStyle:{color:"#B9B8CE"}},toolbox:{iconStyle:{borderColor:Fr}},dataZoom:{borderColor:"#71708A",textStyle:{color:Fr},brushStyle:{color:"rgba(135,163,206,0.3)"},handleStyle:{color:"#353450",borderColor:"#C5CBE3"},moveHandleStyle:{color:"#B0B6C3",opacity:.3},fillerColor:"rgba(135,163,206,0.2)",emphasis:{handleStyle:{borderColor:"#91B7F2",color:"#4D587D"},moveHandleStyle:{color:"#636D9A",opacity:.7}},dataBackground:{lineStyle:{color:"#71708A",width:1},areaStyle:{color:"#71708A"}},selectedDataBackground:{lineStyle:{color:"#87A3CE"},areaStyle:{color:"#87A3CE"}}},visualMap:{textStyle:{color:Fr}},timeline:{lineStyle:{color:Fr},label:{color:Fr},controlStyle:{color:Fr,borderColor:Fr}},calendar:{itemStyle:{color:_T},dayLabel:{color:Fr},monthLabel:{color:Fr},yearLabel:{color:Fr}},timeAxis:cv(),logAxis:cv(),valueAxis:cv(),categoryAxis:cv(),line:{symbol:"circle"},graph:{color:wT},gauge:{title:{color:Fr},axisLine:{lineStyle:{color:[[1,"rgba(207,212,219,0.2)"]]}},axisLabel:{color:Fr},detail:{color:"#EEF1FA"}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}}};fR.categoryAxis.splitLine.show=!1;var J7=function(){function r(){}return r.prototype.normalizeQuery=function(e){var t={},n={},a={};if(Lt(e)){var i=Va(e);t.mainType=i.main||null,t.subType=i.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};B(e,function(l,u){for(var c=!1,h=0;h<o.length;h++){var d=o[h],v=u.lastIndexOf(d);if(v>0&&v===u.length-d.length){var p=u.slice(0,v);p!=="data"&&(t.mainType=p,t[d.toLowerCase()]=l,c=!0)}}s.hasOwnProperty(u)&&(n[u]=l,c=!0),c||(a[u]=l)})}return{cptQuery:t,dataQuery:n,otherQuery:a}},r.prototype.filter=function(e,t){var n=this.eventInfo;if(!n)return!0;var a=n.targetEl,i=n.packedEvent,o=n.model,s=n.view;if(!o||!s)return!0;var l=t.cptQuery,u=t.dataQuery;return c(l,o,"mainType")&&c(l,o,"subType")&&c(l,o,"index","componentIndex")&&c(l,o,"name")&&c(l,o,"id")&&c(u,i,"name")&&c(u,i,"dataIndex")&&c(u,i,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(e,t.otherQuery,a,i));function c(h,d,v,p){return h[v]==null||d[p||v]===h[v]}},r.prototype.afterTrigger=function(){this.eventInfo=null},r}(),R_=["symbol","symbolSize","symbolRotate","symbolOffset"],xT=R_.concat(["symbolKeepAspect"]),t9={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){var t=r.getData();if(r.legendIcon&&t.setVisual("legendIcon",r.legendIcon),!r.hasSymbolVisual)return;for(var n={},a={},i=!1,o=0;o<R_.length;o++){var s=R_[o],l=r.get(s);Nt(l)?(i=!0,a[s]=l):n[s]=l}if(n.symbol=n.symbol||r.defaultSymbol,t.setVisual(lt({legendIcon:r.legendIcon||n.symbol,symbolKeepAspect:r.get("symbolKeepAspect")},n)),e.isSeriesFiltered(r))return;var u=ue(a);function c(h,d){for(var v=r.getRawValue(d),p=r.getDataParams(d),y=0;y<u.length;y++){var _=u[y];h.setItemVisual(d,_,a[_](v,p))}}return{dataEach:i?c:null}}},e9={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,e){if(!r.hasSymbolVisual||e.isSeriesFiltered(r))return;var t=r.getData();function n(a,i){for(var o=a.getItemModel(i),s=0;s<xT.length;s++){var l=xT[s],u=o.getShallow(l,!0);u!=null&&a.setItemVisual(i,l,u)}}return{dataEach:t.hasItemOption?n:null}}};function Aw(r,e,t){switch(t){case"color":var n=r.getItemVisual(e,"style");return n[r.getVisual("drawType")];case"opacity":return r.getItemVisual(e,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getItemVisual(e,t)}}function Eh(r,e){switch(e){case"color":var t=r.getVisual("style");return t[r.getVisual("drawType")];case"opacity":return r.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getVisual(e)}}function vR(r,e,t,n){switch(t){case"color":var a=r.ensureUniqueItemVisual(e,"style");a[r.getVisual("drawType")]=n,r.setItemVisual(e,"colorFromPalette",!1);break;case"opacity":r.ensureUniqueItemVisual(e,"style").opacity=n;break;case"symbol":case"symbolSize":case"liftZ":r.setItemVisual(e,t,n);break}}function dR(r,e){function t(n,a){var i=[];return n.eachComponent({mainType:"series",subType:r,query:a},function(o){i.push(o.seriesIndex)}),i}B([[r+"ToggleSelect","toggleSelect"],[r+"Select","select"],[r+"UnSelect","unselect"]],function(n){e(n[0],function(a,i,o){a=lt({},a),o.dispatchAction(lt(a,{type:n[1],seriesIndex:t(i,a)}))})})}function bl(r,e,t,n,a){var i=r+e;t.isSilent(i)||n.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=a.selected,c=0;c<u.length;c++)if(u[c].seriesIndex===s){var h=o.getData(),d=Bs(h,a.fromActionPayload);t.trigger(i,{type:i,seriesId:o.id,name:ht(d)?h.getName(d[0]):h.getName(d),selected:Lt(l)?l:lt({},l)})}})}function r9(r,e,t){r.on("selectchanged",function(n){var a=t.getModel();n.isFromClick?(bl("map","selectchanged",e,a,n),bl("pie","selectchanged",e,a,n)):n.fromAction==="select"?(bl("map","selected",e,a,n),bl("pie","selected",e,a,n)):n.fromAction==="unselect"&&(bl("map","unselected",e,a,n),bl("pie","unselected",e,a,n))})}function bs(r,e,t){for(var n;r&&!(e(r)&&(n=r,t));)r=r.__hostTarget||r.parent;return n}var n9=Math.round(Math.random()*9),a9=typeof Object.defineProperty=="function",i9=function(){function r(){this._id="__ec_inner_"+n9++}return r.prototype.get=function(e){return this._guard(e)[this._id]},r.prototype.set=function(e,t){var n=this._guard(e);return a9?Object.defineProperty(n,this._id,{value:t,enumerable:!1,configurable:!0}):n[this._id]=t,this},r.prototype.delete=function(e){return this.has(e)?(delete this._guard(e)[this._id],!0):!1},r.prototype.has=function(e){return!!this._guard(e)[this._id]},r.prototype._guard=function(e){if(e!==Object(e))throw TypeError("Value of WeakMap is not a non-null object.");return e},r}(),o9=ie.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,e){var t=e.cx,n=e.cy,a=e.width/2,i=e.height/2;r.moveTo(t,n-i),r.lineTo(t+a,n+i),r.lineTo(t-a,n+i),r.closePath()}}),s9=ie.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,e){var t=e.cx,n=e.cy,a=e.width/2,i=e.height/2;r.moveTo(t,n-i),r.lineTo(t+a,n),r.lineTo(t,n+i),r.lineTo(t-a,n),r.closePath()}}),l9=ie.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,e){var t=e.x,n=e.y,a=e.width/5*3,i=Math.max(a,e.height),o=a/2,s=o*o/(i-o),l=n-i+o+s,u=Math.asin(s/o),c=Math.cos(u)*o,h=Math.sin(u),d=Math.cos(u),v=o*.6,p=o*.7;r.moveTo(t-c,l+s),r.arc(t,l,o,Math.PI-u,Math.PI*2+u),r.bezierCurveTo(t+c-h*v,l+s+d*v,t,n-p,t,n),r.bezierCurveTo(t,n-p,t-c+h*v,l+s+d*v,t-c,l+s),r.closePath()}}),u9=ie.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,e){var t=e.height,n=e.width,a=e.x,i=e.y,o=n/3*2;r.moveTo(a,i),r.lineTo(a+o,i+t),r.lineTo(a,i+t/4*3),r.lineTo(a-o,i+t),r.lineTo(a,i),r.closePath()}}),c9={line:gr,rect:fe,roundRect:fe,square:fe,circle:ki,diamond:s9,pin:l9,arrow:u9,triangle:o9},h9={line:function(r,e,t,n,a){a.x1=r,a.y1=e+n/2,a.x2=r+t,a.y2=e+n/2},rect:function(r,e,t,n,a){a.x=r,a.y=e,a.width=t,a.height=n},roundRect:function(r,e,t,n,a){a.x=r,a.y=e,a.width=t,a.height=n,a.r=Math.min(t,n)/4},square:function(r,e,t,n,a){var i=Math.min(t,n);a.x=r,a.y=e,a.width=i,a.height=i},circle:function(r,e,t,n,a){a.cx=r+t/2,a.cy=e+n/2,a.r=Math.min(t,n)/2},diamond:function(r,e,t,n,a){a.cx=r+t/2,a.cy=e+n/2,a.width=t,a.height=n},pin:function(r,e,t,n,a){a.x=r+t/2,a.y=e+n/2,a.width=t,a.height=n},arrow:function(r,e,t,n,a){a.x=r+t/2,a.y=e+n/2,a.width=t,a.height=n},triangle:function(r,e,t,n,a){a.cx=r+t/2,a.cy=e+n/2,a.width=t,a.height=n}},kd={};B(c9,function(r,e){kd[e]=new r});var f9=ie.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(r,e,t){var n=xd(r,e,t),a=this.shape;return a&&a.symbolType==="pin"&&e.position==="inside"&&(n.y=t.y+t.height*.4),n},buildPath:function(r,e,t){var n=e.symbolType;if(n!=="none"){var a=kd[n];a||(n="rect",a=kd[n]),h9[n](e.x,e.y,e.width,e.height,a.shape),a.buildPath(r,a.shape,t)}}});function v9(r,e){if(this.type!=="image"){var t=this.style;this.__isEmptyBrush?(t.stroke=r,t.fill=e||"#fff",t.lineWidth=2):this.shape.symbolType==="line"?t.stroke=r:t.fill=r,this.markRedraw()}}function or(r,e,t,n,a,i,o){var s=r.indexOf("empty")===0;s&&(r=r.substr(5,1).toLowerCase()+r.substr(6));var l;return r.indexOf("image://")===0?l=rk(r.slice(8),new Qt(e,t,n,a),o?"center":"cover"):r.indexOf("path://")===0?l=Tp(r.slice(7),{},new Qt(e,t,n,a),o?"center":"cover"):l=new f9({shape:{symbolType:r,x:e,y:t,width:n,height:a}}),l.__isEmptyBrush=s,l.setColor=v9,i&&l.setColor(i),l}function xu(r){return ht(r)||(r=[+r,+r]),[r[0]||0,r[1]||0]}function Ys(r,e){if(r!=null)return ht(r)||(r=[r,r]),[At(r[0],e[0])||0,At(Zt(r[1],r[0]),e[1])||0]}function Ss(r){return isFinite(r)}function d9(r,e,t){var n=e.x==null?0:e.x,a=e.x2==null?1:e.x2,i=e.y==null?0:e.y,o=e.y2==null?0:e.y2;e.global||(n=n*t.width+t.x,a=a*t.width+t.x,i=i*t.height+t.y,o=o*t.height+t.y),n=Ss(n)?n:0,a=Ss(a)?a:1,i=Ss(i)?i:0,o=Ss(o)?o:0;var s=r.createLinearGradient(n,i,a,o);return s}function p9(r,e,t){var n=t.width,a=t.height,i=Math.min(n,a),o=e.x==null?.5:e.x,s=e.y==null?.5:e.y,l=e.r==null?.5:e.r;e.global||(o=o*n+t.x,s=s*a+t.y,l=l*i),o=Ss(o)?o:.5,s=Ss(s)?s:.5,l=l>=0&&Ss(l)?l:.5;var u=r.createRadialGradient(o,s,0,o,s,l);return u}function E_(r,e,t){for(var n=e.type==="radial"?p9(r,e,t):d9(r,e,t),a=e.colorStops,i=0;i<a.length;i++)n.addColorStop(a[i].offset,a[i].color);return n}function g9(r,e){if(r===e||!r&&!e)return!1;if(!r||!e||r.length!==e.length)return!0;for(var t=0;t<r.length;t++)if(r[t]!==e[t])return!0;return!1}function hv(r){return parseInt(r,10)}function Gl(r,e,t){var n=["width","height"][e],a=["clientWidth","clientHeight"][e],i=["paddingLeft","paddingTop"][e],o=["paddingRight","paddingBottom"][e];if(t[n]!=null&&t[n]!=="auto")return parseFloat(t[n]);var s=document.defaultView.getComputedStyle(r);return(r[a]||hv(s[n])||hv(r.style[n]))-(hv(s[i])||0)-(hv(s[o])||0)|0}function y9(r,e){return!r||r==="solid"||!(e>0)?null:r==="dashed"?[4*e,2*e]:r==="dotted"?[e]:ye(r)?[r]:ht(r)?r:null}function Tw(r){var e=r.style,t=e.lineDash&&e.lineWidth>0&&y9(e.lineDash,e.lineWidth),n=e.lineDashOffset;if(t){var a=e.strokeNoScale&&r.getLineScale?r.getLineScale():1;a&&a!==1&&(t=ft(t,function(i){return i/a}),n/=a)}return[t,n]}var m9=new ja(!0);function Rd(r){var e=r.stroke;return!(e==null||e==="none"||!(r.lineWidth>0))}function bT(r){return typeof r=="string"&&r!=="none"}function Ed(r){var e=r.fill;return e!=null&&e!=="none"}function ST(r,e){if(e.fillOpacity!=null&&e.fillOpacity!==1){var t=r.globalAlpha;r.globalAlpha=e.fillOpacity*e.opacity,r.fill(),r.globalAlpha=t}else r.fill()}function AT(r,e){if(e.strokeOpacity!=null&&e.strokeOpacity!==1){var t=r.globalAlpha;r.globalAlpha=e.strokeOpacity*e.opacity,r.stroke(),r.globalAlpha=t}else r.stroke()}function O_(r,e,t){var n=K1(e.image,e.__image,t);if(mp(n)){var a=r.createPattern(n,e.repeat||"repeat");if(typeof DOMMatrix=="function"&&a&&a.setTransform){var i=new DOMMatrix;i.translateSelf(e.x||0,e.y||0),i.rotateSelf(0,0,(e.rotation||0)*Uv),i.scaleSelf(e.scaleX||1,e.scaleY||1),a.setTransform(i)}return a}}function _9(r,e,t,n){var a,i=Rd(t),o=Ed(t),s=t.strokePercent,l=s<1,u=!e.path;(!e.silent||l)&&u&&e.createPathProxy();var c=e.path||m9,h=e.__dirty;if(!n){var d=t.fill,v=t.stroke,p=o&&!!d.colorStops,y=i&&!!v.colorStops,_=o&&!!d.image,g=i&&!!v.image,f=void 0,w=void 0,x=void 0,S=void 0,A=void 0;(p||y)&&(A=e.getBoundingRect()),p&&(f=h?E_(r,d,A):e.__canvasFillGradient,e.__canvasFillGradient=f),y&&(w=h?E_(r,v,A):e.__canvasStrokeGradient,e.__canvasStrokeGradient=w),_&&(x=h||!e.__canvasFillPattern?O_(r,d,e):e.__canvasFillPattern,e.__canvasFillPattern=x),g&&(S=h||!e.__canvasStrokePattern?O_(r,v,e):e.__canvasStrokePattern,e.__canvasStrokePattern=x),p?r.fillStyle=f:_&&(x?r.fillStyle=x:o=!1),y?r.strokeStyle=w:g&&(S?r.strokeStyle=S:i=!1)}var T=e.getGlobalScale();c.setScale(T[0],T[1],e.segmentIgnoreThreshold);var L,M;r.setLineDash&&t.lineDash&&(a=Tw(e),L=a[0],M=a[1]);var I=!0;(u||h&El)&&(c.setDPR(r.dpr),l?c.setContext(null):(c.setContext(r),I=!1),c.reset(),e.buildPath(c,e.shape,n),c.toStatic(),e.pathUpdated()),I&&c.rebuildPath(r,l?s:1),L&&(r.setLineDash(L),r.lineDashOffset=M),n||(t.strokeFirst?(i&&AT(r,t),o&&ST(r,t)):(o&&ST(r,t),i&&AT(r,t))),L&&r.setLineDash([])}function w9(r,e,t){var n=e.__image=K1(t.image,e.__image,e,e.onload);if(!(!n||!mp(n))){var a=t.x||0,i=t.y||0,o=e.getWidth(),s=e.getHeight(),l=n.width/n.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=n.width,s=n.height),t.sWidth&&t.sHeight){var u=t.sx||0,c=t.sy||0;r.drawImage(n,u,c,t.sWidth,t.sHeight,a,i,o,s)}else if(t.sx&&t.sy){var u=t.sx,c=t.sy,h=o-u,d=s-c;r.drawImage(n,u,c,h,d,a,i,o,s)}else r.drawImage(n,a,i,o,s)}}function x9(r,e,t){var n,a=t.text;if(a!=null&&(a+=""),a){r.font=t.font||mo,r.textAlign=t.textAlign,r.textBaseline=t.textBaseline;var i=void 0,o=void 0;r.setLineDash&&t.lineDash&&(n=Tw(e),i=n[0],o=n[1]),i&&(r.setLineDash(i),r.lineDashOffset=o),t.strokeFirst?(Rd(t)&&r.strokeText(a,t.x,t.y),Ed(t)&&r.fillText(a,t.x,t.y)):(Ed(t)&&r.fillText(a,t.x,t.y),Rd(t)&&r.strokeText(a,t.x,t.y)),i&&r.setLineDash([])}}var TT=["shadowBlur","shadowOffsetX","shadowOffsetY"],CT=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function pR(r,e,t,n,a){var i=!1;if(!n&&(t=t||{},e===t))return!1;if(n||e.opacity!==t.opacity){dn(r,a),i=!0;var o=Math.max(Math.min(e.opacity,1),0);r.globalAlpha=isNaN(o)?Ms.opacity:o}(n||e.blend!==t.blend)&&(i||(dn(r,a),i=!0),r.globalCompositeOperation=e.blend||Ms.blend);for(var s=0;s<TT.length;s++){var l=TT[s];(n||e[l]!==t[l])&&(i||(dn(r,a),i=!0),r[l]=r.dpr*(e[l]||0))}return(n||e.shadowColor!==t.shadowColor)&&(i||(dn(r,a),i=!0),r.shadowColor=e.shadowColor||Ms.shadowColor),i}function LT(r,e,t,n,a){var i=lh(e,a.inHover),o=n?null:t&&lh(t,a.inHover)||{};if(i===o)return!1;var s=pR(r,i,o,n,a);if((n||i.fill!==o.fill)&&(s||(dn(r,a),s=!0),bT(i.fill)&&(r.fillStyle=i.fill)),(n||i.stroke!==o.stroke)&&(s||(dn(r,a),s=!0),bT(i.stroke)&&(r.strokeStyle=i.stroke)),(n||i.opacity!==o.opacity)&&(s||(dn(r,a),s=!0),r.globalAlpha=i.opacity==null?1:i.opacity),e.hasStroke()){var l=i.lineWidth,u=l/(i.strokeNoScale&&e.getLineScale?e.getLineScale():1);r.lineWidth!==u&&(s||(dn(r,a),s=!0),r.lineWidth=u)}for(var c=0;c<CT.length;c++){var h=CT[c],d=h[0];(n||i[d]!==o[d])&&(s||(dn(r,a),s=!0),r[d]=i[d]||h[1])}return s}function b9(r,e,t,n,a){return pR(r,lh(e,a.inHover),t&&lh(t,a.inHover),n,a)}function gR(r,e){var t=e.transform,n=r.dpr||1;t?r.setTransform(n*t[0],n*t[1],n*t[2],n*t[3],n*t[4],n*t[5]):r.setTransform(n,0,0,n,0,0)}function S9(r,e,t){for(var n=!1,a=0;a<r.length;a++){var i=r[a];n=n||i.isZeroArea(),gR(e,i),e.beginPath(),i.buildPath(e,i.shape),e.clip()}t.allClipped=n}function A9(r,e){return r&&e?r[0]!==e[0]||r[1]!==e[1]||r[2]!==e[2]||r[3]!==e[3]||r[4]!==e[4]||r[5]!==e[5]:!(!r&&!e)}var MT=1,DT=2,IT=3,PT=4;function T9(r){var e=Ed(r),t=Rd(r);return!(r.lineDash||!(+e^+t)||e&&typeof r.fill!="string"||t&&typeof r.stroke!="string"||r.strokePercent<1||r.strokeOpacity<1||r.fillOpacity<1)}function dn(r,e){e.batchFill&&r.fill(),e.batchStroke&&r.stroke(),e.batchFill="",e.batchStroke=""}function lh(r,e){return e&&r.__hoverStyle||r.style}function yR(r,e){As(r,e,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function As(r,e,t,n){var a=e.transform;if(!e.shouldBePainted(t.viewWidth,t.viewHeight,!1,!1)){e.__dirty&=~Tn,e.__isRendered=!1;return}var i=e.__clipPaths,o=t.prevElClipPaths,s=!1,l=!1;if((!o||g9(i,o))&&(o&&o.length&&(dn(r,t),r.restore(),l=s=!0,t.prevElClipPaths=null,t.allClipped=!1,t.prevEl=null),i&&i.length&&(dn(r,t),r.save(),S9(i,r,t),s=!0),t.prevElClipPaths=i),t.allClipped){e.__isRendered=!1;return}e.beforeBrush&&e.beforeBrush(),e.innerBeforeBrush();var u=t.prevEl;u||(l=s=!0);var c=e instanceof ie&&e.autoBatch&&T9(e.style);s||A9(a,u.transform)?(dn(r,t),gR(r,e)):c||dn(r,t);var h=lh(e,t.inHover);e instanceof ie?(t.lastDrawType!==MT&&(l=!0,t.lastDrawType=MT),LT(r,e,u,l,t),(!c||!t.batchFill&&!t.batchStroke)&&r.beginPath(),_9(r,e,h,c),c&&(t.batchFill=h.fill||"",t.batchStroke=h.stroke||"")):e instanceof Ql?(t.lastDrawType!==IT&&(l=!0,t.lastDrawType=IT),LT(r,e,u,l,t),x9(r,e,h)):e instanceof Tr?(t.lastDrawType!==DT&&(l=!0,t.lastDrawType=DT),b9(r,e,u,l,t),w9(r,e,h)):e.getTemporalDisplayables&&(t.lastDrawType!==PT&&(l=!0,t.lastDrawType=PT),C9(r,e,t)),c&&n&&dn(r,t),e.innerAfterBrush(),e.afterBrush&&e.afterBrush(),t.prevEl=e,e.__dirty=0,e.__isRendered=!0}function C9(r,e,t){var n=e.getDisplayables(),a=e.getTemporalDisplayables();r.save();var i={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:t.viewWidth,viewHeight:t.viewHeight,inHover:t.inHover},o,s;for(o=e.getCursor(),s=n.length;o<s;o++){var l=n[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),As(r,l,i,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),i.prevEl=l}for(var u=0,c=a.length;u<c;u++){var l=a[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),As(r,l,i,u===c-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),i.prevEl=l}e.clearTemporalDisplayables(),e.notClear=!0,r.restore()}var im=new i9,kT=new Ah(100),RT=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function eu(r,e){if(r==="none")return null;var t=e.getDevicePixelRatio(),n=e.getZr(),a=n.painter.type==="svg";r.dirty&&im.delete(r);var i=im.get(r);if(i)return i;var o=zt(r,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=a?1:1/t,im.set(r,s),r.dirty=!1,s;function l(u){for(var c=[t],h=!0,d=0;d<RT.length;++d){var v=o[RT[d]];if(v!=null&&!ht(v)&&!Lt(v)&&!ye(v)&&typeof v!="boolean"){h=!1;break}c.push(v)}var p;if(h){p=c.join(",")+(a?"-svg":"");var y=kT.get(p);y&&(a?u.svgElement=y:u.image=y)}var _=_R(o.dashArrayX),g=L9(o.dashArrayY),f=mR(o.symbol),w=M9(_),x=wR(g),S=!a&&_o.createCanvas(),A=a&&{tag:"g",attrs:{},key:"dcl",children:[]},T=M(),L;S&&(S.width=T.width*t,S.height=T.height*t,L=S.getContext("2d")),I(),h&&kT.put(p,S||A),u.image=S,u.svgElement=A,u.svgWidth=T.width,u.svgHeight=T.height;function M(){for(var R=1,P=0,E=w.length;P<E;++P)R=q2(R,w[P]);for(var D=1,P=0,E=f.length;P<E;++P)D=q2(D,f[P].length);R*=D;var N=x*w.length*f.length;return{width:Math.max(1,Math.min(R,o.maxTileWidth)),height:Math.max(1,Math.min(N,o.maxTileHeight))}}function I(){L&&(L.clearRect(0,0,S.width,S.height),o.backgroundColor&&(L.fillStyle=o.backgroundColor,L.fillRect(0,0,S.width,S.height)));for(var R=0,P=0;P<g.length;++P)R+=g[P];if(R<=0)return;for(var E=-x,D=0,N=0,V=0;E<T.height;){if(D%2===0){for(var W=N/2%f.length,$=0,H=0,K=0;$<T.width*2;){for(var U=0,P=0;P<_[V].length;++P)U+=_[V][P];if(U<=0)break;if(H%2===0){var j=(1-o.symbolSize)*.5,ut=$+_[V][H]*j,ot=E+g[D]*j,it=_[V][H]*o.symbolSize,Et=g[D]*o.symbolSize,jt=K/2%f[W].length;bt(ut,ot,it,Et,f[W][jt])}$+=_[V][H],++K,++H,H===_[V].length&&(H=0)}++V,V===_.length&&(V=0)}E+=g[D],++N,++D,D===g.length&&(D=0)}function bt(wt,Ot,xt,kt,ae){var O=a?1:t,st=or(ae,wt*O,Ot*O,xt*O,kt*O,o.color,o.symbolKeepAspect);if(a){var nt=n.painter.renderOneToVNode(st);nt&&A.children.push(nt)}else yR(L,st)}}}}function mR(r){if(!r||r.length===0)return[["rect"]];if(Lt(r))return[[r]];for(var e=!0,t=0;t<r.length;++t)if(!Lt(r[t])){e=!1;break}if(e)return mR([r]);for(var n=[],t=0;t<r.length;++t)Lt(r[t])?n.push([r[t]]):n.push(r[t]);return n}function _R(r){if(!r||r.length===0)return[[0,0]];if(ye(r)){var e=Math.ceil(r);return[[e,e]]}for(var t=!0,n=0;n<r.length;++n)if(!ye(r[n])){t=!1;break}if(t)return _R([r]);for(var a=[],n=0;n<r.length;++n)if(ye(r[n])){var e=Math.ceil(r[n]);a.push([e,e])}else{var e=ft(r[n],function(s){return Math.ceil(s)});e.length%2===1?a.push(e.concat(e)):a.push(e)}return a}function L9(r){if(!r||typeof r=="object"&&r.length===0)return[0,0];if(ye(r)){var e=Math.ceil(r);return[e,e]}var t=ft(r,function(n){return Math.ceil(n)});return r.length%2?t.concat(t):t}function M9(r){return ft(r,function(e){return wR(e)})}function wR(r){for(var e=0,t=0;t<r.length;++t)e+=r[t];return r.length%2===1?e*2:e}function D9(r,e){r.eachRawSeries(function(t){if(!r.isSeriesFiltered(t)){var n=t.getData();n.hasItemVisual()&&n.each(function(o){var s=n.getItemVisual(o,"decal");if(s){var l=n.ensureUniqueItemVisual(o,"style");l.decal=eu(s,e)}});var a=n.getVisual("decal");if(a){var i=n.getVisual("style");i.decal=eu(a,e)}}})}var va=new ea,xR={};function I9(r,e){xR[r]=e}function P9(r){return xR[r]}var k9=1,R9=800,E9=900,O9=1e3,B9=2e3,N9=5e3,bR=1e3,z9=1100,Cw=2e3,SR=3e3,F9=4e3,Np=4500,V9=4600,G9=5e3,W9=6e3,AR=7e3,H9={PROCESSOR:{FILTER:O9,SERIES_FILTER:R9,STATISTIC:N9},VISUAL:{LAYOUT:bR,PROGRESSIVE_LAYOUT:z9,GLOBAL:Cw,CHART:SR,POST_CHART_LAYOUT:V9,COMPONENT:F9,BRUSH:G9,CHART_ITEM:Np,ARIA:W9,DECAL:AR}},Nr="__flagInMainProcess",cn="__pendingUpdate",om="__needsUpdateStatus",ET=/^[a-zA-Z0-9_]+$/,sm="__connectUpdateStatus",OT=0,U9=1,Z9=2;function TR(r){return function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];if(this.isDisposed()){this.id;return}return LR(this,r,e)}}function CR(r){return function(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];return LR(this,r,e)}}function LR(r,e,t){return t[0]=t[0]&&t[0].toLowerCase(),ea.prototype[e].apply(r,t)}var MR=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e}(ea),DR=MR.prototype;DR.on=CR("on");DR.off=CR("off");var Sl,lm,fv,$i,um,cm,hm,Ku,Qu,BT,NT,fm,zT,vv,FT,IR,Fn,VT,PR=function(r){rt(e,r);function e(t,n,a){var i=r.call(this,new J7)||this;i._chartsViews=[],i._chartsMap={},i._componentsViews=[],i._componentsMap={},i._pendingActions=[],a=a||{},Lt(n)&&(n=kR[n]),i._dom=t;var o="canvas",s="auto",l=!1;a.ssr&&V8(function(d){var v=Ht(d),p=v.dataIndex;if(p!=null){var y=Pt();return y.set("series_index",v.seriesIndex),y.set("data_index",p),v.ssrType&&y.set("ssr_type",v.ssrType),y}});var u=i._zr=Y2(t,{renderer:a.renderer||o,devicePixelRatio:a.devicePixelRatio,width:a.width,height:a.height,ssr:a.ssr,useDirtyRect:Zt(a.useDirtyRect,l),useCoarsePointer:Zt(a.useCoarsePointer,s),pointerSize:a.pointerSize});i._ssr=a.ssr,i._throttledZrFlush=Sw(Mt(u.flush,u),17),n=Gt(n),n&&Nk(n,!0),i._theme=n,i._locale=cU(a.locale||fk),i._coordSysMgr=new Rh;var c=i._api=FT(i);function h(d,v){return d.__prio-v.__prio}return Xv(Bd,h),Xv(B_,h),i._scheduler=new lR(i,c,B_,Bd),i._messageCenter=new MR,i._initEvents(),i.resize=Mt(i.resize,i),u.animation.on("frame",i._onframe,i),BT(u,i),NT(u,i),vd(i),i}return e.prototype._onframe=function(){if(!this._disposed){VT(this);var t=this._scheduler;if(this[cn]){var n=this[cn].silent;this[Nr]=!0;try{Sl(this),$i.update.call(this,null,this[cn].updateParams)}catch(l){throw this[Nr]=!1,this[cn]=null,l}this._zr.flush(),this[Nr]=!1,this[cn]=null,Ku.call(this,n),Qu.call(this,n)}else if(t.unfinished){var a=k9,i=this._model,o=this._api;t.unfinished=!1;do{var s=+new Date;t.performSeriesTasks(i),t.performDataProcessorTasks(i),cm(this,i),t.performVisualTasks(i),vv(this,this._model,o,"remain",{}),a-=+new Date-s}while(a>0&&t.unfinished);t.unfinished||this._zr.flush()}}},e.prototype.getDom=function(){return this._dom},e.prototype.getId=function(){return this.id},e.prototype.getZr=function(){return this._zr},e.prototype.isSSR=function(){return this._ssr},e.prototype.setOption=function(t,n,a){if(!this[Nr]){if(this._disposed){this.id;return}var i,o,s;if(Vt(n)&&(a=n.lazyUpdate,i=n.silent,o=n.replaceMerge,s=n.transition,n=n.notMerge),this[Nr]=!0,!this._model||n){var l=new OU(this._api),u=this._theme,c=this._model=new mw;c.scheduler=this._scheduler,c.ssr=this._ssr,c.init(null,null,null,u,this._locale,l)}this._model.setOption(t,{replaceMerge:o},N_);var h={seriesTransition:s,optionChanged:!0};if(a)this[cn]={silent:i,updateParams:h},this[Nr]=!1,this.getZr().wakeUp();else{try{Sl(this),$i.update.call(this,null,h)}catch(d){throw this[cn]=null,this[Nr]=!1,d}this._ssr||this._zr.flush(),this[cn]=null,this[Nr]=!1,Ku.call(this,i),Qu.call(this,i)}}},e.prototype.setTheme=function(){},e.prototype.getModel=function(){return this._model},e.prototype.getOption=function(){return this._model&&this._model.getOption()},e.prototype.getWidth=function(){return this._zr.getWidth()},e.prototype.getHeight=function(){return this._zr.getHeight()},e.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||oe.hasGlobalWindow&&window.devicePixelRatio||1},e.prototype.getRenderedCanvas=function(t){return this.renderToCanvas(t)},e.prototype.renderToCanvas=function(t){t=t||{};var n=this._zr.painter;return n.getRenderedCanvas({backgroundColor:t.backgroundColor||this._model.get("backgroundColor"),pixelRatio:t.pixelRatio||this.getDevicePixelRatio()})},e.prototype.renderToSVGString=function(t){t=t||{};var n=this._zr.painter;return n.renderToString({useViewBox:t.useViewBox})},e.prototype.getSvgDataURL=function(){if(oe.svgSupported){var t=this._zr,n=t.storage.getDisplayList();return B(n,function(a){a.stopAnimation(null,!0)}),t.painter.toDataURL()}},e.prototype.getDataURL=function(t){if(this._disposed){this.id;return}t=t||{};var n=t.excludeComponents,a=this._model,i=[],o=this;B(n,function(l){a.eachComponent({mainType:l},function(u){var c=o._componentsMap[u.__viewId];c.group.ignore||(i.push(c),c.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(t).toDataURL("image/"+(t&&t.type||"png"));return B(i,function(l){l.group.ignore=!1}),s},e.prototype.getConnectedDataURL=function(t){if(this._disposed){this.id;return}var n=t.type==="svg",a=this.group,i=Math.min,o=Math.max,s=1/0;if(GT[a]){var l=s,u=s,c=-s,h=-s,d=[],v=t&&t.pixelRatio||this.getDevicePixelRatio();B(Hc,function(w,x){if(w.group===a){var S=n?w.getZr().painter.getSvgDom().innerHTML:w.renderToCanvas(Gt(t)),A=w.getDom().getBoundingClientRect();l=i(A.left,l),u=i(A.top,u),c=o(A.right,c),h=o(A.bottom,h),d.push({dom:S,left:A.left,top:A.top})}}),l*=v,u*=v,c*=v,h*=v;var p=c-l,y=h-u,_=_o.createCanvas(),g=Y2(_,{renderer:n?"svg":"canvas"});if(g.resize({width:p,height:y}),n){var f="";return B(d,function(w){var x=w.left-l,S=w.top-u;f+='<g transform="translate('+x+","+S+')">'+w.dom+"</g>"}),g.painter.getSvgRoot().innerHTML=f,t.connectedBackgroundColor&&g.painter.setBackgroundColor(t.connectedBackgroundColor),g.refreshImmediately(),g.painter.toDataURL()}else return t.connectedBackgroundColor&&g.add(new fe({shape:{x:0,y:0,width:p,height:y},style:{fill:t.connectedBackgroundColor}})),B(d,function(w){var x=new Tr({style:{x:w.left*v-l,y:w.top*v-u,image:w.dom}});g.add(x)}),g.refreshImmediately(),_.toDataURL("image/"+(t&&t.type||"png"))}else return this.getDataURL(t)},e.prototype.convertToPixel=function(t,n){return um(this,"convertToPixel",t,n)},e.prototype.convertFromPixel=function(t,n){return um(this,"convertFromPixel",t,n)},e.prototype.containPixel=function(t,n){if(this._disposed){this.id;return}var a=this._model,i,o=Bc(a,t);return B(o,function(s,l){l.indexOf("Models")>=0&&B(s,function(u){var c=u.coordinateSystem;if(c&&c.containPoint)i=i||!!c.containPoint(n);else if(l==="seriesModels"){var h=this._chartsMap[u.__viewId];h&&h.containPoint&&(i=i||h.containPoint(n,u))}},this)},this),!!i},e.prototype.getVisual=function(t,n){var a=this._model,i=Bc(a,t,{defaultMainType:"series"}),o=i.seriesModel,s=o.getData(),l=i.hasOwnProperty("dataIndexInside")?i.dataIndexInside:i.hasOwnProperty("dataIndex")?s.indexOfRawIndex(i.dataIndex):null;return l!=null?Aw(s,l,n):Eh(s,n)},e.prototype.getViewOfComponentModel=function(t){return this._componentsMap[t.__viewId]},e.prototype.getViewOfSeriesModel=function(t){return this._chartsMap[t.__viewId]},e.prototype._initEvents=function(){var t=this;B(Y9,function(n){var a=function(i){var o=t.getModel(),s=i.target,l,u=n==="globalout";if(u?l={}:s&&bs(s,function(p){var y=Ht(p);if(y&&y.dataIndex!=null){var _=y.dataModel||o.getSeriesByIndex(y.seriesIndex);return l=_&&_.getDataParams(y.dataIndex,y.dataType,s)||{},!0}else if(y.eventData)return l=lt({},y.eventData),!0},!0),l){var c=l.componentType,h=l.componentIndex;(c==="markLine"||c==="markPoint"||c==="markArea")&&(c="series",h=l.seriesIndex);var d=c&&h!=null&&o.getComponent(c,h),v=d&&t[d.mainType==="series"?"_chartsMap":"_componentsMap"][d.__viewId];l.event=i,l.type=n,t._$eventProcessor.eventInfo={targetEl:s,packedEvent:l,model:d,view:v},t.trigger(n,l)}};a.zrEventfulCallAtLast=!0,t._zr.on(n,a,t)}),B(Wc,function(n,a){t._messageCenter.on(a,function(i){this.trigger(a,i)},t)}),B(["selectchanged"],function(n){t._messageCenter.on(n,function(a){this.trigger(n,a)},t)}),r9(this._messageCenter,this,this._api)},e.prototype.isDisposed=function(){return this._disposed},e.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},e.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var t=this.getDom();t&&AP(this.getDom(),Mw,"");var n=this,a=n._api,i=n._model;B(n._componentsViews,function(o){o.dispose(i,a)}),B(n._chartsViews,function(o){o.dispose(i,a)}),n._zr.dispose(),n._dom=n._model=n._chartsMap=n._componentsMap=n._chartsViews=n._componentsViews=n._scheduler=n._api=n._zr=n._throttledZrFlush=n._theme=n._coordSysMgr=n._messageCenter=null,delete Hc[n.id]},e.prototype.resize=function(t){if(!this[Nr]){if(this._disposed){this.id;return}this._zr.resize(t);var n=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!n){var a=n.resetOption("media"),i=t&&t.silent;this[cn]&&(i==null&&(i=this[cn].silent),a=!0,this[cn]=null),this[Nr]=!0;try{a&&Sl(this),$i.update.call(this,{type:"resize",animation:lt({duration:0},t&&t.animation)})}catch(o){throw this[Nr]=!1,o}this[Nr]=!1,Ku.call(this,i),Qu.call(this,i)}}},e.prototype.showLoading=function(t,n){if(this._disposed){this.id;return}if(Vt(t)&&(n=t,t=""),t=t||"default",this.hideLoading(),!!z_[t]){var a=z_[t](this._api,n),i=this._zr;this._loadingFX=a,i.add(a)}},e.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},e.prototype.makeActionFromEvent=function(t){var n=lt({},t);return n.type=Wc[t.type],n},e.prototype.dispatchAction=function(t,n){if(this._disposed){this.id;return}if(Vt(n)||(n={silent:!!n}),!!Od[t.type]&&this._model){if(this[Nr]){this._pendingActions.push(t);return}var a=n.silent;hm.call(this,t,a);var i=n.flush;i?this._zr.flush():i!==!1&&oe.browser.weChat&&this._throttledZrFlush(),Ku.call(this,a),Qu.call(this,a)}},e.prototype.updateLabelLayout=function(){va.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},e.prototype.appendData=function(t){if(this._disposed){this.id;return}var n=t.seriesIndex,a=this.getModel(),i=a.getSeriesByIndex(n);i.appendData(t),this._scheduler.unfinished=!0,this.getZr().wakeUp()},e.internalField=function(){Sl=function(h){var d=h._scheduler;d.restorePipelines(h._model),d.prepareStageTasks(),lm(h,!0),lm(h,!1),d.plan()},lm=function(h,d){for(var v=h._model,p=h._scheduler,y=d?h._componentsViews:h._chartsViews,_=d?h._componentsMap:h._chartsMap,g=h._zr,f=h._api,w=0;w<y.length;w++)y[w].__alive=!1;d?v.eachComponent(function(A,T){A!=="series"&&x(T)}):v.eachSeries(x);function x(A){var T=A.__requireNewView;A.__requireNewView=!1;var L="_ec_"+A.id+"_"+A.type,M=!T&&_[L];if(!M){var I=Va(A.type),R=d?Ze.getClass(I.main,I.sub):Re.getClass(I.sub);M=new R,M.init(v,f),_[L]=M,y.push(M),g.add(M.group)}A.__viewId=M.__id=L,M.__alive=!0,M.__model=A,M.group.__ecComponentInfo={mainType:A.mainType,index:A.componentIndex},!d&&p.prepareView(M,A,v,f)}for(var w=0;w<y.length;){var S=y[w];S.__alive?w++:(!d&&S.renderTask.dispose(),g.remove(S.group),S.dispose(v,f),y.splice(w,1),_[S.__id]===S&&delete _[S.__id],S.__id=S.group.__ecComponentInfo=null)}},fv=function(h,d,v,p,y){var _=h._model;if(_.setUpdatePayload(v),!p){B([].concat(h._componentsViews).concat(h._chartsViews),S);return}var g={};g[p+"Id"]=v[p+"Id"],g[p+"Index"]=v[p+"Index"],g[p+"Name"]=v[p+"Name"];var f={mainType:p,query:g};y&&(f.subType=y);var w=v.excludeSeriesId,x;w!=null&&(x=Pt(),B(Ie(w),function(A){var T=ur(A,null);T!=null&&x.set(T,!0)})),_&&_.eachComponent(f,function(A){var T=x&&x.get(A.id)!=null;if(!T)if(bA(v))if(A instanceof Ve)v.type===Ds&&!v.notBlur&&!A.get(["emphasis","disabled"])&&uH(A,v,h._api);else{var L=nw(A.mainType,A.componentIndex,v.name,h._api),M=L.focusSelf,I=L.dispatchers;v.type===Ds&&M&&!v.notBlur&&m_(A.mainType,A.componentIndex,h._api),I&&B(I,function(R){v.type===Ds?Ti(R):Ci(R)})}else w_(v)&&A instanceof Ve&&(fH(A,v,h._api),wA(A),Fn(h))},h),_&&_.eachComponent(f,function(A){var T=x&&x.get(A.id)!=null;T||S(h[p==="series"?"_chartsMap":"_componentsMap"][A.__viewId])},h);function S(A){A&&A.__alive&&A[d]&&A[d](A.__model,_,h._api,v)}},$i={prepareAndUpdate:function(h){Sl(this),$i.update.call(this,h,{optionChanged:h.newOption!=null})},update:function(h,d){var v=this._model,p=this._api,y=this._zr,_=this._coordSysMgr,g=this._scheduler;if(v){v.setUpdatePayload(h),g.restoreData(v,h),g.performSeriesTasks(v),_.create(v,p),g.performDataProcessorTasks(v,h),cm(this,v),_.update(v,p),t(v),g.performVisualTasks(v,h),fm(this,v,p,h,d);var f=v.get("backgroundColor")||"transparent",w=v.get("darkMode");y.setBackgroundColor(f),w!=null&&w!=="auto"&&y.setDarkMode(w),va.trigger("afterupdate",v,p)}},updateTransform:function(h){var d=this,v=this._model,p=this._api;if(v){v.setUpdatePayload(h);var y=[];v.eachComponent(function(g,f){if(g!=="series"){var w=d.getViewOfComponentModel(f);if(w&&w.__alive)if(w.updateTransform){var x=w.updateTransform(f,v,p,h);x&&x.update&&y.push(w)}else y.push(w)}});var _=Pt();v.eachSeries(function(g){var f=d._chartsMap[g.__viewId];if(f.updateTransform){var w=f.updateTransform(g,v,p,h);w&&w.update&&_.set(g.uid,1)}else _.set(g.uid,1)}),t(v),this._scheduler.performVisualTasks(v,h,{setDirty:!0,dirtyMap:_}),vv(this,v,p,h,{},_),va.trigger("afterupdate",v,p)}},updateView:function(h){var d=this._model;d&&(d.setUpdatePayload(h),Re.markUpdateMethod(h,"updateView"),t(d),this._scheduler.performVisualTasks(d,h,{setDirty:!0}),fm(this,d,this._api,h,{}),va.trigger("afterupdate",d,this._api))},updateVisual:function(h){var d=this,v=this._model;v&&(v.setUpdatePayload(h),v.eachSeries(function(p){p.getData().clearAllVisual()}),Re.markUpdateMethod(h,"updateVisual"),t(v),this._scheduler.performVisualTasks(v,h,{visualType:"visual",setDirty:!0}),v.eachComponent(function(p,y){if(p!=="series"){var _=d.getViewOfComponentModel(y);_&&_.__alive&&_.updateVisual(y,v,d._api,h)}}),v.eachSeries(function(p){var y=d._chartsMap[p.__viewId];y.updateVisual(p,v,d._api,h)}),va.trigger("afterupdate",v,this._api))},updateLayout:function(h){$i.update.call(this,h)}},um=function(h,d,v,p){if(h._disposed){h.id;return}for(var y=h._model,_=h._coordSysMgr.getCoordinateSystems(),g,f=Bc(y,v),w=0;w<_.length;w++){var x=_[w];if(x[d]&&(g=x[d](y,f,p))!=null)return g}},cm=function(h,d){var v=h._chartsMap,p=h._scheduler;d.eachSeries(function(y){p.updateStreamModes(y,v[y.__viewId])})},hm=function(h,d){var v=this,p=this.getModel(),y=h.type,_=h.escapeConnect,g=Od[y],f=g.actionInfo,w=(f.update||"update").split(":"),x=w.pop(),S=w[0]!=null&&Va(w[0]);this[Nr]=!0;var A=[h],T=!1;h.batch&&(T=!0,A=ft(h.batch,function(D){return D=zt(lt({},D),h),D.batch=null,D}));var L=[],M,I=w_(h),R=bA(h);if(R&&ZP(this._api),B(A,function(D){if(M=g.action(D,v._model,v._api),M=M||lt({},D),M.type=f.event||M.type,L.push(M),R){var N=j1(h),V=N.queryOptionMap,W=N.mainTypeSpecified,$=W?V.keys()[0]:"series";fv(v,x,D,$),Fn(v)}else I?(fv(v,x,D,"series"),Fn(v)):S&&fv(v,x,D,S.main,S.sub)}),x!=="none"&&!R&&!I&&!S)try{this[cn]?(Sl(this),$i.update.call(this,h),this[cn]=null):$i[x].call(this,h)}catch(D){throw this[Nr]=!1,D}if(T?M={type:f.event||y,escapeConnect:_,batch:L}:M=L[0],this[Nr]=!1,!d){var P=this._messageCenter;if(P.trigger(M.type,M),I){var E={type:"selectchanged",escapeConnect:_,selected:vH(p),isFromClick:h.isFromClick||!1,fromAction:h.type,fromActionPayload:h};P.trigger(E.type,E)}}},Ku=function(h){for(var d=this._pendingActions;d.length;){var v=d.shift();hm.call(this,v,h)}},Qu=function(h){!h&&this.trigger("updated")},BT=function(h,d){h.on("rendered",function(v){d.trigger("rendered",v),h.animation.isFinished()&&!d[cn]&&!d._scheduler.unfinished&&!d._pendingActions.length&&d.trigger("finished")})},NT=function(h,d){h.on("mouseover",function(v){var p=v.target,y=bs(p,eh);y&&(cH(y,v,d._api),Fn(d))}).on("mouseout",function(v){var p=v.target,y=bs(p,eh);y&&(hH(y,v,d._api),Fn(d))}).on("click",function(v){var p=v.target,y=bs(p,function(f){return Ht(f).dataIndex!=null},!0);if(y){var _=y.selected?"unselect":"select",g=Ht(y);d._api.dispatchAction({type:_,dataType:g.dataType,dataIndexInside:g.dataIndex,seriesIndex:g.seriesIndex,isFromClick:!0})}})};function t(h){h.clearColorPalette(),h.eachSeries(function(d){d.clearColorPalette()})}function n(h){var d=[],v=[],p=!1;if(h.eachComponent(function(f,w){var x=w.get("zlevel")||0,S=w.get("z")||0,A=w.getZLevelKey();p=p||!!A,(f==="series"?v:d).push({zlevel:x,z:S,idx:w.componentIndex,type:f,key:A})}),p){var y=d.concat(v),_,g;Xv(y,function(f,w){return f.zlevel===w.zlevel?f.z-w.z:f.zlevel-w.zlevel}),B(y,function(f){var w=h.getComponent(f.type,f.idx),x=f.zlevel,S=f.key;_!=null&&(x=Math.max(_,x)),S?(x===_&&S!==g&&x++,g=S):g&&(x===_&&x++,g=""),_=x,w.setZLevel(x)})}}fm=function(h,d,v,p,y){n(d),zT(h,d,v,p,y),B(h._chartsViews,function(_){_.__alive=!1}),vv(h,d,v,p,y),B(h._chartsViews,function(_){_.__alive||_.remove(d,v)})},zT=function(h,d,v,p,y,_){B(_||h._componentsViews,function(g){var f=g.__model;u(f,g),g.render(f,d,v,p),s(f,g),c(f,g)})},vv=function(h,d,v,p,y,_){var g=h._scheduler;y=lt(y||{},{updatedSeries:d.getSeries()}),va.trigger("series:beforeupdate",d,v,y);var f=!1;d.eachSeries(function(w){var x=h._chartsMap[w.__viewId];x.__alive=!0;var S=x.renderTask;g.updatePayload(S,p),u(w,x),_&&_.get(w.uid)&&S.dirty(),S.perform(g.getPerformArgs(S))&&(f=!0),x.group.silent=!!w.get("silent"),o(w,x),wA(w)}),g.unfinished=f||g.unfinished,va.trigger("series:layoutlabels",d,v,y),va.trigger("series:transition",d,v,y),d.eachSeries(function(w){var x=h._chartsMap[w.__viewId];s(w,x),c(w,x)}),i(h,d),va.trigger("series:afterupdate",d,v,y)},Fn=function(h){h[om]=!0,h.getZr().wakeUp()},VT=function(h){h[om]&&(h.getZr().storage.traverse(function(d){Yl(d)||a(d)}),h[om]=!1)};function a(h){for(var d=[],v=h.currentStates,p=0;p<v.length;p++){var y=v[p];y==="emphasis"||y==="blur"||y==="select"||d.push(y)}h.selected&&h.states.select&&d.push("select"),h.hoverState===xp&&h.states.emphasis?d.push("emphasis"):h.hoverState===Lh&&h.states.blur&&d.push("blur"),h.useStates(d)}function i(h,d){var v=h._zr,p=v.storage,y=0;p.traverse(function(_){_.isGroup||y++}),y>d.get("hoverLayerThreshold")&&!oe.node&&!oe.worker&&d.eachSeries(function(_){if(!_.preventUsingHoverLayer){var g=h._chartsMap[_.__viewId];g.__alive&&g.eachRendered(function(f){f.states.emphasis&&(f.states.emphasis.hoverLayer=!0)})}})}function o(h,d){var v=h.get("blendMode")||null;d.eachRendered(function(p){p.isGroup||(p.style.blend=v)})}function s(h,d){if(!h.preventAutoZ){var v=h.get("z")||0,p=h.get("zlevel")||0;d.eachRendered(function(y){return l(y,v,p,-1/0),!0})}}function l(h,d,v,p){var y=h.getTextContent(),_=h.getTextGuideLine(),g=h.isGroup;if(g)for(var f=h.childrenRef(),w=0;w<f.length;w++)p=Math.max(l(f[w],d,v,p),p);else h.z=d,h.zlevel=v,p=Math.max(h.z2,p);if(y&&(y.z=d,y.zlevel=v,isFinite(p)&&(y.z2=p+2)),_){var x=h.textGuideLineConfig;_.z=d,_.zlevel=v,isFinite(p)&&(_.z2=p+(x&&x.showAbove?1:-1))}return p}function u(h,d){d.eachRendered(function(v){if(!Yl(v)){var p=v.getTextContent(),y=v.getTextGuideLine();v.stateTransition&&(v.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),y&&y.stateTransition&&(y.stateTransition=null),v.hasState()?(v.prevStates=v.currentStates,v.clearStates()):v.prevStates&&(v.prevStates=null)}})}function c(h,d){var v=h.getModel("stateAnimation"),p=h.isAnimationEnabled(),y=v.get("duration"),_=y>0?{duration:y,delay:v.get("delay"),easing:v.get("easing")}:null;d.eachRendered(function(g){if(g.states&&g.states.emphasis){if(Yl(g))return;if(g instanceof ie&&mH(g),g.__dirty){var f=g.prevStates;f&&g.useStates(f)}if(p){g.stateTransition=_;var w=g.getTextContent(),x=g.getTextGuideLine();w&&(w.stateTransition=_),x&&(x.stateTransition=_)}g.__dirty&&a(g)}})}FT=function(h){return new(function(d){rt(v,d);function v(){return d!==null&&d.apply(this,arguments)||this}return v.prototype.getCoordinateSystems=function(){return h._coordSysMgr.getCoordinateSystems()},v.prototype.getComponentByElement=function(p){for(;p;){var y=p.__ecComponentInfo;if(y!=null)return h._model.getComponent(y.mainType,y.index);p=p.parent}},v.prototype.enterEmphasis=function(p,y){Ti(p,y),Fn(h)},v.prototype.leaveEmphasis=function(p,y){Ci(p,y),Fn(h)},v.prototype.enterBlur=function(p){GP(p),Fn(h)},v.prototype.leaveBlur=function(p){rw(p),Fn(h)},v.prototype.enterSelect=function(p){WP(p),Fn(h)},v.prototype.leaveSelect=function(p){HP(p),Fn(h)},v.prototype.getModel=function(){return h.getModel()},v.prototype.getViewOfComponentModel=function(p){return h.getViewOfComponentModel(p)},v.prototype.getViewOfSeriesModel=function(p){return h.getViewOfSeriesModel(p)},v}(Ok))(h)},IR=function(h){function d(v,p){for(var y=0;y<v.length;y++){var _=v[y];_[sm]=p}}B(Wc,function(v,p){h._messageCenter.on(p,function(y){if(GT[h.group]&&h[sm]!==OT){if(y&&y.escapeConnect)return;var _=h.makeActionFromEvent(y),g=[];B(Hc,function(f){f!==h&&f.group===h.group&&g.push(f)}),d(g,OT),B(g,function(f){f[sm]!==U9&&f.dispatchAction(_)}),d(g,Z9)}})})}}(),e}(ea),Lw=PR.prototype;Lw.on=TR("on");Lw.off=TR("off");Lw.one=function(r,e,t){var n=this;function a(){for(var i=[],o=0;o<arguments.length;o++)i[o]=arguments[o];e&&e.apply&&e.apply(this,i),n.off(r,a)}this.on.call(this,r,a,t)};var Y9=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var Od={},Wc={},B_=[],N_=[],Bd=[],kR={},z_={},Hc={},GT={},X9=+new Date-0,Mw="_echarts_instance_";function $9(r,e,t){var n=!(t&&t.ssr);if(n){var a=j9(r);if(a)return a}var i=new PR(r,e,t);return i.id="ec_"+X9++,Hc[i.id]=i,n&&AP(r,Mw,i.id),IR(i),va.trigger("afterinit",i),i}function j9(r){return Hc[oW(r,Mw)]}function RR(r,e){kR[r]=e}function ER(r){te(N_,r)<0&&N_.push(r)}function OR(r,e){Iw(B_,r,e,B9)}function q9(r){Dw("afterinit",r)}function K9(r){Dw("afterupdate",r)}function Dw(r,e){va.on(r,e)}function Qa(r,e,t){Nt(e)&&(t=e,e="");var n=Vt(r)?r.type:[r,r={event:e}][0];r.event=(r.event||n).toLowerCase(),e=r.event,!Wc[e]&&(Jr(ET.test(n)&&ET.test(e)),Od[n]||(Od[n]={action:t,actionInfo:r}),Wc[e]=n)}function Q9(r,e){Rh.register(r,e)}function J9(r,e){Iw(Bd,r,e,bR,"layout")}function Xs(r,e){Iw(Bd,r,e,SR,"visual")}var WT=[];function Iw(r,e,t,n,a){if((Nt(e)||Vt(e))&&(t=e,e=n),!(te(WT,t)>=0)){WT.push(t);var i=lR.wrapStageHandler(t,a);i.__prio=e,i.__raw=t,r.push(i)}}function BR(r,e){z_[r]=e}function tZ(r,e,t){var n=P9("registerMap");n&&n(r,e,t)}var eZ=v7;Xs(Cw,F7);Xs(Np,V7);Xs(Np,G7);Xs(Cw,t9);Xs(Np,e9);Xs(AR,D9);ER(Nk);OR(E9,XU);BR("default",W7);Qa({type:Ds,event:Ds,update:Ds},tr);Qa({type:Qv,event:Qv,update:Qv},tr);Qa({type:Nc,event:Nc,update:Nc},tr);Qa({type:Jv,event:Jv,update:Jv},tr);Qa({type:zc,event:zc,update:zc},tr);RR("light",Q7);RR("dark",fR);var HT=[],rZ={registerPreprocessor:ER,registerProcessor:OR,registerPostInit:q9,registerPostUpdate:K9,registerUpdateLifecycle:Dw,registerAction:Qa,registerCoordinateSystem:Q9,registerLayout:J9,registerVisual:Xs,registerTransform:eZ,registerLoading:BR,registerMap:tZ,registerImpl:I9,PRIORITY:H9,ComponentModel:le,ComponentView:Ze,SeriesModel:Ve,ChartView:Re,registerComponentModel:function(r){le.registerClass(r)},registerComponentView:function(r){Ze.registerClass(r)},registerSeriesModel:function(r){Ve.registerClass(r)},registerChartView:function(r){Re.registerClass(r)},registerSubTypeDefaulter:function(r,e){le.registerSubTypeDefaulter(r,e)},registerPainter:function(r,e){z8(r,e)}};function ne(r){if(ht(r)){B(r,function(e){ne(e)});return}te(HT,r)>=0||(HT.push(r),Nt(r)&&(r={install:r}),r.install(rZ))}function Ju(r){return r==null?0:r.length||1}function UT(r){return r}var Li=function(){function r(e,t,n,a,i,o){this._old=e,this._new=t,this._oldKeyGetter=n||UT,this._newKeyGetter=a||UT,this.context=i,this._diffModeMultiple=o==="multiple"}return r.prototype.add=function(e){return this._add=e,this},r.prototype.update=function(e){return this._update=e,this},r.prototype.updateManyToOne=function(e){return this._updateManyToOne=e,this},r.prototype.updateOneToMany=function(e){return this._updateOneToMany=e,this},r.prototype.updateManyToMany=function(e){return this._updateManyToMany=e,this},r.prototype.remove=function(e){return this._remove=e,this},r.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},r.prototype._executeOneToOne=function(){var e=this._old,t=this._new,n={},a=new Array(e.length),i=new Array(t.length);this._initIndexMap(e,null,a,"_oldKeyGetter"),this._initIndexMap(t,n,i,"_newKeyGetter");for(var o=0;o<e.length;o++){var s=a[o],l=n[s],u=Ju(l);if(u>1){var c=l.shift();l.length===1&&(n[s]=l[0]),this._update&&this._update(c,o)}else u===1?(n[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(i,n)},r.prototype._executeMultiple=function(){var e=this._old,t=this._new,n={},a={},i=[],o=[];this._initIndexMap(e,n,i,"_oldKeyGetter"),this._initIndexMap(t,a,o,"_newKeyGetter");for(var s=0;s<i.length;s++){var l=i[s],u=n[l],c=a[l],h=Ju(u),d=Ju(c);if(h>1&&d===1)this._updateManyToOne&&this._updateManyToOne(c,u),a[l]=null;else if(h===1&&d>1)this._updateOneToMany&&this._updateOneToMany(c,u),a[l]=null;else if(h===1&&d===1)this._update&&this._update(c,u),a[l]=null;else if(h>1&&d>1)this._updateManyToMany&&this._updateManyToMany(c,u),a[l]=null;else if(h>1)for(var v=0;v<h;v++)this._remove&&this._remove(u[v]);else this._remove&&this._remove(u)}this._performRestAdd(o,a)},r.prototype._performRestAdd=function(e,t){for(var n=0;n<e.length;n++){var a=e[n],i=t[a],o=Ju(i);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(i[s]);else o===1&&this._add&&this._add(i);t[a]=null}},r.prototype._initIndexMap=function(e,t,n,a){for(var i=this._diffModeMultiple,o=0;o<e.length;o++){var s="_ec_"+this[a](e[o],o);if(i||(n[o]=s),!!t){var l=t[s],u=Ju(l);u===0?(t[s]=o,i&&n.push(s)):u===1?t[s]=[l,o]:l.push(o)}}},r}(),nZ=function(){function r(e,t){this._encode=e,this._schema=t}return r.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},r.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},r}();function aZ(r,e){var t={},n=t.encode={},a=Pt(),i=[],o=[],s={};B(r.dimensions,function(d){var v=r.getDimensionInfo(d),p=v.coordDim;if(p){var y=v.coordDimIndex;vm(n,p)[y]=d,v.isExtraCoord||(a.set(p,1),iZ(v.type)&&(i[0]=d),vm(s,p)[y]=r.getDimensionIndex(v.name)),v.defaultTooltip&&o.push(d)}Mk.each(function(_,g){var f=vm(n,g),w=v.otherDims[g];w!=null&&w!==!1&&(f[w]=v.name)})});var l=[],u={};a.each(function(d,v){var p=n[v];u[v]=p[0],l=l.concat(p)}),t.dataDimsOnCoord=l,t.dataDimIndicesOnCoord=ft(l,function(d){return r.getDimensionInfo(d).storeDimIndex}),t.encodeFirstDimNotExtra=u;var c=n.label;c&&c.length&&(i=c.slice());var h=n.tooltip;return h&&h.length?o=h.slice():o.length||(o=i.slice()),n.defaultedLabel=i,n.defaultedTooltip=o,t.userOutput=new nZ(s,e),t}function vm(r,e){return r.hasOwnProperty(e)||(r[e]=[]),r[e]}function Nd(r){return r==="category"?"ordinal":r==="time"?"time":"float"}function iZ(r){return!(r==="ordinal"||r==="time")}var ad=function(){function r(e){this.otherDims={},e!=null&&lt(this,e)}return r}(),oZ=ve(),sZ={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},NR=function(){function r(e){this.dimensions=e.dimensions,this._dimOmitted=e.dimensionOmitted,this.source=e.source,this._fullDimCount=e.fullDimensionCount,this._updateDimOmitted(e.dimensionOmitted)}return r.prototype.isDimensionOmitted=function(){return this._dimOmitted},r.prototype._updateDimOmitted=function(e){this._dimOmitted=e,e&&(this._dimNameMap||(this._dimNameMap=VR(this.source)))},r.prototype.getSourceDimensionIndex=function(e){return Zt(this._dimNameMap.get(e),-1)},r.prototype.getSourceDimension=function(e){var t=this.source.dimensionsDefine;if(t)return t[e]},r.prototype.makeStoreSchema=function(){for(var e=this._fullDimCount,t=Fk(this.source),n=!GR(e),a="",i=[],o=0,s=0;o<e;o++){var l=void 0,u=void 0,c=void 0,h=this.dimensions[s];if(h&&h.storeDimIndex===o)l=t?h.name:null,u=h.type,c=h.ordinalMeta,s++;else{var d=this.getSourceDimension(o);d&&(l=t?d.name:null,u=d.type)}i.push({property:l,type:u,ordinalMeta:c}),t&&l!=null&&(!h||!h.isCalculationCoord)&&(a+=n?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),a+="$",a+=sZ[u]||"f",c&&(a+=c.uid),a+="$"}var v=this.source,p=[v.seriesLayoutBy,v.startIndex,a].join("$$");return{dimensions:i,hash:p}},r.prototype.makeOutputDimensionNames=function(){for(var e=[],t=0,n=0;t<this._fullDimCount;t++){var a=void 0,i=this.dimensions[n];if(i&&i.storeDimIndex===t)i.isCalculationCoord||(a=i.name),n++;else{var o=this.getSourceDimension(t);o&&(a=o.name)}e.push(a)}return e},r.prototype.appendCalculationDimension=function(e){this.dimensions.push(e),e.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},r}();function zR(r){return r instanceof NR}function FR(r){for(var e=Pt(),t=0;t<(r||[]).length;t++){var n=r[t],a=Vt(n)?n.name:n;a!=null&&e.get(a)==null&&e.set(a,t)}return e}function VR(r){var e=oZ(r);return e.dimNameMap||(e.dimNameMap=FR(r.dimensionsDefine))}function GR(r){return r>30}var tc=Vt,ji=ft,lZ=typeof Int32Array>"u"?Array:Int32Array,uZ="e\0\0",ZT=-1,cZ=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],hZ=["_approximateExtent"],YT,dv,ec,rc,dm,nc,pm,Kr=function(){function r(e,t){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","minmaxDownSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","minmaxDownSample","lttbDownSample"];var n,a=!1;zR(e)?(n=e.dimensions,this._dimOmitted=e.isDimensionOmitted(),this._schema=e):(a=!0,n=e),n=n||["x","y"];for(var i={},o=[],s={},l=!1,u={},c=0;c<n.length;c++){var h=n[c],d=Lt(h)?new ad({name:h}):h instanceof ad?h:new ad(h),v=d.name;d.type=d.type||"float",d.coordDim||(d.coordDim=v,d.coordDimIndex=0);var p=d.otherDims=d.otherDims||{};o.push(v),i[v]=d,u[v]!=null&&(l=!0),d.createInvertedIndices&&(s[v]=[]),p.itemName===0&&(this._nameDimIdx=c),p.itemId===0&&(this._idDimIdx=c),a&&(d.storeDimIndex=c)}if(this.dimensions=o,this._dimInfos=i,this._initGetDimensionInfo(l),this.hostModel=t,this._invertedIndicesMap=s,this._dimOmitted){var y=this._dimIdxToName=Pt();B(o,function(_){y.set(i[_].storeDimIndex,_)})}}return r.prototype.getDimension=function(e){var t=this._recognizeDimIndex(e);if(t==null)return e;if(t=e,!this._dimOmitted)return this.dimensions[t];var n=this._dimIdxToName.get(t);if(n!=null)return n;var a=this._schema.getSourceDimension(t);if(a)return a.name},r.prototype.getDimensionIndex=function(e){var t=this._recognizeDimIndex(e);if(t!=null)return t;if(e==null)return-1;var n=this._getDimInfo(e);return n?n.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(e):-1},r.prototype._recognizeDimIndex=function(e){if(ye(e)||e!=null&&!isNaN(e)&&!this._getDimInfo(e)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(e)<0))return+e},r.prototype._getStoreDimIndex=function(e){var t=this.getDimensionIndex(e);return t},r.prototype.getDimensionInfo=function(e){return this._getDimInfo(this.getDimension(e))},r.prototype._initGetDimensionInfo=function(e){var t=this._dimInfos;this._getDimInfo=e?function(n){return t.hasOwnProperty(n)?t[n]:void 0}:function(n){return t[n]}},r.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},r.prototype.mapDimension=function(e,t){var n=this._dimSummary;if(t==null)return n.encodeFirstDimNotExtra[e];var a=n.encode[e];return a?a[t]:null},r.prototype.mapDimensionsAll=function(e){var t=this._dimSummary,n=t.encode[e];return(n||[]).slice()},r.prototype.getStore=function(){return this._store},r.prototype.initData=function(e,t,n){var a=this,i;if(e instanceof D_&&(i=e),!i){var o=this.dimensions,s=_w(e)||Gr(e)?new Vk(e,o.length):e;i=new D_;var l=ji(o,function(u){return{type:a._dimInfos[u].type,property:u}});i.initData(s,l,n)}this._store=i,this._nameList=(t||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,i.count()),this._dimSummary=aZ(this,this._schema),this.userOutput=this._dimSummary.userOutput},r.prototype.appendData=function(e){var t=this._store.appendData(e);this._doInit(t[0],t[1])},r.prototype.appendValues=function(e,t){var n=this._store.appendValues(e,t&&t.length),a=n.start,i=n.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),t)for(var s=a;s<i;s++){var l=s-a;this._nameList[s]=t[l],o&&pm(this,s)}},r.prototype._updateOrdinalMeta=function(){for(var e=this._store,t=this.dimensions,n=0;n<t.length;n++){var a=this._dimInfos[t[n]];a.ordinalMeta&&e.collectOrdinalMeta(a.storeDimIndex,a.ordinalMeta)}},r.prototype._shouldMakeIdFromName=function(){var e=this._store.getProvider();return this._idDimIdx==null&&e.getSource().sourceFormat!==po&&!e.fillStorage},r.prototype._doInit=function(e,t){if(!(e>=t)){var n=this._store,a=n.getProvider();this._updateOrdinalMeta();var i=this._nameList,o=this._idList,s=a.getSource().sourceFormat,l=s===ra;if(l&&!a.pure)for(var u=[],c=e;c<t;c++){var h=a.getItem(c,u);if(!this.hasItemOption&&X8(h)&&(this.hasItemOption=!0),h){var d=h.name;i[c]==null&&d!=null&&(i[c]=ur(d,null));var v=h.id;o[c]==null&&v!=null&&(o[c]=ur(v,null))}}if(this._shouldMakeIdFromName())for(var c=e;c<t;c++)pm(this,c);YT(this)}},r.prototype.getApproximateExtent=function(e){return this._approximateExtent[e]||this._store.getDataExtent(this._getStoreDimIndex(e))},r.prototype.setApproximateExtent=function(e,t){t=this.getDimension(t),this._approximateExtent[t]=e.slice()},r.prototype.getCalculationInfo=function(e){return this._calculationInfo[e]},r.prototype.setCalculationInfo=function(e,t){tc(e)?lt(this._calculationInfo,e):this._calculationInfo[e]=t},r.prototype.getName=function(e){var t=this.getRawIndex(e),n=this._nameList[t];return n==null&&this._nameDimIdx!=null&&(n=ec(this,this._nameDimIdx,t)),n==null&&(n=""),n},r.prototype._getCategory=function(e,t){var n=this._store.get(e,t),a=this._store.getOrdinalMeta(e);return a?a.categories[n]:n},r.prototype.getId=function(e){return dv(this,this.getRawIndex(e))},r.prototype.count=function(){return this._store.count()},r.prototype.get=function(e,t){var n=this._store,a=this._dimInfos[e];if(a)return n.get(a.storeDimIndex,t)},r.prototype.getByRawIndex=function(e,t){var n=this._store,a=this._dimInfos[e];if(a)return n.getByRawIndex(a.storeDimIndex,t)},r.prototype.getIndices=function(){return this._store.getIndices()},r.prototype.getDataExtent=function(e){return this._store.getDataExtent(this._getStoreDimIndex(e))},r.prototype.getSum=function(e){return this._store.getSum(this._getStoreDimIndex(e))},r.prototype.getMedian=function(e){return this._store.getMedian(this._getStoreDimIndex(e))},r.prototype.getValues=function(e,t){var n=this,a=this._store;return ht(e)?a.getValues(ji(e,function(i){return n._getStoreDimIndex(i)}),t):a.getValues(e)},r.prototype.hasValue=function(e){for(var t=this._dimSummary.dataDimIndicesOnCoord,n=0,a=t.length;n<a;n++)if(isNaN(this._store.get(t[n],e)))return!1;return!0},r.prototype.indexOfName=function(e){for(var t=0,n=this._store.count();t<n;t++)if(this.getName(t)===e)return t;return-1},r.prototype.getRawIndex=function(e){return this._store.getRawIndex(e)},r.prototype.indexOfRawIndex=function(e){return this._store.indexOfRawIndex(e)},r.prototype.rawIndexOf=function(e,t){var n=e&&this._invertedIndicesMap[e],a=n&&n[t];return a==null||isNaN(a)?ZT:a},r.prototype.indicesOfNearest=function(e,t,n){return this._store.indicesOfNearest(this._getStoreDimIndex(e),t,n)},r.prototype.each=function(e,t,n){Nt(e)&&(n=t,t=e,e=[]);var a=n||this,i=ji(rc(e),this._getStoreDimIndex,this);this._store.each(i,a?Mt(t,a):t)},r.prototype.filterSelf=function(e,t,n){Nt(e)&&(n=t,t=e,e=[]);var a=n||this,i=ji(rc(e),this._getStoreDimIndex,this);return this._store=this._store.filter(i,a?Mt(t,a):t),this},r.prototype.selectRange=function(e){var t=this,n={},a=ue(e);return B(a,function(i){var o=t._getStoreDimIndex(i);n[o]=e[i]}),this._store=this._store.selectRange(n),this},r.prototype.mapArray=function(e,t,n){Nt(e)&&(n=t,t=e,e=[]),n=n||this;var a=[];return this.each(e,function(){a.push(t&&t.apply(this,arguments))},n),a},r.prototype.map=function(e,t,n,a){var i=n||a||this,o=ji(rc(e),this._getStoreDimIndex,this),s=nc(this);return s._store=this._store.map(o,i?Mt(t,i):t),s},r.prototype.modify=function(e,t,n,a){var i=n||a||this,o=ji(rc(e),this._getStoreDimIndex,this);this._store.modify(o,i?Mt(t,i):t)},r.prototype.downSample=function(e,t,n,a){var i=nc(this);return i._store=this._store.downSample(this._getStoreDimIndex(e),t,n,a),i},r.prototype.minmaxDownSample=function(e,t){var n=nc(this);return n._store=this._store.minmaxDownSample(this._getStoreDimIndex(e),t),n},r.prototype.lttbDownSample=function(e,t){var n=nc(this);return n._store=this._store.lttbDownSample(this._getStoreDimIndex(e),t),n},r.prototype.getRawDataItem=function(e){return this._store.getRawDataItem(e)},r.prototype.getItemModel=function(e){var t=this.hostModel,n=this.getRawDataItem(e);return new De(n,t,t&&t.ecModel)},r.prototype.diff=function(e){var t=this;return new Li(e?e.getStore().getIndices():[],this.getStore().getIndices(),function(n){return dv(e,n)},function(n){return dv(t,n)})},r.prototype.getVisual=function(e){var t=this._visual;return t&&t[e]},r.prototype.setVisual=function(e,t){this._visual=this._visual||{},tc(e)?lt(this._visual,e):this._visual[e]=t},r.prototype.getItemVisual=function(e,t){var n=this._itemVisuals[e],a=n&&n[t];return a??this.getVisual(t)},r.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},r.prototype.ensureUniqueItemVisual=function(e,t){var n=this._itemVisuals,a=n[e];a||(a=n[e]={});var i=a[t];return i==null&&(i=this.getVisual(t),ht(i)?i=i.slice():tc(i)&&(i=lt({},i)),a[t]=i),i},r.prototype.setItemVisual=function(e,t,n){var a=this._itemVisuals[e]||{};this._itemVisuals[e]=a,tc(t)?lt(a,t):a[t]=n},r.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},r.prototype.setLayout=function(e,t){tc(e)?lt(this._layout,e):this._layout[e]=t},r.prototype.getLayout=function(e){return this._layout[e]},r.prototype.getItemLayout=function(e){return this._itemLayouts[e]},r.prototype.setItemLayout=function(e,t,n){this._itemLayouts[e]=n?lt(this._itemLayouts[e]||{},t):t},r.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},r.prototype.setItemGraphicEl=function(e,t){var n=this.hostModel&&this.hostModel.seriesIndex;g_(n,this.dataType,e,t),this._graphicEls[e]=t},r.prototype.getItemGraphicEl=function(e){return this._graphicEls[e]},r.prototype.eachItemGraphicEl=function(e,t){B(this._graphicEls,function(n,a){n&&e&&e.call(t,n,a)})},r.prototype.cloneShallow=function(e){return e||(e=new r(this._schema?this._schema:ji(this.dimensions,this._getDimInfo,this),this.hostModel)),dm(e,this),e._store=this._store,e},r.prototype.wrapMethod=function(e,t){var n=this[e];Nt(n)&&(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(e),this[e]=function(){var a=n.apply(this,arguments);return t.apply(this,[a].concat(F1(arguments)))})},r.internalField=function(){YT=function(e){var t=e._invertedIndicesMap;B(t,function(n,a){var i=e._dimInfos[a],o=i.ordinalMeta,s=e._store;if(o){n=t[a]=new lZ(o.categories.length);for(var l=0;l<n.length;l++)n[l]=ZT;for(var l=0;l<s.count();l++)n[s.get(i.storeDimIndex,l)]=l}})},ec=function(e,t,n){return ur(e._getCategory(t,n),null)},dv=function(e,t){var n=e._idList[t];return n==null&&e._idDimIdx!=null&&(n=ec(e,e._idDimIdx,t)),n==null&&(n=uZ+t),n},rc=function(e){return ht(e)||(e=e!=null?[e]:[]),e},nc=function(e){var t=new r(e._schema?e._schema:ji(e.dimensions,e._getDimInfo,e),e.hostModel);return dm(t,e),t},dm=function(e,t){B(cZ.concat(t.__wrappedMethods||[]),function(n){t.hasOwnProperty(n)&&(e[n]=t[n])}),e.__wrappedMethods=t.__wrappedMethods,B(hZ,function(n){e[n]=Gt(t[n])}),e._calculationInfo=lt({},t._calculationInfo)},pm=function(e,t){var n=e._nameList,a=e._idList,i=e._nameDimIdx,o=e._idDimIdx,s=n[t],l=a[t];if(s==null&&i!=null&&(n[t]=s=ec(e,i,t)),l==null&&o!=null&&(a[t]=l=ec(e,o,t)),l==null&&s!=null){var u=e._nameRepeatCount,c=u[s]=(u[s]||0)+1;l=s,c>1&&(l+="__ec__"+c),a[t]=l}}}(),r}();function Oh(r,e){_w(r)||(r=ww(r)),e=e||{};var t=e.coordDimensions||[],n=e.dimensionsDefine||r.dimensionsDefine||[],a=Pt(),i=[],o=vZ(r,t,n,e.dimensionsCount),s=e.canOmitUnusedDimensions&&GR(o),l=n===r.dimensionsDefine,u=l?VR(r):FR(n),c=e.encodeDefine;!c&&e.encodeDefaulter&&(c=e.encodeDefaulter(r,o));for(var h=Pt(c),d=new $k(o),v=0;v<d.length;v++)d[v]=-1;function p(M){var I=d[M];if(I<0){var R=n[M],P=Vt(R)?R:{name:R},E=new ad,D=P.name;D!=null&&u.get(D)!=null&&(E.name=E.displayName=D),P.type!=null&&(E.type=P.type),P.displayName!=null&&(E.displayName=P.displayName);var N=i.length;return d[M]=N,E.storeDimIndex=M,i.push(E),E}return i[I]}if(!s)for(var v=0;v<o;v++)p(v);h.each(function(M,I){var R=Ie(M).slice();if(R.length===1&&!Lt(R[0])&&R[0]<0){h.set(I,!1);return}var P=h.set(I,[]);B(R,function(E,D){var N=Lt(E)?u.get(E):E;N!=null&&N<o&&(P[D]=N,_(p(N),I,D))})});var y=0;B(t,function(M){var I,R,P,E;if(Lt(M))I=M,E={};else{E=M,I=E.name;var D=E.ordinalMeta;E.ordinalMeta=null,E=lt({},E),E.ordinalMeta=D,R=E.dimsDef,P=E.otherDims,E.name=E.coordDim=E.coordDimIndex=E.dimsDef=E.otherDims=null}var N=h.get(I);if(N!==!1){if(N=Ie(N),!N.length)for(var V=0;V<(R&&R.length||1);V++){for(;y<o&&p(y).coordDim!=null;)y++;y<o&&N.push(y++)}B(N,function(W,$){var H=p(W);if(l&&E.type!=null&&(H.type=E.type),_(zt(H,E),I,$),H.name==null&&R){var K=R[$];!Vt(K)&&(K={name:K}),H.name=H.displayName=K.name,H.defaultTooltip=K.defaultTooltip}P&&zt(H.otherDims,P)})}});function _(M,I,R){Mk.get(I)!=null?M.otherDims[I]=R:(M.coordDim=I,M.coordDimIndex=R,a.set(I,!0))}var g=e.generateCoord,f=e.generateCoordCount,w=f!=null;f=g?f||1:0;var x=g||"value";function S(M){M.name==null&&(M.name=M.coordDim)}if(s)B(i,function(M){S(M)}),i.sort(function(M,I){return M.storeDimIndex-I.storeDimIndex});else for(var A=0;A<o;A++){var T=p(A),L=T.coordDim;L==null&&(T.coordDim=dZ(x,a,w),T.coordDimIndex=0,(!g||f<=0)&&(T.isExtraCoord=!0),f--),S(T),T.type==null&&(kk(r,A)===Ir.Must||T.isExtraCoord&&(T.otherDims.itemName!=null||T.otherDims.seriesName!=null))&&(T.type="ordinal")}return fZ(i),new NR({source:r,dimensions:i,fullDimensionCount:o,dimensionOmitted:s})}function fZ(r){for(var e=Pt(),t=0;t<r.length;t++){var n=r[t],a=n.name,i=e.get(a)||0;i>0&&(n.name=a+(i-1)),i++,e.set(a,i)}}function vZ(r,e,t,n){var a=Math.max(r.dimensionsDetectedCount||1,e.length,t.length,n||0);return B(e,function(i){var o;Vt(i)&&(o=i.dimsDef)&&(a=Math.max(a,o.length))}),a}function dZ(r,e,t){if(t||e.hasKey(r)){for(var n=0;e.hasKey(r+n);)n++;r+=n}return e.set(r,!0),r}var pZ=function(){function r(e){this.coordSysDims=[],this.axisMap=Pt(),this.categoryAxisMap=Pt(),this.coordSysName=e}return r}();function gZ(r){var e=r.get("coordinateSystem"),t=new pZ(e),n=yZ[e];if(n)return n(r,t,t.axisMap,t.categoryAxisMap),t}var yZ={cartesian2d:function(r,e,t,n){var a=r.getReferringComponents("xAxis",ir).models[0],i=r.getReferringComponents("yAxis",ir).models[0];e.coordSysDims=["x","y"],t.set("x",a),t.set("y",i),Al(a)&&(n.set("x",a),e.firstCategoryDimIndex=0),Al(i)&&(n.set("y",i),e.firstCategoryDimIndex==null&&(e.firstCategoryDimIndex=1))},singleAxis:function(r,e,t,n){var a=r.getReferringComponents("singleAxis",ir).models[0];e.coordSysDims=["single"],t.set("single",a),Al(a)&&(n.set("single",a),e.firstCategoryDimIndex=0)},polar:function(r,e,t,n){var a=r.getReferringComponents("polar",ir).models[0],i=a.findAxisModel("radiusAxis"),o=a.findAxisModel("angleAxis");e.coordSysDims=["radius","angle"],t.set("radius",i),t.set("angle",o),Al(i)&&(n.set("radius",i),e.firstCategoryDimIndex=0),Al(o)&&(n.set("angle",o),e.firstCategoryDimIndex==null&&(e.firstCategoryDimIndex=1))},geo:function(r,e,t,n){e.coordSysDims=["lng","lat"]},parallel:function(r,e,t,n){var a=r.ecModel,i=a.getComponent("parallel",r.get("parallelIndex")),o=e.coordSysDims=i.dimensions.slice();B(i.parallelAxisIndex,function(s,l){var u=a.getComponent("parallelAxis",s),c=o[l];t.set(c,u),Al(u)&&(n.set(c,u),e.firstCategoryDimIndex==null&&(e.firstCategoryDimIndex=l))})}};function Al(r){return r.get("type")==="category"}function mZ(r,e,t){t=t||{};var n=t.byIndex,a=t.stackedCoordDimension,i,o,s;_Z(e)?i=e:(o=e.schema,i=o.dimensions,s=e.store);var l=!!(r&&r.get("stack")),u,c,h,d;if(B(i,function(f,w){Lt(f)&&(i[w]=f={name:f}),l&&!f.isExtraCoord&&(!n&&!u&&f.ordinalMeta&&(u=f),!c&&f.type!=="ordinal"&&f.type!=="time"&&(!a||a===f.coordDim)&&(c=f))}),c&&!n&&!u&&(n=!0),c){h="__\0ecstackresult_"+r.id,d="__\0ecstackedover_"+r.id,u&&(u.createInvertedIndices=!0);var v=c.coordDim,p=c.type,y=0;B(i,function(f){f.coordDim===v&&y++});var _={name:h,coordDim:v,coordDimIndex:y,type:p,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:i.length},g={name:d,coordDim:d,coordDimIndex:y+1,type:p,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:i.length+1};o?(s&&(_.storeDimIndex=s.ensureCalculationDimension(d,p),g.storeDimIndex=s.ensureCalculationDimension(h,p)),o.appendCalculationDimension(_),o.appendCalculationDimension(g)):(i.push(_),i.push(g))}return{stackedDimension:c&&c.name,stackedByDimension:u&&u.name,isStackedByIndex:n,stackedOverDimension:d,stackResultDimension:h}}function _Z(r){return!zR(r.schema)}function So(r,e){return!!e&&e===r.getCalculationInfo("stackedDimension")}function WR(r,e){return So(r,e)?r.getCalculationInfo("stackResultDimension"):e}function wZ(r,e){var t=r.get("coordinateSystem"),n=Rh.get(t),a;return e&&e.coordSysDims&&(a=ft(e.coordSysDims,function(i){var o={name:i},s=e.axisMap.get(i);if(s){var l=s.get("type");o.type=Nd(l)}return o})),a||(a=n&&(n.getDimensionsInfo?n.getDimensionsInfo():n.dimensions.slice())||["x","y"]),a}function xZ(r,e,t){var n,a;return t&&B(r,function(i,o){var s=i.coordDim,l=t.categoryAxisMap.get(s);l&&(n==null&&(n=o),i.ordinalMeta=l.getOrdinalMeta(),e&&(i.createInvertedIndices=!0)),i.otherDims.itemName!=null&&(a=!0)}),!a&&n!=null&&(r[n].otherDims.itemName=0),n}function Ri(r,e,t){t=t||{};var n=e.getSourceManager(),a,i=!1;r?(i=!0,a=ww(r)):(a=n.getSource(),i=a.sourceFormat===ra);var o=gZ(e),s=wZ(e,o),l=t.useEncodeDefaulter,u=Nt(l)?l:l?Xt(Pk,s,e):null,c={coordDimensions:s,generateCoord:t.generateCoord,encodeDefine:e.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!i},h=Oh(a,c),d=xZ(h.dimensions,t.createInvertedIndices,o),v=i?null:n.getSharedDataStore(h),p=mZ(e,{schema:h,store:v}),y=new Kr(h,e);y.setCalculationInfo(p);var _=d!=null&&bZ(a)?function(g,f,w,x){return x===d?w:this.defaultDimValueGetter(g,f,w,x)}:null;return y.hasItemOption=!1,y.initData(i?a:v,null,_),y}function bZ(r){if(r.sourceFormat===ra){var e=SZ(r.data||[]);return!ht(hu(e))}}function SZ(r){for(var e=0;e<r.length&&r[e]==null;)e++;return r[e]}var Ja=function(){function r(e){this._setting=e||{},this._extent=[1/0,-1/0]}return r.prototype.getSetting=function(e){return this._setting[e]},r.prototype.unionExtent=function(e){var t=this._extent;e[0]<t[0]&&(t[0]=e[0]),e[1]>t[1]&&(t[1]=e[1])},r.prototype.unionExtentFromData=function(e,t){this.unionExtent(e.getApproximateExtent(t))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.setExtent=function(e,t){var n=this._extent;isNaN(e)||(n[0]=e),isNaN(t)||(n[1]=t)},r.prototype.isInExtentRange=function(e){return this._extent[0]<=e&&this._extent[1]>=e},r.prototype.isBlank=function(){return this._isBlank},r.prototype.setBlank=function(e){this._isBlank=e},r}();yp(Ja);var AZ=0,F_=function(){function r(e){this.categories=e.categories||[],this._needCollect=e.needCollect,this._deduplication=e.deduplication,this.uid=++AZ}return r.createByAxisModel=function(e){var t=e.option,n=t.data,a=n&&ft(n,TZ);return new r({categories:a,needCollect:!a,deduplication:t.dedplication!==!1})},r.prototype.getOrdinal=function(e){return this._getOrCreateMap().get(e)},r.prototype.parseAndCollect=function(e){var t,n=this._needCollect;if(!Lt(e)&&!n)return e;if(n&&!this._deduplication)return t=this.categories.length,this.categories[t]=e,t;var a=this._getOrCreateMap();return t=a.get(e),t==null&&(n?(t=this.categories.length,this.categories[t]=e,a.set(e,t)):t=NaN),t},r.prototype._getOrCreateMap=function(){return this._map||(this._map=Pt(this.categories))},r}();function TZ(r){return Vt(r)&&r.value!=null?r.value:r+""}function V_(r){return r.type==="interval"||r.type==="log"}function CZ(r,e,t,n){var a={},i=r[1]-r[0],o=a.interval=gP(i/e);t!=null&&o<t&&(o=a.interval=t),n!=null&&o>n&&(o=a.interval=n);var s=a.intervalPrecision=HR(o),l=a.niceTickExtent=[qe(Math.ceil(r[0]/o)*o,s),qe(Math.floor(r[1]/o)*o,s)];return LZ(l,r),a}function gm(r){var e=Math.pow(10,X1(r)),t=r/e;return t?t===2?t=3:t===3?t=5:t*=2:t=1,qe(t*e)}function HR(r){return Fa(r)+2}function XT(r,e,t){r[e]=Math.max(Math.min(r[e],t[1]),t[0])}function LZ(r,e){!isFinite(r[0])&&(r[0]=e[0]),!isFinite(r[1])&&(r[1]=e[1]),XT(r,0,e),XT(r,1,e),r[0]>r[1]&&(r[0]=r[1])}function zp(r,e){return r>=e[0]&&r<=e[1]}function Fp(r,e){return e[1]===e[0]?.5:(r-e[0])/(e[1]-e[0])}function Vp(r,e){return r*(e[1]-e[0])+e[0]}var Gp=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;n.type="ordinal";var a=n.getSetting("ordinalMeta");return a||(a=new F_({})),ht(a)&&(a=new F_({categories:ft(a,function(i){return Vt(i)?i.value:i})})),n._ordinalMeta=a,n._extent=n.getSetting("extent")||[0,a.categories.length-1],n}return e.prototype.parse=function(t){return t==null?NaN:Lt(t)?this._ordinalMeta.getOrdinal(t):Math.round(t)},e.prototype.contain=function(t){return t=this.parse(t),zp(t,this._extent)&&this._ordinalMeta.categories[t]!=null},e.prototype.normalize=function(t){return t=this._getTickNumber(this.parse(t)),Fp(t,this._extent)},e.prototype.scale=function(t){return t=Math.round(Vp(t,this._extent)),this.getRawOrdinalNumber(t)},e.prototype.getTicks=function(){for(var t=[],n=this._extent,a=n[0];a<=n[1];)t.push({value:a}),a++;return t},e.prototype.getMinorTicks=function(t){},e.prototype.setSortInfo=function(t){if(t==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var n=t.ordinalNumbers,a=this._ordinalNumbersByTick=[],i=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,n.length);o<l;++o){var u=n[o];a[o]=u,i[u]=o}for(var c=0;o<s;++o){for(;i[c]!=null;)c++;a.push(c),i[c]=o}},e.prototype._getTickNumber=function(t){var n=this._ticksByOrdinalNumber;return n&&t>=0&&t<n.length?n[t]:t},e.prototype.getRawOrdinalNumber=function(t){var n=this._ordinalNumbersByTick;return n&&t>=0&&t<n.length?n[t]:t},e.prototype.getLabel=function(t){if(!this.isBlank()){var n=this.getRawOrdinalNumber(t.value),a=this._ordinalMeta.categories[n];return a==null?"":a+""}},e.prototype.count=function(){return this._extent[1]-this._extent[0]+1},e.prototype.unionExtentFromData=function(t,n){this.unionExtent(t.getApproximateExtent(n))},e.prototype.isInExtentRange=function(t){return t=this._getTickNumber(t),this._extent[0]<=t&&this._extent[1]>=t},e.prototype.getOrdinalMeta=function(){return this._ordinalMeta},e.prototype.calcNiceTicks=function(){},e.prototype.calcNiceExtent=function(){},e.type="ordinal",e}(Ja);Ja.registerClass(Gp);var ns=qe,Mi=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="interval",t._interval=0,t._intervalPrecision=2,t}return e.prototype.parse=function(t){return t},e.prototype.contain=function(t){return zp(t,this._extent)},e.prototype.normalize=function(t){return Fp(t,this._extent)},e.prototype.scale=function(t){return Vp(t,this._extent)},e.prototype.setExtent=function(t,n){var a=this._extent;isNaN(t)||(a[0]=parseFloat(t)),isNaN(n)||(a[1]=parseFloat(n))},e.prototype.unionExtent=function(t){var n=this._extent;t[0]<n[0]&&(n[0]=t[0]),t[1]>n[1]&&(n[1]=t[1]),this.setExtent(n[0],n[1])},e.prototype.getInterval=function(){return this._interval},e.prototype.setInterval=function(t){this._interval=t,this._niceExtent=this._extent.slice(),this._intervalPrecision=HR(t)},e.prototype.getTicks=function(t){var n=this._interval,a=this._extent,i=this._niceExtent,o=this._intervalPrecision,s=[];if(!n)return s;var l=1e4;a[0]<i[0]&&(t?s.push({value:ns(i[0]-n,o)}):s.push({value:a[0]}));for(var u=i[0];u<=i[1]&&(s.push({value:u}),u=ns(u+n,o),u!==s[s.length-1].value);)if(s.length>l)return[];var c=s.length?s[s.length-1].value:i[1];return a[1]>c&&(t?s.push({value:ns(c+n,o)}):s.push({value:a[1]})),s},e.prototype.getMinorTicks=function(t){for(var n=this.getTicks(!0),a=[],i=this.getExtent(),o=1;o<n.length;o++){for(var s=n[o],l=n[o-1],u=0,c=[],h=s.value-l.value,d=h/t;u<t-1;){var v=ns(l.value+(u+1)*d);v>i[0]&&v<i[1]&&c.push(v),u++}a.push(c)}return a},e.prototype.getLabel=function(t,n){if(t==null)return"";var a=n&&n.precision;a==null?a=Fa(t.value)||0:a==="auto"&&(a=this._intervalPrecision);var i=ns(t.value,a,!0);return bk(i)},e.prototype.calcNiceTicks=function(t,n,a){t=t||5;var i=this._extent,o=i[1]-i[0];if(isFinite(o)){o<0&&(o=-o,i.reverse());var s=CZ(i,t,n,a);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},e.prototype.calcNiceExtent=function(t){var n=this._extent;if(n[0]===n[1])if(n[0]!==0){var a=Math.abs(n[0]);t.fixMax||(n[1]+=a/2),n[0]-=a/2}else n[1]=1;var i=n[1]-n[0];isFinite(i)||(n[0]=0,n[1]=1),this.calcNiceTicks(t.splitNumber,t.minInterval,t.maxInterval);var o=this._interval;t.fixMin||(n[0]=ns(Math.floor(n[0]/o)*o)),t.fixMax||(n[1]=ns(Math.ceil(n[1]/o)*o))},e.prototype.setNiceExtent=function(t,n){this._niceExtent=[t,n]},e.type="interval",e}(Ja);Ja.registerClass(Mi);var UR=typeof Float32Array<"u",MZ=UR?Float32Array:Array;function Ga(r){return ht(r)?UR?new Float32Array(r):r:new MZ(r)}var G_="__ec_stack_";function ZR(r){return r.get("stack")||G_+r.seriesIndex}function Pw(r){return r.dim+r.index}function DZ(r){var e=[],t=r.axis,n="axis0";if(t.type==="category"){for(var a=t.getBandWidth(),i=0;i<r.count;i++)e.push(zt({bandWidth:a,axisKey:n,stackId:G_+i},r));for(var o=$R(e),s=[],i=0;i<r.count;i++){var l=o[n][G_+i];l.offsetCenter=l.offset+l.width/2,s.push(l)}return s}}function YR(r,e){var t=[];return e.eachSeriesByType(r,function(n){KR(n)&&t.push(n)}),t}function IZ(r){var e={};B(r,function(l){var u=l.coordinateSystem,c=u.getBaseAxis();if(!(c.type!=="time"&&c.type!=="value"))for(var h=l.getData(),d=c.dim+"_"+c.index,v=h.getDimensionIndex(h.mapDimension(c.dim)),p=h.getStore(),y=0,_=p.count();y<_;++y){var g=p.get(v,y);e[d]?e[d].push(g):e[d]=[g]}});var t={};for(var n in e)if(e.hasOwnProperty(n)){var a=e[n];if(a){a.sort(function(l,u){return l-u});for(var i=null,o=1;o<a.length;++o){var s=a[o]-a[o-1];s>0&&(i=i===null?s:Math.min(i,s))}t[n]=i}}return t}function XR(r){var e=IZ(r),t=[];return B(r,function(n){var a=n.coordinateSystem,i=a.getBaseAxis(),o=i.getExtent(),s;if(i.type==="category")s=i.getBandWidth();else if(i.type==="value"||i.type==="time"){var l=i.dim+"_"+i.index,u=e[l],c=Math.abs(o[1]-o[0]),h=i.scale.getExtent(),d=Math.abs(h[1]-h[0]);s=u?c/d*u:c}else{var v=n.getData();s=Math.abs(o[1]-o[0])/v.count()}var p=At(n.get("barWidth"),s),y=At(n.get("barMaxWidth"),s),_=At(n.get("barMinWidth")||(QR(n)?.5:1),s),g=n.get("barGap"),f=n.get("barCategoryGap");t.push({bandWidth:s,barWidth:p,barMaxWidth:y,barMinWidth:_,barGap:g,barCategoryGap:f,axisKey:Pw(i),stackId:ZR(n)})}),$R(t)}function $R(r){var e={};B(r,function(n,a){var i=n.axisKey,o=n.bandWidth,s=e[i]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:"20%",stacks:{}},l=s.stacks;e[i]=s;var u=n.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var c=n.barWidth;c&&!l[u].width&&(l[u].width=c,c=Math.min(s.remainedWidth,c),s.remainedWidth-=c);var h=n.barMaxWidth;h&&(l[u].maxWidth=h);var d=n.barMinWidth;d&&(l[u].minWidth=d);var v=n.barGap;v!=null&&(s.gap=v);var p=n.barCategoryGap;p!=null&&(s.categoryGap=p)});var t={};return B(e,function(n,a){t[a]={};var i=n.stacks,o=n.bandWidth,s=n.categoryGap;if(s==null){var l=ue(i).length;s=Math.max(35-l*4,15)+"%"}var u=At(s,o),c=At(n.gap,1),h=n.remainedWidth,d=n.autoWidthCount,v=(h-u)/(d+(d-1)*c);v=Math.max(v,0),B(i,function(g){var f=g.maxWidth,w=g.minWidth;if(g.width){var x=g.width;f&&(x=Math.min(x,f)),w&&(x=Math.max(x,w)),g.width=x,h-=x+c*x,d--}else{var x=v;f&&f<x&&(x=Math.min(f,h)),w&&w>x&&(x=w),x!==v&&(g.width=x,h-=x+c*x,d--)}}),v=(h-u)/(d+(d-1)*c),v=Math.max(v,0);var p=0,y;B(i,function(g,f){g.width||(g.width=v),y=g,p+=g.width*(1+c)}),y&&(p-=y.width*c);var _=-p/2;B(i,function(g,f){t[a][f]=t[a][f]||{bandWidth:o,offset:_,width:g.width},_+=g.width*(1+c)})}),t}function PZ(r,e,t){if(r&&e){var n=r[Pw(e)];return n}}function jR(r,e){var t=YR(r,e),n=XR(t);B(t,function(a){var i=a.getData(),o=a.coordinateSystem,s=o.getBaseAxis(),l=ZR(a),u=n[Pw(s)][l],c=u.offset,h=u.width;i.setLayout({bandWidth:u.bandWidth,offset:c,size:h})})}function qR(r){return{seriesType:r,plan:_u(),reset:function(e){if(KR(e)){var t=e.getData(),n=e.coordinateSystem,a=n.getBaseAxis(),i=n.getOtherAxis(a),o=t.getDimensionIndex(t.mapDimension(i.dim)),s=t.getDimensionIndex(t.mapDimension(a.dim)),l=e.get("showBackground",!0),u=t.mapDimension(i.dim),c=t.getCalculationInfo("stackResultDimension"),h=So(t,u)&&!!t.getCalculationInfo("stackedOnSeries"),d=i.isHorizontal(),v=kZ(a,i),p=QR(e),y=e.get("barMinHeight")||0,_=c&&t.getDimensionIndex(c),g=t.getLayout("size"),f=t.getLayout("offset");return{progress:function(w,x){for(var S=w.count,A=p&&Ga(S*3),T=p&&l&&Ga(S*3),L=p&&Ga(S),M=n.master.getRect(),I=d?M.width:M.height,R,P=x.getStore(),E=0;(R=w.next())!=null;){var D=P.get(h?_:o,R),N=P.get(s,R),V=v,W=void 0;h&&(W=+D-P.get(o,R));var $=void 0,H=void 0,K=void 0,U=void 0;if(d){var j=n.dataToPoint([D,N]);if(h){var ut=n.dataToPoint([W,N]);V=ut[0]}$=V,H=j[1]+f,K=j[0]-V,U=g,Math.abs(K)<y&&(K=(K<0?-1:1)*y)}else{var j=n.dataToPoint([N,D]);if(h){var ut=n.dataToPoint([N,W]);V=ut[1]}$=j[0]+f,H=V,K=g,U=j[1]-V,Math.abs(U)<y&&(U=(U<=0?-1:1)*y)}p?(A[E]=$,A[E+1]=H,A[E+2]=d?K:U,T&&(T[E]=d?M.x:$,T[E+1]=d?H:M.y,T[E+2]=I),L[R]=R):x.setItemLayout(R,{x:$,y:H,width:K,height:U}),E+=3}p&&x.setLayout({largePoints:A,largeDataIndices:L,largeBackgroundPoints:T,valueAxisHorizontal:d})}}}}}}function KR(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function QR(r){return r.pipelineContext&&r.pipelineContext.large}function kZ(r,e){var t=e.model.get("startValue");return t||(t=0),e.toGlobalCoord(e.dataToCoord(e.type==="log"?t>0?t:1:t))}var RZ=function(r,e,t,n){for(;t<n;){var a=t+n>>>1;r[a][1]<e?t=a+1:n=a}return t},kw=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="time",n}return e.prototype.getLabel=function(t){var n=this.getSetting("useUTC");return Mp(t.value,NA[vU($l(this._minLevelUnit))]||NA.second,n,this.getSetting("locale"))},e.prototype.getFormattedLabel=function(t,n,a){var i=this.getSetting("useUTC"),o=this.getSetting("locale");return dU(t,n,a,o,i)},e.prototype.getTicks=function(){var t=this._interval,n=this._extent,a=[];if(!t)return a;a.push({value:n[0],level:0});var i=this.getSetting("useUTC"),o=VZ(this._minLevelUnit,this._approxInterval,i,n);return a=a.concat(o),a.push({value:n[1],level:0}),a},e.prototype.calcNiceExtent=function(t){var n=this._extent;if(n[0]===n[1]&&(n[0]-=Kn,n[1]+=Kn),n[1]===-1/0&&n[0]===1/0){var a=new Date;n[1]=+new Date(a.getFullYear(),a.getMonth(),a.getDate()),n[0]=n[1]-Kn}this.calcNiceTicks(t.splitNumber,t.minInterval,t.maxInterval)},e.prototype.calcNiceTicks=function(t,n,a){t=t||10;var i=this._extent,o=i[1]-i[0];this._approxInterval=o/t,n!=null&&this._approxInterval<n&&(this._approxInterval=n),a!=null&&this._approxInterval>a&&(this._approxInterval=a);var s=pv.length,l=Math.min(RZ(pv,this._approxInterval,0,s),s-1);this._interval=pv[l][1],this._minLevelUnit=pv[Math.max(l-1,0)][0]},e.prototype.parse=function(t){return ye(t)?t:+$a(t)},e.prototype.contain=function(t){return zp(this.parse(t),this._extent)},e.prototype.normalize=function(t){return Fp(this.parse(t),this._extent)},e.prototype.scale=function(t){return Vp(t,this._extent)},e.type="time",e}(Mi),pv=[["second",hw],["minute",fw],["hour",Vc],["quarter-day",Vc*6],["half-day",Vc*12],["day",Kn*1.2],["half-week",Kn*3.5],["week",Kn*7],["month",Kn*31],["quarter",Kn*95],["half-year",BA/2],["year",BA]];function EZ(r,e,t,n){var a=$a(e),i=$a(t),o=function(p){return zA(a,p,n)===zA(i,p,n)},s=function(){return o("year")},l=function(){return s()&&o("month")},u=function(){return l()&&o("day")},c=function(){return u()&&o("hour")},h=function(){return c()&&o("minute")},d=function(){return h()&&o("second")},v=function(){return d()&&o("millisecond")};switch(r){case"year":return s();case"month":return l();case"day":return u();case"hour":return c();case"minute":return h();case"second":return d();case"millisecond":return v()}}function OZ(r,e){return r/=Kn,r>16?16:r>7.5?7:r>3.5?4:r>1.5?2:1}function BZ(r){var e=30*Kn;return r/=e,r>6?6:r>3?3:r>2?2:1}function NZ(r){return r/=Vc,r>12?12:r>6?6:r>3.5?4:r>2?2:1}function $T(r,e){return r/=e?fw:hw,r>30?30:r>20?20:r>15?15:r>10?10:r>5?5:r>2?2:1}function zZ(r){return gP(r)}function FZ(r,e,t){var n=new Date(r);switch($l(e)){case"year":case"month":n[gk(t)](0);case"day":n[yk(t)](1);case"hour":n[mk(t)](0);case"minute":n[_k(t)](0);case"second":n[wk(t)](0),n[xk(t)](0)}return n.getTime()}function VZ(r,e,t,n){var a=1e4,i=dk,o=0;function s(I,R,P,E,D,N,V){for(var W=new Date(R),$=R,H=W[E]();$<P&&$<=n[1];)V.push({value:$}),H+=I,W[D](H),$=W.getTime();V.push({value:$,notAdd:!0})}function l(I,R,P){var E=[],D=!R.length;if(!EZ($l(I),n[0],n[1],t)){D&&(R=[{value:FZ(new Date(n[0]),I,t)},{value:n[1]}]);for(var N=0;N<R.length-1;N++){var V=R[N].value,W=R[N+1].value;if(V!==W){var $=void 0,H=void 0,K=void 0,U=!1;switch(I){case"year":$=Math.max(1,Math.round(e/Kn/365)),H=vw(t),K=pU(t);break;case"half-year":case"quarter":case"month":$=BZ(e),H=jl(t),K=gk(t);break;case"week":case"half-week":case"day":$=OZ(e),H=Dp(t),K=yk(t),U=!0;break;case"half-day":case"quarter-day":case"hour":$=NZ(e),H=nh(t),K=mk(t);break;case"minute":$=$T(e,!0),H=Ip(t),K=_k(t);break;case"second":$=$T(e,!1),H=Pp(t),K=wk(t);break;case"millisecond":$=zZ(e),H=kp(t),K=xk(t);break}s($,V,W,H,K,U,E),I==="year"&&P.length>1&&N===0&&P.unshift({value:P[0].value-$})}}for(var N=0;N<E.length;N++)P.push(E[N]);return E}}for(var u=[],c=[],h=0,d=0,v=0;v<i.length&&o++<a;++v){var p=$l(i[v]);if(fU(i[v])){l(i[v],u[u.length-1]||[],c);var y=i[v+1]?$l(i[v+1]):null;if(p!==y){if(c.length){d=h,c.sort(function(I,R){return I.value-R.value});for(var _=[],g=0;g<c.length;++g){var f=c[g].value;(g===0||c[g-1].value!==f)&&(_.push(c[g]),f>=n[0]&&f<=n[1]&&h++)}var w=(n[1]-n[0])/e;if(h>w*1.5&&d>w/1.5||(u.push(_),h>w||r===i[v]))break}c=[]}}}for(var x=Te(ft(u,function(I){return Te(I,function(R){return R.value>=n[0]&&R.value<=n[1]&&!R.notAdd})}),function(I){return I.length>0}),S=[],A=x.length-1,v=0;v<x.length;++v)for(var T=x[v],L=0;L<T.length;++L)S.push({value:T[L].value,level:A-v});S.sort(function(I,R){return I.value-R.value});for(var M=[],v=0;v<S.length;++v)(v===0||S[v].value!==S[v-1].value)&&M.push(S[v]);return M}Ja.registerClass(kw);var jT=Ja.prototype,Uc=Mi.prototype,GZ=qe,WZ=Math.floor,HZ=Math.ceil,gv=Math.pow,ca=Math.log,Rw=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="log",t.base=10,t._originalScale=new Mi,t._interval=0,t}return e.prototype.getTicks=function(t){var n=this._originalScale,a=this._extent,i=n.getExtent(),o=Uc.getTicks.call(this,t);return ft(o,function(s){var l=s.value,u=qe(gv(this.base,l));return u=l===a[0]&&this._fixMin?yv(u,i[0]):u,u=l===a[1]&&this._fixMax?yv(u,i[1]):u,{value:u}},this)},e.prototype.setExtent=function(t,n){var a=ca(this.base);t=ca(Math.max(0,t))/a,n=ca(Math.max(0,n))/a,Uc.setExtent.call(this,t,n)},e.prototype.getExtent=function(){var t=this.base,n=jT.getExtent.call(this);n[0]=gv(t,n[0]),n[1]=gv(t,n[1]);var a=this._originalScale,i=a.getExtent();return this._fixMin&&(n[0]=yv(n[0],i[0])),this._fixMax&&(n[1]=yv(n[1],i[1])),n},e.prototype.unionExtent=function(t){this._originalScale.unionExtent(t);var n=this.base;t[0]=ca(t[0])/ca(n),t[1]=ca(t[1])/ca(n),jT.unionExtent.call(this,t)},e.prototype.unionExtentFromData=function(t,n){this.unionExtent(t.getApproximateExtent(n))},e.prototype.calcNiceTicks=function(t){t=t||10;var n=this._extent,a=n[1]-n[0];if(!(a===1/0||a<=0)){var i=Y8(a),o=t/a*i;for(o<=.5&&(i*=10);!isNaN(i)&&Math.abs(i)<1&&Math.abs(i)>0;)i*=10;var s=[qe(HZ(n[0]/i)*i),qe(WZ(n[1]/i)*i)];this._interval=i,this._niceExtent=s}},e.prototype.calcNiceExtent=function(t){Uc.calcNiceExtent.call(this,t),this._fixMin=t.fixMin,this._fixMax=t.fixMax},e.prototype.parse=function(t){return t},e.prototype.contain=function(t){return t=ca(t)/ca(this.base),zp(t,this._extent)},e.prototype.normalize=function(t){return t=ca(t)/ca(this.base),Fp(t,this._extent)},e.prototype.scale=function(t){return t=Vp(t,this._extent),gv(this.base,t)},e.type="log",e}(Ja),JR=Rw.prototype;JR.getMinorTicks=Uc.getMinorTicks;JR.getLabel=Uc.getLabel;function yv(r,e){return GZ(r,Fa(e))}Ja.registerClass(Rw);var UZ=function(){function r(e,t,n){this._prepareParams(e,t,n)}return r.prototype._prepareParams=function(e,t,n){n[1]<n[0]&&(n=[NaN,NaN]),this._dataMin=n[0],this._dataMax=n[1];var a=this._isOrdinal=e.type==="ordinal";this._needCrossZero=e.type==="interval"&&t.getNeedCrossZero&&t.getNeedCrossZero();var i=t.get("min",!0);i==null&&(i=t.get("startValue",!0));var o=this._modelMinRaw=i;Nt(o)?this._modelMinNum=mv(e,o({min:n[0],max:n[1]})):o!=="dataMin"&&(this._modelMinNum=mv(e,o));var s=this._modelMaxRaw=t.get("max",!0);if(Nt(s)?this._modelMaxNum=mv(e,s({min:n[0],max:n[1]})):s!=="dataMax"&&(this._modelMaxNum=mv(e,s)),a)this._axisDataLen=t.getCategories().length;else{var l=t.get("boundaryGap"),u=ht(l)?l:[l||0,l||0];typeof u[0]=="boolean"||typeof u[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[wa(u[0],1),wa(u[1],1)]}},r.prototype.calculate=function(){var e=this._isOrdinal,t=this._dataMin,n=this._dataMax,a=this._axisDataLen,i=this._boundaryGapInner,o=e?null:n-t||Math.abs(t),s=this._modelMinRaw==="dataMin"?t:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?n:this._modelMaxNum,u=s!=null,c=l!=null;s==null&&(s=e?a?0:NaN:t-i[0]*o),l==null&&(l=e?a?a-1:NaN:n+i[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var h=Xc(s)||Xc(l)||e&&!a;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!c&&(l=0));var d=this._determinedMin,v=this._determinedMax;return d!=null&&(s=d,u=!0),v!=null&&(l=v,c=!0),{min:s,max:l,minFixed:u,maxFixed:c,isBlank:h}},r.prototype.modifyDataMinMax=function(e,t){this[YZ[e]]=t},r.prototype.setDeterminedMinMax=function(e,t){var n=ZZ[e];this[n]=t},r.prototype.freeze=function(){this.frozen=!0},r}(),ZZ={min:"_determinedMin",max:"_determinedMax"},YZ={min:"_dataMin",max:"_dataMax"};function tE(r,e,t){var n=r.rawExtentInfo;return n||(n=new UZ(r,e,t),r.rawExtentInfo=n,n)}function mv(r,e){return e==null?null:Xc(e)?NaN:r.parse(e)}function eE(r,e){var t=r.type,n=tE(r,e,r.getExtent()).calculate();r.setBlank(n.isBlank);var a=n.min,i=n.max,o=e.ecModel;if(o&&t==="time"){var s=YR("bar",o),l=!1;if(B(s,function(h){l=l||h.getBaseAxis()===e.axis}),l){var u=XR(s),c=XZ(a,i,e,u);a=c.min,i=c.max}}return{extent:[a,i],fixMin:n.minFixed,fixMax:n.maxFixed}}function XZ(r,e,t,n){var a=t.axis.getExtent(),i=Math.abs(a[1]-a[0]),o=PZ(n,t.axis);if(o===void 0)return{min:r,max:e};var s=1/0;B(o,function(v){s=Math.min(v.offset,s)});var l=-1/0;B(o,function(v){l=Math.max(v.offset+v.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,c=e-r,h=1-(s+l)/i,d=c/h-c;return e+=d*(l/u),r-=d*(s/u),{min:r,max:e}}function ru(r,e){var t=e,n=eE(r,t),a=n.extent,i=t.get("splitNumber");r instanceof Rw&&(r.base=t.get("logBase"));var o=r.type,s=t.get("interval"),l=o==="interval"||o==="time";r.setExtent(a[0],a[1]),r.calcNiceExtent({splitNumber:i,fixMin:n.fixMin,fixMax:n.fixMax,minInterval:l?t.get("minInterval"):null,maxInterval:l?t.get("maxInterval"):null}),s!=null&&r.setInterval&&r.setInterval(s)}function Wp(r,e){if(e=e||r.get("type"),e)switch(e){case"category":return new Gp({ordinalMeta:r.getOrdinalMeta?r.getOrdinalMeta():r.getCategories(),extent:[1/0,-1/0]});case"time":return new kw({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new(Ja.getClass(e)||Mi)}}function $Z(r){var e=r.scale.getExtent(),t=e[0],n=e[1];return!(t>0&&n>0||t<0&&n<0)}function bu(r){var e=r.getLabelModel().get("formatter"),t=r.type==="category"?r.scale.getExtent()[0]:null;return r.scale.type==="time"?function(n){return function(a,i){return r.scale.getFormattedLabel(a,i,n)}}(e):Lt(e)?function(n){return function(a){var i=r.scale.getLabel(a),o=n.replace("{value}",i??"");return o}}(e):Nt(e)?function(n){return function(a,i){return t!=null&&(i=a.value-t),n(Ew(r,a),i,a.level!=null?{level:a.level}:null)}}(e):function(n){return r.scale.getLabel(n)}}function Ew(r,e){return r.type==="category"?r.scale.getLabel(e):e.value}function jZ(r){var e=r.model,t=r.scale;if(!(!e.get(["axisLabel","show"])||t.isBlank())){var n,a,i=t.getExtent();t instanceof Gp?a=t.count():(n=t.getTicks(),a=n.length);var o=r.getLabelModel(),s=bu(r),l,u=1;a>40&&(u=Math.ceil(a/40));for(var c=0;c<a;c+=u){var h=n?n[c]:{value:i[0]+c},d=s(h,c),v=o.getTextRect(d),p=qZ(v,o.get("rotate")||0);l?l.union(p):l=p}return l}}function qZ(r,e){var t=e*Math.PI/180,n=r.width,a=r.height,i=n*Math.abs(Math.cos(t))+Math.abs(a*Math.sin(t)),o=n*Math.abs(Math.sin(t))+Math.abs(a*Math.cos(t)),s=new Qt(r.x,r.y,i,o);return s}function Ow(r){var e=r.get("interval");return e??"auto"}function rE(r){return r.type==="category"&&Ow(r.getLabelModel())===0}function zd(r,e){var t={};return B(r.mapDimensionsAll(e),function(n){t[WR(r,n)]=!0}),ue(t)}function KZ(r,e,t){e&&B(zd(e,t),function(n){var a=e.getApproximateExtent(n);a[0]<r[0]&&(r[0]=a[0]),a[1]>r[1]&&(r[1]=a[1])})}var Bh=function(){function r(){}return r.prototype.getNeedCrossZero=function(){var e=this.option;return!e.scale},r.prototype.getCoordSysModel=function(){},r}(),QZ=1e-8;function qT(r,e){return Math.abs(r-e)<QZ}function ds(r,e,t){var n=0,a=r[0];if(!a)return!1;for(var i=1;i<r.length;i++){var o=r[i];n+=di(a[0],a[1],o[0],o[1],e,t),a=o}var s=r[0];return(!qT(a[0],s[0])||!qT(a[1],s[1]))&&(n+=di(a[0],a[1],s[0],s[1],e,t)),n!==0}var JZ=[];function ym(r,e){for(var t=0;t<r.length;t++)Pr(r[t],r[t],e)}function KT(r,e,t,n){for(var a=0;a<r.length;a++){var i=r[a];n&&(i=n.project(i)),i&&isFinite(i[0])&&isFinite(i[1])&&(io(e,e,i),oo(t,t,i))}}function tY(r){for(var e=0,t=0,n=0,a=r.length,i=r[a-1][0],o=r[a-1][1],s=0;s<a;s++){var l=r[s][0],u=r[s][1],c=i*u-l*o;e+=c,t+=(i+l)*c,n+=(o+u)*c,i=l,o=u}return e?[t/e/3,n/e/3,e]:[r[0][0]||0,r[0][1]||0]}var nE=function(){function r(e){this.name=e}return r.prototype.setCenter=function(e){this._center=e},r.prototype.getCenter=function(){var e=this._center;return e||(e=this._center=this.calcCenter()),e},r}(),QT=function(){function r(e,t){this.type="polygon",this.exterior=e,this.interiors=t}return r}(),JT=function(){function r(e){this.type="linestring",this.points=e}return r}(),aE=function(r){rt(e,r);function e(t,n,a){var i=r.call(this,t)||this;return i.type="geoJSON",i.geometries=n,i._center=a&&[a[0],a[1]],i}return e.prototype.calcCenter=function(){for(var t=this.geometries,n,a=0,i=0;i<t.length;i++){var o=t[i],s=o.exterior,l=s&&s.length;l>a&&(n=o,a=l)}if(n)return tY(n.exterior);var u=this.getBoundingRect();return[u.x+u.width/2,u.y+u.height/2]},e.prototype.getBoundingRect=function(t){var n=this._rect;if(n&&!t)return n;var a=[1/0,1/0],i=[-1/0,-1/0],o=this.geometries;return B(o,function(s){s.type==="polygon"?KT(s.exterior,a,i,t):B(s.points,function(l){KT(l,a,i,t)})}),isFinite(a[0])&&isFinite(a[1])&&isFinite(i[0])&&isFinite(i[1])||(a[0]=a[1]=i[0]=i[1]=0),n=new Qt(a[0],a[1],i[0]-a[0],i[1]-a[1]),t||(this._rect=n),n},e.prototype.contain=function(t){var n=this.getBoundingRect(),a=this.geometries;if(!n.contain(t[0],t[1]))return!1;t:for(var i=0,o=a.length;i<o;i++){var s=a[i];if(s.type==="polygon"){var l=s.exterior,u=s.interiors;if(ds(l,t[0],t[1])){for(var c=0;c<(u?u.length:0);c++)if(ds(u[c],t[0],t[1]))continue t;return!0}}}return!1},e.prototype.transformTo=function(t,n,a,i){var o=this.getBoundingRect(),s=o.width/o.height;a?i||(i=a/s):a=s*i;for(var l=new Qt(t,n,a,i),u=o.calculateTransform(l),c=this.geometries,h=0;h<c.length;h++){var d=c[h];d.type==="polygon"?(ym(d.exterior,u),B(d.interiors,function(v){ym(v,u)})):B(d.points,function(v){ym(v,u)})}o=this._rect,o.copy(l),this._center=[o.x+o.width/2,o.y+o.height/2]},e.prototype.cloneShallow=function(t){t==null&&(t=this.name);var n=new e(t,this.geometries,this._center);return n._rect=this._rect,n.transformTo=null,n},e}(nE),eY=function(r){rt(e,r);function e(t,n){var a=r.call(this,t)||this;return a.type="geoSVG",a._elOnlyForCalculate=n,a}return e.prototype.calcCenter=function(){for(var t=this._elOnlyForCalculate,n=t.getBoundingRect(),a=[n.x+n.width/2,n.y+n.height/2],i=vp(JZ),o=t;o&&!o.isGeoSVGGraphicRoot;)_i(i,o.getLocalTransform(),i),o=o.parent;return cu(i,i),Pr(a,a,i),a},e}(nE);function rY(r){if(!r.UTF8Encoding)return r;var e=r,t=e.UTF8Scale;t==null&&(t=1024);var n=e.features;return B(n,function(a){var i=a.geometry,o=i.encodeOffsets,s=i.coordinates;if(o)switch(i.type){case"LineString":i.coordinates=iE(s,o,t);break;case"Polygon":mm(s,o,t);break;case"MultiLineString":mm(s,o,t);break;case"MultiPolygon":B(s,function(l,u){return mm(l,o[u],t)})}}),e.UTF8Encoding=!1,e}function mm(r,e,t){for(var n=0;n<r.length;n++)r[n]=iE(r[n],e[n],t)}function iE(r,e,t){for(var n=[],a=e[0],i=e[1],o=0;o<r.length;o+=2){var s=r.charCodeAt(o)-64,l=r.charCodeAt(o+1)-64;s=s>>1^-(s&1),l=l>>1^-(l&1),s+=a,l+=i,a=s,i=l,n.push([s/t,l/t])}return n}function nY(r,e){return r=rY(r),ft(Te(r.features,function(t){return t.geometry&&t.properties&&t.geometry.coordinates.length>0}),function(t){var n=t.properties,a=t.geometry,i=[];switch(a.type){case"Polygon":var o=a.coordinates;i.push(new QT(o[0],o.slice(1)));break;case"MultiPolygon":B(a.coordinates,function(l){l[0]&&i.push(new QT(l[0],l.slice(1)))});break;case"LineString":i.push(new JT([a.coordinates]));break;case"MultiLineString":i.push(new JT(a.coordinates))}var s=new aE(n[e||"name"],i,n.cp);return s.properties=n,s})}var uh=ve();function oE(r,e){var t=ft(e,function(n){return r.scale.parse(n)});return r.type==="time"&&t.length>0&&(t.sort(),t.unshift(t[0]),t.push(t[t.length-1])),t}function aY(r){var e=r.getLabelModel().get("customValues");if(e){var t=bu(r),n=r.scale.getExtent(),a=oE(r,e),i=Te(a,function(o){return o>=n[0]&&o<=n[1]});return{labels:ft(i,function(o){var s={value:o};return{formattedLabel:t(s),rawLabel:r.scale.getLabel(s),tickValue:o}})}}return r.type==="category"?oY(r):lY(r)}function iY(r,e){var t=r.getTickModel().get("customValues");if(t){var n=r.scale.getExtent(),a=oE(r,t);return{ticks:Te(a,function(i){return i>=n[0]&&i<=n[1]})}}return r.type==="category"?sY(r,e):{ticks:ft(r.scale.getTicks(),function(i){return i.value})}}function oY(r){var e=r.getLabelModel(),t=sE(r,e);return!e.get("show")||r.scale.isBlank()?{labels:[],labelCategoryInterval:t.labelCategoryInterval}:t}function sE(r,e){var t=lE(r,"labels"),n=Ow(e),a=uE(t,n);if(a)return a;var i,o;return Nt(n)?i=fE(r,n):(o=n==="auto"?uY(r):n,i=hE(r,o)),cE(t,n,{labels:i,labelCategoryInterval:o})}function sY(r,e){var t=lE(r,"ticks"),n=Ow(e),a=uE(t,n);if(a)return a;var i,o;if((!e.get("show")||r.scale.isBlank())&&(i=[]),Nt(n))i=fE(r,n,!0);else if(n==="auto"){var s=sE(r,r.getLabelModel());o=s.labelCategoryInterval,i=ft(s.labels,function(l){return l.tickValue})}else o=n,i=hE(r,o,!0);return cE(t,n,{ticks:i,tickCategoryInterval:o})}function lY(r){var e=r.scale.getTicks(),t=bu(r);return{labels:ft(e,function(n,a){return{level:n.level,formattedLabel:t(n,a),rawLabel:r.scale.getLabel(n),tickValue:n.value}})}}function lE(r,e){return uh(r)[e]||(uh(r)[e]=[])}function uE(r,e){for(var t=0;t<r.length;t++)if(r[t].key===e)return r[t].value}function cE(r,e,t){return r.push({key:e,value:t}),t}function uY(r){var e=uh(r).autoInterval;return e??(uh(r).autoInterval=r.calculateCategoryInterval())}function cY(r){var e=hY(r),t=bu(r),n=(e.axisRotate-e.labelRotate)/180*Math.PI,a=r.scale,i=a.getExtent(),o=a.count();if(i[1]-i[0]<1)return 0;var s=1;o>40&&(s=Math.max(1,Math.floor(o/40)));for(var l=i[0],u=r.dataToCoord(l+1)-r.dataToCoord(l),c=Math.abs(u*Math.cos(n)),h=Math.abs(u*Math.sin(n)),d=0,v=0;l<=i[1];l+=s){var p=0,y=0,_=Th(t({value:l}),e.font,"center","top");p=_.width*1.3,y=_.height*1.3,d=Math.max(d,p,7),v=Math.max(v,y,7)}var g=d/c,f=v/h;isNaN(g)&&(g=1/0),isNaN(f)&&(f=1/0);var w=Math.max(0,Math.floor(Math.min(g,f))),x=uh(r.model),S=r.getExtent(),A=x.lastAutoInterval,T=x.lastTickCount;return A!=null&&T!=null&&Math.abs(A-w)<=1&&Math.abs(T-o)<=1&&A>w&&x.axisExtent0===S[0]&&x.axisExtent1===S[1]?w=A:(x.lastTickCount=o,x.lastAutoInterval=w,x.axisExtent0=S[0],x.axisExtent1=S[1]),w}function hY(r){var e=r.getLabelModel();return{axisRotate:r.getRotate?r.getRotate():r.isHorizontal&&!r.isHorizontal()?90:0,labelRotate:e.get("rotate")||0,font:e.getFont()}}function hE(r,e,t){var n=bu(r),a=r.scale,i=a.getExtent(),o=r.getLabelModel(),s=[],l=Math.max((e||0)+1,1),u=i[0],c=a.count();u!==0&&l>1&&c/l>2&&(u=Math.round(Math.ceil(u/l)*l));var h=rE(r),d=o.get("showMinLabel")||h,v=o.get("showMaxLabel")||h;d&&u!==i[0]&&y(i[0]);for(var p=u;p<=i[1];p+=l)y(p);v&&p-l!==i[1]&&y(i[1]);function y(_){var g={value:_};s.push(t?_:{formattedLabel:n(g),rawLabel:a.getLabel(g),tickValue:_})}return s}function fE(r,e,t){var n=r.scale,a=bu(r),i=[];return B(n.getTicks(),function(o){var s=n.getLabel(o),l=o.value;e(o.value,s)&&i.push(t?l:{formattedLabel:a(o),rawLabel:s,tickValue:l})}),i}var tC=[0,1],Sa=function(){function r(e,t,n){this.onBand=!1,this.inverse=!1,this.dim=e,this.scale=t,this._extent=n||[0,0]}return r.prototype.contain=function(e){var t=this._extent,n=Math.min(t[0],t[1]),a=Math.max(t[0],t[1]);return e>=n&&e<=a},r.prototype.containData=function(e){return this.scale.contain(e)},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.getPixelPrecision=function(e){return dP(e||this.scale.getExtent(),this._extent)},r.prototype.setExtent=function(e,t){var n=this._extent;n[0]=e,n[1]=t},r.prototype.dataToCoord=function(e,t){var n=this._extent,a=this.scale;return e=a.normalize(e),this.onBand&&a.type==="ordinal"&&(n=n.slice(),eC(n,a.count())),Me(e,tC,n,t)},r.prototype.coordToData=function(e,t){var n=this._extent,a=this.scale;this.onBand&&a.type==="ordinal"&&(n=n.slice(),eC(n,a.count()));var i=Me(e,n,tC,t);return this.scale.scale(i)},r.prototype.pointToData=function(e,t){},r.prototype.getTicksCoords=function(e){e=e||{};var t=e.tickModel||this.getTickModel(),n=iY(this,t),a=n.ticks,i=ft(a,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=t.get("alignWithLabel");return fY(this,i,o,e.clamp),i},r.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var e=this.model.getModel("minorTick"),t=e.get("splitNumber");t>0&&t<100||(t=5);var n=this.scale.getMinorTicks(t),a=ft(n,function(i){return ft(i,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return a},r.prototype.getViewLabels=function(){return aY(this).labels},r.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},r.prototype.getTickModel=function(){return this.model.getModel("axisTick")},r.prototype.getBandWidth=function(){var e=this._extent,t=this.scale.getExtent(),n=t[1]-t[0]+(this.onBand?1:0);n===0&&(n=1);var a=Math.abs(e[1]-e[0]);return Math.abs(a)/n},r.prototype.calculateCategoryInterval=function(){return cY(this)},r}();function eC(r,e){var t=r[1]-r[0],n=e,a=t/n/2;r[0]+=a,r[1]-=a}function fY(r,e,t,n){var a=e.length;if(!r.onBand||t||!a)return;var i=r.getExtent(),o,s;if(a===1)e[0].coord=i[0],o=e[1]={coord:i[1],tickValue:e[0].tickValue};else{var l=e[a-1].tickValue-e[0].tickValue,u=(e[a-1].coord-e[0].coord)/l;B(e,function(v){v.coord-=u/2});var c=r.scale.getExtent();s=1+c[1]-e[a-1].tickValue,o={coord:e[a-1].coord+u*s,tickValue:c[1]+1},e.push(o)}var h=i[0]>i[1];d(e[0].coord,i[0])&&(n?e[0].coord=i[0]:e.shift()),n&&d(i[0],e[0].coord)&&e.unshift({coord:i[0]}),d(i[1],o.coord)&&(n?o.coord=i[1]:e.pop()),n&&d(o.coord,i[1])&&e.push({coord:i[1]});function d(v,p){return v=qe(v),p=qe(p),h?v>p:v<p}}var ac=Math.PI*2,as=ja.CMD,vY=["top","right","bottom","left"];function dY(r,e,t,n,a){var i=t.width,o=t.height;switch(r){case"top":n.set(t.x+i/2,t.y-e),a.set(0,-1);break;case"bottom":n.set(t.x+i/2,t.y+o+e),a.set(0,1);break;case"left":n.set(t.x-e,t.y+o/2),a.set(-1,0);break;case"right":n.set(t.x+i+e,t.y+o/2),a.set(1,0);break}}function pY(r,e,t,n,a,i,o,s,l){o-=r,s-=e;var u=Math.sqrt(o*o+s*s);o/=u,s/=u;var c=o*t+r,h=s*t+e;if(Math.abs(n-a)%ac<1e-4)return l[0]=c,l[1]=h,u-t;if(i){var d=n;n=Cn(a),a=Cn(d)}else n=Cn(n),a=Cn(a);n>a&&(a+=ac);var v=Math.atan2(s,o);if(v<0&&(v+=ac),v>=n&&v<=a||v+ac>=n&&v+ac<=a)return l[0]=c,l[1]=h,u-t;var p=t*Math.cos(n)+r,y=t*Math.sin(n)+e,_=t*Math.cos(a)+r,g=t*Math.sin(a)+e,f=(p-o)*(p-o)+(y-s)*(y-s),w=(_-o)*(_-o)+(g-s)*(g-s);return f<w?(l[0]=p,l[1]=y,Math.sqrt(f)):(l[0]=_,l[1]=g,Math.sqrt(w))}function Fd(r,e,t,n,a,i,o,s){var l=a-r,u=i-e,c=t-r,h=n-e,d=Math.sqrt(c*c+h*h);c/=d,h/=d;var v=l*c+u*h,p=v/d;s&&(p=Math.min(Math.max(p,0),1)),p*=d;var y=o[0]=r+p*c,_=o[1]=e+p*h;return Math.sqrt((y-a)*(y-a)+(_-i)*(_-i))}function vE(r,e,t,n,a,i,o){t<0&&(r=r+t,t=-t),n<0&&(e=e+n,n=-n);var s=r+t,l=e+n,u=o[0]=Math.min(Math.max(a,r),s),c=o[1]=Math.min(Math.max(i,e),l);return Math.sqrt((u-a)*(u-a)+(c-i)*(c-i))}var da=[];function gY(r,e,t){var n=vE(e.x,e.y,e.width,e.height,r.x,r.y,da);return t.set(da[0],da[1]),n}function yY(r,e,t){for(var n=0,a=0,i=0,o=0,s,l,u=1/0,c=e.data,h=r.x,d=r.y,v=0;v<c.length;){var p=c[v++];v===1&&(n=c[v],a=c[v+1],i=n,o=a);var y=u;switch(p){case as.M:i=c[v++],o=c[v++],n=i,a=o;break;case as.L:y=Fd(n,a,c[v],c[v+1],h,d,da,!0),n=c[v++],a=c[v++];break;case as.C:y=qI(n,a,c[v++],c[v++],c[v++],c[v++],c[v],c[v+1],h,d,da),n=c[v++],a=c[v++];break;case as.Q:y=QI(n,a,c[v++],c[v++],c[v],c[v+1],h,d,da),n=c[v++],a=c[v++];break;case as.A:var _=c[v++],g=c[v++],f=c[v++],w=c[v++],x=c[v++],S=c[v++];v+=1;var A=!!(1-c[v++]);s=Math.cos(x)*f+_,l=Math.sin(x)*w+g,v<=1&&(i=s,o=l);var T=(h-_)*w/f+_;y=pY(_,g,w,x,x+S,A,T,d,da),n=Math.cos(x+S)*f+_,a=Math.sin(x+S)*w+g;break;case as.R:i=n=c[v++],o=a=c[v++];var L=c[v++],M=c[v++];y=vE(i,o,L,M,h,d,da);break;case as.Z:y=Fd(n,a,i,o,h,d,da,!0),n=i,a=o;break}y<u&&(u=y,t.set(da[0],da[1]))}return u}var ya=new Kt,ze=new Kt,Je=new Kt,Wa=new Kt,za=new Kt;function rC(r,e){if(r){var t=r.getTextGuideLine(),n=r.getTextContent();if(n&&t){var a=r.textGuideLineConfig||{},i=[[0,0],[0,0],[0,0]],o=a.candidates||vY,s=n.getBoundingRect().clone();s.applyTransform(n.getComputedTransform());var l=1/0,u=a.anchor,c=r.getComputedTransform(),h=c&&cu([],c),d=e.get("length2")||0;u&&Je.copy(u);for(var v=0;v<o.length;v++){var p=o[v];dY(p,0,s,ya,Wa),Kt.scaleAndAdd(ze,ya,Wa,d),ze.transform(h);var y=r.getBoundingRect(),_=u?u.distance(ze):r instanceof ie?yY(ze,r.path,Je):gY(ze,y,Je);_<l&&(l=_,ze.transform(c),Je.transform(c),Je.toArray(i[0]),ze.toArray(i[1]),ya.toArray(i[2]))}dE(i,e.get("minTurnAngle")),t.setShape({points:i})}}}var Vd=[],jr=new Kt;function dE(r,e){if(e<=180&&e>0){e=e/180*Math.PI,ya.fromArray(r[0]),ze.fromArray(r[1]),Je.fromArray(r[2]),Kt.sub(Wa,ya,ze),Kt.sub(za,Je,ze);var t=Wa.len(),n=za.len();if(!(t<.001||n<.001)){Wa.scale(1/t),za.scale(1/n);var a=Wa.dot(za),i=Math.cos(e);if(i<a){var o=Fd(ze.x,ze.y,Je.x,Je.y,ya.x,ya.y,Vd,!1);jr.fromArray(Vd),jr.scaleAndAdd(za,o/Math.tan(Math.PI-e));var s=Je.x!==ze.x?(jr.x-ze.x)/(Je.x-ze.x):(jr.y-ze.y)/(Je.y-ze.y);if(isNaN(s))return;s<0?Kt.copy(jr,ze):s>1&&Kt.copy(jr,Je),jr.toArray(r[1])}}}}function mY(r,e,t){if(t<=180&&t>0){t=t/180*Math.PI,ya.fromArray(r[0]),ze.fromArray(r[1]),Je.fromArray(r[2]),Kt.sub(Wa,ze,ya),Kt.sub(za,Je,ze);var n=Wa.len(),a=za.len();if(!(n<.001||a<.001)){Wa.scale(1/n),za.scale(1/a);var i=Wa.dot(e),o=Math.cos(t);if(i<o){var s=Fd(ze.x,ze.y,Je.x,Je.y,ya.x,ya.y,Vd,!1);jr.fromArray(Vd);var l=Math.PI/2,u=Math.acos(za.dot(e)),c=l+u-t;if(c>=l)Kt.copy(jr,Je);else{jr.scaleAndAdd(za,s/Math.tan(Math.PI/2-c));var h=Je.x!==ze.x?(jr.x-ze.x)/(Je.x-ze.x):(jr.y-ze.y)/(Je.y-ze.y);if(isNaN(h))return;h<0?Kt.copy(jr,ze):h>1&&Kt.copy(jr,Je)}jr.toArray(r[1])}}}}function _m(r,e,t,n){var a=t==="normal",i=a?r:r.ensureState(t);i.ignore=e;var o=n.get("smooth");o&&o===!0&&(o=.3),i.shape=i.shape||{},o>0&&(i.shape.smooth=o);var s=n.getModel("lineStyle").getLineStyle();a?r.useStyle(s):i.style=s}function _Y(r,e){var t=e.smooth,n=e.points;if(n)if(r.moveTo(n[0][0],n[0][1]),t>0&&n.length>=3){var a=ao(n[0],n[1]),i=ao(n[1],n[2]);if(!a||!i){r.lineTo(n[1][0],n[1][1]),r.lineTo(n[2][0],n[2][1]);return}var o=Math.min(a,i)*t,s=Yv([],n[1],n[0],o/a),l=Yv([],n[1],n[2],o/i),u=Yv([],s,l,.5);r.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),r.bezierCurveTo(l[0],l[1],l[0],l[1],n[2][0],n[2][1])}else for(var c=1;c<n.length;c++)r.lineTo(n[c][0],n[c][1])}function Bw(r,e,t){var n=r.getTextGuideLine(),a=r.getTextContent();if(!a){n&&r.removeTextGuideLine();return}for(var i=e.normal,o=i.get("show"),s=a.ignore,l=0;l<th.length;l++){var u=th[l],c=e[u],h=u==="normal";if(c){var d=c.get("show"),v=h?s:Zt(a.states[u]&&a.states[u].ignore,s);if(v||!Zt(d,o)){var p=h?n:n&&n.states[u];p&&(p.ignore=!0),n&&_m(n,!0,u,c);continue}n||(n=new nn,r.setTextGuideLine(n),!h&&(s||!o)&&_m(n,!0,"normal",e.normal),r.stateProxy&&(n.stateProxy=r.stateProxy)),_m(n,!1,u,c)}}if(n){zt(n.style,t),n.style.fill=null;var y=i.get("showAbove"),_=r.textGuideLineConfig=r.textGuideLineConfig||{};_.showAbove=y||!1,n.buildPath=_Y}}function Nw(r,e){e=e||"labelLine";for(var t={normal:r.getModel(e)},n=0;n<tn.length;n++){var a=tn[n];t[a]=r.getModel([a,e])}return t}function pE(r){for(var e=[],t=0;t<r.length;t++){var n=r[t];if(!n.defaultAttr.ignore){var a=n.label,i=a.getComputedTransform(),o=a.getBoundingRect(),s=!i||i[1]<1e-5&&i[2]<1e-5,l=a.style.margin||0,u=o.clone();u.applyTransform(i),u.x-=l/2,u.y-=l/2,u.width+=l,u.height+=l;var c=s?new Ad(o,i):null;e.push({label:a,labelLine:n.labelLine,rect:u,localRect:o,obb:c,priority:n.priority,defaultAttr:n.defaultAttr,layoutOption:n.computedLayoutOption,axisAligned:s,transform:i})}}return e}function gE(r,e,t,n,a,i){var o=r.length;if(o<2)return;r.sort(function(A,T){return A.rect[e]-T.rect[e]});for(var s=0,l,u=!1,c=0;c<o;c++){var h=r[c],d=h.rect;l=d[e]-s,l<0&&(d[e]-=l,h.label[e]-=l,u=!0),s=d[e]+d[t]}var v=r[0],p=r[o-1],y,_;g(),y<0&&x(-y,.8),_<0&&x(_,.8),g(),f(y,_,1),f(_,y,-1),g(),y<0&&S(-y),_<0&&S(_);function g(){y=v.rect[e]-n,_=a-p.rect[e]-p.rect[t]}function f(A,T,L){if(A<0){var M=Math.min(T,-A);if(M>0){w(M*L,0,o);var I=M+A;I<0&&x(-I*L,1)}else x(-A*L,1)}}function w(A,T,L){A!==0&&(u=!0);for(var M=T;M<L;M++){var I=r[M],R=I.rect;R[e]+=A,I.label[e]+=A}}function x(A,T){for(var L=[],M=0,I=1;I<o;I++){var R=r[I-1].rect,P=Math.max(r[I].rect[e]-R[e]-R[t],0);L.push(P),M+=P}if(M){var E=Math.min(Math.abs(A)/M,T);if(A>0)for(var I=0;I<o-1;I++){var D=L[I]*E;w(D,0,I+1)}else for(var I=o-1;I>0;I--){var D=L[I-1]*E;w(-D,I,o)}}}function S(A){var T=A<0?-1:1;A=Math.abs(A);for(var L=Math.ceil(A/(o-1)),M=0;M<o-1;M++)if(T>0?w(L,0,M+1):w(-L,o-M-1,o),A-=L,A<=0)return}return u}function wY(r,e,t,n){return gE(r,"x","width",e,t)}function yE(r,e,t,n){return gE(r,"y","height",e,t)}function mE(r){var e=[];r.sort(function(y,_){return _.priority-y.priority});var t=new Qt(0,0,0,0);function n(y){if(!y.ignore){var _=y.ensureState("emphasis");_.ignore==null&&(_.ignore=!1)}y.ignore=!0}for(var a=0;a<r.length;a++){var i=r[a],o=i.axisAligned,s=i.localRect,l=i.transform,u=i.label,c=i.labelLine;t.copy(i.rect),t.width-=.1,t.height-=.1,t.x+=.05,t.y+=.05;for(var h=i.obb,d=!1,v=0;v<e.length;v++){var p=e[v];if(t.intersect(p.rect)){if(o&&p.axisAligned){d=!0;break}if(p.obb||(p.obb=new Ad(p.localRect,p.transform)),h||(h=new Ad(s,l)),h.intersect(p.obb)){d=!0;break}}}d?(n(u),c&&n(c)):(u.attr("ignore",i.defaultAttr.ignore),c&&c.attr("ignore",i.defaultAttr.labelGuideIgnore),e.push(i))}}function xY(r){if(r){for(var e=[],t=0;t<r.length;t++)e.push(r[t].slice());return e}}function bY(r,e){var t=r.label,n=e&&e.getTextGuideLine();return{dataIndex:r.dataIndex,dataType:r.dataType,seriesIndex:r.seriesModel.seriesIndex,text:r.label.style.text,rect:r.hostRect,labelRect:r.rect,align:t.style.align,verticalAlign:t.style.verticalAlign,labelLinePoints:xY(n&&n.shape.points)}}var nC=["align","verticalAlign","width","height","fontSize"],Yr=new gi,wm=ve(),SY=ve();function _v(r,e,t){for(var n=0;n<t.length;n++){var a=t[n];e[a]!=null&&(r[a]=e[a])}}var wv=["x","y","rotation"],AY=function(){function r(){this._labelList=[],this._chartViewList=[]}return r.prototype.clearLabels=function(){this._labelList=[],this._chartViewList=[]},r.prototype._addLabel=function(e,t,n,a,i){var o=a.style,s=a.__hostTarget,l=s.textConfig||{},u=a.getComputedTransform(),c=a.getBoundingRect().plain();Qt.applyTransform(c,c,u),u?Yr.setLocalTransform(u):(Yr.x=Yr.y=Yr.rotation=Yr.originX=Yr.originY=0,Yr.scaleX=Yr.scaleY=1),Yr.rotation=Cn(Yr.rotation);var h=a.__hostTarget,d;if(h){d=h.getBoundingRect().plain();var v=h.getComputedTransform();Qt.applyTransform(d,d,v)}var p=d&&h.getTextGuideLine();this._labelList.push({label:a,labelLine:p,seriesModel:n,dataIndex:e,dataType:t,layoutOption:i,computedLayoutOption:null,rect:c,hostRect:d,priority:d?d.width*d.height:0,defaultAttr:{ignore:a.ignore,labelGuideIgnore:p&&p.ignore,x:Yr.x,y:Yr.y,scaleX:Yr.scaleX,scaleY:Yr.scaleY,rotation:Yr.rotation,style:{x:o.x,y:o.y,align:o.align,verticalAlign:o.verticalAlign,width:o.width,height:o.height,fontSize:o.fontSize},cursor:a.cursor,attachedPos:l.position,attachedRot:l.rotation}})},r.prototype.addLabelsOfSeries=function(e){var t=this;this._chartViewList.push(e);var n=e.__model,a=n.get("labelLayout");(Nt(a)||ue(a).length)&&e.group.traverse(function(i){if(i.ignore)return!0;var o=i.getTextContent(),s=Ht(i);o&&!o.disableLabelLayout&&t._addLabel(s.dataIndex,s.dataType,n,o,a)})},r.prototype.updateLayoutConfig=function(e){var t=e.getWidth(),n=e.getHeight();function a(w,x){return function(){rC(w,x)}}for(var i=0;i<this._labelList.length;i++){var o=this._labelList[i],s=o.label,l=s.__hostTarget,u=o.defaultAttr,c=void 0;Nt(o.layoutOption)?c=o.layoutOption(bY(o,l)):c=o.layoutOption,c=c||{},o.computedLayoutOption=c;var h=Math.PI/180;l&&l.setTextConfig({local:!1,position:c.x!=null||c.y!=null?null:u.attachedPos,rotation:c.rotate!=null?c.rotate*h:u.attachedRot,offset:[c.dx||0,c.dy||0]});var d=!1;if(c.x!=null?(s.x=At(c.x,t),s.setStyle("x",0),d=!0):(s.x=u.x,s.setStyle("x",u.style.x)),c.y!=null?(s.y=At(c.y,n),s.setStyle("y",0),d=!0):(s.y=u.y,s.setStyle("y",u.style.y)),c.labelLinePoints){var v=l.getTextGuideLine();v&&(v.setShape({points:c.labelLinePoints}),d=!1)}var p=wm(s);p.needsUpdateLabelLine=d,s.rotation=c.rotate!=null?c.rotate*h:u.rotation,s.scaleX=u.scaleX,s.scaleY=u.scaleY;for(var y=0;y<nC.length;y++){var _=nC[y];s.setStyle(_,c[_]!=null?c[_]:u.style[_])}if(c.draggable){if(s.draggable=!0,s.cursor="move",l){var g=o.seriesModel;if(o.dataIndex!=null){var f=o.seriesModel.getData(o.dataType);g=f.getItemModel(o.dataIndex)}s.on("drag",a(l,g.getModel("labelLine")))}}else s.off("drag"),s.cursor=u.cursor}},r.prototype.layout=function(e){var t=e.getWidth(),n=e.getHeight(),a=pE(this._labelList),i=Te(a,function(l){return l.layoutOption.moveOverlap==="shiftX"}),o=Te(a,function(l){return l.layoutOption.moveOverlap==="shiftY"});wY(i,0,t),yE(o,0,n);var s=Te(a,function(l){return l.layoutOption.hideOverlap});mE(s)},r.prototype.processLabelsOverall=function(){var e=this;B(this._chartViewList,function(t){var n=t.__model,a=t.ignoreLabelLineUpdate,i=n.isAnimationEnabled();t.group.traverse(function(o){if(o.ignore&&!o.forceLabelAnimation)return!0;var s=!a,l=o.getTextContent();!s&&l&&(s=wm(l).needsUpdateLabelLine),s&&e._updateLabelLine(o,n),i&&e._animateLabels(o,n)})})},r.prototype._updateLabelLine=function(e,t){var n=e.getTextContent(),a=Ht(e),i=a.dataIndex;if(n&&i!=null){var o=t.getData(a.dataType),s=o.getItemModel(i),l={},u=o.getItemVisual(i,"style");if(u){var c=o.getVisual("drawType");l.stroke=u[c]}var h=s.getModel("labelLine");Bw(e,Nw(s),l),rC(e,h)}},r.prototype._animateLabels=function(e,t){var n=e.getTextContent(),a=e.getTextGuideLine();if(n&&(e.forceLabelAnimation||!n.ignore&&!n.invisible&&!e.disableLabelAnimation&&!Yl(e))){var i=wm(n),o=i.oldLayout,s=Ht(e),l=s.dataIndex,u={x:n.x,y:n.y,rotation:n.rotation},c=t.getData(s.dataType);if(o){n.attr(o);var d=e.prevStates;d&&(te(d,"select")>=0&&n.attr(i.oldLayoutSelect),te(d,"emphasis")>=0&&n.attr(i.oldLayoutEmphasis)),_e(n,u,t,l)}else if(n.attr(u),!du(n).valueAnimation){var h=Zt(n.style.opacity,1);n.style.opacity=0,He(n,{style:{opacity:h}},t,l)}if(i.oldLayout=u,n.states.select){var v=i.oldLayoutSelect={};_v(v,u,wv),_v(v,n.states.select,wv)}if(n.states.emphasis){var p=i.oldLayoutEmphasis={};_v(p,u,wv),_v(p,n.states.emphasis,wv)}uk(n,l,c,t,t)}if(a&&!a.ignore&&!a.invisible){var i=SY(a),o=i.oldLayout,y={points:a.shape.points};o?(a.attr({shape:o}),_e(a,{shape:y},t)):(a.setShape(y),a.style.strokePercent=0,He(a,{style:{strokePercent:1}},t)),i.oldLayout=y}},r}(),xm=ve();function TY(r){r.registerUpdateLifecycle("series:beforeupdate",function(e,t,n){var a=xm(t).labelManager;a||(a=xm(t).labelManager=new AY),a.clearLabels()}),r.registerUpdateLifecycle("series:layoutlabels",function(e,t,n){var a=xm(t).labelManager;n.updatedSeries.forEach(function(i){a.addLabelsOfSeries(t.getViewOfSeriesModel(i))}),a.updateLayoutConfig(t),a.layout(t),a.processLabelsOverall()})}var bm=Math.sin,Sm=Math.cos,_E=Math.PI,is=Math.PI*2,CY=180/_E,wE=function(){function r(){}return r.prototype.reset=function(e){this._start=!0,this._d=[],this._str="",this._p=Math.pow(10,e||4)},r.prototype.moveTo=function(e,t){this._add("M",e,t)},r.prototype.lineTo=function(e,t){this._add("L",e,t)},r.prototype.bezierCurveTo=function(e,t,n,a,i,o){this._add("C",e,t,n,a,i,o)},r.prototype.quadraticCurveTo=function(e,t,n,a){this._add("Q",e,t,n,a)},r.prototype.arc=function(e,t,n,a,i,o){this.ellipse(e,t,n,n,0,a,i,o)},r.prototype.ellipse=function(e,t,n,a,i,o,s,l){var u=s-o,c=!l,h=Math.abs(u),d=uo(h-is)||(c?u>=is:-u>=is),v=u>0?u%is:u%is+is,p=!1;d?p=!0:uo(h)?p=!1:p=v>=_E==!!c;var y=e+n*Sm(o),_=t+a*bm(o);this._start&&this._add("M",y,_);var g=Math.round(i*CY);if(d){var f=1/this._p,w=(c?1:-1)*(is-f);this._add("A",n,a,g,1,+c,e+n*Sm(o+w),t+a*bm(o+w)),f>.01&&this._add("A",n,a,g,0,+c,y,_)}else{var x=e+n*Sm(s),S=t+a*bm(s);this._add("A",n,a,g,+p,+c,x,S)}},r.prototype.rect=function(e,t,n,a){this._add("M",e,t),this._add("l",n,0),this._add("l",0,a),this._add("l",-n,0),this._add("Z")},r.prototype.closePath=function(){this._d.length>0&&this._add("Z")},r.prototype._add=function(e,t,n,a,i,o,s,l,u){for(var c=[],h=this._p,d=1;d<arguments.length;d++){var v=arguments[d];if(isNaN(v)){this._invalid=!0;return}c.push(Math.round(v*h)/h)}this._d.push(e+c.join(" ")),this._start=e==="Z"},r.prototype.generateStr=function(){this._str=this._invalid?"":this._d.join(""),this._d=[]},r.prototype.getStr=function(){return this._str},r}(),zw="none",LY=Math.round;function MY(r){var e=r.fill;return e!=null&&e!==zw}function DY(r){var e=r.stroke;return e!=null&&e!==zw}var W_=["lineCap","miterLimit","lineJoin"],IY=ft(W_,function(r){return"stroke-"+r.toLowerCase()});function PY(r,e,t,n){var a=e.opacity==null?1:e.opacity;if(t instanceof Tr){r("opacity",a);return}if(MY(e)){var i=Kc(e.fill);r("fill",i.color);var o=e.fillOpacity!=null?e.fillOpacity*i.opacity*a:i.opacity*a;o<1&&r("fill-opacity",o)}else r("fill",zw);if(DY(e)){var s=Kc(e.stroke);r("stroke",s.color);var l=e.strokeNoScale?t.getLineScale():1,u=l?(e.lineWidth||0)/l:0,c=e.strokeOpacity!=null?e.strokeOpacity*s.opacity*a:s.opacity*a,h=e.strokeFirst;if(u!==1&&r("stroke-width",u),h&&r("paint-order",h?"stroke":"fill"),c<1&&r("stroke-opacity",c),e.lineDash){var d=Tw(t),v=d[0],p=d[1];v&&(p=LY(p||0),r("stroke-dasharray",v.join(",")),(p||n)&&r("stroke-dashoffset",p))}for(var y=0;y<W_.length;y++){var _=W_[y];if(e[_]!==bd[_]){var g=e[_]||bd[_];g&&r(IY[y],g)}}}}var xE="http://www.w3.org/2000/svg",bE="http://www.w3.org/1999/xlink",kY="http://www.w3.org/2000/xmlns/",RY="http://www.w3.org/XML/1998/namespace",aC="ecmeta_";function SE(r){return document.createElementNS(xE,r)}function yr(r,e,t,n,a){return{tag:r,attrs:t||{},children:n,text:a,key:e}}function EY(r,e){var t=[];if(e)for(var n in e){var a=e[n],i=n;a!==!1&&(a!==!0&&a!=null&&(i+='="'+a+'"'),t.push(i))}return"<"+r+" "+t.join(" ")+">"}function OY(r){return"</"+r+">"}function Fw(r,e){e=e||{};var t=e.newline?`
`:"";function n(a){var i=a.children,o=a.tag,s=a.attrs,l=a.text;return EY(o,s)+(o!=="style"?qr(l):l||"")+(i?""+t+ft(i,function(u){return n(u)}).join(t)+t:"")+OY(o)}return n(r)}function BY(r,e,t){t=t||{};var n=t.newline?`
`:"",a=" {"+n,i=n+"}",o=ft(ue(r),function(l){return l+a+ft(ue(r[l]),function(u){return u+":"+r[l][u]+";"}).join(n)+i}).join(n),s=ft(ue(e),function(l){return"@keyframes "+l+a+ft(ue(e[l]),function(u){return u+a+ft(ue(e[l][u]),function(c){var h=e[l][u][c];return c==="d"&&(h='path("'+h+'")'),c+":"+h+";"}).join(n)+i}).join(n)+i}).join(n);return!o&&!s?"":["<![CDATA[",o,s,"]]>"].join(n)}function H_(r){return{zrId:r,shadowCache:{},patternCache:{},gradientCache:{},clipPathCache:{},defs:{},cssNodes:{},cssAnims:{},cssStyleCache:{},cssAnimIdx:0,shadowIdx:0,gradientIdx:0,patternIdx:0,clipPathIdx:0}}function iC(r,e,t,n){return yr("svg","root",{width:r,height:e,xmlns:xE,"xmlns:xlink":bE,version:"1.1",baseProfile:"full",viewBox:n?"0 0 "+r+" "+e:!1},t)}var NY=0;function AE(){return NY++}var oC={cubicIn:"0.32,0,0.67,0",cubicOut:"0.33,1,0.68,1",cubicInOut:"0.65,0,0.35,1",quadraticIn:"0.11,0,0.5,0",quadraticOut:"0.5,1,0.89,1",quadraticInOut:"0.45,0,0.55,1",quarticIn:"0.5,0,0.75,0",quarticOut:"0.25,1,0.5,1",quarticInOut:"0.76,0,0.24,1",quinticIn:"0.64,0,0.78,0",quinticOut:"0.22,1,0.36,1",quinticInOut:"0.83,0,0.17,1",sinusoidalIn:"0.12,0,0.39,0",sinusoidalOut:"0.61,1,0.88,1",sinusoidalInOut:"0.37,0,0.63,1",exponentialIn:"0.7,0,0.84,0",exponentialOut:"0.16,1,0.3,1",exponentialInOut:"0.87,0,0.13,1",circularIn:"0.55,0,1,0.45",circularOut:"0,0.55,0.45,1",circularInOut:"0.85,0,0.15,1"},ls="transform-origin";function zY(r,e,t){var n=lt({},r.shape);lt(n,e),r.buildPath(t,n);var a=new wE;return a.reset(iP(r)),t.rebuildPath(a,1),a.generateStr(),a.getStr()}function FY(r,e){var t=e.originX,n=e.originY;(t||n)&&(r[ls]=t+"px "+n+"px")}var VY={fill:"fill",opacity:"opacity",lineWidth:"stroke-width",lineDashOffset:"stroke-dashoffset"};function TE(r,e){var t=e.zrId+"-ani-"+e.cssAnimIdx++;return e.cssAnims[t]=r,t}function GY(r,e,t){var n=r.shape.paths,a={},i,o;if(B(n,function(l){var u=H_(t.zrId);u.animation=!0,Hp(l,{},u,!0);var c=u.cssAnims,h=u.cssNodes,d=ue(c),v=d.length;if(v){o=d[v-1];var p=c[o];for(var y in p){var _=p[y];a[y]=a[y]||{d:""},a[y].d+=_.d||""}for(var g in h){var f=h[g].animation;f.indexOf(o)>=0&&(i=f)}}}),!!i){e.d=!1;var s=TE(a,t);return i.replace(o,s)}}function sC(r){return Lt(r)?oC[r]?"cubic-bezier("+oC[r]+")":U1(r)?r:"":""}function Hp(r,e,t,n){var a=r.animators,i=a.length,o=[];if(r instanceof iw){var s=GY(r,e,t);if(s)o.push(s);else if(!i)return}else if(!i)return;for(var l={},u=0;u<i;u++){var c=a[u],h=[c.getMaxTime()/1e3+"s"],d=sC(c.getClip().easing),v=c.getDelay();d?h.push(d):h.push("linear"),v&&h.push(v/1e3+"s"),c.getLoop()&&h.push("infinite");var p=h.join(" ");l[p]=l[p]||[p,[]],l[p][1].push(c)}function y(f){var w=f[1],x=w.length,S={},A={},T={},L="animation-timing-function";function M(bt,wt,Ot){for(var xt=bt.getTracks(),kt=bt.getMaxTime(),ae=0;ae<xt.length;ae++){var O=xt[ae];if(O.needsAnimate()){var st=O.keyframes,nt=O.propName;if(Ot&&(nt=Ot(nt)),nt)for(var X=0;X<st.length;X++){var Z=st[X],J=Math.round(Z.time/kt*100)+"%",pt=sC(Z.easing),vt=Z.rawValue;(Lt(vt)||ye(vt))&&(wt[J]=wt[J]||{},wt[J][nt]=Z.rawValue,pt&&(wt[J][L]=pt))}}}}for(var I=0;I<x;I++){var R=w[I],P=R.targetName;P?P==="shape"&&M(R,A):!n&&M(R,S)}for(var E in S){var D={};cP(D,r),lt(D,S[E]);var N=oP(D),V=S[E][L];T[E]=N?{transform:N}:{},FY(T[E],D),V&&(T[E][L]=V)}var W,$=!0;for(var E in A){T[E]=T[E]||{};var H=!W,V=A[E][L];H&&(W=new ja);var K=W.len();W.reset(),T[E].d=zY(r,A[E],W);var U=W.len();if(!H&&K!==U){$=!1;break}V&&(T[E][L]=V)}if(!$)for(var E in T)delete T[E].d;if(!n)for(var I=0;I<x;I++){var R=w[I],P=R.targetName;P==="style"&&M(R,T,function(xt){return VY[xt]})}for(var j=ue(T),ut=!0,ot,I=1;I<j.length;I++){var it=j[I-1],Et=j[I];if(T[it][ls]!==T[Et][ls]){ut=!1;break}ot=T[it][ls]}if(ut&&ot){for(var E in T)T[E][ls]&&delete T[E][ls];e[ls]=ot}if(Te(j,function(bt){return ue(T[bt]).length>0}).length){var jt=TE(T,t);return jt+" "+f[0]+" both"}}for(var _ in l){var s=y(l[_]);s&&o.push(s)}if(o.length){var g=t.zrId+"-cls-"+AE();t.cssNodes["."+g]={animation:o.join(",")},e.class=g}}function WY(r,e,t){if(!r.ignore)if(r.isSilent()){var n={"pointer-events":"none"};lC(n,e,t)}else{var a=r.states.emphasis&&r.states.emphasis.style?r.states.emphasis.style:{},i=a.fill;if(!i){var o=r.style&&r.style.fill,s=r.states.select&&r.states.select.style&&r.states.select.style.fill,l=r.currentStates.indexOf("select")>=0&&s||o;l&&(i=e_(l))}var u=a.lineWidth;if(u){var c=!a.strokeNoScale&&r.transform?r.transform[0]:1;u=u/c}var n={cursor:"pointer"};i&&(n.fill=i),a.stroke&&(n.stroke=a.stroke),u&&(n["stroke-width"]=u),lC(n,e,t)}}function lC(r,e,t,n){var a=JSON.stringify(r),i=t.cssStyleCache[a];i||(i=t.zrId+"-cls-"+AE(),t.cssStyleCache[a]=i,t.cssNodes["."+i+":hover"]=r),e.class=e.class?e.class+" "+i:i}var ch=Math.round;function CE(r){return r&&Lt(r.src)}function LE(r){return r&&Nt(r.toDataURL)}function Vw(r,e,t,n){PY(function(a,i){var o=a==="fill"||a==="stroke";o&&aP(i)?DE(e,r,a,n):o&&Z1(i)?IE(t,r,a,n):r[a]=i,o&&n.ssr&&i==="none"&&(r["pointer-events"]="visible")},e,t,!1),jY(t,r,n)}function Gw(r,e){var t=F8(e);t&&(t.each(function(n,a){n!=null&&(r[(aC+a).toLowerCase()]=n+"")}),e.isSilent()&&(r[aC+"silent"]="true"))}function uC(r){return uo(r[0]-1)&&uo(r[1])&&uo(r[2])&&uo(r[3]-1)}function HY(r){return uo(r[4])&&uo(r[5])}function Ww(r,e,t){if(e&&!(HY(e)&&uC(e))){var n=1e4;r.transform=uC(e)?"translate("+ch(e[4]*n)/n+" "+ch(e[5]*n)/n+")":l8(e)}}function cC(r,e,t){for(var n=r.points,a=[],i=0;i<n.length;i++)a.push(ch(n[i][0]*t)/t),a.push(ch(n[i][1]*t)/t);e.points=a.join(" ")}function hC(r){return!r.smooth}function UY(r){var e=ft(r,function(t){return typeof t=="string"?[t,t]:t});return function(t,n,a){for(var i=0;i<e.length;i++){var o=e[i],s=t[o[0]];s!=null&&(n[o[1]]=ch(s*a)/a)}}}var ZY={circle:[UY(["cx","cy","r"])],polyline:[cC,hC],polygon:[cC,hC]};function YY(r){for(var e=r.animators,t=0;t<e.length;t++)if(e[t].targetName==="shape")return!0;return!1}function ME(r,e){var t=r.style,n=r.shape,a=ZY[r.type],i={},o=e.animation,s="path",l=r.style.strokePercent,u=e.compress&&iP(r)||4;if(a&&!e.willUpdate&&!(a[1]&&!a[1](n))&&!(o&&YY(r))&&!(l<1)){s=r.type;var c=Math.pow(10,u);a[0](n,i,c)}else{var h=!r.path||r.shapeChanged();r.path||r.createPathProxy();var d=r.path;h&&(d.beginPath(),r.buildPath(d,r.shape),r.pathUpdated());var v=d.getVersion(),p=r,y=p.__svgPathBuilder;(p.__svgPathVersion!==v||!y||l!==p.__svgPathStrokePercent)&&(y||(y=p.__svgPathBuilder=new wE),y.reset(u),d.rebuildPath(y,l),y.generateStr(),p.__svgPathVersion=v,p.__svgPathStrokePercent=l),i.d=y.getStr()}return Ww(i,r.transform),Vw(i,t,r,e),Gw(i,r),e.animation&&Hp(r,i,e),e.emphasis&&WY(r,i,e),yr(s,r.id+"",i)}function XY(r,e){var t=r.style,n=t.image;if(n&&!Lt(n)&&(CE(n)?n=n.src:LE(n)&&(n=n.toDataURL())),!!n){var a=t.x||0,i=t.y||0,o=t.width,s=t.height,l={href:n,width:o,height:s};return a&&(l.x=a),i&&(l.y=i),Ww(l,r.transform),Vw(l,t,r,e),Gw(l,r),e.animation&&Hp(r,l,e),yr("image",r.id+"",l)}}function $Y(r,e){var t=r.style,n=t.text;if(n!=null&&(n+=""),!(!n||isNaN(t.x)||isNaN(t.y))){var a=t.font||mo,i=t.x||0,o=c8(t.y||0,pp(a),t.textBaseline),s=u8[t.textAlign]||t.textAlign,l={"dominant-baseline":"central","text-anchor":s};if(BP(t)){var u="",c=t.fontStyle,h=OP(t.fontSize);if(!parseFloat(h))return;var d=t.fontFamily||OI,v=t.fontWeight;u+="font-size:"+h+";font-family:"+d+";",c&&c!=="normal"&&(u+="font-style:"+c+";"),v&&v!=="normal"&&(u+="font-weight:"+v+";"),l.style=u}else l.style="font: "+a;return n.match(/\s/)&&(l["xml:space"]="preserve"),i&&(l.x=i),o&&(l.y=o),Ww(l,r.transform),Vw(l,t,r,e),Gw(l,r),e.animation&&Hp(r,l,e),yr("text",r.id+"",l,void 0,n)}}function fC(r,e){if(r instanceof ie)return ME(r,e);if(r instanceof Tr)return XY(r,e);if(r instanceof Ql)return $Y(r,e)}function jY(r,e,t){var n=r.style;if(h8(n)){var a=f8(r),i=t.shadowCache,o=i[a];if(!o){var s=r.getGlobalScale(),l=s[0],u=s[1];if(!l||!u)return;var c=n.shadowOffsetX||0,h=n.shadowOffsetY||0,d=n.shadowBlur,v=Kc(n.shadowColor),p=v.opacity,y=v.color,_=d/2/l,g=d/2/u,f=_+" "+g;o=t.zrId+"-s"+t.shadowIdx++,t.defs[o]=yr("filter",o,{id:o,x:"-100%",y:"-100%",width:"300%",height:"300%"},[yr("feDropShadow","",{dx:c/l,dy:h/u,stdDeviation:f,"flood-color":y,"flood-opacity":p})]),i[a]=o}e.filter=dp(o)}}function DE(r,e,t,n){var a=r[t],i,o={gradientUnits:a.global?"userSpaceOnUse":"objectBoundingBox"};if(rP(a))i="linearGradient",o.x1=a.x,o.y1=a.y,o.x2=a.x2,o.y2=a.y2;else if(nP(a))i="radialGradient",o.cx=Zt(a.x,.5),o.cy=Zt(a.y,.5),o.r=Zt(a.r,.5);else return;for(var s=a.colorStops,l=[],u=0,c=s.length;u<c;++u){var h=r_(s[u].offset)*100+"%",d=s[u].color,v=Kc(d),p=v.color,y=v.opacity,_={offset:h};_["stop-color"]=p,y<1&&(_["stop-opacity"]=y),l.push(yr("stop",u+"",_))}var g=yr(i,"",o,l),f=Fw(g),w=n.gradientCache,x=w[f];x||(x=n.zrId+"-g"+n.gradientIdx++,w[f]=x,o.id=x,n.defs[x]=yr(i,x,o,l)),e[t]=dp(x)}function IE(r,e,t,n){var a=r.style[t],i=r.getBoundingRect(),o={},s=a.repeat,l=s==="no-repeat",u=s==="repeat-x",c=s==="repeat-y",h;if(eP(a)){var d=a.imageWidth,v=a.imageHeight,p=void 0,y=a.image;if(Lt(y)?p=y:CE(y)?p=y.src:LE(y)&&(p=y.toDataURL()),typeof Image>"u"){var _="Image width/height must been given explictly in svg-ssr renderer.";Jr(d,_),Jr(v,_)}else if(d==null||v==null){var g=function(I,R){if(I){var P=I.elm,E=d||R.width,D=v||R.height;I.tag==="pattern"&&(u?(D=1,E/=i.width):c&&(E=1,D/=i.height)),I.attrs.width=E,I.attrs.height=D,P&&(P.setAttribute("width",E),P.setAttribute("height",D))}},f=K1(p,null,r,function(I){l||g(A,I),g(h,I)});f&&f.width&&f.height&&(d=d||f.width,v=v||f.height)}h=yr("image","img",{href:p,width:d,height:v}),o.width=d,o.height=v}else a.svgElement&&(h=Gt(a.svgElement),o.width=a.svgWidth,o.height=a.svgHeight);if(h){var w,x;l?w=x=1:u?(x=1,w=o.width/i.width):c?(w=1,x=o.height/i.height):o.patternUnits="userSpaceOnUse",w!=null&&!isNaN(w)&&(o.width=w),x!=null&&!isNaN(x)&&(o.height=x);var S=oP(a);S&&(o.patternTransform=S);var A=yr("pattern","",o,[h]),T=Fw(A),L=n.patternCache,M=L[T];M||(M=n.zrId+"-p"+n.patternIdx++,L[T]=M,o.id=M,A=n.defs[M]=yr("pattern",M,o,[h])),e[t]=dp(M)}}function qY(r,e,t){var n=t.clipPathCache,a=t.defs,i=n[r.id];if(!i){i=t.zrId+"-c"+t.clipPathIdx++;var o={id:i};n[r.id]=i,a[i]=yr("clipPath",i,o,[ME(r,t)])}e["clip-path"]=dp(i)}function vC(r){return document.createTextNode(r)}function ps(r,e,t){r.insertBefore(e,t)}function dC(r,e){r.removeChild(e)}function pC(r,e){r.appendChild(e)}function PE(r){return r.parentNode}function kE(r){return r.nextSibling}function Am(r,e){r.textContent=e}var gC=58,KY=120,QY=yr("","");function U_(r){return r===void 0}function Ba(r){return r!==void 0}function JY(r,e,t){for(var n={},a=e;a<=t;++a){var i=r[a].key;i!==void 0&&(n[i]=a)}return n}function Tc(r,e){var t=r.key===e.key,n=r.tag===e.tag;return n&&t}function hh(r){var e,t=r.children,n=r.tag;if(Ba(n)){var a=r.elm=SE(n);if(Hw(QY,r),ht(t))for(e=0;e<t.length;++e){var i=t[e];i!=null&&pC(a,hh(i))}else Ba(r.text)&&!Vt(r.text)&&pC(a,vC(r.text))}else r.elm=vC(r.text);return r.elm}function RE(r,e,t,n,a){for(;n<=a;++n){var i=t[n];i!=null&&ps(r,hh(i),e)}}function Gd(r,e,t,n){for(;t<=n;++t){var a=e[t];if(a!=null)if(Ba(a.tag)){var i=PE(a.elm);dC(i,a.elm)}else dC(r,a.elm)}}function Hw(r,e){var t,n=e.elm,a=r&&r.attrs||{},i=e.attrs||{};if(a!==i){for(t in i){var o=i[t],s=a[t];s!==o&&(o===!0?n.setAttribute(t,""):o===!1?n.removeAttribute(t):t==="style"?n.style.cssText=o:t.charCodeAt(0)!==KY?n.setAttribute(t,o):t==="xmlns:xlink"||t==="xmlns"?n.setAttributeNS(kY,t,o):t.charCodeAt(3)===gC?n.setAttributeNS(RY,t,o):t.charCodeAt(5)===gC?n.setAttributeNS(bE,t,o):n.setAttribute(t,o))}for(t in a)t in i||n.removeAttribute(t)}}function tX(r,e,t){for(var n=0,a=0,i=e.length-1,o=e[0],s=e[i],l=t.length-1,u=t[0],c=t[l],h,d,v,p;n<=i&&a<=l;)o==null?o=e[++n]:s==null?s=e[--i]:u==null?u=t[++a]:c==null?c=t[--l]:Tc(o,u)?(Bl(o,u),o=e[++n],u=t[++a]):Tc(s,c)?(Bl(s,c),s=e[--i],c=t[--l]):Tc(o,c)?(Bl(o,c),ps(r,o.elm,kE(s.elm)),o=e[++n],c=t[--l]):Tc(s,u)?(Bl(s,u),ps(r,s.elm,o.elm),s=e[--i],u=t[++a]):(U_(h)&&(h=JY(e,n,i)),d=h[u.key],U_(d)?ps(r,hh(u),o.elm):(v=e[d],v.tag!==u.tag?ps(r,hh(u),o.elm):(Bl(v,u),e[d]=void 0,ps(r,v.elm,o.elm))),u=t[++a]);(n<=i||a<=l)&&(n>i?(p=t[l+1]==null?null:t[l+1].elm,RE(r,p,t,a,l)):Gd(r,e,n,i))}function Bl(r,e){var t=e.elm=r.elm,n=r.children,a=e.children;r!==e&&(Hw(r,e),U_(e.text)?Ba(n)&&Ba(a)?n!==a&&tX(t,n,a):Ba(a)?(Ba(r.text)&&Am(t,""),RE(t,null,a,0,a.length-1)):Ba(n)?Gd(t,n,0,n.length-1):Ba(r.text)&&Am(t,""):r.text!==e.text&&(Ba(n)&&Gd(t,n,0,n.length-1),Am(t,e.text)))}function eX(r,e){if(Tc(r,e))Bl(r,e);else{var t=r.elm,n=PE(t);hh(e),n!==null&&(ps(n,e.elm,kE(t)),Gd(n,[r],0,0))}return e}var rX=0,nX=function(){function r(e,t,n){if(this.type="svg",this.refreshHover=yC(),this.configLayer=yC(),this.storage=t,this._opts=n=lt({},n),this.root=e,this._id="zr"+rX++,this._oldVNode=iC(n.width,n.height),e&&!n.ssr){var a=this._viewport=document.createElement("div");a.style.cssText="position:relative;overflow:hidden";var i=this._svgDom=this._oldVNode.elm=SE("svg");Hw(null,this._oldVNode),a.appendChild(i),e.appendChild(a)}this.resize(n.width,n.height)}return r.prototype.getType=function(){return this.type},r.prototype.getViewportRoot=function(){return this._viewport},r.prototype.getViewportRootOffset=function(){var e=this.getViewportRoot();if(e)return{offsetLeft:e.offsetLeft||0,offsetTop:e.offsetTop||0}},r.prototype.getSvgDom=function(){return this._svgDom},r.prototype.refresh=function(){if(this.root){var e=this.renderToVNode({willUpdate:!0});e.attrs.style="position:absolute;left:0;top:0;user-select:none",eX(this._oldVNode,e),this._oldVNode=e}},r.prototype.renderOneToVNode=function(e){return fC(e,H_(this._id))},r.prototype.renderToVNode=function(e){e=e||{};var t=this.storage.getDisplayList(!0),n=this._width,a=this._height,i=H_(this._id);i.animation=e.animation,i.willUpdate=e.willUpdate,i.compress=e.compress,i.emphasis=e.emphasis,i.ssr=this._opts.ssr;var o=[],s=this._bgVNode=aX(n,a,this._backgroundColor,i);s&&o.push(s);var l=e.compress?null:this._mainVNode=yr("g","main",{},[]);this._paintList(t,i,l?l.children:o),l&&o.push(l);var u=ft(ue(i.defs),function(d){return i.defs[d]});if(u.length&&o.push(yr("defs","defs",{},u)),e.animation){var c=BY(i.cssNodes,i.cssAnims,{newline:!0});if(c){var h=yr("style","stl",{},[],c);o.push(h)}}return iC(n,a,o,e.useViewBox)},r.prototype.renderToString=function(e){return e=e||{},Fw(this.renderToVNode({animation:Zt(e.cssAnimation,!0),emphasis:Zt(e.cssEmphasis,!0),willUpdate:!1,compress:!0,useViewBox:Zt(e.useViewBox,!0)}),{newline:!0})},r.prototype.setBackgroundColor=function(e){this._backgroundColor=e},r.prototype.getSvgRoot=function(){return this._mainVNode&&this._mainVNode.elm},r.prototype._paintList=function(e,t,n){for(var a=e.length,i=[],o=0,s,l,u=0,c=0;c<a;c++){var h=e[c];if(!h.invisible){var d=h.__clipPaths,v=d&&d.length||0,p=l&&l.length||0,y=void 0;for(y=Math.max(v-1,p-1);y>=0&&!(d&&l&&d[y]===l[y]);y--);for(var _=p-1;_>y;_--)o--,s=i[o-1];for(var g=y+1;g<v;g++){var f={};qY(d[g],f,t);var w=yr("g","clip-g-"+u++,f,[]);(s?s.children:n).push(w),i[o++]=w,s=w}l=d;var x=fC(h,t);x&&(s?s.children:n).push(x)}}},r.prototype.resize=function(e,t){var n=this._opts,a=this.root,i=this._viewport;if(e!=null&&(n.width=e),t!=null&&(n.height=t),a&&i&&(i.style.display="none",e=Gl(a,0,n),t=Gl(a,1,n),i.style.display=""),this._width!==e||this._height!==t){if(this._width=e,this._height=t,i){var o=i.style;o.width=e+"px",o.height=t+"px"}if(Z1(this._backgroundColor))this.refresh();else{var s=this._svgDom;s&&(s.setAttribute("width",e),s.setAttribute("height",t));var l=this._bgVNode&&this._bgVNode.elm;l&&(l.setAttribute("width",e),l.setAttribute("height",t))}}},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r.prototype.dispose=function(){this.root&&(this.root.innerHTML=""),this._svgDom=this._viewport=this.storage=this._oldVNode=this._bgVNode=this._mainVNode=null},r.prototype.clear=function(){this._svgDom&&(this._svgDom.innerHTML=null),this._oldVNode=null},r.prototype.toDataURL=function(e){var t=this.renderToString(),n="data:image/svg+xml;";return e?(t=d8(t),t&&n+"base64,"+t):n+"charset=UTF-8,"+encodeURIComponent(t)},r}();function yC(r){return function(){}}function aX(r,e,t,n){var a;if(t&&t!=="none")if(a=yr("rect","bg",{width:r,height:e,x:"0",y:"0"}),aP(t))DE({fill:t},a.attrs,"fill",n);else if(Z1(t))IE({style:{fill:t},dirty:tr,getBoundingRect:function(){return{width:r,height:e}}},a.attrs,"fill",n);else{var i=Kc(t),o=i.color,s=i.opacity;a.attrs.fill=o,s<1&&(a.attrs["fill-opacity"]=s)}return a}function iX(r){r.registerPainter("svg",nX)}function mC(r,e,t){var n=_o.createCanvas(),a=e.getWidth(),i=e.getHeight(),o=n.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=a+"px",o.height=i+"px",n.setAttribute("data-zr-dom-id",r)),n.width=a*t,n.height=i*t,n}var Tm=function(r){Ge(e,r);function e(t,n,a){var i=r.call(this)||this;i.motionBlur=!1,i.lastFrameAlpha=.7,i.dpr=1,i.virtual=!1,i.config={},i.incremental=!1,i.zlevel=0,i.maxRepaintRectCount=5,i.__dirty=!0,i.__firstTimePaint=!0,i.__used=!1,i.__drawIndex=0,i.__startIndex=0,i.__endIndex=0,i.__prevStartIndex=null,i.__prevEndIndex=null;var o;a=a||wd,typeof t=="string"?o=mC(t,n,a):Vt(t)&&(o=t,t=o.id),i.id=t,i.dom=o;var s=o.style;return s&&(GI(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),i.painter=n,i.dpr=a,i}return e.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},e.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},e.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},e.prototype.setUnpainted=function(){this.__firstTimePaint=!0},e.prototype.createBackBuffer=function(){var t=this.dpr;this.domBack=mC("back-"+this.id,this.painter,t),this.ctxBack=this.domBack.getContext("2d"),t!==1&&this.ctxBack.scale(t,t)},e.prototype.createRepaintRects=function(t,n,a,i){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new Qt(0,0,0,0);function c(f){if(!(!f.isFinite()||f.isZero()))if(o.length===0){var w=new Qt(0,0,0,0);w.copy(f),o.push(w)}else{for(var x=!1,S=1/0,A=0,T=0;T<o.length;++T){var L=o[T];if(L.intersect(f)){var M=new Qt(0,0,0,0);M.copy(L),M.union(f),o[T]=M,x=!0;break}else if(l){u.copy(f),u.union(L);var I=f.width*f.height,R=L.width*L.height,P=u.width*u.height,E=P-I-R;E<S&&(S=E,A=T)}}if(l&&(o[A].union(f),x=!0),!x){var w=new Qt(0,0,0,0);w.copy(f),o.push(w)}l||(l=o.length>=s)}}for(var h=this.__startIndex;h<this.__endIndex;++h){var d=t[h];if(d){var v=d.shouldBePainted(a,i,!0,!0),p=d.__isRendered&&(d.__dirty&Tn||!v)?d.getPrevPaintRect():null;p&&c(p);var y=v&&(d.__dirty&Tn||!d.__isRendered)?d.getPaintRect():null;y&&c(y)}}for(var h=this.__prevStartIndex;h<this.__prevEndIndex;++h){var d=n[h],v=d&&d.shouldBePainted(a,i,!0,!0);if(d&&(!v||!d.__zr)&&d.__isRendered){var p=d.getPrevPaintRect();p&&c(p)}}var _;do{_=!1;for(var h=0;h<o.length;){if(o[h].isZero()){o.splice(h,1);continue}for(var g=h+1;g<o.length;)o[h].intersect(o[g])?(_=!0,o[h].union(o[g]),o.splice(g,1)):g++;h++}}while(_);return this._paintRects=o,o},e.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},e.prototype.resize=function(t,n){var a=this.dpr,i=this.dom,o=i.style,s=this.domBack;o&&(o.width=t+"px",o.height=n+"px"),i.width=t*a,i.height=n*a,s&&(s.width=t*a,s.height=n*a,a!==1&&this.ctxBack.scale(a,a))},e.prototype.clear=function(t,n,a){var i=this.dom,o=this.ctx,s=i.width,l=i.height;n=n||this.clearColor;var u=this.motionBlur&&!t,c=this.lastFrameAlpha,h=this.dpr,d=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(i,0,0,s/h,l/h));var v=this.domBack;function p(y,_,g,f){if(o.clearRect(y,_,g,f),n&&n!=="transparent"){var w=void 0;if(hp(n)){var x=n.global||n.__width===g&&n.__height===f;w=x&&n.__canvasGradient||E_(o,n,{x:0,y:0,width:g,height:f}),n.__canvasGradient=w,n.__width=g,n.__height=f}else b6(n)&&(n.scaleX=n.scaleX||h,n.scaleY=n.scaleY||h,w=O_(o,n,{dirty:function(){d.setUnpainted(),d.painter.refresh()}}));o.save(),o.fillStyle=w||n,o.fillRect(y,_,g,f),o.restore()}u&&(o.save(),o.globalAlpha=c,o.drawImage(v,y,_,g,f),o.restore())}!a||u?p(0,0,s,l):a.length&&B(a,function(y){p(y.x*h,y.y*h,y.width*h,y.height*h)})},e}(ea),_C=1e5,os=314159,xv=.01,oX=.001;function sX(r){return r?r.__builtin__?!0:!(typeof r.resize!="function"||typeof r.refresh!="function"):!1}function lX(r,e){var t=document.createElement("div");return t.style.cssText=["position:relative","width:"+r+"px","height:"+e+"px","padding:0","margin:0","border-width:0"].join(";")+";",t}var uX=function(){function r(e,t,n,a){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var i=!e.nodeName||e.nodeName.toUpperCase()==="CANVAS";this._opts=n=lt({},n||{}),this.dpr=n.devicePixelRatio||wd,this._singleCanvas=i,this.root=e;var o=e.style;o&&(GI(e),e.innerHTML=""),this.storage=t;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(i){var c=e,h=c.width,d=c.height;n.width!=null&&(h=n.width),n.height!=null&&(d=n.height),this.dpr=n.devicePixelRatio||1,c.width=h*this.dpr,c.height=d*this.dpr,this._width=h,this._height=d;var v=new Tm(c,this,this.dpr);v.__builtin__=!0,v.initContext(),l[os]=v,v.zlevel=os,s.push(os),this._domRoot=e}else{this._width=Gl(e,0,n),this._height=Gl(e,1,n);var u=this._domRoot=lX(this._width,this._height);e.appendChild(u)}}return r.prototype.getType=function(){return"canvas"},r.prototype.isSingleCanvas=function(){return this._singleCanvas},r.prototype.getViewportRoot=function(){return this._domRoot},r.prototype.getViewportRootOffset=function(){var e=this.getViewportRoot();if(e)return{offsetLeft:e.offsetLeft||0,offsetTop:e.offsetTop||0}},r.prototype.refresh=function(e){var t=this.storage.getDisplayList(!0),n=this._prevDisplayList,a=this._zlevelList;this._redrawId=Math.random(),this._paintList(t,n,e,this._redrawId);for(var i=0;i<a.length;i++){var o=a[i],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=i===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=t.slice()),this},r.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},r.prototype._paintHoverList=function(e){var t=e.length,n=this._hoverlayer;if(n&&n.clear(),!!t){for(var a={inHover:!0,viewWidth:this._width,viewHeight:this._height},i,o=0;o<t;o++){var s=e[o];s.__inHover&&(n||(n=this._hoverlayer=this.getLayer(_C)),i||(i=n.ctx,i.save()),As(i,s,a,o===t-1))}i&&i.restore()}},r.prototype.getHoverLayer=function(){return this.getLayer(_C)},r.prototype.paintOne=function(e,t){yR(e,t)},r.prototype._paintList=function(e,t,n,a){if(this._redrawId===a){n=n||!1,this._updateLayerStatus(e);var i=this._doPaintList(e,t,n),o=i.finished,s=i.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(e),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;dd(function(){l._paintList(e,t,n,a)})}}},r.prototype._compositeManually=function(){var e=this.getLayer(os).ctx,t=this._domRoot.width,n=this._domRoot.height;e.clearRect(0,0,t,n),this.eachBuiltinLayer(function(a){a.virtual&&e.drawImage(a.dom,0,0,t,n)})},r.prototype._doPaintList=function(e,t,n){for(var a=this,i=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||n)&&i.push(u)}for(var c=!0,h=!1,d=function(y){var _=i[y],g=_.ctx,f=o&&_.createRepaintRects(e,t,v._width,v._height),w=n?_.__startIndex:_.__drawIndex,x=!n&&_.incremental&&Date.now,S=x&&Date.now(),A=_.zlevel===v._zlevelList[0]?v._backgroundColor:null;if(_.__startIndex===_.__endIndex)_.clear(!1,A,f);else if(w===_.__startIndex){var T=e[w];(!T.incremental||!T.notClear||n)&&_.clear(!1,A,f)}w===-1&&(console.error("For some unknown reason. drawIndex is -1"),w=_.__startIndex);var L,M=function(E){var D={inHover:!1,allClipped:!1,prevEl:null,viewWidth:a._width,viewHeight:a._height};for(L=w;L<_.__endIndex;L++){var N=e[L];if(N.__inHover&&(h=!0),a._doPaintEl(N,_,o,E,D,L===_.__endIndex-1),x){var V=Date.now()-S;if(V>15)break}}D.prevElClipPaths&&g.restore()};if(f)if(f.length===0)L=_.__endIndex;else for(var I=v.dpr,R=0;R<f.length;++R){var P=f[R];g.save(),g.beginPath(),g.rect(P.x*I,P.y*I,P.width*I,P.height*I),g.clip(),M(P),g.restore()}else g.save(),M(),g.restore();_.__drawIndex=L,_.__drawIndex<_.__endIndex&&(c=!1)},v=this,p=0;p<i.length;p++)d(p);return oe.wxa&&B(this._layers,function(y){y&&y.ctx&&y.ctx.draw&&y.ctx.draw()}),{finished:c,needsRefreshHover:h}},r.prototype._doPaintEl=function(e,t,n,a,i,o){var s=t.ctx;if(n){var l=e.getPaintRect();(!a||l&&l.intersect(a))&&(As(s,e,i,o),e.setPrevPaintRect(l))}else As(s,e,i,o)},r.prototype.getLayer=function(e,t){this._singleCanvas&&!this._needsManuallyCompositing&&(e=os);var n=this._layers[e];return n||(n=new Tm("zr_"+e,this,this.dpr),n.zlevel=e,n.__builtin__=!0,this._layerConfig[e]?qt(n,this._layerConfig[e],!0):this._layerConfig[e-xv]&&qt(n,this._layerConfig[e-xv],!0),t&&(n.virtual=t),this.insertLayer(e,n),n.initContext()),n},r.prototype.insertLayer=function(e,t){var n=this._layers,a=this._zlevelList,i=a.length,o=this._domRoot,s=null,l=-1;if(!n[e]&&sX(t)){if(i>0&&e>a[0]){for(l=0;l<i-1&&!(a[l]<e&&a[l+1]>e);l++);s=n[a[l]]}if(a.splice(l+1,0,e),n[e]=t,!t.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(t.dom,u.nextSibling):o.appendChild(t.dom)}else o.firstChild?o.insertBefore(t.dom,o.firstChild):o.appendChild(t.dom);t.painter||(t.painter=this)}},r.prototype.eachLayer=function(e,t){for(var n=this._zlevelList,a=0;a<n.length;a++){var i=n[a];e.call(t,this._layers[i],i)}},r.prototype.eachBuiltinLayer=function(e,t){for(var n=this._zlevelList,a=0;a<n.length;a++){var i=n[a],o=this._layers[i];o.__builtin__&&e.call(t,o,i)}},r.prototype.eachOtherLayer=function(e,t){for(var n=this._zlevelList,a=0;a<n.length;a++){var i=n[a],o=this._layers[i];o.__builtin__||e.call(t,o,i)}},r.prototype.getLayers=function(){return this._layers},r.prototype._updateLayerStatus=function(e){this.eachBuiltinLayer(function(h,d){h.__dirty=h.__used=!1});function t(h){i&&(i.__endIndex!==h&&(i.__dirty=!0),i.__endIndex=h)}if(this._singleCanvas)for(var n=1;n<e.length;n++){var a=e[n];if(a.zlevel!==e[n-1].zlevel||a.incremental){this._needsManuallyCompositing=!0;break}}var i=null,o=0,s,l;for(l=0;l<e.length;l++){var a=e[l],u=a.zlevel,c=void 0;s!==u&&(s=u,o=0),a.incremental?(c=this.getLayer(u+oX,this._needsManuallyCompositing),c.incremental=!0,o=1):c=this.getLayer(u+(o>0?xv:0),this._needsManuallyCompositing),c.__builtin__||N1("ZLevel "+u+" has been used by unkown layer "+c.id),c!==i&&(c.__used=!0,c.__startIndex!==l&&(c.__dirty=!0),c.__startIndex=l,c.incremental?c.__drawIndex=-1:c.__drawIndex=l,t(l),i=c),a.__dirty&Tn&&!a.__inHover&&(c.__dirty=!0,c.incremental&&c.__drawIndex<0&&(c.__drawIndex=l))}t(l),this.eachBuiltinLayer(function(h,d){!h.__used&&h.getElementCount()>0&&(h.__dirty=!0,h.__startIndex=h.__endIndex=h.__drawIndex=0),h.__dirty&&h.__drawIndex<0&&(h.__drawIndex=h.__startIndex)})},r.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},r.prototype._clearLayer=function(e){e.clear()},r.prototype.setBackgroundColor=function(e){this._backgroundColor=e,B(this._layers,function(t){t.setUnpainted()})},r.prototype.configLayer=function(e,t){if(t){var n=this._layerConfig;n[e]?qt(n[e],t,!0):n[e]=t;for(var a=0;a<this._zlevelList.length;a++){var i=this._zlevelList[a];if(i===e||i===e+xv){var o=this._layers[i];qt(o,n[e],!0)}}}},r.prototype.delLayer=function(e){var t=this._layers,n=this._zlevelList,a=t[e];a&&(a.dom.parentNode.removeChild(a.dom),delete t[e],n.splice(te(n,e),1))},r.prototype.resize=function(e,t){if(this._domRoot.style){var n=this._domRoot;n.style.display="none";var a=this._opts,i=this.root;if(e!=null&&(a.width=e),t!=null&&(a.height=t),e=Gl(i,0,a),t=Gl(i,1,a),n.style.display="",this._width!==e||t!==this._height){n.style.width=e+"px",n.style.height=t+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(e,t);this.refresh(!0)}this._width=e,this._height=t}else{if(e==null||t==null)return;this._width=e,this._height=t,this.getLayer(os).resize(e,t)}return this},r.prototype.clearLayer=function(e){var t=this._layers[e];t&&t.clear()},r.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},r.prototype.getRenderedCanvas=function(e){if(e=e||{},this._singleCanvas&&!this._compositeManually)return this._layers[os].dom;var t=new Tm("image",this,e.pixelRatio||this.dpr);t.initContext(),t.clear(!1,e.backgroundColor||this._backgroundColor);var n=t.ctx;if(e.pixelRatio<=this.dpr){this.refresh();var a=t.dom.width,i=t.dom.height;this.eachLayer(function(h){h.__builtin__?n.drawImage(h.dom,0,0,a,i):h.renderToCanvas&&(n.save(),h.renderToCanvas(n),n.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var c=s[l];As(n,c,o,l===u-1)}return t.dom},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r}();function cX(r){r.registerPainter("canvas",uX)}var hX=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.getInitialData=function(t){return Ri(null,this,{useEncodeDefaulter:!0})},e.prototype.getLegendIcon=function(t){var n=new Wt,a=or("line",0,t.itemHeight/2,t.itemWidth,0,t.lineStyle.stroke,!1);n.add(a),a.setStyle(t.lineStyle);var i=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=i==="none"?"circle":i,l=t.itemHeight*.8,u=or(s,(t.itemWidth-l)/2,(t.itemHeight-l)/2,l,l,t.itemStyle.fill);n.add(u),u.setStyle(t.itemStyle);var c=t.iconRotate==="inherit"?o:t.iconRotate||0;return u.rotation=c*Math.PI/180,u.setOrigin([t.itemWidth/2,t.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill="#fff",u.style.lineWidth=2),n},e.type="series.line",e.dependencies=["grid","polar"],e.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:4,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},e}(Ve);function nu(r,e){var t=r.mapDimensionsAll("defaultedLabel"),n=t.length;if(n===1){var a=tu(r,e,t[0]);return a!=null?a+"":null}else if(n){for(var i=[],o=0;o<t.length;o++)i.push(tu(r,e,t[o]));return i.join(" ")}}function EE(r,e){var t=r.mapDimensionsAll("defaultedLabel");if(!ht(e))return e+"";for(var n=[],a=0;a<t.length;a++){var i=r.getDimensionIndex(t[a]);i>=0&&n.push(e[i])}return n.join(" ")}var Nh=function(r){rt(e,r);function e(t,n,a,i){var o=r.call(this)||this;return o.updateData(t,n,a,i),o}return e.prototype._createSymbol=function(t,n,a,i,o){this.removeAll();var s=or(t,-1,-1,2,2,null,o);s.attr({z2:100,culling:!0,scaleX:i[0]/2,scaleY:i[1]/2}),s.drift=fX,this._symbolType=t,this.add(s)},e.prototype.stopSymbolAnimation=function(t){this.childAt(0).stopAnimation(null,t)},e.prototype.getSymbolType=function(){return this._symbolType},e.prototype.getSymbolPath=function(){return this.childAt(0)},e.prototype.highlight=function(){Ti(this.childAt(0))},e.prototype.downplay=function(){Ci(this.childAt(0))},e.prototype.setZ=function(t,n){var a=this.childAt(0);a.zlevel=t,a.z=n},e.prototype.setDraggable=function(t,n){var a=this.childAt(0);a.draggable=t,a.cursor=!n&&t?"move":a.cursor},e.prototype.updateData=function(t,n,a,i){this.silent=!1;var o=t.getItemVisual(n,"symbol")||"circle",s=t.hostModel,l=e.getSymbolSize(t,n),u=o!==this._symbolType,c=i&&i.disableAnimation;if(u){var h=t.getItemVisual(n,"symbolKeepAspect");this._createSymbol(o,t,n,l,h)}else{var d=this.childAt(0);d.silent=!1;var v={scaleX:l[0]/2,scaleY:l[1]/2};c?d.attr(v):_e(d,v,s,n),xa(d)}if(this._updateCommon(t,n,l,a,i),u){var d=this.childAt(0);if(!c){var v={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:d.style.opacity}};d.scaleX=d.scaleY=0,d.style.opacity=0,He(d,v,s,n)}}c&&this.childAt(0).stopAnimation("leave")},e.prototype._updateCommon=function(t,n,a,i,o){var s=this.childAt(0),l=t.hostModel,u,c,h,d,v,p,y,_,g;if(i&&(u=i.emphasisItemStyle,c=i.blurItemStyle,h=i.selectItemStyle,d=i.focus,v=i.blurScope,y=i.labelStatesModels,_=i.hoverScale,g=i.cursorStyle,p=i.emphasisDisabled),!i||t.hasItemOption){var f=i&&i.itemModel?i.itemModel:t.getItemModel(n),w=f.getModel("emphasis");u=w.getModel("itemStyle").getItemStyle(),h=f.getModel(["select","itemStyle"]).getItemStyle(),c=f.getModel(["blur","itemStyle"]).getItemStyle(),d=w.get("focus"),v=w.get("blurScope"),p=w.get("disabled"),y=_r(f),_=w.getShallow("scale"),g=f.getShallow("cursor")}var x=t.getItemVisual(n,"symbolRotate");s.attr("rotation",(x||0)*Math.PI/180||0);var S=Ys(t.getItemVisual(n,"symbolOffset"),a);S&&(s.x=S[0],s.y=S[1]),g&&s.attr("cursor",g);var A=t.getItemVisual(n,"style"),T=A.fill;if(s instanceof Tr){var L=s.style;s.useStyle(lt({image:L.image,x:L.x,y:L.y,width:L.width,height:L.height},A))}else s.__isEmptyBrush?s.useStyle(lt({},A)):s.useStyle(A),s.style.decal=null,s.setColor(T,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var M=t.getItemVisual(n,"liftZ"),I=this._z2;M!=null?I==null&&(this._z2=s.z2,s.z2+=M):I!=null&&(s.z2=I,this._z2=null);var R=o&&o.useNameLabel;Rr(s,y,{labelFetcher:l,labelDataIndex:n,defaultText:P,inheritColor:T,defaultOpacity:A.opacity});function P(N){return R?t.getName(N):nu(t,N)}this._sizeX=a[0]/2,this._sizeY=a[1]/2;var E=s.ensureState("emphasis");E.style=u,s.ensureState("select").style=h,s.ensureState("blur").style=c;var D=_==null||_===!0?Math.max(1.1,3/this._sizeY):isFinite(_)&&_>0?+_:1;E.scaleX=this._sizeX*D,E.scaleY=this._sizeY*D,this.setSymbolScale(1),Xe(this,d,v,p)},e.prototype.setSymbolScale=function(t){this.scaleX=this.scaleY=t},e.prototype.fadeOut=function(t,n,a){var i=this.childAt(0),o=Ht(this).dataIndex,s=a&&a.animation;if(this.silent=i.silent=!0,a&&a.fadeLabel){var l=i.getTextContent();l&&xo(l,{style:{opacity:0}},n,{dataIndex:o,removeOpt:s,cb:function(){i.removeTextContent()}})}else i.removeTextContent();xo(i,{style:{opacity:0},scaleX:0,scaleY:0},n,{dataIndex:o,cb:t,removeOpt:s})},e.getSymbolSize=function(t,n){return xu(t.getItemVisual(n,"symbolSize"))},e}(Wt);function fX(r,e){this.parent.drift(r,e)}function Cm(r,e,t,n){return e&&!isNaN(e[0])&&!isNaN(e[1])&&!(n.isIgnore&&n.isIgnore(t))&&!(n.clipShape&&!n.clipShape.contain(e[0],e[1]))&&r.getItemVisual(t,"symbol")!=="none"}function wC(r){return r!=null&&!Vt(r)&&(r={isIgnore:r}),r||{}}function xC(r){var e=r.hostModel,t=e.getModel("emphasis");return{emphasisItemStyle:t.getModel("itemStyle").getItemStyle(),blurItemStyle:e.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:e.getModel(["select","itemStyle"]).getItemStyle(),focus:t.get("focus"),blurScope:t.get("blurScope"),emphasisDisabled:t.get("disabled"),hoverScale:t.get("scale"),labelStatesModels:_r(e),cursorStyle:e.get("cursor")}}var zh=function(){function r(e){this.group=new Wt,this._SymbolCtor=e||Nh}return r.prototype.updateData=function(e,t){this._progressiveEls=null,t=wC(t);var n=this.group,a=e.hostModel,i=this._data,o=this._SymbolCtor,s=t.disableAnimation,l=xC(e),u={disableAnimation:s},c=t.getSymbolPoint||function(h){return e.getItemLayout(h)};i||n.removeAll(),e.diff(i).add(function(h){var d=c(h);if(Cm(e,d,h,t)){var v=new o(e,h,l,u);v.setPosition(d),e.setItemGraphicEl(h,v),n.add(v)}}).update(function(h,d){var v=i.getItemGraphicEl(d),p=c(h);if(!Cm(e,p,h,t)){n.remove(v);return}var y=e.getItemVisual(h,"symbol")||"circle",_=v&&v.getSymbolType&&v.getSymbolType();if(!v||_&&_!==y)n.remove(v),v=new o(e,h,l,u),v.setPosition(p);else{v.updateData(e,h,l,u);var g={x:p[0],y:p[1]};s?v.attr(g):_e(v,g,a)}n.add(v),e.setItemGraphicEl(h,v)}).remove(function(h){var d=i.getItemGraphicEl(h);d&&d.fadeOut(function(){n.remove(d)},a)}).execute(),this._getSymbolPoint=c,this._data=e},r.prototype.updateLayout=function(){var e=this,t=this._data;t&&t.eachItemGraphicEl(function(n,a){var i=e._getSymbolPoint(a);n.setPosition(i),n.markRedraw()})},r.prototype.incrementalPrepareUpdate=function(e){this._seriesScope=xC(e),this._data=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(e,t,n){this._progressiveEls=[],n=wC(n);function a(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var i=e.start;i<e.end;i++){var o=t.getItemLayout(i);if(Cm(t,o,i,n)){var s=new this._SymbolCtor(t,i,this._seriesScope);s.traverse(a),s.setPosition(o),this.group.add(s),t.setItemGraphicEl(i,s),this._progressiveEls.push(s)}}},r.prototype.eachRendered=function(e){Co(this._progressiveEls||this.group,e)},r.prototype.remove=function(e){var t=this.group,n=this._data;n&&e?n.eachItemGraphicEl(function(a){a.fadeOut(function(){t.remove(a)},n.hostModel)}):t.removeAll()},r}();function OE(r,e,t){var n=r.getBaseAxis(),a=r.getOtherAxis(n),i=vX(a,t),o=n.dim,s=a.dim,l=e.mapDimension(s),u=e.mapDimension(o),c=s==="x"||s==="radius"?1:0,h=ft(r.dimensions,function(p){return e.mapDimension(p)}),d=!1,v=e.getCalculationInfo("stackResultDimension");return So(e,h[0])&&(d=!0,h[0]=v),So(e,h[1])&&(d=!0,h[1]=v),{dataDimsForPoint:h,valueStart:i,valueAxisDim:s,baseAxisDim:o,stacked:!!d,valueDim:l,baseDim:u,baseDataOffset:c,stackedOverDimension:e.getCalculationInfo("stackedOverDimension")}}function vX(r,e){var t=0,n=r.scale.getExtent();return e==="start"?t=n[0]:e==="end"?t=n[1]:ye(e)&&!isNaN(e)?t=e:n[0]>0?t=n[0]:n[1]<0&&(t=n[1]),t}function BE(r,e,t,n){var a=NaN;r.stacked&&(a=t.get(t.getCalculationInfo("stackedOverDimension"),n)),isNaN(a)&&(a=r.valueStart);var i=r.baseDataOffset,o=[];return o[i]=t.get(r.baseDim,n),o[1-i]=a,e.dataToPoint(o)}function dX(r,e){var t=[];return e.diff(r).add(function(n){t.push({cmd:"+",idx:n})}).update(function(n,a){t.push({cmd:"=",idx:a,idx1:n})}).remove(function(n){t.push({cmd:"-",idx:n})}).execute(),t}function pX(r,e,t,n,a,i,o,s){for(var l=dX(r,e),u=[],c=[],h=[],d=[],v=[],p=[],y=[],_=OE(a,e,o),g=r.getLayout("points")||[],f=e.getLayout("points")||[],w=0;w<l.length;w++){var x=l[w],S=!0,A=void 0,T=void 0;switch(x.cmd){case"=":A=x.idx*2,T=x.idx1*2;var L=g[A],M=g[A+1],I=f[T],R=f[T+1];(isNaN(L)||isNaN(M))&&(L=I,M=R),u.push(L,M),c.push(I,R),h.push(t[A],t[A+1]),d.push(n[T],n[T+1]),y.push(e.getRawIndex(x.idx1));break;case"+":var P=x.idx,E=_.dataDimsForPoint,D=a.dataToPoint([e.get(E[0],P),e.get(E[1],P)]);T=P*2,u.push(D[0],D[1]),c.push(f[T],f[T+1]);var N=BE(_,a,e,P);h.push(N[0],N[1]),d.push(n[T],n[T+1]),y.push(e.getRawIndex(P));break;case"-":S=!1}S&&(v.push(x),p.push(p.length))}p.sort(function(it,Et){return y[it]-y[Et]});for(var V=u.length,W=Ga(V),$=Ga(V),H=Ga(V),K=Ga(V),U=[],w=0;w<p.length;w++){var j=p[w],ut=w*2,ot=j*2;W[ut]=u[ot],W[ut+1]=u[ot+1],$[ut]=c[ot],$[ut+1]=c[ot+1],H[ut]=h[ot],H[ut+1]=h[ot+1],K[ut]=d[ot],K[ut+1]=d[ot+1],U[w]=v[j]}return{current:W,next:$,stackedOnCurrent:H,stackedOnNext:K,status:U}}var qi=Math.min,Ki=Math.max;function Rs(r,e){return isNaN(r)||isNaN(e)}function Z_(r,e,t,n,a,i,o,s,l){for(var u,c,h,d,v,p,y=t,_=0;_<n;_++){var g=e[y*2],f=e[y*2+1];if(y>=a||y<0)break;if(Rs(g,f)){if(l){y+=i;continue}break}if(y===t)r[i>0?"moveTo":"lineTo"](g,f),h=g,d=f;else{var w=g-u,x=f-c;if(w*w+x*x<.5){y+=i;continue}if(o>0){for(var S=y+i,A=e[S*2],T=e[S*2+1];A===g&&T===f&&_<n;)_++,S+=i,y+=i,A=e[S*2],T=e[S*2+1],g=e[y*2],f=e[y*2+1],w=g-u,x=f-c;var L=_+1;if(l)for(;Rs(A,T)&&L<n;)L++,S+=i,A=e[S*2],T=e[S*2+1];var M=.5,I=0,R=0,P=void 0,E=void 0;if(L>=n||Rs(A,T))v=g,p=f;else{I=A-u,R=T-c;var D=g-u,N=A-g,V=f-c,W=T-f,$=void 0,H=void 0;if(s==="x"){$=Math.abs(D),H=Math.abs(N);var K=I>0?1:-1;v=g-K*$*o,p=f,P=g+K*H*o,E=f}else if(s==="y"){$=Math.abs(V),H=Math.abs(W);var U=R>0?1:-1;v=g,p=f-U*$*o,P=g,E=f+U*H*o}else $=Math.sqrt(D*D+V*V),H=Math.sqrt(N*N+W*W),M=H/(H+$),v=g-I*o*(1-M),p=f-R*o*(1-M),P=g+I*o*M,E=f+R*o*M,P=qi(P,Ki(A,g)),E=qi(E,Ki(T,f)),P=Ki(P,qi(A,g)),E=Ki(E,qi(T,f)),I=P-g,R=E-f,v=g-I*$/H,p=f-R*$/H,v=qi(v,Ki(u,g)),p=qi(p,Ki(c,f)),v=Ki(v,qi(u,g)),p=Ki(p,qi(c,f)),I=g-v,R=f-p,P=g+I*H/$,E=f+R*H/$}r.bezierCurveTo(h,d,v,p,g,f),h=P,d=E}else r.lineTo(g,f)}u=g,c=f,y+=i}return _}var NE=function(){function r(){this.smooth=0,this.smoothConstraint=!0}return r}(),gX=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="ec-polyline",n}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new NE},e.prototype.buildPath=function(t,n){var a=n.points,i=0,o=a.length/2;if(n.connectNulls){for(;o>0&&Rs(a[o*2-2],a[o*2-1]);o--);for(;i<o&&Rs(a[i*2],a[i*2+1]);i++);}for(;i<o;)i+=Z_(t,a,i,o,o,1,n.smooth,n.smoothMonotone,n.connectNulls)+1},e.prototype.getPointOn=function(t,n){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var a=this.path,i=a.data,o=ja.CMD,s,l,u=n==="x",c=[],h=0;h<i.length;){var d=i[h++],v=void 0,p=void 0,y=void 0,_=void 0,g=void 0,f=void 0,w=void 0;switch(d){case o.M:s=i[h++],l=i[h++];break;case o.L:if(v=i[h++],p=i[h++],w=u?(t-s)/(v-s):(t-l)/(p-l),w<=1&&w>=0){var x=u?(p-l)*w+l:(v-s)*w+s;return u?[t,x]:[x,t]}s=v,l=p;break;case o.C:v=i[h++],p=i[h++],y=i[h++],_=i[h++],g=i[h++],f=i[h++];var S=u?gd(s,v,y,g,t,c):gd(l,p,_,f,t,c);if(S>0)for(var A=0;A<S;A++){var T=c[A];if(T<=1&&T>=0){var x=u?vr(l,p,_,f,T):vr(s,v,y,g,T);return u?[t,x]:[x,t]}}s=g,l=f;break}}},e}(ie),yX=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e}(NE),zE=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="ec-polygon",n}return e.prototype.getDefaultShape=function(){return new yX},e.prototype.buildPath=function(t,n){var a=n.points,i=n.stackedOnPoints,o=0,s=a.length/2,l=n.smoothMonotone;if(n.connectNulls){for(;s>0&&Rs(a[s*2-2],a[s*2-1]);s--);for(;o<s&&Rs(a[o*2],a[o*2+1]);o++);}for(;o<s;){var u=Z_(t,a,o,s,s,1,n.smooth,l,n.connectNulls);Z_(t,i,o+u-1,u,s,-1,n.stackedOnSmooth,l,n.connectNulls),o+=u+1,t.closePath()}},e}(ie);function FE(r,e,t,n,a){var i=r.getArea(),o=i.x,s=i.y,l=i.width,u=i.height,c=t.get(["lineStyle","width"])||0;o-=c/2,s-=c/2,l+=c,u+=c,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var h=new fe({shape:{x:o,y:s,width:l,height:u}});if(e){var d=r.getBaseAxis(),v=d.isHorizontal(),p=d.inverse;v?(p&&(h.shape.x+=l),h.shape.width=0):(p||(h.shape.y+=u),h.shape.height=0);var y=Nt(a)?function(_){a(_,h)}:null;He(h,{shape:{width:l,height:u,x:o,y:s}},t,null,n,y)}return h}function VE(r,e,t){var n=r.getArea(),a=qe(n.r0,1),i=qe(n.r,1),o=new en({shape:{cx:qe(r.cx,1),cy:qe(r.cy,1),r0:a,r:i,startAngle:n.startAngle,endAngle:n.endAngle,clockwise:n.clockwise}});if(e){var s=r.getBaseAxis().dim==="angle";s?o.shape.endAngle=n.startAngle:o.shape.r=a,He(o,{shape:{endAngle:n.endAngle,r:i}},t)}return o}function Fh(r,e,t,n,a){if(r){if(r.type==="polar")return VE(r,e,t);if(r.type==="cartesian2d")return FE(r,e,t,n,a)}else return null;return null}function $s(r,e){return r.type===e}function bC(r,e){if(r.length===e.length){for(var t=0;t<r.length;t++)if(r[t]!==e[t])return;return!0}}function SC(r){for(var e=1/0,t=1/0,n=-1/0,a=-1/0,i=0;i<r.length;){var o=r[i++],s=r[i++];isNaN(o)||(e=Math.min(o,e),n=Math.max(o,n)),isNaN(s)||(t=Math.min(s,t),a=Math.max(s,a))}return[[e,t],[n,a]]}function AC(r,e){var t=SC(r),n=t[0],a=t[1],i=SC(e),o=i[0],s=i[1];return Math.max(Math.abs(n[0]-o[0]),Math.abs(n[1]-o[1]),Math.abs(a[0]-s[0]),Math.abs(a[1]-s[1]))}function TC(r){return ye(r)?r:r?.5:0}function mX(r,e,t){if(!t.valueDim)return[];for(var n=e.count(),a=Ga(n*2),i=0;i<n;i++){var o=BE(t,r,e,i);a[i*2]=o[0],a[i*2+1]=o[1]}return a}function Qi(r,e,t,n,a){var i=t.getBaseAxis(),o=i.dim==="x"||i.dim==="radius"?0:1,s=[],l=0,u=[],c=[],h=[],d=[];if(a){for(l=0;l<r.length;l+=2){var v=e||r;!isNaN(v[l])&&!isNaN(v[l+1])&&d.push(r[l],r[l+1])}r=d}for(l=0;l<r.length-2;l+=2)switch(h[0]=r[l+2],h[1]=r[l+3],c[0]=r[l],c[1]=r[l+1],s.push(c[0],c[1]),n){case"end":u[o]=h[o],u[1-o]=c[1-o],s.push(u[0],u[1]);break;case"middle":var p=(c[o]+h[o])/2,y=[];u[o]=y[o]=p,u[1-o]=c[1-o],y[1-o]=h[1-o],s.push(u[0],u[1]),s.push(y[0],y[1]);break;default:u[o]=c[o],u[1-o]=h[1-o],s.push(u[0],u[1])}return s.push(r[l++],r[l++]),s}function _X(r,e){var t=[],n=r.length,a,i;function o(c,h,d){var v=c.coord,p=(d-v)/(h.coord-v),y=s8(p,[c.color,h.color]);return{coord:d,color:y}}for(var s=0;s<n;s++){var l=r[s],u=l.coord;if(u<0)a=l;else if(u>e){i?t.push(o(i,l,e)):a&&t.push(o(a,l,0),o(a,l,e));break}else a&&(t.push(o(a,l,0)),a=null),t.push(l),i=l}return t}function wX(r,e,t){var n=r.getVisual("visualMeta");if(!(!n||!n.length||!r.count())&&e.type==="cartesian2d"){for(var a,i,o=n.length-1;o>=0;o--){var s=r.getDimensionInfo(n[o].dimension);if(a=s&&s.coordDim,a==="x"||a==="y"){i=n[o];break}}if(i){var l=e.getAxis(a),u=ft(i.stops,function(w){return{coord:l.toGlobalCoord(l.dataToCoord(w.value)),color:w.color}}),c=u.length,h=i.outerColors.slice();c&&u[0].coord>u[c-1].coord&&(u.reverse(),h.reverse());var d=_X(u,a==="x"?t.getWidth():t.getHeight()),v=d.length;if(!v&&c)return u[0].coord<0?h[1]?h[1]:u[c-1].color:h[0]?h[0]:u[0].color;var p=10,y=d[0].coord-p,_=d[v-1].coord+p,g=_-y;if(g<.001)return"transparent";B(d,function(w){w.offset=(w.coord-y)/g}),d.push({offset:v?d[v-1].offset:.5,color:h[1]||"transparent"}),d.unshift({offset:v?d[0].offset:.5,color:h[0]||"transparent"});var f=new Ih(0,0,0,0,d,!0);return f[a]=y,f[a+"2"]=_,f}}}function xX(r,e,t){var n=r.get("showAllSymbol"),a=n==="auto";if(!(n&&!a)){var i=t.getAxesByScale("ordinal")[0];if(i&&!(a&&bX(i,e))){var o=e.mapDimension(i.dim),s={};return B(i.getViewLabels(),function(l){var u=i.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(e.get(o,l))}}}}function bX(r,e){var t=r.getExtent(),n=Math.abs(t[1]-t[0])/r.scale.count();isNaN(n)&&(n=0);for(var a=e.count(),i=Math.max(1,Math.round(a/5)),o=0;o<a;o+=i)if(Nh.getSymbolSize(e,o)[r.isHorizontal()?1:0]*1.5>n)return!1;return!0}function SX(r,e){return isNaN(r)||isNaN(e)}function AX(r){for(var e=r.length/2;e>0&&SX(r[e*2-2],r[e*2-1]);e--);return e-1}function CC(r,e){return[r[e*2],r[e*2+1]]}function TX(r,e,t){for(var n=r.length/2,a=t==="x"?0:1,i,o,s=0,l=-1,u=0;u<n;u++)if(o=r[u*2+a],!(isNaN(o)||isNaN(r[u*2+1-a]))){if(u===0){i=o;continue}if(i<=e&&o>=e||i>=e&&o<=e){l=u;break}s=u,i=o}return{range:[s,l],t:(e-i)/(o-i)}}function GE(r){if(r.get(["endLabel","show"]))return!0;for(var e=0;e<tn.length;e++)if(r.get([tn[e],"endLabel","show"]))return!0;return!1}function Lm(r,e,t,n){if($s(e,"cartesian2d")){var a=n.getModel("endLabel"),i=a.get("valueAnimation"),o=n.getData(),s={lastFrameIndex:0},l=GE(n)?function(v,p){r._endLabelOnDuring(v,p,o,s,i,a,e)}:null,u=e.getBaseAxis().isHorizontal(),c=FE(e,t,n,function(){var v=r._endLabel;v&&t&&s.originalX!=null&&v.attr({x:s.originalX,y:s.originalY})},l);if(!n.get("clip",!0)){var h=c.shape,d=Math.max(h.width,h.height);u?(h.y-=d,h.height+=d*2):(h.x-=d,h.width+=d*2)}return l&&l(1,c),c}else return VE(e,t,n)}function CX(r,e){var t=e.getBaseAxis(),n=t.isHorizontal(),a=t.inverse,i=n?a?"right":"left":"center",o=n?"middle":a?"top":"bottom";return{normal:{align:r.get("align")||i,verticalAlign:r.get("verticalAlign")||o}}}var LX=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.init=function(){var t=new Wt,n=new zh;this.group.add(n.group),this._symbolDraw=n,this._lineGroup=t,this._changePolyState=Mt(this._changePolyState,this)},e.prototype.render=function(t,n,a){var i=t.coordinateSystem,o=this.group,s=t.getData(),l=t.getModel("lineStyle"),u=t.getModel("areaStyle"),c=s.getLayout("points")||[],h=i.type==="polar",d=this._coordSys,v=this._symbolDraw,p=this._polyline,y=this._polygon,_=this._lineGroup,g=!n.ssr&&t.get("animation"),f=!u.isEmpty(),w=u.get("origin"),x=OE(i,s,w),S=f&&mX(i,s,x),A=t.get("showSymbol"),T=t.get("connectNulls"),L=A&&!h&&xX(t,s,i),M=this._data;M&&M.eachItemGraphicEl(function(it,Et){it.__temp&&(o.remove(it),M.setItemGraphicEl(Et,null))}),A||v.remove(),o.add(_);var I=h?!1:t.get("step"),R;i&&i.getArea&&t.get("clip",!0)&&(R=i.getArea(),R.width!=null?(R.x-=.1,R.y-=.1,R.width+=.2,R.height+=.2):R.r0&&(R.r0-=.5,R.r+=.5)),this._clipShapeForSymbol=R;var P=wX(s,i,a)||s.getVisual("style")[s.getVisual("drawType")];if(!(p&&d.type===i.type&&I===this._step))A&&v.updateData(s,{isIgnore:L,clipShape:R,disableAnimation:!0,getSymbolPoint:function(it){return[c[it*2],c[it*2+1]]}}),g&&this._initSymbolLabelAnimation(s,i,R),I&&(S&&(S=Qi(S,c,i,I,T)),c=Qi(c,null,i,I,T)),p=this._newPolyline(c),f?y=this._newPolygon(c,S):y&&(_.remove(y),y=this._polygon=null),h||this._initOrUpdateEndLabel(t,i,Fs(P)),_.setClipPath(Lm(this,i,!0,t));else{f&&!y?y=this._newPolygon(c,S):y&&!f&&(_.remove(y),y=this._polygon=null),h||this._initOrUpdateEndLabel(t,i,Fs(P));var E=_.getClipPath();if(E){var D=Lm(this,i,!1,t);He(E,{shape:D.shape},t)}else _.setClipPath(Lm(this,i,!0,t));A&&v.updateData(s,{isIgnore:L,clipShape:R,disableAnimation:!0,getSymbolPoint:function(it){return[c[it*2],c[it*2+1]]}}),(!bC(this._stackedOnPoints,S)||!bC(this._points,c))&&(g?this._doUpdateAnimation(s,S,i,a,I,w,T):(I&&(S&&(S=Qi(S,c,i,I,T)),c=Qi(c,null,i,I,T)),p.setShape({points:c}),y&&y.setShape({points:c,stackedOnPoints:S})))}var N=t.getModel("emphasis"),V=N.get("focus"),W=N.get("blurScope"),$=N.get("disabled");if(p.useStyle(zt(l.getLineStyle(),{fill:"none",stroke:P,lineJoin:"bevel"})),kr(p,t,"lineStyle"),p.style.lineWidth>0&&t.get(["emphasis","lineStyle","width"])==="bolder"){var H=p.getState("emphasis").style;H.lineWidth=+p.style.lineWidth+1}Ht(p).seriesIndex=t.seriesIndex,Xe(p,V,W,$);var K=TC(t.get("smooth")),U=t.get("smoothMonotone");if(p.setShape({smooth:K,smoothMonotone:U,connectNulls:T}),y){var j=s.getCalculationInfo("stackedOnSeries"),ut=0;y.useStyle(zt(u.getAreaStyle(),{fill:P,opacity:.7,lineJoin:"bevel",decal:s.getVisual("style").decal})),j&&(ut=TC(j.get("smooth"))),y.setShape({smooth:K,stackedOnSmooth:ut,smoothMonotone:U,connectNulls:T}),kr(y,t,"areaStyle"),Ht(y).seriesIndex=t.seriesIndex,Xe(y,V,W,$)}var ot=this._changePolyState;s.eachItemGraphicEl(function(it){it&&(it.onHoverStateChange=ot)}),this._polyline.onHoverStateChange=ot,this._data=s,this._coordSys=i,this._stackedOnPoints=S,this._points=c,this._step=I,this._valueOrigin=w,t.get("triggerLineEvent")&&(this.packEventData(t,p),y&&this.packEventData(t,y))},e.prototype.packEventData=function(t,n){Ht(n).eventData={componentType:"series",componentSubType:"line",componentIndex:t.componentIndex,seriesIndex:t.seriesIndex,seriesName:t.name,seriesType:"line"}},e.prototype.highlight=function(t,n,a,i){var o=t.getData(),s=Bs(o,i);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var c=l[s*2],h=l[s*2+1];if(isNaN(c)||isNaN(h)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(c,h))return;var d=t.get("zlevel")||0,v=t.get("z")||0;u=new Nh(o,s),u.x=c,u.y=h,u.setZ(d,v);var p=u.getSymbolPath().getTextContent();p&&(p.zlevel=d,p.z=v,p.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else Re.prototype.highlight.call(this,t,n,a,i)},e.prototype.downplay=function(t,n,a,i){var o=t.getData(),s=Bs(o,i);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else Re.prototype.downplay.call(this,t,n,a,i)},e.prototype._changePolyState=function(t){var n=this._polygon;Sd(this._polyline,t),n&&Sd(n,t)},e.prototype._newPolyline=function(t){var n=this._polyline;return n&&this._lineGroup.remove(n),n=new gX({shape:{points:t},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(n),this._polyline=n,n},e.prototype._newPolygon=function(t,n){var a=this._polygon;return a&&this._lineGroup.remove(a),a=new zE({shape:{points:t,stackedOnPoints:n},segmentIgnoreThreshold:2}),this._lineGroup.add(a),this._polygon=a,a},e.prototype._initSymbolLabelAnimation=function(t,n,a){var i,o,s=n.getBaseAxis(),l=s.inverse;n.type==="cartesian2d"?(i=s.isHorizontal(),o=!1):n.type==="polar"&&(i=s.dim==="angle",o=!0);var u=t.hostModel,c=u.get("animationDuration");Nt(c)&&(c=c(null));var h=u.get("animationDelay")||0,d=Nt(h)?h(null):h;t.eachItemGraphicEl(function(v,p){var y=v;if(y){var _=[v.x,v.y],g=void 0,f=void 0,w=void 0;if(a)if(o){var x=a,S=n.pointToCoord(_);i?(g=x.startAngle,f=x.endAngle,w=-S[1]/180*Math.PI):(g=x.r0,f=x.r,w=S[0])}else{var A=a;i?(g=A.x,f=A.x+A.width,w=v.x):(g=A.y+A.height,f=A.y,w=v.y)}var T=f===g?0:(w-g)/(f-g);l&&(T=1-T);var L=Nt(h)?h(p):c*T+d,M=y.getSymbolPath(),I=M.getTextContent();y.attr({scaleX:0,scaleY:0}),y.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:L}),I&&I.animateFrom({style:{opacity:0}},{duration:300,delay:L}),M.disableLabelAnimation=!0}})},e.prototype._initOrUpdateEndLabel=function(t,n,a){var i=t.getModel("endLabel");if(GE(t)){var o=t.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new pe({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var c=AX(l);c>=0&&(Rr(s,_r(t,"endLabel"),{inheritColor:a,labelFetcher:t,labelDataIndex:c,defaultText:function(h,d,v){return v!=null?EE(o,v):nu(o,h)},enableTextSetter:!0},CX(i,n)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},e.prototype._endLabelOnDuring=function(t,n,a,i,o,s,l){var u=this._endLabel,c=this._polyline;if(u){t<1&&i.originalX==null&&(i.originalX=u.x,i.originalY=u.y);var h=a.getLayout("points"),d=a.hostModel,v=d.get("connectNulls"),p=s.get("precision"),y=s.get("distance")||0,_=l.getBaseAxis(),g=_.isHorizontal(),f=_.inverse,w=n.shape,x=f?g?w.x:w.y+w.height:g?w.x+w.width:w.y,S=(g?y:0)*(f?-1:1),A=(g?0:-y)*(f?-1:1),T=g?"x":"y",L=TX(h,x,T),M=L.range,I=M[1]-M[0],R=void 0;if(I>=1){if(I>1&&!v){var P=CC(h,M[0]);u.attr({x:P[0]+S,y:P[1]+A}),o&&(R=d.getRawValue(M[0]))}else{var P=c.getPointOn(x,T);P&&u.attr({x:P[0]+S,y:P[1]+A});var E=d.getRawValue(M[0]),D=d.getRawValue(M[1]);o&&(R=TP(a,p,E,D,L.t))}i.lastFrameIndex=M[0]}else{var N=t===1||i.lastFrameIndex>0?M[0]:0,P=CC(h,N);o&&(R=d.getRawValue(N)),u.attr({x:P[0]+S,y:P[1]+A})}if(o){var V=du(u);typeof V.setLabelText=="function"&&V.setLabelText(R)}}},e.prototype._doUpdateAnimation=function(t,n,a,i,o,s,l){var u=this._polyline,c=this._polygon,h=t.hostModel,d=pX(this._data,t,this._stackedOnPoints,n,this._coordSys,a,this._valueOrigin),v=d.current,p=d.stackedOnCurrent,y=d.next,_=d.stackedOnNext;if(o&&(p=Qi(d.stackedOnCurrent,d.current,a,o,l),v=Qi(d.current,null,a,o,l),_=Qi(d.stackedOnNext,d.next,a,o,l),y=Qi(d.next,null,a,o,l)),AC(v,y)>3e3||c&&AC(p,_)>3e3){u.stopAnimation(),u.setShape({points:y}),c&&(c.stopAnimation(),c.setShape({points:y,stackedOnPoints:_}));return}u.shape.__points=d.current,u.shape.points=v;var g={shape:{points:y}};d.current!==v&&(g.shape.__points=d.next),u.stopAnimation(),_e(u,g,h),c&&(c.setShape({points:v,stackedOnPoints:p}),c.stopAnimation(),_e(c,{shape:{stackedOnPoints:_}},h),u.shape.points!==c.shape.points&&(c.shape.points=u.shape.points));for(var f=[],w=d.status,x=0;x<w.length;x++){var S=w[x].cmd;if(S==="="){var A=t.getItemGraphicEl(w[x].idx1);A&&f.push({el:A,ptIdx:x})}}u.animators&&u.animators.length&&u.animators[0].during(function(){c&&c.dirtyShape();for(var T=u.shape.__points,L=0;L<f.length;L++){var M=f[L].el,I=f[L].ptIdx*2;M.x=T[I],M.y=T[I+1],M.markRedraw()}})},e.prototype.remove=function(t){var n=this.group,a=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),a&&a.eachItemGraphicEl(function(i,o){i.__temp&&(n.remove(i),a.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},e.type="line",e}(Re);function Vh(r,e){return{seriesType:r,plan:_u(),reset:function(t){var n=t.getData(),a=t.coordinateSystem,i=t.pipelineContext,o=e||i.large;if(a){var s=ft(a.dimensions,function(v){return n.mapDimension(v)}).slice(0,2),l=s.length,u=n.getCalculationInfo("stackResultDimension");So(n,s[0])&&(s[0]=u),So(n,s[1])&&(s[1]=u);var c=n.getStore(),h=n.getDimensionIndex(s[0]),d=n.getDimensionIndex(s[1]);return l&&{progress:function(v,p){for(var y=v.end-v.start,_=o&&Ga(y*l),g=[],f=[],w=v.start,x=0;w<v.end;w++){var S=void 0;if(l===1){var A=c.get(h,w);S=a.dataToPoint(A,null,f)}else g[0]=c.get(h,w),g[1]=c.get(d,w),S=a.dataToPoint(g,null,f);o?(_[x++]=S[0],_[x++]=S[1]):p.setItemLayout(w,S.slice())}o&&p.setLayout("points",_)}}}}}}var MX={average:function(r){for(var e=0,t=0,n=0;n<r.length;n++)isNaN(r[n])||(e+=r[n],t++);return t===0?NaN:e/t},sum:function(r){for(var e=0,t=0;t<r.length;t++)e+=r[t]||0;return e},max:function(r){for(var e=-1/0,t=0;t<r.length;t++)r[t]>e&&(e=r[t]);return isFinite(e)?e:NaN},min:function(r){for(var e=1/0,t=0;t<r.length;t++)r[t]<e&&(e=r[t]);return isFinite(e)?e:NaN},nearest:function(r){return r[0]}},DX=function(r){return Math.round(r.length/2)};function WE(r){return{seriesType:r,reset:function(e,t,n){var a=e.getData(),i=e.get("sampling"),o=e.coordinateSystem,s=a.count();if(s>10&&o.type==="cartesian2d"&&i){var l=o.getBaseAxis(),u=o.getOtherAxis(l),c=l.getExtent(),h=n.getDevicePixelRatio(),d=Math.abs(c[1]-c[0])*(h||1),v=Math.round(s/d);if(isFinite(v)&&v>1){i==="lttb"?e.setData(a.lttbDownSample(a.mapDimension(u.dim),1/v)):i==="minmax"&&e.setData(a.minmaxDownSample(a.mapDimension(u.dim),1/v));var p=void 0;Lt(i)?p=MX[i]:Nt(i)&&(p=i),p&&e.setData(a.downSample(a.mapDimension(u.dim),1/v,p,DX))}}}}}function IX(r){r.registerChartView(LX),r.registerSeriesModel(hX),r.registerLayout(Vh("line",!0)),r.registerVisual({seriesType:"line",reset:function(e){var t=e.getData(),n=e.getModel("lineStyle").getLineStyle();n&&!n.stroke&&(n.stroke=t.getVisual("style").fill),t.setVisual("legendLineStyle",n)}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,WE("line"))}var fh=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(t,n){return Ri(null,this,{useEncodeDefaulter:!0})},e.prototype.getMarkerPosition=function(t,n,a){var i=this.coordinateSystem;if(i&&i.clampData){var o=i.clampData(t),s=i.dataToPoint(o);if(a)B(i.getAxes(),function(d,v){if(d.type==="category"&&n!=null){var p=d.getTicksCoords(),y=d.getTickModel().get("alignWithLabel"),_=o[v],g=n[v]==="x1"||n[v]==="y1";if(g&&!y&&(_+=1),p.length<2)return;if(p.length===2){s[v]=d.toGlobalCoord(d.getExtent()[g?1:0]);return}for(var f=void 0,w=void 0,x=1,S=0;S<p.length;S++){var A=p[S].coord,T=S===p.length-1?p[S-1].tickValue+x:p[S].tickValue;if(T===_){w=A;break}else if(T<_)f=A;else if(f!=null&&T>_){w=(A+f)/2;break}S===1&&(x=T-p[0].tickValue)}w==null&&(f?f&&(w=p[p.length-1].coord):w=p[0].coord),s[v]=d.toGlobalCoord(w)}});else{var l=this.getData(),u=l.getLayout("offset"),c=l.getLayout("size"),h=i.getBaseAxis().isHorizontal()?0:1;s[h]+=u+c/2}return s}return[NaN,NaN]},e.type="series.__base_bar__",e.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,barMinHeight:0,barMinAngle:0,large:!1,largeThreshold:400,progressive:3e3,progressiveChunkMode:"mod"},e}(Ve);Ve.registerClass(fh);var PX=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(){return Ri(null,this,{useEncodeDefaulter:!0,createInvertedIndices:!!this.get("realtimeSort",!0)||null})},e.prototype.getProgressive=function(){return this.get("large")?this.get("progressive"):!1},e.prototype.getProgressiveThreshold=function(){var t=this.get("progressiveThreshold"),n=this.get("largeThreshold");return n>t&&(t=n),t},e.prototype.brushSelector=function(t,n,a){return a.rect(n.getItemLayout(t))},e.type="series.bar",e.dependencies=["grid","polar"],e.defaultOption=Lo(fh.defaultOption,{clip:!0,roundCap:!1,showBackground:!1,backgroundStyle:{color:"rgba(180, 180, 180, 0.2)",borderColor:null,borderWidth:0,borderType:"solid",borderRadius:0,shadowBlur:0,shadowColor:null,shadowOffsetX:0,shadowOffsetY:0,opacity:1},select:{itemStyle:{borderColor:"#212121"}},realtimeSort:!1}),e}(fh),kX=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),Wd=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="sausage",n}return e.prototype.getDefaultShape=function(){return new kX},e.prototype.buildPath=function(t,n){var a=n.cx,i=n.cy,o=Math.max(n.r0||0,0),s=Math.max(n.r,0),l=(s-o)*.5,u=o+l,c=n.startAngle,h=n.endAngle,d=n.clockwise,v=Math.PI*2,p=d?h-c<v:c-h<v;p||(c=h-(d?v:-v));var y=Math.cos(c),_=Math.sin(c),g=Math.cos(h),f=Math.sin(h);p?(t.moveTo(y*o+a,_*o+i),t.arc(y*u+a,_*u+i,l,-Math.PI+c,c,!d)):t.moveTo(y*s+a,_*s+i),t.arc(a,i,s,c,h,!d),t.arc(g*u+a,f*u+i,l,h-Math.PI*2,h-Math.PI,!d),o!==0&&t.arc(a,i,o,h,c,d)},e}(ie);function RX(r,e){e=e||{};var t=e.isRoundCap;return function(n,a,i){var o=a.position;if(!o||o instanceof Array)return xd(n,a,i);var s=r(o),l=a.distance!=null?a.distance:5,u=this.shape,c=u.cx,h=u.cy,d=u.r,v=u.r0,p=(d+v)/2,y=u.startAngle,_=u.endAngle,g=(y+_)/2,f=t?Math.abs(d-v)/2:0,w=Math.cos,x=Math.sin,S=c+d*w(y),A=h+d*x(y),T="left",L="top";switch(s){case"startArc":S=c+(v-l)*w(g),A=h+(v-l)*x(g),T="center",L="top";break;case"insideStartArc":S=c+(v+l)*w(g),A=h+(v+l)*x(g),T="center",L="bottom";break;case"startAngle":S=c+p*w(y)+bv(y,l+f,!1),A=h+p*x(y)+Sv(y,l+f,!1),T="right",L="middle";break;case"insideStartAngle":S=c+p*w(y)+bv(y,-l+f,!1),A=h+p*x(y)+Sv(y,-l+f,!1),T="left",L="middle";break;case"middle":S=c+p*w(g),A=h+p*x(g),T="center",L="middle";break;case"endArc":S=c+(d+l)*w(g),A=h+(d+l)*x(g),T="center",L="bottom";break;case"insideEndArc":S=c+(d-l)*w(g),A=h+(d-l)*x(g),T="center",L="top";break;case"endAngle":S=c+p*w(_)+bv(_,l+f,!0),A=h+p*x(_)+Sv(_,l+f,!0),T="left",L="middle";break;case"insideEndAngle":S=c+p*w(_)+bv(_,-l+f,!0),A=h+p*x(_)+Sv(_,-l+f,!0),T="right",L="middle";break;default:return xd(n,a,i)}return n=n||{},n.x=S,n.y=A,n.align=T,n.verticalAlign=L,n}}function EX(r,e,t,n){if(ye(n)){r.setTextConfig({rotation:n});return}else if(ht(e)){r.setTextConfig({rotation:0});return}var a=r.shape,i=a.clockwise?a.startAngle:a.endAngle,o=a.clockwise?a.endAngle:a.startAngle,s=(i+o)/2,l,u=t(e);switch(u){case"startArc":case"insideStartArc":case"middle":case"insideEndArc":case"endArc":l=s;break;case"startAngle":case"insideStartAngle":l=i;break;case"endAngle":case"insideEndAngle":l=o;break;default:r.setTextConfig({rotation:0});return}var c=Math.PI*1.5-l;u==="middle"&&c>Math.PI/2&&c<Math.PI*1.5&&(c-=Math.PI),r.setTextConfig({rotation:c})}function bv(r,e,t){return e*Math.sin(r)*(t?-1:1)}function Sv(r,e,t){return e*Math.cos(r)*(t?1:-1)}function Ts(r,e,t){var n=r.get("borderRadius");if(n==null)return t?{cornerRadius:0}:null;ht(n)||(n=[n,n,n,n]);var a=Math.abs(e.r||0-e.r0||0);return{cornerRadius:ft(n,function(i){return wa(i,a)})}}var Mm=Math.max,Dm=Math.min;function OX(r,e){var t=r.getArea&&r.getArea();if($s(r,"cartesian2d")){var n=r.getBaseAxis();if(n.type!=="category"||!n.onBand){var a=e.getLayout("bandWidth");n.isHorizontal()?(t.x-=a,t.width+=a*2):(t.y-=a,t.height+=a*2)}}return t}var BX=function(r){rt(e,r);function e(){var t=r.call(this)||this;return t.type=e.type,t._isFirstFrame=!0,t}return e.prototype.render=function(t,n,a,i){this._model=t,this._removeOnRenderedListener(a),this._updateDrawMode(t);var o=t.get("coordinateSystem");(o==="cartesian2d"||o==="polar")&&(this._progressiveEls=null,this._isLargeDraw?this._renderLarge(t,n,a):this._renderNormal(t,n,a,i))},e.prototype.incrementalPrepareRender=function(t){this._clear(),this._updateDrawMode(t),this._updateLargeClip(t)},e.prototype.incrementalRender=function(t,n){this._progressiveEls=[],this._incrementalRenderLarge(t,n)},e.prototype.eachRendered=function(t){Co(this._progressiveEls||this.group,t)},e.prototype._updateDrawMode=function(t){var n=t.pipelineContext.large;(this._isLargeDraw==null||n!==this._isLargeDraw)&&(this._isLargeDraw=n,this._clear())},e.prototype._renderNormal=function(t,n,a,i){var o=this.group,s=t.getData(),l=this._data,u=t.coordinateSystem,c=u.getBaseAxis(),h;u.type==="cartesian2d"?h=c.isHorizontal():u.type==="polar"&&(h=c.dim==="angle");var d=t.isAnimationEnabled()?t:null,v=NX(t,u);v&&this._enableRealtimeSort(v,s,a);var p=t.get("clip",!0)||v,y=OX(u,s);o.removeClipPath();var _=t.get("roundCap",!0),g=t.get("showBackground",!0),f=t.getModel("backgroundStyle"),w=f.get("borderRadius")||0,x=[],S=this._backgroundEls,A=i&&i.isInitSort,T=i&&i.type==="changeAxisOrder";function L(R){var P=Av[u.type](s,R),E=UX(u,h,P);return E.useStyle(f.getItemStyle()),u.type==="cartesian2d"?E.setShape("r",w):E.setShape("cornerRadius",w),x[R]=E,E}s.diff(l).add(function(R){var P=s.getItemModel(R),E=Av[u.type](s,R,P);if(g&&L(R),!(!s.hasValue(R)||!PC[u.type](E))){var D=!1;p&&(D=LC[u.type](y,E));var N=MC[u.type](t,s,R,E,h,d,c.model,!1,_);v&&(N.forceLabelAnimation=!0),kC(N,s,R,P,E,t,h,u.type==="polar"),A?N.attr({shape:E}):v?DC(v,d,N,E,R,h,!1,!1):He(N,{shape:E},t,R),s.setItemGraphicEl(R,N),o.add(N),N.ignore=D}}).update(function(R,P){var E=s.getItemModel(R),D=Av[u.type](s,R,E);if(g){var N=void 0;S.length===0?N=L(P):(N=S[P],N.useStyle(f.getItemStyle()),u.type==="cartesian2d"?N.setShape("r",w):N.setShape("cornerRadius",w),x[R]=N);var V=Av[u.type](s,R),W=UE(h,V,u);_e(N,{shape:W},d,R)}var $=l.getItemGraphicEl(P);if(!s.hasValue(R)||!PC[u.type](D)){o.remove($);return}var H=!1;if(p&&(H=LC[u.type](y,D),H&&o.remove($)),$?xa($):$=MC[u.type](t,s,R,D,h,d,c.model,!!$,_),v&&($.forceLabelAnimation=!0),T){var K=$.getTextContent();if(K){var U=du(K);U.prevValue!=null&&(U.prevValue=U.value)}}else kC($,s,R,E,D,t,h,u.type==="polar");A?$.attr({shape:D}):v?DC(v,d,$,D,R,h,!0,T):_e($,{shape:D},t,R,null),s.setItemGraphicEl(R,$),$.ignore=H,o.add($)}).remove(function(R){var P=l.getItemGraphicEl(R);P&&rh(P,t,R)}).execute();var M=this._backgroundGroup||(this._backgroundGroup=new Wt);M.removeAll();for(var I=0;I<x.length;++I)M.add(x[I]);o.add(M),this._backgroundEls=x,this._data=s},e.prototype._renderLarge=function(t,n,a){this._clear(),EC(t,this.group),this._updateLargeClip(t)},e.prototype._incrementalRenderLarge=function(t,n){this._removeBackground(),EC(n,this.group,this._progressiveEls,!0)},e.prototype._updateLargeClip=function(t){var n=t.get("clip",!0)&&Fh(t.coordinateSystem,!1,t),a=this.group;n?a.setClipPath(n):a.removeClipPath()},e.prototype._enableRealtimeSort=function(t,n,a){var i=this;if(n.count()){var o=t.baseAxis;if(this._isFirstFrame)this._dispatchInitSort(n,t,a),this._isFirstFrame=!1;else{var s=function(l){var u=n.getItemGraphicEl(l),c=u&&u.shape;return c&&Math.abs(o.isHorizontal()?c.height:c.width)||0};this._onRendered=function(){i._updateSortWithinSameData(n,s,o,a)},a.getZr().on("rendered",this._onRendered)}}},e.prototype._dataSort=function(t,n,a){var i=[];return t.each(t.mapDimension(n.dim),function(o,s){var l=a(s);l=l??NaN,i.push({dataIndex:s,mappedValue:l,ordinalNumber:o})}),i.sort(function(o,s){return s.mappedValue-o.mappedValue}),{ordinalNumbers:ft(i,function(o){return o.ordinalNumber})}},e.prototype._isOrderChangedWithinSameData=function(t,n,a){for(var i=a.scale,o=t.mapDimension(a.dim),s=Number.MAX_VALUE,l=0,u=i.getOrdinalMeta().categories.length;l<u;++l){var c=t.rawIndexOf(o,i.getRawOrdinalNumber(l)),h=c<0?Number.MIN_VALUE:n(t.indexOfRawIndex(c));if(h>s)return!0;s=h}return!1},e.prototype._isOrderDifferentInView=function(t,n){for(var a=n.scale,i=a.getExtent(),o=Math.max(0,i[0]),s=Math.min(i[1],a.getOrdinalMeta().categories.length-1);o<=s;++o)if(t.ordinalNumbers[o]!==a.getRawOrdinalNumber(o))return!0},e.prototype._updateSortWithinSameData=function(t,n,a,i){if(this._isOrderChangedWithinSameData(t,n,a)){var o=this._dataSort(t,a,n);this._isOrderDifferentInView(o,a)&&(this._removeOnRenderedListener(i),i.dispatchAction({type:"changeAxisOrder",componentType:a.dim+"Axis",axisId:a.index,sortInfo:o}))}},e.prototype._dispatchInitSort=function(t,n,a){var i=n.baseAxis,o=this._dataSort(t,i,function(s){return t.get(t.mapDimension(n.otherAxis.dim),s)});a.dispatchAction({type:"changeAxisOrder",componentType:i.dim+"Axis",isInitSort:!0,axisId:i.index,sortInfo:o})},e.prototype.remove=function(t,n){this._clear(this._model),this._removeOnRenderedListener(n)},e.prototype.dispose=function(t,n){this._removeOnRenderedListener(n)},e.prototype._removeOnRenderedListener=function(t){this._onRendered&&(t.getZr().off("rendered",this._onRendered),this._onRendered=null)},e.prototype._clear=function(t){var n=this.group,a=this._data;t&&t.isAnimationEnabled()&&a&&!this._isLargeDraw?(this._removeBackground(),this._backgroundEls=[],a.eachItemGraphicEl(function(i){rh(i,t,Ht(i).dataIndex)})):n.removeAll(),this._data=null,this._isFirstFrame=!0},e.prototype._removeBackground=function(){this.group.remove(this._backgroundGroup),this._backgroundGroup=null},e.type="bar",e}(Re),LC={cartesian2d:function(r,e){var t=e.width<0?-1:1,n=e.height<0?-1:1;t<0&&(e.x+=e.width,e.width=-e.width),n<0&&(e.y+=e.height,e.height=-e.height);var a=r.x+r.width,i=r.y+r.height,o=Mm(e.x,r.x),s=Dm(e.x+e.width,a),l=Mm(e.y,r.y),u=Dm(e.y+e.height,i),c=s<o,h=u<l;return e.x=c&&o>a?s:o,e.y=h&&l>i?u:l,e.width=c?0:s-o,e.height=h?0:u-l,t<0&&(e.x+=e.width,e.width=-e.width),n<0&&(e.y+=e.height,e.height=-e.height),c||h},polar:function(r,e){var t=e.r0<=e.r?1:-1;if(t<0){var n=e.r;e.r=e.r0,e.r0=n}var a=Dm(e.r,r.r),i=Mm(e.r0,r.r0);e.r=a,e.r0=i;var o=a-i<0;if(t<0){var n=e.r;e.r=e.r0,e.r0=n}return o}},MC={cartesian2d:function(r,e,t,n,a,i,o,s,l){var u=new fe({shape:lt({},n),z2:1});if(u.__dataIndex=t,u.name="item",i){var c=u.shape,h=a?"height":"width";c[h]=0}return u},polar:function(r,e,t,n,a,i,o,s,l){var u=!a&&l?Wd:en,c=new u({shape:n,z2:1});c.name="item";var h=HE(a);if(c.calculateTextPosition=RX(h,{isRoundCap:u===Wd}),i){var d=c.shape,v=a?"r":"endAngle",p={};d[v]=a?n.r0:n.startAngle,p[v]=n[v],(s?_e:He)(c,{shape:p},i)}return c}};function NX(r,e){var t=r.get("realtimeSort",!0),n=e.getBaseAxis();if(t&&n.type==="category"&&e.type==="cartesian2d")return{baseAxis:n,otherAxis:e.getOtherAxis(n)}}function DC(r,e,t,n,a,i,o,s){var l,u;i?(u={x:n.x,width:n.width},l={y:n.y,height:n.height}):(u={y:n.y,height:n.height},l={x:n.x,width:n.width}),s||(o?_e:He)(t,{shape:l},e,a,null);var c=e?r.baseAxis.model:null;(o?_e:He)(t,{shape:u},c,a)}function IC(r,e){for(var t=0;t<e.length;t++)if(!isFinite(r[e[t]]))return!0;return!1}var zX=["x","y","width","height"],FX=["cx","cy","r","startAngle","endAngle"],PC={cartesian2d:function(r){return!IC(r,zX)},polar:function(r){return!IC(r,FX)}},Av={cartesian2d:function(r,e,t){var n=r.getItemLayout(e),a=t?GX(t,n):0,i=n.width>0?1:-1,o=n.height>0?1:-1;return{x:n.x+i*a/2,y:n.y+o*a/2,width:n.width-i*a,height:n.height-o*a}},polar:function(r,e,t){var n=r.getItemLayout(e);return{cx:n.cx,cy:n.cy,r0:n.r0,r:n.r,startAngle:n.startAngle,endAngle:n.endAngle,clockwise:n.clockwise}}};function VX(r){return r.startAngle!=null&&r.endAngle!=null&&r.startAngle===r.endAngle}function HE(r){return function(e){var t=e?"Arc":"Angle";return function(n){switch(n){case"start":case"insideStart":case"end":case"insideEnd":return n+t;default:return n}}}(r)}function kC(r,e,t,n,a,i,o,s){var l=e.getItemVisual(t,"style");if(s){if(!i.get("roundCap")){var c=r.shape,h=Ts(n.getModel("itemStyle"),c,!0);lt(c,h),r.setShape(c)}}else{var u=n.get(["itemStyle","borderRadius"])||0;r.setShape("r",u)}r.useStyle(l);var d=n.getShallow("cursor");d&&r.attr("cursor",d);var v=s?o?a.r>=a.r0?"endArc":"startArc":a.endAngle>=a.startAngle?"endAngle":"startAngle":o?a.height>=0?"bottom":"top":a.width>=0?"right":"left",p=_r(n);Rr(r,p,{labelFetcher:i,labelDataIndex:t,defaultText:nu(i.getData(),t),inheritColor:l.fill,defaultOpacity:l.opacity,defaultOutsidePosition:v});var y=r.getTextContent();if(s&&y){var _=n.get(["label","position"]);r.textConfig.inside=_==="middle"?!0:null,EX(r,_==="outside"?v:_,HE(o),n.get(["label","rotate"]))}lk(y,p,i.getRawValue(t),function(f){return EE(e,f)});var g=n.getModel(["emphasis"]);Xe(r,g.get("focus"),g.get("blurScope"),g.get("disabled")),kr(r,n),VX(a)&&(r.style.fill="none",r.style.stroke="none",B(r.states,function(f){f.style&&(f.style.fill=f.style.stroke="none")}))}function GX(r,e){var t=r.get(["itemStyle","borderColor"]);if(!t||t==="none")return 0;var n=r.get(["itemStyle","borderWidth"])||0,a=isNaN(e.width)?Number.MAX_VALUE:Math.abs(e.width),i=isNaN(e.height)?Number.MAX_VALUE:Math.abs(e.height);return Math.min(n,a,i)}var WX=function(){function r(){}return r}(),RC=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="largeBar",n}return e.prototype.getDefaultShape=function(){return new WX},e.prototype.buildPath=function(t,n){for(var a=n.points,i=this.baseDimIdx,o=1-this.baseDimIdx,s=[],l=[],u=this.barWidth,c=0;c<a.length;c+=3)l[i]=u,l[o]=a[c+2],s[i]=a[c+i],s[o]=a[c+o],t.rect(s[0],s[1],l[0],l[1])},e}(ie);function EC(r,e,t,n){var a=r.getData(),i=a.getLayout("valueAxisHorizontal")?1:0,o=a.getLayout("largeDataIndices"),s=a.getLayout("size"),l=r.getModel("backgroundStyle"),u=a.getLayout("largeBackgroundPoints");if(u){var c=new RC({shape:{points:u},incremental:!!n,silent:!0,z2:0});c.baseDimIdx=i,c.largeDataIndices=o,c.barWidth=s,c.useStyle(l.getItemStyle()),e.add(c),t&&t.push(c)}var h=new RC({shape:{points:a.getLayout("largePoints")},incremental:!!n,ignoreCoarsePointer:!0,z2:1});h.baseDimIdx=i,h.largeDataIndices=o,h.barWidth=s,e.add(h),h.useStyle(a.getVisual("style")),h.style.stroke=null,Ht(h).seriesIndex=r.seriesIndex,r.get("silent")||(h.on("mousedown",OC),h.on("mousemove",OC)),t&&t.push(h)}var OC=Sw(function(r){var e=this,t=HX(e,r.offsetX,r.offsetY);Ht(e).dataIndex=t>=0?t:null},30,!1);function HX(r,e,t){for(var n=r.baseDimIdx,a=1-n,i=r.shape.points,o=r.largeDataIndices,s=[],l=[],u=r.barWidth,c=0,h=i.length/3;c<h;c++){var d=c*3;if(l[n]=u,l[a]=i[d+2],s[n]=i[d+n],s[a]=i[d+a],l[a]<0&&(s[a]+=l[a],l[a]=-l[a]),e>=s[0]&&e<=s[0]+l[0]&&t>=s[1]&&t<=s[1]+l[1])return o[c]}return-1}function UE(r,e,t){if($s(t,"cartesian2d")){var n=e,a=t.getArea();return{x:r?n.x:a.x,y:r?a.y:n.y,width:r?n.width:a.width,height:r?a.height:n.height}}else{var a=t.getArea(),i=e;return{cx:a.cx,cy:a.cy,r0:r?a.r0:i.r0,r:r?a.r:i.r,startAngle:r?i.startAngle:0,endAngle:r?i.endAngle:Math.PI*2}}}function UX(r,e,t){var n=r.type==="polar"?en:fe;return new n({shape:UE(e,t,r),silent:!0,z2:0})}function ZX(r){r.registerChartView(BX),r.registerSeriesModel(PX),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,Xt(jR,"bar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,qR("bar")),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,WE("bar")),r.registerAction({type:"changeAxisOrder",event:"changeAxisOrder",update:"update"},function(e,t){var n=e.componentType||"series";t.eachComponent({mainType:n,query:e},function(a){e.sortInfo&&a.axis.setCategorySortInfo(e.sortInfo)})})}var BC=Math.PI*2,Tv=Math.PI/180;function ZE(r,e){return cr(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function YE(r,e){var t=ZE(r,e),n=r.get("center"),a=r.get("radius");ht(a)||(a=[0,a]);var i=At(t.width,e.getWidth()),o=At(t.height,e.getHeight()),s=Math.min(i,o),l=At(a[0],s/2),u=At(a[1],s/2),c,h,d=r.coordinateSystem;if(d){var v=d.dataToPoint(n);c=v[0]||0,h=v[1]||0}else ht(n)||(n=[n,n]),c=At(n[0],i)+t.x,h=At(n[1],o)+t.y;return{cx:c,cy:h,r0:l,r:u}}function YX(r,e,t){e.eachSeriesByType(r,function(n){var a=n.getData(),i=a.mapDimension("value"),o=ZE(n,t),s=YE(n,t),l=s.cx,u=s.cy,c=s.r,h=s.r0,d=-n.get("startAngle")*Tv,v=n.get("endAngle"),p=n.get("padAngle")*Tv;v=v==="auto"?d-BC:-v*Tv;var y=n.get("minAngle")*Tv,_=y+p,g=0;a.each(i,function(W){!isNaN(W)&&g++});var f=a.getSum(i),w=Math.PI/(f||g)*2,x=n.get("clockwise"),S=n.get("roseType"),A=n.get("stillShowZeroSum"),T=a.getDataExtent(i);T[0]=0;var L=x?1:-1,M=[d,v],I=L*p/2;Q1(M,!x),d=M[0],v=M[1];var R=XE(n);R.startAngle=d,R.endAngle=v,R.clockwise=x;var P=Math.abs(v-d),E=P,D=0,N=d;if(a.setLayout({viewRect:o,r:c}),a.each(i,function(W,$){var H;if(isNaN(W)){a.setItemLayout($,{angle:NaN,startAngle:NaN,endAngle:NaN,clockwise:x,cx:l,cy:u,r0:h,r:S?NaN:c});return}S!=="area"?H=f===0&&A?w:W*w:H=P/g,H<_?(H=_,E-=_):D+=W;var K=N+L*H,U=0,j=0;p>H?(U=N+L*H/2,j=U):(U=N+I,j=K-I),a.setItemLayout($,{angle:H,startAngle:U,endAngle:j,clockwise:x,cx:l,cy:u,r0:h,r:S?Me(W,T,[h,c]):c}),N=K}),E<BC&&g)if(E<=.001){var V=P/g;a.each(i,function(W,$){if(!isNaN(W)){var H=a.getItemLayout($);H.angle=V;var K=0,U=0;V<p?(K=d+L*($+1/2)*V,U=K):(K=d+L*$*V+I,U=d+L*($+1)*V-I),H.startAngle=K,H.endAngle=U}})}else w=E/D,N=d,a.each(i,function(W,$){if(!isNaN(W)){var H=a.getItemLayout($),K=H.angle===_?_:W*w,U=0,j=0;K<p?(U=N+L*K/2,j=U):(U=N+I,j=N+L*K-I),H.startAngle=U,H.endAngle=j,N+=L*K}})})}var XE=ve();function Gh(r){return{seriesType:r,reset:function(e,t){var n=t.findComponents({mainType:"legend"});if(!(!n||!n.length)){var a=e.getData();a.filterSelf(function(i){for(var o=a.getName(i),s=0;s<n.length;s++)if(!n[s].isSelected(o))return!1;return!0})}}}}var XX=Math.PI/180;function NC(r,e,t,n,a,i,o,s,l,u){if(r.length<2)return;function c(y){for(var _=y.rB,g=_*_,f=0;f<y.list.length;f++){var w=y.list[f],x=Math.abs(w.label.y-t),S=n+w.len,A=S*S,T=Math.sqrt(Math.abs((1-x*x/g)*A)),L=e+(T+w.len2)*a,M=L-w.label.x,I=w.targetTextWidth-M*a;$E(w,I,!0),w.label.x=L}}function h(y){for(var _={list:[],maxY:0},g={list:[],maxY:0},f=0;f<y.length;f++)if(y[f].labelAlignTo==="none"){var w=y[f],x=w.label.y>t?g:_,S=Math.abs(w.label.y-t);if(S>=x.maxY){var A=w.label.x-e-w.len2*a,T=n+w.len,L=Math.abs(A)<T?Math.sqrt(S*S/(1-A*A/T/T)):T;x.rB=L,x.maxY=S}x.list.push(w)}c(_),c(g)}for(var d=r.length,v=0;v<d;v++)if(r[v].position==="outer"&&r[v].labelAlignTo==="labelLine"){var p=r[v].label.x-u;r[v].linePoints[1][0]+=p,r[v].label.x=u}yE(r,l,l+o)&&h(r)}function $X(r,e,t,n,a,i,o,s){for(var l=[],u=[],c=Number.MAX_VALUE,h=-Number.MAX_VALUE,d=0;d<r.length;d++){var v=r[d].label;Im(r[d])||(v.x<e?(c=Math.min(c,v.x),l.push(r[d])):(h=Math.max(h,v.x),u.push(r[d])))}for(var d=0;d<r.length;d++){var p=r[d];if(!Im(p)&&p.linePoints){if(p.labelStyleWidth!=null)continue;var v=p.label,y=p.linePoints,_=void 0;p.labelAlignTo==="edge"?v.x<e?_=y[2][0]-p.labelDistance-o-p.edgeDistance:_=o+a-p.edgeDistance-y[2][0]-p.labelDistance:p.labelAlignTo==="labelLine"?v.x<e?_=c-o-p.bleedMargin:_=o+a-h-p.bleedMargin:v.x<e?_=v.x-o-p.bleedMargin:_=o+a-v.x-p.bleedMargin,p.targetTextWidth=_,$E(p,_)}}NC(u,e,t,n,1,a,i,o,s,h),NC(l,e,t,n,-1,a,i,o,s,c);for(var d=0;d<r.length;d++){var p=r[d];if(!Im(p)&&p.linePoints){var v=p.label,y=p.linePoints,g=p.labelAlignTo==="edge",f=v.style.padding,w=f?f[1]+f[3]:0,x=v.style.backgroundColor?0:w,S=p.rect.width+x,A=y[1][0]-y[2][0];g?v.x<e?y[2][0]=o+p.edgeDistance+S+p.labelDistance:y[2][0]=o+a-p.edgeDistance-S-p.labelDistance:(v.x<e?y[2][0]=v.x+p.labelDistance:y[2][0]=v.x-p.labelDistance,y[1][0]=y[2][0]+A),y[1][1]=y[2][1]=v.y}}}function $E(r,e,t){if(t===void 0&&(t=!1),r.labelStyleWidth==null){var n=r.label,a=n.style,i=r.rect,o=a.backgroundColor,s=a.padding,l=s?s[1]+s[3]:0,u=a.overflow,c=i.width+(o?0:l);if(e<c||t){var h=i.height;if(u&&u.match("break")){n.setStyle("backgroundColor",null),n.setStyle("width",e-l);var d=n.getBoundingRect();n.setStyle("width",Math.ceil(d.width)),n.setStyle("backgroundColor",o)}else{var v=e-l,p=e<c?v:t?v>r.unconstrainedWidth?null:v:null;n.setStyle("width",p)}var y=n.getBoundingRect();i.width=y.width;var _=(n.style.margin||0)+2.1;i.height=y.height+_,i.y-=(i.height-h)/2}}}function Im(r){return r.position==="center"}function jX(r){var e=r.getData(),t=[],n,a,i=!1,o=(r.get("minShowLabelAngle")||0)*XX,s=e.getLayout("viewRect"),l=e.getLayout("r"),u=s.width,c=s.x,h=s.y,d=s.height;function v(A){A.ignore=!0}function p(A){if(!A.ignore)return!0;for(var T in A.states)if(A.states[T].ignore===!1)return!0;return!1}e.each(function(A){var T=e.getItemGraphicEl(A),L=T.shape,M=T.getTextContent(),I=T.getTextGuideLine(),R=e.getItemModel(A),P=R.getModel("label"),E=P.get("position")||R.get(["emphasis","label","position"]),D=P.get("distanceToLabelLine"),N=P.get("alignTo"),V=At(P.get("edgeDistance"),u),W=P.get("bleedMargin"),$=R.getModel("labelLine"),H=$.get("length");H=At(H,u);var K=$.get("length2");if(K=At(K,u),Math.abs(L.endAngle-L.startAngle)<o){B(M.states,v),M.ignore=!0,I&&(B(I.states,v),I.ignore=!0);return}if(p(M)){var U=(L.startAngle+L.endAngle)/2,j=Math.cos(U),ut=Math.sin(U),ot,it,Et,jt;n=L.cx,a=L.cy;var bt=E==="inside"||E==="inner";if(E==="center")ot=L.cx,it=L.cy,jt="center";else{var wt=(bt?(L.r+L.r0)/2*j:L.r*j)+n,Ot=(bt?(L.r+L.r0)/2*ut:L.r*ut)+a;if(ot=wt+j*3,it=Ot+ut*3,!bt){var xt=wt+j*(H+l-L.r),kt=Ot+ut*(H+l-L.r),ae=xt+(j<0?-1:1)*K,O=kt;N==="edge"?ot=j<0?c+V:c+u-V:ot=ae+(j<0?-D:D),it=O,Et=[[wt,Ot],[xt,kt],[ae,O]]}jt=bt?"center":N==="edge"?j>0?"right":"left":j>0?"left":"right"}var st=Math.PI,nt=0,X=P.get("rotate");if(ye(X))nt=X*(st/180);else if(E==="center")nt=0;else if(X==="radial"||X===!0){var Z=j<0?-U+st:-U;nt=Z}else if(X==="tangential"&&E!=="outside"&&E!=="outer"){var J=Math.atan2(j,ut);J<0&&(J=st*2+J);var pt=ut>0;pt&&(J=st+J),nt=J-st}if(i=!!nt,M.x=ot,M.y=it,M.rotation=nt,M.setStyle({verticalAlign:"middle"}),bt){M.setStyle({align:jt});var Tt=M.states.select;Tt&&(Tt.x+=M.x,Tt.y+=M.y)}else{var vt=M.getBoundingRect().clone();vt.applyTransform(M.getComputedTransform());var at=(M.style.margin||0)+2.1;vt.y-=at/2,vt.height+=at,t.push({label:M,labelLine:I,position:E,len:H,len2:K,minTurnAngle:$.get("minTurnAngle"),maxSurfaceAngle:$.get("maxSurfaceAngle"),surfaceNormal:new Kt(j,ut),linePoints:Et,textAlign:jt,labelDistance:D,labelAlignTo:N,edgeDistance:V,bleedMargin:W,rect:vt,unconstrainedWidth:vt.width,labelStyleWidth:M.style.width})}T.setTextConfig({inside:bt})}}),!i&&r.get("avoidLabelOverlap")&&$X(t,n,a,l,u,d,c,h);for(var y=0;y<t.length;y++){var _=t[y],g=_.label,f=_.labelLine,w=isNaN(g.x)||isNaN(g.y);if(g){g.setStyle({align:_.textAlign}),w&&(B(g.states,v),g.ignore=!0);var x=g.states.select;x&&(x.x+=g.x,x.y+=g.y)}if(f){var S=_.linePoints;w||!S?(B(f.states,v),f.ignore=!0):(dE(S,_.minTurnAngle),mY(S,_.surfaceNormal,_.maxSurfaceAngle),f.setShape({points:S}),g.__hostTarget.textGuideLineConfig={anchor:new Kt(S[0][0],S[0][1])})}}}var qX=function(r){rt(e,r);function e(t,n,a){var i=r.call(this)||this;i.z2=2;var o=new pe;return i.setTextContent(o),i.updateData(t,n,a,!0),i}return e.prototype.updateData=function(t,n,a,i){var o=this,s=t.hostModel,l=t.getItemModel(n),u=l.getModel("emphasis"),c=t.getItemLayout(n),h=lt(Ts(l.getModel("itemStyle"),c,!0),c);if(isNaN(h.startAngle)){o.setShape(h);return}if(i){o.setShape(h);var d=s.getShallow("animationType");s.ecModel.ssr?(He(o,{scaleX:0,scaleY:0},s,{dataIndex:n,isFrom:!0}),o.originX=h.cx,o.originY=h.cy):d==="scale"?(o.shape.r=c.r0,He(o,{shape:{r:c.r}},s,n)):a!=null?(o.setShape({startAngle:a,endAngle:a}),He(o,{shape:{startAngle:c.startAngle,endAngle:c.endAngle}},s,n)):(o.shape.endAngle=c.startAngle,_e(o,{shape:{endAngle:c.endAngle}},s,n))}else xa(o),_e(o,{shape:h},s,n);o.useStyle(t.getItemVisual(n,"style")),kr(o,l);var v=(c.startAngle+c.endAngle)/2,p=s.get("selectedOffset"),y=Math.cos(v)*p,_=Math.sin(v)*p,g=l.getShallow("cursor");g&&o.attr("cursor",g),this._updateLabel(s,t,n),o.ensureState("emphasis").shape=lt({r:c.r+(u.get("scale")&&u.get("scaleSize")||0)},Ts(u.getModel("itemStyle"),c)),lt(o.ensureState("select"),{x:y,y:_,shape:Ts(l.getModel(["select","itemStyle"]),c)}),lt(o.ensureState("blur"),{shape:Ts(l.getModel(["blur","itemStyle"]),c)});var f=o.getTextGuideLine(),w=o.getTextContent();f&&lt(f.ensureState("select"),{x:y,y:_}),lt(w.ensureState("select"),{x:y,y:_}),Xe(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},e.prototype._updateLabel=function(t,n,a){var i=this,o=n.getItemModel(a),s=o.getModel("labelLine"),l=n.getItemVisual(a,"style"),u=l&&l.fill,c=l&&l.opacity;Rr(i,_r(o),{labelFetcher:n.hostModel,labelDataIndex:a,inheritColor:u,defaultOpacity:c,defaultText:t.getFormattedLabel(a,"normal")||n.getName(a)});var h=i.getTextContent();i.setTextConfig({position:null,rotation:null}),h.attr({z2:10});var d=t.get(["label","position"]);if(d!=="outside"&&d!=="outer")i.removeTextGuideLine();else{var v=this.getTextGuideLine();v||(v=new nn,this.setTextGuideLine(v)),Bw(this,Nw(o),{stroke:u,opacity:Ha(s.get(["lineStyle","opacity"]),c,1)})}},e}(en),KX=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.ignoreLabelLineUpdate=!0,t}return e.prototype.render=function(t,n,a,i){var o=t.getData(),s=this._data,l=this.group,u;if(!s&&o.count()>0){for(var c=o.getItemLayout(0),h=1;isNaN(c&&c.startAngle)&&h<o.count();++h)c=o.getItemLayout(h);c&&(u=c.startAngle)}if(this._emptyCircleSector&&l.remove(this._emptyCircleSector),o.count()===0&&t.get("showEmptyCircle")){var d=XE(t),v=new en({shape:lt(YE(t,a),d)});v.useStyle(t.getModel("emptyCircleStyle").getItemStyle()),this._emptyCircleSector=v,l.add(v)}o.diff(s).add(function(p){var y=new qX(o,p,u);o.setItemGraphicEl(p,y),l.add(y)}).update(function(p,y){var _=s.getItemGraphicEl(y);_.updateData(o,p,u),_.off("click"),l.add(_),o.setItemGraphicEl(p,_)}).remove(function(p){var y=s.getItemGraphicEl(p);rh(y,t,p)}).execute(),jX(t),t.get("animationTypeUpdate")!=="expansion"&&(this._data=o)},e.prototype.dispose=function(){},e.prototype.containPoint=function(t,n){var a=n.getData(),i=a.getItemLayout(0);if(i){var o=t[0]-i.cx,s=t[1]-i.cy,l=Math.sqrt(o*o+s*s);return l<=i.r&&l>=i.r0}},e.type="pie",e}(Re);function Su(r,e,t){e=ht(e)&&{coordDimensions:e}||lt({encodeDefine:r.getEncode()},e);var n=r.getSource(),a=Oh(n,e).dimensions,i=new Kr(a,r);return i.initData(n,t),i}var Wh=function(){function r(e,t){this._getDataWithEncodedVisual=e,this._getRawData=t}return r.prototype.getAllNames=function(){var e=this._getRawData();return e.mapArray(e.getName)},r.prototype.containName=function(e){var t=this._getRawData();return t.indexOfName(e)>=0},r.prototype.indexOfName=function(e){var t=this._getDataWithEncodedVisual();return t.indexOfName(e)},r.prototype.getItemVisual=function(e,t){var n=this._getDataWithEncodedVisual();return n.getItemVisual(e,t)},r}(),QX=ve(),JX=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Wh(Mt(this.getData,this),Mt(this.getRawData,this)),this._defaultLabelLine(t)},e.prototype.mergeOption=function(){r.prototype.mergeOption.apply(this,arguments)},e.prototype.getInitialData=function(){return Su(this,{coordDimensions:["value"],encodeDefaulter:Xt(pw,this)})},e.prototype.getDataParams=function(t){var n=this.getData(),a=QX(n),i=a.seats;if(!i){var o=[];n.each(n.mapDimension("value"),function(l){o.push(l)}),i=a.seats=H8(o,n.hostModel.get("percentPrecision"))}var s=r.prototype.getDataParams.call(this,t);return s.percent=i[t]||0,s.$vars.push("percent"),s},e.prototype._defaultLabelLine=function(t){Os(t,"labelLine",["show"]);var n=t.labelLine,a=t.emphasis.labelLine;n.show=n.show&&t.label.show,a.show=a.show&&t.emphasis.label.show},e.type="series.pie",e.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,endAngle:"auto",padAngle:0,minAngle:0,minShowLabelAngle:0,selectedOffset:10,percentPrecision:2,stillShowZeroSum:!0,left:0,top:0,right:0,bottom:0,width:null,height:null,label:{rotate:0,show:!0,overflow:"truncate",position:"outer",alignTo:"none",edgeDistance:"25%",bleedMargin:10,distanceToLabelLine:5},labelLine:{show:!0,length:15,length2:15,smooth:!1,minTurnAngle:90,maxSurfaceAngle:90,lineStyle:{width:1,type:"solid"}},itemStyle:{borderWidth:1,borderJoin:"round"},showEmptyCircle:!0,emptyCircleStyle:{color:"lightgray",opacity:1},labelLayout:{hideOverlap:!0},emphasis:{scale:!0,scaleSize:5},avoidLabelOverlap:!0,animationType:"expansion",animationDuration:1e3,animationTypeUpdate:"transition",animationEasingUpdate:"cubicInOut",animationDurationUpdate:500,animationEasing:"cubicInOut"},e}(Ve);function t$(r){return{seriesType:r,reset:function(e,t){var n=e.getData();n.filterSelf(function(a){var i=n.mapDimension("value"),o=n.get(i,a);return!(ye(o)&&!isNaN(o)&&o<0)})}}}function e$(r){r.registerChartView(KX),r.registerSeriesModel(JX),dR("pie",r.registerAction),r.registerLayout(Xt(YX,"pie")),r.registerProcessor(Gh("pie")),r.registerProcessor(t$("pie"))}var r$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.getInitialData=function(t,n){return Ri(null,this,{useEncodeDefaulter:!0})},e.prototype.getProgressive=function(){var t=this.option.progressive;return t??(this.option.large?5e3:this.get("progressive"))},e.prototype.getProgressiveThreshold=function(){var t=this.option.progressiveThreshold;return t??(this.option.large?1e4:this.get("progressiveThreshold"))},e.prototype.brushSelector=function(t,n,a){return a.point(n.getItemLayout(t))},e.prototype.getZLevelKey=function(){return this.getData().count()>this.getProgressiveThreshold()?this.id:""},e.type="series.scatter",e.dependencies=["grid","polar","geo","singleAxis","calendar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,symbolSize:10,large:!1,largeThreshold:2e3,itemStyle:{opacity:.8},emphasis:{scale:!0},clip:!0,select:{itemStyle:{borderColor:"#212121"}},universalTransition:{divideShape:"clone"}},e}(Ve),jE=4,n$=function(){function r(){}return r}(),a$=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n._off=0,n.hoverDataIdx=-1,n}return e.prototype.getDefaultShape=function(){return new n$},e.prototype.reset=function(){this.notClear=!1,this._off=0},e.prototype.buildPath=function(t,n){var a=n.points,i=n.size,o=this.symbolProxy,s=o.shape,l=t.getContext?t.getContext():t,u=l&&i[0]<jE,c=this.softClipShape,h;if(u){this._ctx=l;return}for(this._ctx=null,h=this._off;h<a.length;){var d=a[h++],v=a[h++];isNaN(d)||isNaN(v)||c&&!c.contain(d,v)||(s.x=d-i[0]/2,s.y=v-i[1]/2,s.width=i[0],s.height=i[1],o.buildPath(t,s,!0))}this.incremental&&(this._off=h,this.notClear=!0)},e.prototype.afterBrush=function(){var t=this.shape,n=t.points,a=t.size,i=this._ctx,o=this.softClipShape,s;if(i){for(s=this._off;s<n.length;){var l=n[s++],u=n[s++];isNaN(l)||isNaN(u)||o&&!o.contain(l,u)||i.fillRect(l-a[0]/2,u-a[1]/2,a[0],a[1])}this.incremental&&(this._off=s,this.notClear=!0)}},e.prototype.findDataIndex=function(t,n){for(var a=this.shape,i=a.points,o=a.size,s=Math.max(o[0],4),l=Math.max(o[1],4),u=i.length/2-1;u>=0;u--){var c=u*2,h=i[c]-s/2,d=i[c+1]-l/2;if(t>=h&&n>=d&&t<=h+s&&n<=d+l)return u}return-1},e.prototype.contain=function(t,n){var a=this.transformCoordToLocal(t,n),i=this.getBoundingRect();if(t=a[0],n=a[1],i.contain(t,n)){var o=this.hoverDataIdx=this.findDataIndex(t,n);return o>=0}return this.hoverDataIdx=-1,!1},e.prototype.getBoundingRect=function(){var t=this._rect;if(!t){for(var n=this.shape,a=n.points,i=n.size,o=i[0],s=i[1],l=1/0,u=1/0,c=-1/0,h=-1/0,d=0;d<a.length;){var v=a[d++],p=a[d++];l=Math.min(v,l),c=Math.max(v,c),u=Math.min(p,u),h=Math.max(p,h)}t=this._rect=new Qt(l-o/2,u-s/2,c-l+o,h-u+s)}return t},e}(ie),i$=function(){function r(){this.group=new Wt}return r.prototype.updateData=function(e,t){this._clear();var n=this._create();n.setShape({points:e.getLayout("points")}),this._setCommon(n,e,t)},r.prototype.updateLayout=function(e){var t=e.getLayout("points");this.group.eachChild(function(n){if(n.startIndex!=null){var a=(n.endIndex-n.startIndex)*2,i=n.startIndex*4*2;t=new Float32Array(t.buffer,i,a)}n.setShape("points",t),n.reset()})},r.prototype.incrementalPrepareUpdate=function(e){this._clear()},r.prototype.incrementalUpdate=function(e,t,n){var a=this._newAdded[0],i=t.getLayout("points"),o=a&&a.shape.points;if(o&&o.length<2e4){var s=o.length,l=new Float32Array(s+i.length);l.set(o),l.set(i,s),a.endIndex=e.end,a.setShape({points:l})}else{this._newAdded=[];var u=this._create();u.startIndex=e.start,u.endIndex=e.end,u.incremental=!0,u.setShape({points:i}),this._setCommon(u,t,n)}},r.prototype.eachRendered=function(e){this._newAdded[0]&&e(this._newAdded[0])},r.prototype._create=function(){var e=new a$({cursor:"default"});return e.ignoreCoarsePointer=!0,this.group.add(e),this._newAdded.push(e),e},r.prototype._setCommon=function(e,t,n){var a=t.hostModel;n=n||{};var i=t.getVisual("symbolSize");e.setShape("size",i instanceof Array?i:[i,i]),e.softClipShape=n.clipShape||null,e.symbolProxy=or(t.getVisual("symbol"),0,0,0,0),e.setColor=e.symbolProxy.setColor;var o=e.shape.size[0]<jE;e.useStyle(a.getModel("itemStyle").getItemStyle(o?["color","shadowBlur","shadowColor"]:["color"]));var s=t.getVisual("style"),l=s&&s.fill;l&&e.setColor(l);var u=Ht(e);u.seriesIndex=a.seriesIndex,e.on("mousemove",function(c){u.dataIndex=null;var h=e.hoverDataIdx;h>=0&&(u.dataIndex=h+(e.startIndex||0))})},r.prototype.remove=function(){this._clear()},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),o$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=t.getData(),o=this._updateSymbolDraw(i,t);o.updateData(i,{clipShape:this._getClipShape(t)}),this._finished=!0},e.prototype.incrementalPrepareRender=function(t,n,a){var i=t.getData(),o=this._updateSymbolDraw(i,t);o.incrementalPrepareUpdate(i),this._finished=!1},e.prototype.incrementalRender=function(t,n,a){this._symbolDraw.incrementalUpdate(t,n.getData(),{clipShape:this._getClipShape(n)}),this._finished=t.end===n.getData().count()},e.prototype.updateTransform=function(t,n,a){var i=t.getData();if(this.group.dirty(),!this._finished||i.count()>1e4)return{update:!0};var o=Vh("").reset(t,n,a);o.progress&&o.progress({start:0,end:i.count(),count:i.count()},i),this._symbolDraw.updateLayout(i)},e.prototype.eachRendered=function(t){this._symbolDraw&&this._symbolDraw.eachRendered(t)},e.prototype._getClipShape=function(t){if(t.get("clip",!0)){var n=t.coordinateSystem;return n&&n.getArea&&n.getArea(.1)}},e.prototype._updateSymbolDraw=function(t,n){var a=this._symbolDraw,i=n.pipelineContext,o=i.large;return(!a||o!==this._isLargeDraw)&&(a&&a.remove(),a=this._symbolDraw=o?new i$:new zh,this._isLargeDraw=o,this.group.removeAll()),this.group.add(a.group),a},e.prototype.remove=function(t,n){this._symbolDraw&&this._symbolDraw.remove(!0),this._symbolDraw=null},e.prototype.dispose=function(){},e.type="scatter",e}(Re),s$=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.type="grid",e.dependencies=["xAxis","yAxis"],e.layoutMode="box",e.defaultOption={show:!1,z:0,left:"10%",top:60,right:"10%",bottom:70,containLabel:!1,backgroundColor:"rgba(0,0,0,0)",borderWidth:1,borderColor:"#ccc"},e}(le),Y_=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",ir).models[0]},e.type="cartesian2dAxis",e}(le);sr(Y_,Bh);var qE={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:"#6E7079",width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15]},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12},splitLine:{show:!0,showMinLine:!0,showMaxLine:!0,lineStyle:{color:["#E0E6F1"],width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:["rgba(250,250,250,0.2)","rgba(210,219,238,0.2)"]}}},l$=qt({boundaryGap:!0,deduplication:null,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto"},axisLabel:{interval:"auto"}},qE),Uw=qt({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:"#F4F7FD",width:1}}},qE),u$=qt({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},Uw),c$=zt({logBase:10},Uw);const KE={category:l$,value:Uw,time:u$,log:c$};var h$={value:1,category:1,time:1,log:1};function au(r,e,t,n){B(h$,function(a,i){var o=qt(qt({},KE[i],!0),n,!0),s=function(l){rt(u,l);function u(){var c=l!==null&&l.apply(this,arguments)||this;return c.type=e+"Axis."+i,c}return u.prototype.mergeDefaultAndTheme=function(c,h){var d=ah(this),v=d?yu(c):{},p=h.getTheme();qt(c,p.get(i+"Axis")),qt(c,this.getDefaultOption()),c.type=zC(c),d&&bo(c,v,d)},u.prototype.optionUpdated=function(){var c=this.option;c.type==="category"&&(this.__ordinalMeta=F_.createByAxisModel(this))},u.prototype.getCategories=function(c){var h=this.option;if(h.type==="category")return c?h.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.type=e+"Axis."+i,u.defaultOption=o,u}(t);r.registerComponentModel(s)}),r.registerSubTypeDefaulter(e+"Axis",zC)}function zC(r){return r.type||(r.data?"category":"value")}var f$=function(){function r(e){this.type="cartesian",this._dimList=[],this._axes={},this.name=e||""}return r.prototype.getAxis=function(e){return this._axes[e]},r.prototype.getAxes=function(){return ft(this._dimList,function(e){return this._axes[e]},this)},r.prototype.getAxesByScale=function(e){return e=e.toLowerCase(),Te(this.getAxes(),function(t){return t.scale.type===e})},r.prototype.addAxis=function(e){var t=e.dim;this._axes[t]=e,this._dimList.push(t)},r}(),X_=["x","y"];function FC(r){return r.type==="interval"||r.type==="time"}var v$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="cartesian2d",t.dimensions=X_,t}return e.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var t=this.getAxis("x").scale,n=this.getAxis("y").scale;if(!(!FC(t)||!FC(n))){var a=t.getExtent(),i=n.getExtent(),o=this.dataToPoint([a[0],i[0]]),s=this.dataToPoint([a[1],i[1]]),l=a[1]-a[0],u=i[1]-i[0];if(!(!l||!u)){var c=(s[0]-o[0])/l,h=(s[1]-o[1])/u,d=o[0]-a[0]*c,v=o[1]-i[0]*h,p=this._transform=[c,0,0,h,d,v];this._invTransform=cu([],p)}}},e.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},e.prototype.containPoint=function(t){var n=this.getAxis("x"),a=this.getAxis("y");return n.contain(n.toLocalCoord(t[0]))&&a.contain(a.toLocalCoord(t[1]))},e.prototype.containData=function(t){return this.getAxis("x").containData(t[0])&&this.getAxis("y").containData(t[1])},e.prototype.containZone=function(t,n){var a=this.dataToPoint(t),i=this.dataToPoint(n),o=this.getArea(),s=new Qt(a[0],a[1],i[0]-a[0],i[1]-a[1]);return o.intersect(s)},e.prototype.dataToPoint=function(t,n,a){a=a||[];var i=t[0],o=t[1];if(this._transform&&i!=null&&isFinite(i)&&o!=null&&isFinite(o))return Pr(a,t,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return a[0]=s.toGlobalCoord(s.dataToCoord(i,n)),a[1]=l.toGlobalCoord(l.dataToCoord(o,n)),a},e.prototype.clampData=function(t,n){var a=this.getAxis("x").scale,i=this.getAxis("y").scale,o=a.getExtent(),s=i.getExtent(),l=a.parse(t[0]),u=i.parse(t[1]);return n=n||[],n[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),n[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),n},e.prototype.pointToData=function(t,n){var a=[];if(this._invTransform)return Pr(a,t,this._invTransform);var i=this.getAxis("x"),o=this.getAxis("y");return a[0]=i.coordToData(i.toLocalCoord(t[0]),n),a[1]=o.coordToData(o.toLocalCoord(t[1]),n),a},e.prototype.getOtherAxis=function(t){return this.getAxis(t.dim==="x"?"y":"x")},e.prototype.getArea=function(t){t=t||0;var n=this.getAxis("x").getGlobalExtent(),a=this.getAxis("y").getGlobalExtent(),i=Math.min(n[0],n[1])-t,o=Math.min(a[0],a[1])-t,s=Math.max(n[0],n[1])-i+t,l=Math.max(a[0],a[1])-o+t;return new Qt(i,o,s,l)},e}(f$),d$=function(r){rt(e,r);function e(t,n,a,i,o){var s=r.call(this,t,n,a)||this;return s.index=0,s.type=i||"value",s.position=o||"bottom",s}return e.prototype.isHorizontal=function(){var t=this.position;return t==="top"||t==="bottom"},e.prototype.getGlobalExtent=function(t){var n=this.getExtent();return n[0]=this.toGlobalCoord(n[0]),n[1]=this.toGlobalCoord(n[1]),t&&n[0]>n[1]&&n.reverse(),n},e.prototype.pointToData=function(t,n){return this.coordToData(this.toLocalCoord(t[this.dim==="x"?0:1]),n)},e.prototype.setCategorySortInfo=function(t){if(this.type!=="category")return!1;this.model.option.categorySortInfo=t,this.scale.setSortInfo(t)},e}(Sa);function $_(r,e,t){t=t||{};var n=r.coordinateSystem,a=e.axis,i={},o=a.getAxesOnZeroOf()[0],s=a.position,l=o?"onZero":s,u=a.dim,c=n.getRect(),h=[c.x,c.x+c.width,c.y,c.y+c.height],d={left:0,right:1,top:0,bottom:1,onZero:2},v=e.get("offset")||0,p=u==="x"?[h[2]-v,h[3]+v]:[h[0]-v,h[1]+v];if(o){var y=o.toGlobalCoord(o.dataToCoord(0));p[d.onZero]=Math.max(Math.min(y,p[1]),p[0])}i.position=[u==="y"?p[d[l]]:h[0],u==="x"?p[d[l]]:h[3]],i.rotation=Math.PI/2*(u==="x"?0:1);var _={top:-1,bottom:1,left:-1,right:1};i.labelDirection=i.tickDirection=i.nameDirection=_[s],i.labelOffset=o?p[d[s]]-p[d.onZero]:0,e.get(["axisTick","inside"])&&(i.tickDirection=-i.tickDirection),Ar(t.labelInside,e.get(["axisLabel","inside"]))&&(i.labelDirection=-i.labelDirection);var g=e.get(["axisLabel","rotate"]);return i.labelRotate=l==="top"?-g:g,i.z2=1,i}function VC(r){return r.get("coordinateSystem")==="cartesian2d"}function GC(r){var e={xAxisModel:null,yAxisModel:null};return B(e,function(t,n){var a=n.replace(/Model$/,""),i=r.getReferringComponents(a,ir).models[0];e[n]=i}),e}var Pm=Math.log;function QE(r,e,t){var n=Mi.prototype,a=n.getTicks.call(t),i=n.getTicks.call(t,!0),o=a.length-1,s=n.getInterval.call(t),l=eE(r,e),u=l.extent,c=l.fixMin,h=l.fixMax;if(r.type==="log"){var d=Pm(r.base);u=[Pm(u[0])/d,Pm(u[1])/d]}r.setExtent(u[0],u[1]),r.calcNiceExtent({splitNumber:o,fixMin:c,fixMax:h});var v=n.getExtent.call(r);c&&(u[0]=v[0]),h&&(u[1]=v[1]);var p=n.getInterval.call(r),y=u[0],_=u[1];if(c&&h)p=(_-y)/o;else if(c)for(_=u[0]+p*o;_<u[1]&&isFinite(_)&&isFinite(u[1]);)p=gm(p),_=u[0]+p*o;else if(h)for(y=u[1]-p*o;y>u[0]&&isFinite(y)&&isFinite(u[0]);)p=gm(p),y=u[1]-p*o;else{var g=r.getTicks().length-1;g>o&&(p=gm(p));var f=p*o;_=Math.ceil(u[1]/p)*p,y=qe(_-f),y<0&&u[0]>=0?(y=0,_=qe(f)):_>0&&u[1]<=0&&(_=0,y=-qe(f))}var w=(a[0].value-i[0].value)/s,x=(a[o].value-i[o].value)/s;n.setExtent.call(r,y+p*w,_+p*x),n.setInterval.call(r,p),(w||x)&&n.setNiceExtent.call(r,y+p,_-p)}var p$=function(){function r(e,t,n){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=X_,this._initCartesian(e,t,n),this.model=e}return r.prototype.getRect=function(){return this._rect},r.prototype.update=function(e,t){var n=this._axesMap;this._updateScale(e,this.model);function a(o){var s,l=ue(o),u=l.length;if(u){for(var c=[],h=u-1;h>=0;h--){var d=+l[h],v=o[d],p=v.model,y=v.scale;V_(y)&&p.get("alignTicks")&&p.get("interval")==null?c.push(v):(ru(y,p),V_(y)&&(s=v))}c.length&&(s||(s=c.pop(),ru(s.scale,s.model)),B(c,function(_){QE(_.scale,_.model,s.scale)}))}}a(n.x),a(n.y);var i={};B(n.x,function(o){WC(n,"y",o,i)}),B(n.y,function(o){WC(n,"x",o,i)}),this.resize(this.model,t)},r.prototype.resize=function(e,t,n){var a=e.getBoxLayoutParams(),i=!n&&e.get("containLabel"),o=cr(a,{width:t.getWidth(),height:t.getHeight()});this._rect=o;var s=this._axesList;l(),i&&(B(s,function(u){if(!u.model.get(["axisLabel","inside"])){var c=jZ(u);if(c){var h=u.isHorizontal()?"height":"width",d=u.model.get(["axisLabel","margin"]);o[h]-=c[h]+d,u.position==="top"?o.y+=c.height+d:u.position==="left"&&(o.x+=c.width+d)}}}),l()),B(this._coordsList,function(u){u.calcAffineTransform()});function l(){B(s,function(u){var c=u.isHorizontal(),h=c?[0,o.width]:[0,o.height],d=u.inverse?1:0;u.setExtent(h[d],h[1-d]),g$(u,c?o.x:o.y)})}},r.prototype.getAxis=function(e,t){var n=this._axesMap[e];if(n!=null)return n[t||0]},r.prototype.getAxes=function(){return this._axesList.slice()},r.prototype.getCartesian=function(e,t){if(e!=null&&t!=null){var n="x"+e+"y"+t;return this._coordsMap[n]}Vt(e)&&(t=e.yAxisIndex,e=e.xAxisIndex);for(var a=0,i=this._coordsList;a<i.length;a++)if(i[a].getAxis("x").index===e||i[a].getAxis("y").index===t)return i[a]},r.prototype.getCartesians=function(){return this._coordsList.slice()},r.prototype.convertToPixel=function(e,t,n){var a=this._findConvertTarget(t);return a.cartesian?a.cartesian.dataToPoint(n):a.axis?a.axis.toGlobalCoord(a.axis.dataToCoord(n)):null},r.prototype.convertFromPixel=function(e,t,n){var a=this._findConvertTarget(t);return a.cartesian?a.cartesian.pointToData(n):a.axis?a.axis.coordToData(a.axis.toLocalCoord(n)):null},r.prototype._findConvertTarget=function(e){var t=e.seriesModel,n=e.xAxisModel||t&&t.getReferringComponents("xAxis",ir).models[0],a=e.yAxisModel||t&&t.getReferringComponents("yAxis",ir).models[0],i=e.gridModel,o=this._coordsList,s,l;if(t)s=t.coordinateSystem,te(o,s)<0&&(s=null);else if(n&&a)s=this.getCartesian(n.componentIndex,a.componentIndex);else if(n)l=this.getAxis("x",n.componentIndex);else if(a)l=this.getAxis("y",a.componentIndex);else if(i){var u=i.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},r.prototype.containPoint=function(e){var t=this._coordsList[0];if(t)return t.containPoint(e)},r.prototype._initCartesian=function(e,t,n){var a=this,i=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(t.eachComponent("xAxis",u("x"),this),t.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,B(s.x,function(c,h){B(s.y,function(d,v){var p="x"+h+"y"+v,y=new v$(p);y.master=a,y.model=e,a._coordsMap[p]=y,a._coordsList.push(y),y.addAxis(c),y.addAxis(d)})});function u(c){return function(h,d){if(km(h,e)){var v=h.get("position");c==="x"?v!=="top"&&v!=="bottom"&&(v=o.bottom?"top":"bottom"):v!=="left"&&v!=="right"&&(v=o.left?"right":"left"),o[v]=!0;var p=new d$(c,Wp(h),[0,0],h.get("type"),v),y=p.type==="category";p.onBand=y&&h.get("boundaryGap"),p.inverse=h.get("inverse"),h.axis=p,p.model=h,p.grid=i,p.index=d,i._axesList.push(p),s[c][d]=p,l[c]++}}}},r.prototype._updateScale=function(e,t){B(this._axesList,function(a){if(a.scale.setExtent(1/0,-1/0),a.type==="category"){var i=a.model.get("categorySortInfo");a.scale.setSortInfo(i)}}),e.eachSeries(function(a){if(VC(a)){var i=GC(a),o=i.xAxisModel,s=i.yAxisModel;if(!km(o,t)||!km(s,t))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=a.getData(),c=l.getAxis("x"),h=l.getAxis("y");n(u,c),n(u,h)}},this);function n(a,i){B(zd(a,i.dim),function(o){i.scale.unionExtentFromData(a,o)})}},r.prototype.getTooltipAxes=function(e){var t=[],n=[];return B(this.getCartesians(),function(a){var i=e!=null&&e!=="auto"?a.getAxis(e):a.getBaseAxis(),o=a.getOtherAxis(i);te(t,i)<0&&t.push(i),te(n,o)<0&&n.push(o)}),{baseAxes:t,otherAxes:n}},r.create=function(e,t){var n=[];return e.eachComponent("grid",function(a,i){var o=new r(a,e,t);o.name="grid_"+i,o.resize(a,t,!0),a.coordinateSystem=o,n.push(o)}),e.eachSeries(function(a){if(VC(a)){var i=GC(a),o=i.xAxisModel,s=i.yAxisModel,l=o.getCoordSysModel(),u=l.coordinateSystem;a.coordinateSystem=u.getCartesian(o.componentIndex,s.componentIndex)}}),n},r.dimensions=X_,r}();function km(r,e){return r.getCoordSysModel()===e}function WC(r,e,t,n){t.getAxesOnZeroOf=function(){return i?[i]:[]};var a=r[e],i,o=t.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)HC(a[l])&&(i=a[l]);else for(var u in a)if(a.hasOwnProperty(u)&&HC(a[u])&&!n[c(a[u])]){i=a[u];break}i&&(n[c(i)]=!0);function c(h){return h.dim+"_"+h.index}}function HC(r){return r&&r.type!=="category"&&r.type!=="time"&&$Z(r)}function g$(r,e){var t=r.getExtent(),n=t[0]+t[1];r.toGlobalCoord=r.dim==="x"?function(a){return a+e}:function(a){return n-a+e},r.toLocalCoord=r.dim==="x"?function(a){return a-e}:function(a){return n-a+e}}var co=Math.PI,Qr=function(){function r(e,t){this.group=new Wt,this.opt=t,this.axisModel=e,zt(t,{labelOffset:0,nameDirection:1,tickDirection:1,labelDirection:1,silent:!0,handleAutoShown:function(){return!0}});var n=new Wt({x:t.position[0],y:t.position[1],rotation:t.rotation});n.updateTransform(),this._transformGroup=n}return r.prototype.hasBuilder=function(e){return!!UC[e]},r.prototype.add=function(e){UC[e](this.opt,this.axisModel,this.group,this._transformGroup)},r.prototype.getGroup=function(){return this.group},r.innerTextLayout=function(e,t,n){var a=pP(t-e),i,o;return Qc(a)?(o=n>0?"top":"bottom",i="center"):Qc(a-co)?(o=n>0?"bottom":"top",i="center"):(o="middle",a>0&&a<co?i=n>0?"right":"left":i=n>0?"left":"right"),{rotation:a,textAlign:i,textVerticalAlign:o}},r.makeAxisEventDataBase=function(e){var t={componentType:e.mainType,componentIndex:e.componentIndex};return t[e.mainType+"Index"]=e.componentIndex,t},r.isLabelSilent=function(e){var t=e.get("tooltip");return e.get("silent")||!(e.get("triggerEvent")||t&&t.show)},r}(),UC={axisLine:function(r,e,t,n){var a=e.get(["axisLine","show"]);if(a==="auto"&&r.handleAutoShown&&(a=r.handleAutoShown("axisLine")),!!a){var i=e.axis.getExtent(),o=n.transform,s=[i[0],0],l=[i[1],0],u=s[0]>l[0];o&&(Pr(s,s,o),Pr(l,l,o));var c=lt({lineCap:"round"},e.getModel(["axisLine","lineStyle"]).getLineStyle()),h=new gr({shape:{x1:s[0],y1:s[1],x2:l[0],y2:l[1]},style:c,strokeContainThreshold:r.strokeContainThreshold||5,silent:!0,z2:1});Jl(h.shape,h.style.lineWidth),h.anid="line",t.add(h);var d=e.get(["axisLine","symbol"]);if(d!=null){var v=e.get(["axisLine","symbolSize"]);Lt(d)&&(d=[d,d]),(Lt(v)||ye(v))&&(v=[v,v]);var p=Ys(e.get(["axisLine","symbolOffset"])||0,v),y=v[0],_=v[1];B([{rotate:r.rotation+Math.PI/2,offset:p[0],r:0},{rotate:r.rotation-Math.PI/2,offset:p[1],r:Math.sqrt((s[0]-l[0])*(s[0]-l[0])+(s[1]-l[1])*(s[1]-l[1]))}],function(g,f){if(d[f]!=="none"&&d[f]!=null){var w=or(d[f],-y/2,-_/2,y,_,c.stroke,!0),x=g.r+g.offset,S=u?l:s;w.attr({rotation:g.rotate,x:S[0]+x*Math.cos(r.rotation),y:S[1]-x*Math.sin(r.rotation),silent:!0,z2:11}),t.add(w)}})}}},axisTickLabel:function(r,e,t,n){var a=_$(t,n,e,r),i=x$(t,n,e,r);if(m$(e,i,a),w$(t,n,e,r.tickDirection),e.get(["axisLabel","hideOverlap"])){var o=pE(ft(i,function(s){return{label:s,priority:s.z2,defaultAttr:{ignore:s.ignore}}}));mE(o)}},axisName:function(r,e,t,n){var a=Ar(r.axisName,e.get("name"));if(a){var i=e.get("nameLocation"),o=r.nameDirection,s=e.getModel("nameTextStyle"),l=e.get("nameGap")||0,u=e.axis.getExtent(),c=u[0]>u[1]?-1:1,h=[i==="start"?u[0]-c*l:i==="end"?u[1]+c*l:(u[0]+u[1])/2,YC(i)?r.labelOffset+o*l:0],d,v=e.get("nameRotate");v!=null&&(v=v*co/180);var p;YC(i)?d=Qr.innerTextLayout(r.rotation,v??r.rotation,o):(d=y$(r.rotation,i,v||0,u),p=r.axisNameAvailableWidth,p!=null&&(p=Math.abs(p/Math.sin(d.rotation)),!isFinite(p)&&(p=null)));var y=s.getFont(),_=e.get("nameTruncate",!0)||{},g=_.ellipsis,f=Ar(r.nameTruncateMaxWidth,_.maxWidth,p),w=new pe({x:h[0],y:h[1],rotation:d.rotation,silent:Qr.isLabelSilent(e),style:Fe(s,{text:a,font:y,overflow:"truncate",width:f,ellipsis:g,fill:s.getTextColor()||e.get(["axisLine","lineStyle","color"]),align:s.get("align")||d.textAlign,verticalAlign:s.get("verticalAlign")||d.textVerticalAlign}),z2:1});if(Us({el:w,componentModel:e,itemName:a}),w.__fullText=a,w.anid="name",e.get("triggerEvent")){var x=Qr.makeAxisEventDataBase(e);x.targetType="axisName",x.name=a,Ht(w).eventData=x}n.add(w),w.updateTransform(),t.add(w),w.decomposeTransform()}}};function y$(r,e,t,n){var a=pP(t-r),i,o,s=n[0]>n[1],l=e==="start"&&!s||e!=="start"&&s;return Qc(a-co/2)?(o=l?"bottom":"top",i="center"):Qc(a-co*1.5)?(o=l?"top":"bottom",i="center"):(o="middle",a<co*1.5&&a>co/2?i=l?"left":"right":i=l?"right":"left"),{rotation:a,textAlign:i,textVerticalAlign:o}}function m$(r,e,t){if(!rE(r.axis)){var n=r.get(["axisLabel","showMinLabel"]),a=r.get(["axisLabel","showMaxLabel"]);e=e||[],t=t||[];var i=e[0],o=e[1],s=e[e.length-1],l=e[e.length-2],u=t[0],c=t[1],h=t[t.length-1],d=t[t.length-2];n===!1?(Vn(i),Vn(u)):ZC(i,o)&&(n?(Vn(o),Vn(c)):(Vn(i),Vn(u))),a===!1?(Vn(s),Vn(h)):ZC(l,s)&&(a?(Vn(l),Vn(d)):(Vn(s),Vn(h)))}}function Vn(r){r&&(r.ignore=!0)}function ZC(r,e){var t=r&&r.getBoundingRect().clone(),n=e&&e.getBoundingRect().clone();if(!(!t||!n)){var a=vp([]);return Hs(a,a,-r.rotation),t.applyTransform(_i([],a,r.getLocalTransform())),n.applyTransform(_i([],a,e.getLocalTransform())),t.intersect(n)}}function YC(r){return r==="middle"||r==="center"}function JE(r,e,t,n,a){for(var i=[],o=[],s=[],l=0;l<r.length;l++){var u=r[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=t,e&&(Pr(o,o,e),Pr(s,s,e));var c=new gr({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:n,z2:2,autoBatch:!0,silent:!0});Jl(c.shape,c.style.lineWidth),c.anid=a+"_"+r[l].tickValue,i.push(c)}return i}function _$(r,e,t,n){var a=t.axis,i=t.getModel("axisTick"),o=i.get("show");if(o==="auto"&&n.handleAutoShown&&(o=n.handleAutoShown("axisTick")),!(!o||a.scale.isBlank())){for(var s=i.getModel("lineStyle"),l=n.tickDirection*i.get("length"),u=a.getTicksCoords(),c=JE(u,e.transform,l,zt(s.getLineStyle(),{stroke:t.get(["axisLine","lineStyle","color"])}),"ticks"),h=0;h<c.length;h++)r.add(c[h]);return c}}function w$(r,e,t,n){var a=t.axis,i=t.getModel("minorTick");if(!(!i.get("show")||a.scale.isBlank())){var o=a.getMinorTicksCoords();if(o.length)for(var s=i.getModel("lineStyle"),l=n*i.get("length"),u=zt(s.getLineStyle(),zt(t.getModel("axisTick").getLineStyle(),{stroke:t.get(["axisLine","lineStyle","color"])})),c=0;c<o.length;c++)for(var h=JE(o[c],e.transform,l,u,"minorticks_"+c),d=0;d<h.length;d++)r.add(h[d])}}function x$(r,e,t,n){var a=t.axis,i=Ar(n.axisLabelShow,t.get(["axisLabel","show"]));if(!(!i||a.scale.isBlank())){var o=t.getModel("axisLabel"),s=o.get("margin"),l=a.getViewLabels(),u=(Ar(n.labelRotate,o.get("rotate"))||0)*co/180,c=Qr.innerTextLayout(n.rotation,u,n.labelDirection),h=t.getCategories&&t.getCategories(!0),d=[],v=Qr.isLabelSilent(t),p=t.get("triggerEvent");return B(l,function(y,_){var g=a.scale.type==="ordinal"?a.scale.getRawOrdinalNumber(y.tickValue):y.tickValue,f=y.formattedLabel,w=y.rawLabel,x=o;if(h&&h[g]){var S=h[g];Vt(S)&&S.textStyle&&(x=new De(S.textStyle,o,t.ecModel))}var A=x.getTextColor()||t.get(["axisLine","lineStyle","color"]),T=a.dataToCoord(g),L=x.getShallow("align",!0)||c.textAlign,M=Zt(x.getShallow("alignMinLabel",!0),L),I=Zt(x.getShallow("alignMaxLabel",!0),L),R=x.getShallow("verticalAlign",!0)||x.getShallow("baseline",!0)||c.textVerticalAlign,P=Zt(x.getShallow("verticalAlignMinLabel",!0),R),E=Zt(x.getShallow("verticalAlignMaxLabel",!0),R),D=new pe({x:T,y:n.labelOffset+n.labelDirection*s,rotation:c.rotation,silent:v,z2:10+(y.level||0),style:Fe(x,{text:f,align:_===0?M:_===l.length-1?I:L,verticalAlign:_===0?P:_===l.length-1?E:R,fill:Nt(A)?A(a.type==="category"?w:a.type==="value"?g+"":g,_):A})});if(D.anid="label_"+g,Us({el:D,componentModel:t,itemName:f,formatterParamsExtra:{isTruncated:function(){return D.isTruncated},value:w,tickIndex:_}}),p){var N=Qr.makeAxisEventDataBase(t);N.targetType="axisLabel",N.value=w,N.tickIndex=_,a.type==="category"&&(N.dataIndex=g),Ht(D).eventData=N}e.add(D),D.updateTransform(),d.push(D),r.add(D),D.decomposeTransform()}),d}}function b$(r,e){var t={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return S$(t,r,e),t.seriesInvolved&&T$(t,r),t}function S$(r,e,t){var n=e.getComponent("tooltip"),a=e.getComponent("axisPointer"),i=a.get("link",!0)||[],o=[];B(t.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=vh(s.model),u=r.coordSysAxesInfo[l]={};r.coordSysMap[l]=s;var c=s.model,h=c.getModel("tooltip",n);if(B(s.getAxes(),Xt(y,!1,null)),s.getTooltipAxes&&n&&h.get("show")){var d=h.get("trigger")==="axis",v=h.get(["axisPointer","type"])==="cross",p=s.getTooltipAxes(h.get(["axisPointer","axis"]));(d||v)&&B(p.baseAxes,Xt(y,v?"cross":!0,d)),v&&B(p.otherAxes,Xt(y,"cross",!1))}function y(_,g,f){var w=f.model.getModel("axisPointer",a),x=w.get("show");if(!(!x||x==="auto"&&!_&&!j_(w))){g==null&&(g=w.get("triggerTooltip")),w=_?A$(f,h,a,e,_,g):w;var S=w.get("snap"),A=w.get("triggerEmphasis"),T=vh(f.model),L=g||S||f.type==="category",M=r.axesInfo[T]={key:T,axis:f,coordSys:s,axisPointerModel:w,triggerTooltip:g,triggerEmphasis:A,involveSeries:L,snap:S,useHandle:j_(w),seriesModels:[],linkGroup:null};u[T]=M,r.seriesInvolved=r.seriesInvolved||L;var I=C$(i,f);if(I!=null){var R=o[I]||(o[I]={axesInfo:{}});R.axesInfo[T]=M,R.mapper=i[I].mapper,M.linkGroup=R}}}})}function A$(r,e,t,n,a,i){var o=e.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};B(s,function(d){l[d]=Gt(o.get(d))}),l.snap=r.type!=="category"&&!!i,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),a==="cross"){var c=o.get(["label","show"]);if(u.show=c??!0,!i){var h=l.lineStyle=o.get("crossStyle");h&&zt(u,h.textStyle)}}return r.model.getModel("axisPointer",new De(l,t,n))}function T$(r,e){e.eachSeries(function(t){var n=t.coordinateSystem,a=t.get(["tooltip","trigger"],!0),i=t.get(["tooltip","show"],!0);!n||a==="none"||a===!1||a==="item"||i===!1||t.get(["axisPointer","show"],!0)===!1||B(r.coordSysAxesInfo[vh(n.model)],function(o){var s=o.axis;n.getAxis(s.dim)===s&&(o.seriesModels.push(t),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=t.getData().count())})})}function C$(r,e){for(var t=e.model,n=e.dim,a=0;a<r.length;a++){var i=r[a]||{};if(Rm(i[n+"AxisId"],t.id)||Rm(i[n+"AxisIndex"],t.componentIndex)||Rm(i[n+"AxisName"],t.name))return a}}function Rm(r,e){return r==="all"||ht(r)&&te(r,e)>=0||r===e}function L$(r){var e=Zw(r);if(e){var t=e.axisPointerModel,n=e.axis.scale,a=t.option,i=t.get("status"),o=t.get("value");o!=null&&(o=n.parse(o));var s=j_(t);i==null&&(a.status=s?"show":"hide");var l=n.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),a.value=o,s&&(a.status=e.axis.scale.isBlank()?"hide":"show")}}function Zw(r){var e=(r.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return e&&e.axesInfo[vh(r)]}function M$(r){var e=Zw(r);return e&&e.axisPointerModel}function j_(r){return!!r.get(["handle","show"])}function vh(r){return r.type+"||"+r.id}var XC={},js=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a,i){this.axisPointerClass&&L$(t),r.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(t,a,!0)},e.prototype.updateAxisPointer=function(t,n,a,i){this._doUpdateAxisPointerClass(t,a,!1)},e.prototype.remove=function(t,n){var a=this._axisPointer;a&&a.remove(n)},e.prototype.dispose=function(t,n){this._disposeAxisPointer(n),r.prototype.dispose.apply(this,arguments)},e.prototype._doUpdateAxisPointerClass=function(t,n,a){var i=e.getAxisPointerClass(this.axisPointerClass);if(i){var o=M$(t);o?(this._axisPointer||(this._axisPointer=new i)).render(t,o,n,a):this._disposeAxisPointer(n)}},e.prototype._disposeAxisPointer=function(t){this._axisPointer&&this._axisPointer.dispose(t),this._axisPointer=null},e.registerAxisPointerClass=function(t,n){XC[t]=n},e.getAxisPointerClass=function(t){return t&&XC[t]},e.type="axis",e}(Ze),q_=ve();function t5(r,e,t,n){var a=t.axis;if(!a.scale.isBlank()){var i=t.getModel("splitArea"),o=i.getModel("areaStyle"),s=o.get("color"),l=n.coordinateSystem.getRect(),u=a.getTicksCoords({tickModel:i,clamp:!0});if(u.length){var c=s.length,h=q_(r).splitAreaColors,d=Pt(),v=0;if(h)for(var p=0;p<u.length;p++){var y=h.get(u[p].tickValue);if(y!=null){v=(y+(c-1)*p)%c;break}}var _=a.toGlobalCoord(u[0].coord),g=o.getAreaStyle();s=ht(s)?s:[s];for(var p=1;p<u.length;p++){var f=a.toGlobalCoord(u[p].coord),w=void 0,x=void 0,S=void 0,A=void 0;a.isHorizontal()?(w=_,x=l.y,S=f-w,A=l.height,_=w+S):(w=l.x,x=_,S=l.width,A=f-x,_=x+A);var T=u[p-1].tickValue;T!=null&&d.set(T,v),e.add(new fe({anid:T!=null?"area_"+T:null,shape:{x:w,y:x,width:S,height:A},style:zt({fill:s[v]},g),autoBatch:!0,silent:!0})),v=(v+1)%c}q_(r).splitAreaColors=d}}}function e5(r){q_(r).splitAreaColors=null}var D$=["axisLine","axisTickLabel","axisName"],I$=["splitArea","splitLine","minorSplitLine"],r5=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="CartesianAxisPointer",t}return e.prototype.render=function(t,n,a,i){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new Wt,this.group.add(this._axisGroup),!!t.get("show")){var s=t.getCoordSysModel(),l=$_(s,t),u=new Qr(t,lt({handleAutoShown:function(h){for(var d=s.coordinateSystem.getCartesians(),v=0;v<d.length;v++)if(V_(d[v].getOtherAxis(t.axis).scale))return!0;return!1}},l));B(D$,u.add,u),this._axisGroup.add(u.getGroup()),B(I$,function(h){t.get([h,"show"])&&P$[h](this,this._axisGroup,t,s)},this);var c=i&&i.type==="changeAxisOrder"&&i.isInitSort;c||Ph(o,this._axisGroup,t),r.prototype.render.call(this,t,n,a,i)}},e.prototype.remove=function(){e5(this)},e.type="cartesianAxis",e}(js),P$={splitLine:function(r,e,t,n){var a=t.axis;if(!a.scale.isBlank()){var i=t.getModel("splitLine"),o=i.getModel("lineStyle"),s=o.get("color"),l=i.get("showMinLine")!==!1,u=i.get("showMaxLine")!==!1;s=ht(s)?s:[s];for(var c=n.coordinateSystem.getRect(),h=a.isHorizontal(),d=0,v=a.getTicksCoords({tickModel:i}),p=[],y=[],_=o.getLineStyle(),g=0;g<v.length;g++){var f=a.toGlobalCoord(v[g].coord);if(!(g===0&&!l||g===v.length-1&&!u)){var w=v[g].tickValue;h?(p[0]=f,p[1]=c.y,y[0]=f,y[1]=c.y+c.height):(p[0]=c.x,p[1]=f,y[0]=c.x+c.width,y[1]=f);var x=d++%s.length,S=new gr({anid:w!=null?"line_"+w:null,autoBatch:!0,shape:{x1:p[0],y1:p[1],x2:y[0],y2:y[1]},style:zt({stroke:s[x]},_),silent:!0});Jl(S.shape,_.lineWidth),e.add(S)}}}},minorSplitLine:function(r,e,t,n){var a=t.axis,i=t.getModel("minorSplitLine"),o=i.getModel("lineStyle"),s=n.coordinateSystem.getRect(),l=a.isHorizontal(),u=a.getMinorTicksCoords();if(u.length)for(var c=[],h=[],d=o.getLineStyle(),v=0;v<u.length;v++)for(var p=0;p<u[v].length;p++){var y=a.toGlobalCoord(u[v][p].coord);l?(c[0]=y,c[1]=s.y,h[0]=y,h[1]=s.y+s.height):(c[0]=s.x,c[1]=y,h[0]=s.x+s.width,h[1]=y);var _=new gr({anid:"minor_line_"+u[v][p].tickValue,autoBatch:!0,shape:{x1:c[0],y1:c[1],x2:h[0],y2:h[1]},style:d,silent:!0});Jl(_.shape,d.lineWidth),e.add(_)}},splitArea:function(r,e,t,n){t5(r,e,t,n)}},n5=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="xAxis",e}(r5),k$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=n5.type,t}return e.type="yAxis",e}(r5),R$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="grid",t}return e.prototype.render=function(t,n){this.group.removeAll(),t.get("show")&&this.group.add(new fe({shape:t.coordinateSystem.getRect(),style:zt({fill:t.get("backgroundColor")},t.getItemStyle()),silent:!0,z2:-1}))},e.type="grid",e}(Ze),$C={offset:0};function a5(r){r.registerComponentView(R$),r.registerComponentModel(s$),r.registerCoordinateSystem("cartesian2d",p$),au(r,"x",Y_,$C),au(r,"y",Y_,$C),r.registerComponentView(n5),r.registerComponentView(k$),r.registerPreprocessor(function(e){e.xAxis&&e.yAxis&&!e.grid&&(e.grid={})})}function E$(r){ne(a5),r.registerSeriesModel(r$),r.registerChartView(o$),r.registerLayout(Vh("scatter"))}function O$(r){r.eachSeriesByType("radar",function(e){var t=e.getData(),n=[],a=e.coordinateSystem;if(a){var i=a.getIndicatorAxes();B(i,function(o,s){t.each(t.mapDimension(i[s].dim),function(l,u){n[u]=n[u]||[];var c=a.dataToPoint(l,s);n[u][s]=jC(c)?c:qC(a)})}),t.each(function(o){var s=w6(n[o],function(l){return jC(l)})||qC(a);n[o].push(s.slice()),t.setItemLayout(o,n[o])})}})}function jC(r){return!isNaN(r[0])&&!isNaN(r[1])}function qC(r){return[r.cx,r.cy]}function B$(r){var e=r.polar;if(e){ht(e)||(e=[e]);var t=[];B(e,function(n,a){n.indicator?(n.type&&!n.shape&&(n.shape=n.type),r.radar=r.radar||[],ht(r.radar)||(r.radar=[r.radar]),r.radar.push(n)):t.push(n)}),r.polar=t}B(r.series,function(n){n&&n.type==="radar"&&n.polarIndex&&(n.radarIndex=n.polarIndex)})}var N$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=t.coordinateSystem,o=this.group,s=t.getData(),l=this._data;function u(d,v){var p=d.getItemVisual(v,"symbol")||"circle";if(p!=="none"){var y=xu(d.getItemVisual(v,"symbolSize")),_=or(p,-1,-1,2,2),g=d.getItemVisual(v,"symbolRotate")||0;return _.attr({style:{strokeNoScale:!0},z2:100,scaleX:y[0]/2,scaleY:y[1]/2,rotation:g*Math.PI/180||0}),_}}function c(d,v,p,y,_,g){p.removeAll();for(var f=0;f<v.length-1;f++){var w=u(y,_);w&&(w.__dimIdx=f,d[f]?(w.setPosition(d[f]),Zs[g?"initProps":"updateProps"](w,{x:v[f][0],y:v[f][1]},t,_)):w.setPosition(v[f]),p.add(w))}}function h(d){return ft(d,function(v){return[i.cx,i.cy]})}s.diff(l).add(function(d){var v=s.getItemLayout(d);if(v){var p=new rn,y=new nn,_={shape:{points:v}};p.shape.points=h(v),y.shape.points=h(v),He(p,_,t,d),He(y,_,t,d);var g=new Wt,f=new Wt;g.add(y),g.add(p),g.add(f),c(y.shape.points,v,f,s,d,!0),s.setItemGraphicEl(d,g)}}).update(function(d,v){var p=l.getItemGraphicEl(v),y=p.childAt(0),_=p.childAt(1),g=p.childAt(2),f={shape:{points:s.getItemLayout(d)}};f.shape.points&&(c(y.shape.points,f.shape.points,g,s,d,!1),xa(_),xa(y),_e(y,f,t),_e(_,f,t),s.setItemGraphicEl(d,p))}).remove(function(d){o.remove(l.getItemGraphicEl(d))}).execute(),s.eachItemGraphicEl(function(d,v){var p=s.getItemModel(v),y=d.childAt(0),_=d.childAt(1),g=d.childAt(2),f=s.getItemVisual(v,"style"),w=f.fill;o.add(d),y.useStyle(zt(p.getModel("lineStyle").getLineStyle(),{fill:"none",stroke:w})),kr(y,p,"lineStyle"),kr(_,p,"areaStyle");var x=p.getModel("areaStyle"),S=x.isEmpty()&&x.parentModel.isEmpty();_.ignore=S,B(["emphasis","select","blur"],function(L){var M=p.getModel([L,"areaStyle"]),I=M.isEmpty()&&M.parentModel.isEmpty();_.ensureState(L).ignore=I&&S}),_.useStyle(zt(x.getAreaStyle(),{fill:w,opacity:.7,decal:f.decal}));var A=p.getModel("emphasis"),T=A.getModel("itemStyle").getItemStyle();g.eachChild(function(L){if(L instanceof Tr){var M=L.style;L.useStyle(lt({image:M.image,x:M.x,y:M.y,width:M.width,height:M.height},f))}else L.useStyle(f),L.setColor(w),L.style.strokeNoScale=!0;var I=L.ensureState("emphasis");I.style=Gt(T);var R=s.getStore().get(s.getDimensionIndex(L.__dimIdx),v);(R==null||isNaN(R))&&(R=""),Rr(L,_r(p),{labelFetcher:s.hostModel,labelDataIndex:v,labelDimIndex:L.__dimIdx,defaultText:R,inheritColor:w,defaultOpacity:f.opacity})}),Xe(d,A.get("focus"),A.get("blurScope"),A.get("disabled"))}),this._data=s},e.prototype.remove=function(){this.group.removeAll(),this._data=null},e.type="radar",e}(Re),z$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Wh(Mt(this.getData,this),Mt(this.getRawData,this))},e.prototype.getInitialData=function(t,n){return Su(this,{generateCoord:"indicator_",generateCoordCount:1/0})},e.prototype.formatTooltip=function(t,n,a){var i=this.getData(),o=this.coordinateSystem,s=o.getIndicatorAxes(),l=this.getData().getName(t),u=l===""?this.name:l,c=rR(this,t);return wr("section",{header:u,sortBlocks:!0,blocks:ft(s,function(h){var d=i.get(i.mapDimension(h.dim),t);return wr("nameValue",{markerType:"subItem",markerColor:c,name:h.name,value:d,sortParam:d})})})},e.prototype.getTooltipPosition=function(t){if(t!=null){for(var n=this.getData(),a=this.coordinateSystem,i=n.getValues(ft(a.dimensions,function(u){return n.mapDimension(u)}),t),o=0,s=i.length;o<s;o++)if(!isNaN(i[o])){var l=a.getIndicatorAxes();return a.coordToPoint(l[o].dataToCoord(i[o]),o)}}},e.type="series.radar",e.dependencies=["radar"],e.defaultOption={z:2,colorBy:"data",coordinateSystem:"radar",legendHoverLink:!0,radarIndex:0,lineStyle:{width:2,type:"solid",join:"round"},label:{position:"top"},symbolSize:8},e}(Ve),ic=KE.value;function Cv(r,e){return zt({show:e},r)}var F$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(){var t=this.get("boundaryGap"),n=this.get("splitNumber"),a=this.get("scale"),i=this.get("axisLine"),o=this.get("axisTick"),s=this.get("axisLabel"),l=this.get("axisName"),u=this.get(["axisName","show"]),c=this.get(["axisName","formatter"]),h=this.get("axisNameGap"),d=this.get("triggerEvent"),v=ft(this.get("indicator")||[],function(p){p.max!=null&&p.max>0&&!p.min?p.min=0:p.min!=null&&p.min<0&&!p.max&&(p.max=0);var y=l;p.color!=null&&(y=zt({color:p.color},l));var _=qt(Gt(p),{boundaryGap:t,splitNumber:n,scale:a,axisLine:i,axisTick:o,axisLabel:s,name:p.text,showName:u,nameLocation:"end",nameGap:h,nameTextStyle:y,triggerEvent:d},!1);if(Lt(c)){var g=_.name;_.name=c.replace("{value}",g??"")}else Nt(c)&&(_.name=c(_.name,_));var f=new De(_,null,this.ecModel);return sr(f,Bh.prototype),f.mainType="radar",f.componentIndex=this.componentIndex,f},this);this._indicatorModels=v},e.prototype.getIndicatorModels=function(){return this._indicatorModels},e.type="radar",e.defaultOption={z:0,center:["50%","50%"],radius:"75%",startAngle:90,axisName:{show:!0},boundaryGap:[0,0],splitNumber:5,axisNameGap:15,scale:!1,shape:"polygon",axisLine:qt({lineStyle:{color:"#bbb"}},ic.axisLine),axisLabel:Cv(ic.axisLabel,!1),axisTick:Cv(ic.axisTick,!1),splitLine:Cv(ic.splitLine,!0),splitArea:Cv(ic.splitArea,!0),indicator:[]},e}(le),V$=["axisLine","axisTickLabel","axisName"],G$=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=this.group;i.removeAll(),this._buildAxes(t),this._buildSplitLineAndArea(t)},e.prototype._buildAxes=function(t){var n=t.coordinateSystem,a=n.getIndicatorAxes(),i=ft(a,function(o){var s=o.model.get("showName")?o.name:"",l=new Qr(o.model,{axisName:s,position:[n.cx,n.cy],rotation:o.angle,labelDirection:-1,tickDirection:-1,nameDirection:1});return l});B(i,function(o){B(V$,o.add,o),this.group.add(o.getGroup())},this)},e.prototype._buildSplitLineAndArea=function(t){var n=t.coordinateSystem,a=n.getIndicatorAxes();if(!a.length)return;var i=t.get("shape"),o=t.getModel("splitLine"),s=t.getModel("splitArea"),l=o.getModel("lineStyle"),u=s.getModel("areaStyle"),c=o.get("show"),h=s.get("show"),d=l.get("color"),v=u.get("color"),p=ht(d)?d:[d],y=ht(v)?v:[v],_=[],g=[];function f(N,V,W){var $=W%V.length;return N[$]=N[$]||[],$}if(i==="circle")for(var w=a[0].getTicksCoords(),x=n.cx,S=n.cy,A=0;A<w.length;A++){if(c){var T=f(_,p,A);_[T].push(new ki({shape:{cx:x,cy:S,r:w[A].coord}}))}if(h&&A<w.length-1){var T=f(g,y,A);g[T].push(new Mh({shape:{cx:x,cy:S,r0:w[A].coord,r:w[A+1].coord}}))}}else for(var L,M=ft(a,function(N,V){var W=N.getTicksCoords();return L=L==null?W.length-1:Math.min(W.length-1,L),ft(W,function($){return n.coordToPoint($.coord,V)})}),I=[],A=0;A<=L;A++){for(var R=[],P=0;P<a.length;P++)R.push(M[P][A]);if(R[0]&&R.push(R[0].slice()),c){var T=f(_,p,A);_[T].push(new nn({shape:{points:R}}))}if(h&&I){var T=f(g,y,A-1);g[T].push(new rn({shape:{points:R.concat(I)}}))}I=R.slice().reverse()}var E=l.getLineStyle(),D=u.getAreaStyle();B(g,function(N,V){this.group.add(qn(N,{style:zt({stroke:"none",fill:y[V%y.length]},D),silent:!0}))},this),B(_,function(N,V){this.group.add(qn(N,{style:zt({fill:"none",stroke:p[V%p.length]},E),silent:!0}))},this)},e.type="radar",e}(Ze),W$=function(r){rt(e,r);function e(t,n,a){var i=r.call(this,t,n,a)||this;return i.type="value",i.angle=0,i.name="",i}return e}(Sa),H$=function(){function r(e,t,n){this.dimensions=[],this._model=e,this._indicatorAxes=ft(e.getIndicatorModels(),function(a,i){var o="indicator_"+i,s=new W$(o,new Mi);return s.name=a.get("name"),s.model=a,a.axis=s,this.dimensions.push(o),s},this),this.resize(e,n)}return r.prototype.getIndicatorAxes=function(){return this._indicatorAxes},r.prototype.dataToPoint=function(e,t){var n=this._indicatorAxes[t];return this.coordToPoint(n.dataToCoord(e),t)},r.prototype.coordToPoint=function(e,t){var n=this._indicatorAxes[t],a=n.angle,i=this.cx+e*Math.cos(a),o=this.cy-e*Math.sin(a);return[i,o]},r.prototype.pointToData=function(e){var t=e[0]-this.cx,n=e[1]-this.cy,a=Math.sqrt(t*t+n*n);t/=a,n/=a;for(var i=Math.atan2(-n,t),o=1/0,s,l=-1,u=0;u<this._indicatorAxes.length;u++){var c=this._indicatorAxes[u],h=Math.abs(i-c.angle);h<o&&(s=c,l=u,o=h)}return[l,+(s&&s.coordToData(a))]},r.prototype.resize=function(e,t){var n=e.get("center"),a=t.getWidth(),i=t.getHeight(),o=Math.min(a,i)/2;this.cx=At(n[0],a),this.cy=At(n[1],i),this.startAngle=e.get("startAngle")*Math.PI/180;var s=e.get("radius");(Lt(s)||ye(s))&&(s=[0,s]),this.r0=At(s[0],o),this.r=At(s[1],o),B(this._indicatorAxes,function(l,u){l.setExtent(this.r0,this.r);var c=this.startAngle+u*Math.PI*2/this._indicatorAxes.length;c=Math.atan2(Math.sin(c),Math.cos(c)),l.angle=c},this)},r.prototype.update=function(e,t){var n=this._indicatorAxes,a=this._model;B(n,function(s){s.scale.setExtent(1/0,-1/0)}),e.eachSeriesByType("radar",function(s,l){if(!(s.get("coordinateSystem")!=="radar"||e.getComponent("radar",s.get("radarIndex"))!==a)){var u=s.getData();B(n,function(c){c.scale.unionExtentFromData(u,u.mapDimension(c.dim))})}},this);var i=a.get("splitNumber"),o=new Mi;o.setExtent(0,i),o.setInterval(1),B(n,function(s,l){QE(s.scale,s.model,o)})},r.prototype.convertToPixel=function(e,t,n){return console.warn("Not implemented."),null},r.prototype.convertFromPixel=function(e,t,n){return console.warn("Not implemented."),null},r.prototype.containPoint=function(e){return console.warn("Not implemented."),!1},r.create=function(e,t){var n=[];return e.eachComponent("radar",function(a){var i=new r(a,e,t);n.push(i),a.coordinateSystem=i}),e.eachSeriesByType("radar",function(a){a.get("coordinateSystem")==="radar"&&(a.coordinateSystem=n[a.get("radarIndex")||0])}),n},r.dimensions=[],r}();function U$(r){r.registerCoordinateSystem("radar",H$),r.registerComponentModel(F$),r.registerComponentView(G$),r.registerVisual({seriesType:"radar",reset:function(e){var t=e.getData();t.each(function(n){t.setItemVisual(n,"legendIcon","roundRect")}),t.setVisual("legendIcon","roundRect")}})}function Z$(r){ne(U$),r.registerChartView(N$),r.registerSeriesModel(z$),r.registerLayout(O$),r.registerProcessor(Gh("radar")),r.registerPreprocessor(B$)}var KC="\0_ec_interaction_mutex";function Y$(r,e,t){var n=Yw(r);n[e]=t}function X$(r,e,t){var n=Yw(r),a=n[e];a===t&&(n[e]=null)}function QC(r,e){return!!Yw(r)[e]}function Yw(r){return r[KC]||(r[KC]={})}Qa({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},tr);var Hh=function(r){rt(e,r);function e(t){var n=r.call(this)||this;n._zr=t;var a=Mt(n._mousedownHandler,n),i=Mt(n._mousemoveHandler,n),o=Mt(n._mouseupHandler,n),s=Mt(n._mousewheelHandler,n),l=Mt(n._pinchHandler,n);return n.enable=function(u,c){this.disable(),this._opt=zt(Gt(c)||{},{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),u==null&&(u=!0),(u===!0||u==="move"||u==="pan")&&(t.on("mousedown",a),t.on("mousemove",i),t.on("mouseup",o)),(u===!0||u==="scale"||u==="zoom")&&(t.on("mousewheel",s),t.on("pinch",l))},n.disable=function(){t.off("mousedown",a),t.off("mousemove",i),t.off("mouseup",o),t.off("mousewheel",s),t.off("pinch",l)},n}return e.prototype.isDragging=function(){return this._dragging},e.prototype.isPinching=function(){return this._pinching},e.prototype.setPointerChecker=function(t){this.pointerChecker=t},e.prototype.dispose=function(){this.disable()},e.prototype._mousedownHandler=function(t){if(!A2(t)){for(var n=t.target;n;){if(n.draggable)return;n=n.__hostTarget||n.parent}var a=t.offsetX,i=t.offsetY;this.pointerChecker&&this.pointerChecker(t,a,i)&&(this._x=a,this._y=i,this._dragging=!0)}},e.prototype._mousemoveHandler=function(t){if(!(!this._dragging||!id("moveOnMouseMove",t,this._opt)||t.gestureEvent==="pinch"||QC(this._zr,"globalPan"))){var n=t.offsetX,a=t.offsetY,i=this._x,o=this._y,s=n-i,l=a-o;this._x=n,this._y=a,this._opt.preventDefaultMouseMove&&Si(t.event),i5(this,"pan","moveOnMouseMove",t,{dx:s,dy:l,oldX:i,oldY:o,newX:n,newY:a,isAvailableBehavior:null})}},e.prototype._mouseupHandler=function(t){A2(t)||(this._dragging=!1)},e.prototype._mousewheelHandler=function(t){var n=id("zoomOnMouseWheel",t,this._opt),a=id("moveOnMouseWheel",t,this._opt),i=t.wheelDelta,o=Math.abs(i),s=t.offsetX,l=t.offsetY;if(!(i===0||!n&&!a)){if(n){var u=o>3?1.4:o>1?1.2:1.1,c=i>0?u:1/u;Em(this,"zoom","zoomOnMouseWheel",t,{scale:c,originX:s,originY:l,isAvailableBehavior:null})}if(a){var h=Math.abs(i),d=(i>0?1:-1)*(h>3?.4:h>1?.15:.05);Em(this,"scrollMove","moveOnMouseWheel",t,{scrollDelta:d,originX:s,originY:l,isAvailableBehavior:null})}}},e.prototype._pinchHandler=function(t){if(!QC(this._zr,"globalPan")){var n=t.pinchScale>1?1.1:1/1.1;Em(this,"zoom",null,t,{scale:n,originX:t.pinchX,originY:t.pinchY,isAvailableBehavior:null})}},e}(ea);function Em(r,e,t,n,a){r.pointerChecker&&r.pointerChecker(n,a.originX,a.originY)&&(Si(n.event),i5(r,e,t,n,a))}function i5(r,e,t,n,a){a.isAvailableBehavior=Mt(id,null,t,n),r.trigger(e,a)}function id(r,e,t){var n=t[r];return!r||n&&(!Lt(n)||e.event[n+"Key"])}function Xw(r,e,t){var n=r.target;n.x+=e,n.y+=t,n.dirty()}function $w(r,e,t,n){var a=r.target,i=r.zoomLimit,o=r.zoom=r.zoom||1;if(o*=e,i){var s=i.min||0,l=i.max||1/0;o=Math.max(Math.min(l,o),s)}var u=o/r.zoom;r.zoom=o,a.x-=(t-a.x)*(u-1),a.y-=(n-a.y)*(u-1),a.scaleX*=u,a.scaleY*=u,a.dirty()}var $$={axisPointer:1,tooltip:1,brush:1};function Up(r,e,t){var n=e.getComponentByElement(r.topTarget),a=n&&n.coordinateSystem;return n&&n!==t&&!$$.hasOwnProperty(n.mainType)&&a&&a.model!==t}function o5(r){if(Lt(r)){var e=new DOMParser;r=e.parseFromString(r,"text/xml")}var t=r;for(t.nodeType===9&&(t=t.firstChild);t.nodeName.toLowerCase()!=="svg"||t.nodeType!==1;)t=t.nextSibling;return t}var Om,Hd={fill:"fill",stroke:"stroke","stroke-width":"lineWidth",opacity:"opacity","fill-opacity":"fillOpacity","stroke-opacity":"strokeOpacity","stroke-dasharray":"lineDash","stroke-dashoffset":"lineDashOffset","stroke-linecap":"lineCap","stroke-linejoin":"lineJoin","stroke-miterlimit":"miterLimit","font-family":"fontFamily","font-size":"fontSize","font-style":"fontStyle","font-weight":"fontWeight","text-anchor":"textAlign",visibility:"visibility",display:"display"},JC=ue(Hd),Ud={"alignment-baseline":"textBaseline","stop-color":"stopColor"},tL=ue(Ud),j$=function(){function r(){this._defs={},this._root=null}return r.prototype.parse=function(e,t){t=t||{};var n=o5(e);this._defsUsePending=[];var a=new Wt;this._root=a;var i=[],o=n.getAttribute("viewBox")||"",s=parseFloat(n.getAttribute("width")||t.width),l=parseFloat(n.getAttribute("height")||t.height);isNaN(s)&&(s=null),isNaN(l)&&(l=null),An(n,a,null,!0,!1);for(var u=n.firstChild;u;)this._parseNode(u,a,i,null,!1,!1),u=u.nextSibling;Q$(this._defs,this._defsUsePending),this._defsUsePending=[];var c,h;if(o){var d=Zp(o);d.length>=4&&(c={x:parseFloat(d[0]||0),y:parseFloat(d[1]||0),width:parseFloat(d[2]),height:parseFloat(d[3])})}if(c&&s!=null&&l!=null&&(h=l5(c,{x:0,y:0,width:s,height:l}),!t.ignoreViewBox)){var v=a;a=new Wt,a.add(v),v.scaleX=v.scaleY=h.scale,v.x=h.x,v.y=h.y}return!t.ignoreRootClip&&s!=null&&l!=null&&a.setClipPath(new fe({shape:{x:0,y:0,width:s,height:l}})),{root:a,width:s,height:l,viewBoxRect:c,viewBoxTransform:h,named:i}},r.prototype._parseNode=function(e,t,n,a,i,o){var s=e.nodeName.toLowerCase(),l,u=a;if(s==="defs"&&(i=!0),s==="text"&&(o=!0),s==="defs"||s==="switch")l=t;else{if(!i){var c=Om[s];if(c&&It(Om,s)){l=c.call(this,e,t);var h=e.getAttribute("name");if(h){var d={name:h,namedFrom:null,svgNodeTagLower:s,el:l};n.push(d),s==="g"&&(u=d)}else a&&n.push({name:a.name,namedFrom:a,svgNodeTagLower:s,el:l});t.add(l)}}var v=eL[s];if(v&&It(eL,s)){var p=v.call(this,e),y=e.getAttribute("id");y&&(this._defs[y]=p)}}if(l&&l.isGroup)for(var _=e.firstChild;_;)_.nodeType===1?this._parseNode(_,l,n,u,i,o):_.nodeType===3&&o&&this._parseText(_,l),_=_.nextSibling},r.prototype._parseText=function(e,t){var n=new Ql({style:{text:e.textContent},silent:!0,x:this._textX||0,y:this._textY||0});Gn(t,n),An(e,n,this._defsUsePending,!1,!1),q$(n,t);var a=n.style,i=a.fontSize;i&&i<9&&(a.fontSize=9,n.scaleX*=i/9,n.scaleY*=i/9);var o=(a.fontSize||a.fontFamily)&&[a.fontStyle,a.fontWeight,(a.fontSize||12)+"px",a.fontFamily||"sans-serif"].join(" ");a.font=o;var s=n.getBoundingRect();return this._textX+=s.width,t.add(n),n},r.internalField=function(){Om={g:function(e,t){var n=new Wt;return Gn(t,n),An(e,n,this._defsUsePending,!1,!1),n},rect:function(e,t){var n=new fe;return Gn(t,n),An(e,n,this._defsUsePending,!1,!1),n.setShape({x:parseFloat(e.getAttribute("x")||"0"),y:parseFloat(e.getAttribute("y")||"0"),width:parseFloat(e.getAttribute("width")||"0"),height:parseFloat(e.getAttribute("height")||"0")}),n.silent=!0,n},circle:function(e,t){var n=new ki;return Gn(t,n),An(e,n,this._defsUsePending,!1,!1),n.setShape({cx:parseFloat(e.getAttribute("cx")||"0"),cy:parseFloat(e.getAttribute("cy")||"0"),r:parseFloat(e.getAttribute("r")||"0")}),n.silent=!0,n},line:function(e,t){var n=new gr;return Gn(t,n),An(e,n,this._defsUsePending,!1,!1),n.setShape({x1:parseFloat(e.getAttribute("x1")||"0"),y1:parseFloat(e.getAttribute("y1")||"0"),x2:parseFloat(e.getAttribute("x2")||"0"),y2:parseFloat(e.getAttribute("y2")||"0")}),n.silent=!0,n},ellipse:function(e,t){var n=new Sp;return Gn(t,n),An(e,n,this._defsUsePending,!1,!1),n.setShape({cx:parseFloat(e.getAttribute("cx")||"0"),cy:parseFloat(e.getAttribute("cy")||"0"),rx:parseFloat(e.getAttribute("rx")||"0"),ry:parseFloat(e.getAttribute("ry")||"0")}),n.silent=!0,n},polygon:function(e,t){var n=e.getAttribute("points"),a;n&&(a=aL(n));var i=new rn({shape:{points:a||[]},silent:!0});return Gn(t,i),An(e,i,this._defsUsePending,!1,!1),i},polyline:function(e,t){var n=e.getAttribute("points"),a;n&&(a=aL(n));var i=new nn({shape:{points:a||[]},silent:!0});return Gn(t,i),An(e,i,this._defsUsePending,!1,!1),i},image:function(e,t){var n=new Tr;return Gn(t,n),An(e,n,this._defsUsePending,!1,!1),n.setStyle({image:e.getAttribute("xlink:href")||e.getAttribute("href"),x:+e.getAttribute("x"),y:+e.getAttribute("y"),width:+e.getAttribute("width"),height:+e.getAttribute("height")}),n.silent=!0,n},text:function(e,t){var n=e.getAttribute("x")||"0",a=e.getAttribute("y")||"0",i=e.getAttribute("dx")||"0",o=e.getAttribute("dy")||"0";this._textX=parseFloat(n)+parseFloat(i),this._textY=parseFloat(a)+parseFloat(o);var s=new Wt;return Gn(t,s),An(e,s,this._defsUsePending,!1,!0),s},tspan:function(e,t){var n=e.getAttribute("x"),a=e.getAttribute("y");n!=null&&(this._textX=parseFloat(n)),a!=null&&(this._textY=parseFloat(a));var i=e.getAttribute("dx")||"0",o=e.getAttribute("dy")||"0",s=new Wt;return Gn(t,s),An(e,s,this._defsUsePending,!1,!0),this._textX+=parseFloat(i),this._textY+=parseFloat(o),s},path:function(e,t){var n=e.getAttribute("d")||"",a=qP(n);return Gn(t,a),An(e,a,this._defsUsePending,!1,!1),a.silent=!0,a}}}(),r}(),eL={lineargradient:function(r){var e=parseInt(r.getAttribute("x1")||"0",10),t=parseInt(r.getAttribute("y1")||"0",10),n=parseInt(r.getAttribute("x2")||"10",10),a=parseInt(r.getAttribute("y2")||"0",10),i=new Ih(e,t,n,a);return rL(r,i),nL(r,i),i},radialgradient:function(r){var e=parseInt(r.getAttribute("cx")||"0",10),t=parseInt(r.getAttribute("cy")||"0",10),n=parseInt(r.getAttribute("r")||"0",10),a=new tk(e,t,n);return rL(r,a),nL(r,a),a}};function rL(r,e){var t=r.getAttribute("gradientUnits");t==="userSpaceOnUse"&&(e.global=!0)}function nL(r,e){for(var t=r.firstChild;t;){if(t.nodeType===1&&t.nodeName.toLocaleLowerCase()==="stop"){var n=t.getAttribute("offset"),a=void 0;n&&n.indexOf("%")>0?a=parseInt(n,10)/100:n?a=parseFloat(n):a=0;var i={};s5(t,i,i);var o=i.stopColor||t.getAttribute("stop-color")||"#000000";e.colorStops.push({offset:a,color:o})}t=t.nextSibling}}function Gn(r,e){r&&r.__inheritedStyle&&(e.__inheritedStyle||(e.__inheritedStyle={}),zt(e.__inheritedStyle,r.__inheritedStyle))}function aL(r){for(var e=Zp(r),t=[],n=0;n<e.length;n+=2){var a=parseFloat(e[n]),i=parseFloat(e[n+1]);t.push([a,i])}return t}function An(r,e,t,n,a){var i=e,o=i.__inheritedStyle=i.__inheritedStyle||{},s={};r.nodeType===1&&(ej(r,e),s5(r,o,s),n||rj(r,o,s)),i.style=i.style||{},o.fill!=null&&(i.style.fill=iL(i,"fill",o.fill,t)),o.stroke!=null&&(i.style.stroke=iL(i,"stroke",o.stroke,t)),B(["lineWidth","opacity","fillOpacity","strokeOpacity","miterLimit","fontSize"],function(l){o[l]!=null&&(i.style[l]=parseFloat(o[l]))}),B(["lineDashOffset","lineCap","lineJoin","fontWeight","fontFamily","fontStyle","textAlign"],function(l){o[l]!=null&&(i.style[l]=o[l])}),a&&(i.__selfStyle=s),o.lineDash&&(i.style.lineDash=ft(Zp(o.lineDash),function(l){return parseFloat(l)})),(o.visibility==="hidden"||o.visibility==="collapse")&&(i.invisible=!0),o.display==="none"&&(i.ignore=!0)}function q$(r,e){var t=e.__selfStyle;if(t){var n=t.textBaseline,a=n;!n||n==="auto"||n==="baseline"?a="alphabetic":n==="before-edge"||n==="text-before-edge"?a="top":n==="after-edge"||n==="text-after-edge"?a="bottom":(n==="central"||n==="mathematical")&&(a="middle"),r.style.textBaseline=a}var i=e.__inheritedStyle;if(i){var o=i.textAlign,s=o;o&&(o==="middle"&&(s="center"),r.style.textAlign=s)}}var K$=/^url\(\s*#(.*?)\)/;function iL(r,e,t,n){var a=t&&t.match(K$);if(a){var i=ga(a[1]);n.push([r,e,i]);return}return t==="none"&&(t=null),t}function Q$(r,e){for(var t=0;t<e.length;t++){var n=e[t];n[0].style[n[1]]=r[n[2]]}}var J$=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function Zp(r){return r.match(J$)||[]}var tj=/(translate|scale|rotate|skewX|skewY|matrix)\(([\-\s0-9\.eE,]*)\)/g,Bm=Math.PI/180;function ej(r,e){var t=r.getAttribute("transform");if(t){t=t.replace(/,/g," ");var n=[],a=null;t.replace(tj,function(h,d,v){return n.push(d,v),""});for(var i=n.length-1;i>0;i-=2){var o=n[i],s=n[i-1],l=Zp(o);switch(a=a||Ln(),s){case"translate":Ya(a,a,[parseFloat(l[0]),parseFloat(l[1]||"0")]);break;case"scale":H1(a,a,[parseFloat(l[0]),parseFloat(l[1]||l[0])]);break;case"rotate":Hs(a,a,-parseFloat(l[0])*Bm,[parseFloat(l[1]||"0"),parseFloat(l[2]||"0")]);break;case"skewX":var u=Math.tan(parseFloat(l[0])*Bm);_i(a,[1,0,u,1,0,0],a);break;case"skewY":var c=Math.tan(parseFloat(l[0])*Bm);_i(a,[1,c,0,1,0,0],a);break;case"matrix":a[0]=parseFloat(l[0]),a[1]=parseFloat(l[1]),a[2]=parseFloat(l[2]),a[3]=parseFloat(l[3]),a[4]=parseFloat(l[4]),a[5]=parseFloat(l[5]);break}}e.setLocalTransform(a)}}var oL=/([^\s:;]+)\s*:\s*([^:;]+)/g;function s5(r,e,t){var n=r.getAttribute("style");if(n){oL.lastIndex=0;for(var a;(a=oL.exec(n))!=null;){var i=a[1],o=It(Hd,i)?Hd[i]:null;o&&(e[o]=a[2]);var s=It(Ud,i)?Ud[i]:null;s&&(t[s]=a[2])}}}function rj(r,e,t){for(var n=0;n<JC.length;n++){var a=JC[n],i=r.getAttribute(a);i!=null&&(e[Hd[a]]=i)}for(var n=0;n<tL.length;n++){var a=tL[n],i=r.getAttribute(a);i!=null&&(t[Ud[a]]=i)}}function l5(r,e){var t=e.width/r.width,n=e.height/r.height,a=Math.min(t,n);return{scale:a,x:-(r.x+r.width/2)*a+(e.x+e.width/2),y:-(r.y+r.height/2)*a+(e.y+e.height/2)}}function nj(r,e){var t=new j$;return t.parse(r,e)}var aj=Pt(["rect","circle","line","ellipse","polygon","polyline","path","text","tspan","g"]),ij=function(){function r(e,t){this.type="geoSVG",this._usedGraphicMap=Pt(),this._freedGraphics=[],this._mapName=e,this._parsedXML=o5(t)}return r.prototype.load=function(){var e=this._firstGraphic;if(!e){e=this._firstGraphic=this._buildGraphic(this._parsedXML),this._freedGraphics.push(e),this._boundingRect=this._firstGraphic.boundingRect.clone();var t=sj(e.named),n=t.regions,a=t.regionsMap;this._regions=n,this._regionsMap=a}return{boundingRect:this._boundingRect,regions:this._regions,regionsMap:this._regionsMap}},r.prototype._buildGraphic=function(e){var t,n;try{t=e&&nj(e,{ignoreViewBox:!0,ignoreRootClip:!0})||{},n=t.root,Jr(n!=null)}catch(_){throw new Error(`Invalid svg format
`+_.message)}var a=new Wt;a.add(n),a.isGeoSVGGraphicRoot=!0;var i=t.width,o=t.height,s=t.viewBoxRect,l=this._boundingRect;if(!l){var u=void 0,c=void 0,h=void 0,d=void 0;if(i!=null?(u=0,h=i):s&&(u=s.x,h=s.width),o!=null?(c=0,d=o):s&&(c=s.y,d=s.height),u==null||c==null){var v=n.getBoundingRect();u==null&&(u=v.x,h=v.width),c==null&&(c=v.y,d=v.height)}l=this._boundingRect=new Qt(u,c,h,d)}if(s){var p=l5(s,l);n.scaleX=n.scaleY=p.scale,n.x=p.x,n.y=p.y}a.setClipPath(new fe({shape:l.plain()}));var y=[];return B(t.named,function(_){aj.get(_.svgNodeTagLower)!=null&&(y.push(_),oj(_.el))}),{root:a,boundingRect:l,named:y}},r.prototype.useGraphic=function(e){var t=this._usedGraphicMap,n=t.get(e);return n||(n=this._freedGraphics.pop()||this._buildGraphic(this._parsedXML),t.set(e,n),n)},r.prototype.freeGraphic=function(e){var t=this._usedGraphicMap,n=t.get(e);n&&(t.removeKey(e),this._freedGraphics.push(n))},r}();function oj(r){r.silent=!1,r.isGroup&&r.traverse(function(e){e.silent=!1})}function sj(r){var e=[],t=Pt();return B(r,function(n){if(n.namedFrom==null){var a=new eY(n.name,n.el);e.push(a),t.set(n.name,a)}}),{regions:e,regionsMap:t}}var K_=[126,25],sL="南海诸岛",us=[[[0,3.5],[7,11.2],[15,11.9],[30,7],[42,.7],[52,.7],[56,7.7],[59,.7],[64,.7],[64,0],[5,0],[0,3.5]],[[13,16.1],[19,14.7],[16,21.7],[11,23.1],[13,16.1]],[[12,32.2],[14,38.5],[15,38.5],[13,32.2],[12,32.2]],[[16,47.6],[12,53.2],[13,53.2],[18,47.6],[16,47.6]],[[6,64.4],[8,70],[9,70],[8,64.4],[6,64.4]],[[23,82.6],[29,79.8],[30,79.8],[25,82.6],[23,82.6]],[[37,70.7],[43,62.3],[44,62.3],[39,70.7],[37,70.7]],[[48,51.1],[51,45.5],[53,45.5],[50,51.1],[48,51.1]],[[51,35],[51,28.7],[53,28.7],[53,35],[51,35]],[[52,22.4],[55,17.5],[56,17.5],[53,22.4],[52,22.4]],[[58,12.6],[62,7],[63,7],[60,12.6],[58,12.6]],[[0,3.5],[0,93.1],[64,93.1],[64,0],[63,0],[63,92.4],[1,92.4],[1,3.5],[0,3.5]]];for(var ss=0;ss<us.length;ss++)for(var Tl=0;Tl<us[ss].length;Tl++)us[ss][Tl][0]/=10.5,us[ss][Tl][1]/=-10.5/.75,us[ss][Tl][0]+=K_[0],us[ss][Tl][1]+=K_[1];function lj(r,e){if(r==="china"){for(var t=0;t<e.length;t++)if(e[t].name===sL)return;e.push(new aE(sL,ft(us,function(n){return{type:"polygon",exterior:n}}),K_))}}var uj={南海诸岛:[32,80],广东:[0,-10],香港:[10,5],澳门:[-10,10],天津:[5,5]};function cj(r,e){if(r==="china"){var t=uj[e.name];if(t){var n=e.getCenter();n[0]+=t[0]/10.5,n[1]+=-t[1]/(10.5/.75),e.setCenter(n)}}}var hj=[[[123.45165252685547,25.73527164402261],[123.49731445312499,25.73527164402261],[123.49731445312499,25.750734064600884],[123.45165252685547,25.750734064600884],[123.45165252685547,25.73527164402261]]];function fj(r,e){r==="china"&&e.name==="台湾"&&e.geometries.push({type:"polygon",exterior:hj[0]})}var vj="name",dj=function(){function r(e,t,n){this.type="geoJSON",this._parsedMap=Pt(),this._mapName=e,this._specialAreas=n,this._geoJSON=gj(t)}return r.prototype.load=function(e,t){t=t||vj;var n=this._parsedMap.get(t);if(!n){var a=this._parseToRegions(t);n=this._parsedMap.set(t,{regions:a,boundingRect:pj(a)})}var i=Pt(),o=[];return B(n.regions,function(s){var l=s.name;e&&It(e,l)&&(s=s.cloneShallow(l=e[l])),o.push(s),i.set(l,s)}),{regions:o,boundingRect:n.boundingRect||new Qt(0,0,0,0),regionsMap:i}},r.prototype._parseToRegions=function(e){var t=this._mapName,n=this._geoJSON,a;try{a=n?nY(n,e):[]}catch(i){throw new Error(`Invalid geoJson format
`+i.message)}return lj(t,a),B(a,function(i){var o=i.name;cj(t,i),fj(t,i);var s=this._specialAreas&&this._specialAreas[o];s&&i.transformTo(s.left,s.top,s.width,s.height)},this),a},r.prototype.getMapForUser=function(){return{geoJson:this._geoJSON,geoJSON:this._geoJSON,specialAreas:this._specialAreas}},r}();function pj(r){for(var e,t=0;t<r.length;t++){var n=r[t].getBoundingRect();e=e||n.clone(),e.union(n)}return e}function gj(r){return Lt(r)?typeof JSON<"u"&&JSON.parse?JSON.parse(r):new Function("return ("+r+");")():r}var oc=Pt();const Di={registerMap:function(r,e,t){if(e.svg){var n=new ij(r,e.svg);oc.set(r,n)}else{var a=e.geoJson||e.geoJSON;a&&!e.features?t=e.specialAreas:a=e;var n=new dj(r,a,t);oc.set(r,n)}},getGeoResource:function(r){return oc.get(r)},getMapForUser:function(r){var e=oc.get(r);return e&&e.type==="geoJSON"&&e.getMapForUser()},load:function(r,e,t){var n=oc.get(r);if(n)return n.load(e,t)}};var jw=["rect","circle","line","ellipse","polygon","polyline","path"],yj=Pt(jw),mj=Pt(jw.concat(["g"])),_j=Pt(jw.concat(["g"])),u5=ve();function Lv(r){var e=r.getItemStyle(),t=r.get("areaColor");return t!=null&&(e.fill=t),e}function lL(r){var e=r.style;e&&(e.stroke=e.stroke||e.fill,e.fill=null)}var c5=function(){function r(e){var t=new Wt;this.uid=pu("ec_map_draw"),this._controller=new Hh(e.getZr()),this._controllerHost={target:t},this.group=t,t.add(this._regionsGroup=new Wt),t.add(this._svgGroup=new Wt)}return r.prototype.draw=function(e,t,n,a,i){var o=e.mainType==="geo",s=e.getData&&e.getData();o&&t.eachComponent({mainType:"series",subType:"map"},function(g){!s&&g.getHostGeoModel()===e&&(s=g.getData())});var l=e.coordinateSystem,u=this._regionsGroup,c=this.group,h=l.getTransformInfo(),d=h.raw,v=h.roam,p=!u.childAt(0)||i;p?(c.x=v.x,c.y=v.y,c.scaleX=v.scaleX,c.scaleY=v.scaleY,c.dirty()):_e(c,v,e);var y=s&&s.getVisual("visualMeta")&&s.getVisual("visualMeta").length>0,_={api:n,geo:l,mapOrGeoModel:e,data:s,isVisualEncodedByVisualMap:y,isGeo:o,transformInfoRaw:d};l.resourceType==="geoJSON"?this._buildGeoJSON(_):l.resourceType==="geoSVG"&&this._buildSVG(_),this._updateController(e,t,n),this._updateMapSelectHandler(e,u,n,a)},r.prototype._buildGeoJSON=function(e){var t=this._regionsGroupByName=Pt(),n=Pt(),a=this._regionsGroup,i=e.transformInfoRaw,o=e.mapOrGeoModel,s=e.data,l=e.geo.projection,u=l&&l.stream;function c(v,p){return p&&(v=p(v)),v&&[v[0]*i.scaleX+i.x,v[1]*i.scaleY+i.y]}function h(v){for(var p=[],y=!u&&l&&l.project,_=0;_<v.length;++_){var g=c(v[_],y);g&&p.push(g)}return p}function d(v){return{shape:{points:h(v)}}}a.removeAll(),B(e.geo.regions,function(v){var p=v.name,y=t.get(p),_=n.get(p)||{},g=_.dataIdx,f=_.regionModel;if(!y){y=t.set(p,new Wt),a.add(y),g=s?s.indexOfName(p):null,f=e.isGeo?o.getRegionModel(p):s?s.getItemModel(g):null;var w=f.get("silent",!0);w!=null&&(y.silent=w),n.set(p,{dataIdx:g,regionModel:f})}var x=[],S=[];B(v.geometries,function(L){if(L.type==="polygon"){var M=[L.exterior].concat(L.interiors||[]);u&&(M=dL(M,u)),B(M,function(R){x.push(new rn(d(R)))})}else{var I=L.points;u&&(I=dL(I,u,!0)),B(I,function(R){S.push(new nn(d(R)))})}});var A=c(v.getCenter(),l&&l.project);function T(L,M){if(L.length){var I=new iw({culling:!0,segmentIgnoreThreshold:1,shape:{paths:L}});y.add(I),uL(e,I,g,f),cL(e,I,p,f,o,g,A),M&&(lL(I),B(I.states,lL))}}T(x),T(S,!0)}),t.each(function(v,p){var y=n.get(p),_=y.dataIdx,g=y.regionModel;hL(e,v,p,g,o,_),fL(e,v,p,g,o),vL(e,v,p,g,o)},this)},r.prototype._buildSVG=function(e){var t=e.geo.map,n=e.transformInfoRaw;this._svgGroup.x=n.x,this._svgGroup.y=n.y,this._svgGroup.scaleX=n.scaleX,this._svgGroup.scaleY=n.scaleY,this._svgResourceChanged(t)&&(this._freeSVG(),this._useSVG(t));var a=this._svgDispatcherMap=Pt(),i=!1;B(this._svgGraphicRecord.named,function(o){var s=o.name,l=e.mapOrGeoModel,u=e.data,c=o.svgNodeTagLower,h=o.el,d=u?u.indexOfName(s):null,v=l.getRegionModel(s);yj.get(c)!=null&&h instanceof ta&&uL(e,h,d,v),h instanceof ta&&(h.culling=!0);var p=v.get("silent",!0);if(p!=null&&(h.silent=p),h.z2EmphasisLift=0,!o.namedFrom&&(_j.get(c)!=null&&cL(e,h,s,v,l,d,null),hL(e,h,s,v,l,d),fL(e,h,s,v,l),mj.get(c)!=null)){var y=vL(e,h,s,v,l);y==="self"&&(i=!0);var _=a.get(s)||a.set(s,[]);_.push(h)}},this),this._enableBlurEntireSVG(i,e)},r.prototype._enableBlurEntireSVG=function(e,t){if(e&&t.isGeo){var n=t.mapOrGeoModel.getModel(["blur","itemStyle"]).getItemStyle(),a=n.opacity;this._svgGraphicRecord.root.traverse(function(i){if(!i.isGroup){zs(i);var o=i.ensureState("blur").style||{};o.opacity==null&&a!=null&&(o.opacity=a),i.ensureState("emphasis")}})}},r.prototype.remove=function(){this._regionsGroup.removeAll(),this._regionsGroupByName=null,this._svgGroup.removeAll(),this._freeSVG(),this._controller.dispose(),this._controllerHost=null},r.prototype.findHighDownDispatchers=function(e,t){if(e==null)return[];var n=t.coordinateSystem;if(n.resourceType==="geoJSON"){var a=this._regionsGroupByName;if(a){var i=a.get(e);return i?[i]:[]}}else if(n.resourceType==="geoSVG")return this._svgDispatcherMap&&this._svgDispatcherMap.get(e)||[]},r.prototype._svgResourceChanged=function(e){return this._svgMapName!==e},r.prototype._useSVG=function(e){var t=Di.getGeoResource(e);if(t&&t.type==="geoSVG"){var n=t.useGraphic(this.uid);this._svgGroup.add(n.root),this._svgGraphicRecord=n,this._svgMapName=e}},r.prototype._freeSVG=function(){var e=this._svgMapName;if(e!=null){var t=Di.getGeoResource(e);t&&t.type==="geoSVG"&&t.freeGraphic(this.uid),this._svgGraphicRecord=null,this._svgDispatcherMap=null,this._svgGroup.removeAll(),this._svgMapName=null}},r.prototype._updateController=function(e,t,n){var a=e.coordinateSystem,i=this._controller,o=this._controllerHost;o.zoomLimit=e.get("scaleLimit"),o.zoom=a.getZoom(),i.enable(e.get("roam")||!1);var s=e.mainType;function l(){var u={type:"geoRoam",componentType:s};return u[s+"Id"]=e.id,u}i.off("pan").on("pan",function(u){this._mouseDownFlag=!1,Xw(o,u.dx,u.dy),n.dispatchAction(lt(l(),{dx:u.dx,dy:u.dy,animation:{duration:0}}))},this),i.off("zoom").on("zoom",function(u){this._mouseDownFlag=!1,$w(o,u.scale,u.originX,u.originY),n.dispatchAction(lt(l(),{totalZoom:o.zoom,zoom:u.scale,originX:u.originX,originY:u.originY,animation:{duration:0}}))},this),i.setPointerChecker(function(u,c,h){return a.containPoint([c,h])&&!Up(u,n,e)})},r.prototype.resetForLabelLayout=function(){this.group.traverse(function(e){var t=e.getTextContent();t&&(t.ignore=u5(t).ignore)})},r.prototype._updateMapSelectHandler=function(e,t,n,a){var i=this;t.off("mousedown"),t.off("click"),e.get("selectedMode")&&(t.on("mousedown",function(){i._mouseDownFlag=!0}),t.on("click",function(o){i._mouseDownFlag&&(i._mouseDownFlag=!1)}))},r}();function uL(r,e,t,n){var a=n.getModel("itemStyle"),i=n.getModel(["emphasis","itemStyle"]),o=n.getModel(["blur","itemStyle"]),s=n.getModel(["select","itemStyle"]),l=Lv(a),u=Lv(i),c=Lv(s),h=Lv(o),d=r.data;if(d){var v=d.getItemVisual(t,"style"),p=d.getItemVisual(t,"decal");r.isVisualEncodedByVisualMap&&v.fill&&(l.fill=v.fill),p&&(l.decal=eu(p,r.api))}e.setStyle(l),e.style.strokeNoScale=!0,e.ensureState("emphasis").style=u,e.ensureState("select").style=c,e.ensureState("blur").style=h,zs(e)}function cL(r,e,t,n,a,i,o){var s=r.data,l=r.isGeo,u=s&&isNaN(s.get(s.mapDimension("value"),i)),c=s&&s.getItemLayout(i);if(l||u||c&&c.showLabel){var h=l?t:i,d=void 0;(!s||i>=0)&&(d=a);var v=o?{normal:{align:"center",verticalAlign:"middle"}}:null;Rr(e,_r(n),{labelFetcher:d,labelDataIndex:h,defaultText:t},v);var p=e.getTextContent();if(p&&(u5(p).ignore=p.ignore,e.textConfig&&o)){var y=e.getBoundingRect().clone();e.textConfig.layoutRect=y,e.textConfig.position=[(o[0]-y.x)/y.width*100+"%",(o[1]-y.y)/y.height*100+"%"]}e.disableLabelAnimation=!0}else e.removeTextContent(),e.removeTextConfig(),e.disableLabelAnimation=null}function hL(r,e,t,n,a,i){r.data?r.data.setItemGraphicEl(i,e):Ht(e).eventData={componentType:"geo",componentIndex:a.componentIndex,geoIndex:a.componentIndex,name:t,region:n&&n.option||{}}}function fL(r,e,t,n,a){r.data||Us({el:e,componentModel:a,itemName:t,itemTooltipOption:n.get("tooltip")})}function vL(r,e,t,n,a){e.highDownSilentOnTouch=!!a.get("selectedMode");var i=n.getModel("emphasis"),o=i.get("focus");return Xe(e,o,i.get("blurScope"),i.get("disabled")),r.isGeo&&gH(e,a,t),o}function dL(r,e,t){var n=[],a;function i(){a=[]}function o(){a.length&&(n.push(a),a=[])}var s=e({polygonStart:i,polygonEnd:o,lineStart:i,lineEnd:o,point:function(l,u){isFinite(l)&&isFinite(u)&&a.push([l,u])},sphere:function(){}});return!t&&s.polygonStart(),B(r,function(l){s.lineStart();for(var u=0;u<l.length;u++)s.point(l[u][0],l[u][1]);s.lineEnd()}),!t&&s.polygonEnd(),n}var wj=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a,i){if(!(i&&i.type==="mapToggleSelect"&&i.from===this.uid)){var o=this.group;if(o.removeAll(),!t.getHostGeoModel()){if(this._mapDraw&&i&&i.type==="geoRoam"&&this._mapDraw.resetForLabelLayout(),i&&i.type==="geoRoam"&&i.componentType==="series"&&i.seriesId===t.id){var s=this._mapDraw;s&&o.add(s.group)}else if(t.needsDrawMap){var s=this._mapDraw||new c5(a);o.add(s.group),s.draw(t,n,a,this,i),this._mapDraw=s}else this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null;t.get("showLegendSymbol")&&n.getComponent("legend")&&this._renderSymbols(t,n,a)}}},e.prototype.remove=function(){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null,this.group.removeAll()},e.prototype.dispose=function(){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null},e.prototype._renderSymbols=function(t,n,a){var i=t.originalData,o=this.group;i.each(i.mapDimension("value"),function(s,l){if(!isNaN(s)){var u=i.getItemLayout(l);if(!(!u||!u.point)){var c=u.point,h=u.offset,d=new ki({style:{fill:t.getData().getVisual("style").fill},shape:{cx:c[0]+h*9,cy:c[1],r:3},silent:!0,z2:8+(h?0:fu+1)});if(!h){var v=t.mainSeries.getData(),p=i.getName(l),y=v.indexOfName(p),_=i.getItemModel(l),g=_.getModel("label"),f=v.getItemGraphicEl(y);Rr(d,_r(_),{labelFetcher:{getFormattedLabel:function(w,x){return t.getFormattedLabel(y,x)}},defaultText:p}),d.disableLabelAnimation=!0,g.get("position")||d.setTextConfig({position:"bottom"}),f.onHoverStateChange=function(w){Sd(d,w)}}o.add(d)}}})},e.type="map",e}(Re),xj=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.needsDrawMap=!1,t.seriesGroup=[],t.getTooltipPosition=function(n){if(n!=null){var a=this.getData().getName(n),i=this.coordinateSystem,o=i.getRegion(a);return o&&i.dataToPoint(o.getCenter())}},t}return e.prototype.getInitialData=function(t){for(var n=Su(this,{coordDimensions:["value"],encodeDefaulter:Xt(pw,this)}),a=Pt(),i=[],o=0,s=n.count();o<s;o++){var l=n.getName(o);a.set(l,o)}var u=Di.load(this.getMapType(),this.option.nameMap,this.option.nameProperty);return B(u.regions,function(c){var h=c.name,d=a.get(h),v=c.properties&&c.properties.echartsStyle,p;d==null?(p={name:h},i.push(p)):p=n.getRawDataItem(d),v&&qt(p,v)}),n.appendData(i),n},e.prototype.getHostGeoModel=function(){var t=this.option.geoIndex;return t!=null?this.ecModel.getComponent("geo",t):null},e.prototype.getMapType=function(){return(this.getHostGeoModel()||this).option.map},e.prototype.getRawValue=function(t){var n=this.getData();return n.get(n.mapDimension("value"),t)},e.prototype.getRegionModel=function(t){var n=this.getData();return n.getItemModel(n.indexOfName(t))},e.prototype.formatTooltip=function(t,n,a){for(var i=this.getData(),o=this.getRawValue(t),s=i.getName(t),l=this.seriesGroup,u=[],c=0;c<l.length;c++){var h=l[c].originalData.indexOfName(s),d=i.mapDimension("value");isNaN(l[c].originalData.get(d,h))||u.push(l[c].name)}return wr("section",{header:u.join(", "),noHeader:!u.length,blocks:[wr("nameValue",{name:s,value:o})]})},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.getLegendIcon=function(t){var n=t.icon||"roundRect",a=or(n,0,0,t.itemWidth,t.itemHeight,t.itemStyle.fill);return a.setStyle(t.itemStyle),a.style.stroke="none",n.indexOf("empty")>-1&&(a.style.stroke=a.style.fill,a.style.fill="#fff",a.style.lineWidth=2),a},e.type="series.map",e.dependencies=["geo"],e.layoutMode="box",e.defaultOption={z:2,coordinateSystem:"geo",map:"",left:"center",top:"center",aspectScale:null,showLegendSymbol:!0,boundingCoords:null,center:null,zoom:1,scaleLimit:null,selectedMode:!0,label:{show:!1,color:"#000"},itemStyle:{borderWidth:.5,borderColor:"#444",areaColor:"#eee"},emphasis:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{areaColor:"rgba(255,215,0,0.8)"}},select:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{color:"rgba(255,215,0,0.8)"}},nameProperty:"name"},e}(Ve);function bj(r,e){var t={};return B(r,function(n){n.each(n.mapDimension("value"),function(a,i){var o="ec-"+n.getName(i);t[o]=t[o]||[],isNaN(a)||t[o].push(a)})}),r[0].map(r[0].mapDimension("value"),function(n,a){for(var i="ec-"+r[0].getName(a),o=0,s=1/0,l=-1/0,u=t[i].length,c=0;c<u;c++)s=Math.min(s,t[i][c]),l=Math.max(l,t[i][c]),o+=t[i][c];var h;return e==="min"?h=s:e==="max"?h=l:e==="average"?h=o/u:h=o,u===0?NaN:h})}function Sj(r){var e={};r.eachSeriesByType("map",function(t){var n=t.getHostGeoModel(),a=n?"o"+n.id:"i"+t.getMapType();(e[a]=e[a]||[]).push(t)}),B(e,function(t,n){for(var a=bj(ft(t,function(o){return o.getData()}),t[0].get("mapValueCalculation")),i=0;i<t.length;i++)t[i].originalData=t[i].getData();for(var i=0;i<t.length;i++)t[i].seriesGroup=t,t[i].needsDrawMap=i===0&&!t[i].getHostGeoModel(),t[i].setData(a.cloneShallow()),t[i].mainSeries=t[0]})}function Aj(r){var e={};r.eachSeriesByType("map",function(t){var n=t.getMapType();if(!(t.getHostGeoModel()||e[n])){var a={};B(t.seriesGroup,function(o){var s=o.coordinateSystem,l=o.originalData;o.get("showLegendSymbol")&&r.getComponent("legend")&&l.each(l.mapDimension("value"),function(u,c){var h=l.getName(c),d=s.getRegion(h);if(!(!d||isNaN(u))){var v=a[h]||0,p=s.dataToPoint(d.getCenter());a[h]=v+1,l.setItemLayout(c,{point:p,offset:v})}})});var i=t.getData();i.each(function(o){var s=i.getName(o),l=i.getItemLayout(o)||{};l.showLabel=!a[s],i.setItemLayout(o,l)}),e[n]=!0}})}var pL=Pr,Uh=function(r){rt(e,r);function e(t){var n=r.call(this)||this;return n.type="view",n.dimensions=["x","y"],n._roamTransformable=new gi,n._rawTransformable=new gi,n.name=t,n}return e.prototype.setBoundingRect=function(t,n,a,i){return this._rect=new Qt(t,n,a,i),this._rect},e.prototype.getBoundingRect=function(){return this._rect},e.prototype.setViewRect=function(t,n,a,i){this._transformTo(t,n,a,i),this._viewRect=new Qt(t,n,a,i)},e.prototype._transformTo=function(t,n,a,i){var o=this.getBoundingRect(),s=this._rawTransformable;s.transform=o.calculateTransform(new Qt(t,n,a,i));var l=s.parent;s.parent=null,s.decomposeTransform(),s.parent=l,this._updateTransform()},e.prototype.setCenter=function(t,n){t&&(this._center=[At(t[0],n.getWidth()),At(t[1],n.getHeight())],this._updateCenterAndZoom())},e.prototype.setZoom=function(t){t=t||1;var n=this.zoomLimit;n&&(n.max!=null&&(t=Math.min(n.max,t)),n.min!=null&&(t=Math.max(n.min,t))),this._zoom=t,this._updateCenterAndZoom()},e.prototype.getDefaultCenter=function(){var t=this.getBoundingRect(),n=t.x+t.width/2,a=t.y+t.height/2;return[n,a]},e.prototype.getCenter=function(){return this._center||this.getDefaultCenter()},e.prototype.getZoom=function(){return this._zoom||1},e.prototype.getRoamTransform=function(){return this._roamTransformable.getLocalTransform()},e.prototype._updateCenterAndZoom=function(){var t=this._rawTransformable.getLocalTransform(),n=this._roamTransformable,a=this.getDefaultCenter(),i=this.getCenter(),o=this.getZoom();i=Pr([],i,t),a=Pr([],a,t),n.originX=i[0],n.originY=i[1],n.x=a[0]-i[0],n.y=a[1]-i[1],n.scaleX=n.scaleY=o,this._updateTransform()},e.prototype._updateTransform=function(){var t=this._roamTransformable,n=this._rawTransformable;n.parent=t,t.updateTransform(),n.updateTransform(),W1(this.transform||(this.transform=[]),n.transform||Ln()),this._rawTransform=n.getLocalTransform(),this.invTransform=this.invTransform||[],cu(this.invTransform,this.transform),this.decomposeTransform()},e.prototype.getTransformInfo=function(){var t=this._rawTransformable,n=this._roamTransformable,a=new gi;return a.transform=n.transform,a.decomposeTransform(),{roam:{x:a.x,y:a.y,scaleX:a.scaleX,scaleY:a.scaleY},raw:{x:t.x,y:t.y,scaleX:t.scaleX,scaleY:t.scaleY}}},e.prototype.getViewRect=function(){return this._viewRect},e.prototype.getViewRectAfterRoam=function(){var t=this.getBoundingRect().clone();return t.applyTransform(this.transform),t},e.prototype.dataToPoint=function(t,n,a){var i=n?this._rawTransform:this.transform;return a=a||[],i?pL(a,t,i):Xr(a,t)},e.prototype.pointToData=function(t){var n=this.invTransform;return n?pL([],t,n):[t[0],t[1]]},e.prototype.convertToPixel=function(t,n,a){var i=gL(n);return i===this?i.dataToPoint(a):null},e.prototype.convertFromPixel=function(t,n,a){var i=gL(n);return i===this?i.pointToData(a):null},e.prototype.containPoint=function(t){return this.getViewRectAfterRoam().contain(t[0],t[1])},e.dimensions=["x","y"],e}(gi);function gL(r){var e=r.seriesModel;return e?e.coordinateSystem:null}var Tj={geoJSON:{aspectScale:.75,invertLongitute:!0},geoSVG:{aspectScale:1,invertLongitute:!1}},h5=["lng","lat"],Q_=function(r){rt(e,r);function e(t,n,a){var i=r.call(this,t)||this;i.dimensions=h5,i.type="geo",i._nameCoordMap=Pt(),i.map=n;var o=a.projection,s=Di.load(n,a.nameMap,a.nameProperty),l=Di.getGeoResource(n);i.resourceType=l?l.type:null;var u=i.regions=s.regions,c=Tj[l.type];i._regionsMap=s.regionsMap,i.regions=s.regions,i.projection=o;var h;if(o)for(var d=0;d<u.length;d++){var v=u[d].getBoundingRect(o);h=h||v.clone(),h.union(v)}else h=s.boundingRect;return i.setBoundingRect(h.x,h.y,h.width,h.height),i.aspectScale=o?1:Zt(a.aspectScale,c.aspectScale),i._invertLongitute=o?!1:c.invertLongitute,i}return e.prototype._transformTo=function(t,n,a,i){var o=this.getBoundingRect(),s=this._invertLongitute;o=o.clone(),s&&(o.y=-o.y-o.height);var l=this._rawTransformable;l.transform=o.calculateTransform(new Qt(t,n,a,i));var u=l.parent;l.parent=null,l.decomposeTransform(),l.parent=u,s&&(l.scaleY=-l.scaleY),this._updateTransform()},e.prototype.getRegion=function(t){return this._regionsMap.get(t)},e.prototype.getRegionByCoord=function(t){for(var n=this.regions,a=0;a<n.length;a++){var i=n[a];if(i.type==="geoJSON"&&i.contain(t))return n[a]}},e.prototype.addGeoCoord=function(t,n){this._nameCoordMap.set(t,n)},e.prototype.getGeoCoord=function(t){var n=this._regionsMap.get(t);return this._nameCoordMap.get(t)||n&&n.getCenter()},e.prototype.dataToPoint=function(t,n,a){if(Lt(t)&&(t=this.getGeoCoord(t)),t){var i=this.projection;return i&&(t=i.project(t)),t&&this.projectedToPoint(t,n,a)}},e.prototype.pointToData=function(t){var n=this.projection;return n&&(t=n.unproject(t)),t&&this.pointToProjected(t)},e.prototype.pointToProjected=function(t){return r.prototype.pointToData.call(this,t)},e.prototype.projectedToPoint=function(t,n,a){return r.prototype.dataToPoint.call(this,t,n,a)},e.prototype.convertToPixel=function(t,n,a){var i=yL(n);return i===this?i.dataToPoint(a):null},e.prototype.convertFromPixel=function(t,n,a){var i=yL(n);return i===this?i.pointToData(a):null},e}(Uh);sr(Q_,Uh);function yL(r){var e=r.geoModel,t=r.seriesModel;return e?e.coordinateSystem:t?t.coordinateSystem||(t.getReferringComponents("geo",ir).models[0]||{}).coordinateSystem:null}function mL(r,e){var t=r.get("boundingCoords");if(t!=null){var n=t[0],a=t[1];if(isFinite(n[0])&&isFinite(n[1])&&isFinite(a[0])&&isFinite(a[1])){var i=this.projection;if(i){var o=n[0],s=n[1],l=a[0],u=a[1];n=[1/0,1/0],a=[-1/0,-1/0];var c=function(A,T,L,M){for(var I=L-A,R=M-T,P=0;P<=100;P++){var E=P/100,D=i.project([A+I*E,T+R*E]);io(n,n,D),oo(a,a,D)}};c(o,s,l,s),c(l,s,l,u),c(l,u,o,u),c(o,u,l,s)}this.setBoundingRect(n[0],n[1],a[0]-n[0],a[1]-n[1])}}var h=this.getBoundingRect(),d=r.get("layoutCenter"),v=r.get("layoutSize"),p=e.getWidth(),y=e.getHeight(),_=h.width/h.height*this.aspectScale,g=!1,f,w;d&&v&&(f=[At(d[0],p),At(d[1],y)],w=At(v,Math.min(p,y)),!isNaN(f[0])&&!isNaN(f[1])&&!isNaN(w)&&(g=!0));var x;if(g)x={},_>1?(x.width=w,x.height=w/_):(x.height=w,x.width=w*_),x.y=f[1]-x.height/2,x.x=f[0]-x.width/2;else{var S=r.getBoxLayoutParams();S.aspect=_,x=cr(S,{width:p,height:y})}this.setViewRect(x.x,x.y,x.width,x.height),this.setCenter(r.get("center"),e),this.setZoom(r.get("zoom"))}function Cj(r,e){B(e.get("geoCoord"),function(t,n){r.addGeoCoord(n,t)})}var Lj=function(){function r(){this.dimensions=h5}return r.prototype.create=function(e,t){var n=[];function a(o){return{nameProperty:o.get("nameProperty"),aspectScale:o.get("aspectScale"),projection:o.get("projection")}}e.eachComponent("geo",function(o,s){var l=o.get("map"),u=new Q_(l+s,l,lt({nameMap:o.get("nameMap")},a(o)));u.zoomLimit=o.get("scaleLimit"),n.push(u),o.coordinateSystem=u,u.model=o,u.resize=mL,u.resize(o,t)}),e.eachSeries(function(o){var s=o.get("coordinateSystem");if(s==="geo"){var l=o.get("geoIndex")||0;o.coordinateSystem=n[l]}});var i={};return e.eachSeriesByType("map",function(o){if(!o.getHostGeoModel()){var s=o.getMapType();i[s]=i[s]||[],i[s].push(o)}}),B(i,function(o,s){var l=ft(o,function(c){return c.get("nameMap")}),u=new Q_(s,s,lt({nameMap:z1(l)},a(o[0])));u.zoomLimit=Ar.apply(null,ft(o,function(c){return c.get("scaleLimit")})),n.push(u),u.resize=mL,u.resize(o[0],t),B(o,function(c){c.coordinateSystem=u,Cj(u,c)})}),n},r.prototype.getFilledRegions=function(e,t,n,a){for(var i=(e||[]).slice(),o=Pt(),s=0;s<i.length;s++)o.set(i[s].name,i[s]);var l=Di.load(t,n,a);return B(l.regions,function(u){var c=u.name,h=o.get(c),d=u.properties&&u.properties.echartsStyle;h||(h={name:c},i.push(h)),d&&qt(h,d)}),i},r}(),f5=new Lj,Mj=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n,a){var i=Di.getGeoResource(t.map);if(i&&i.type==="geoJSON"){var o=t.itemStyle=t.itemStyle||{};"color"in o||(o.color="#eee")}this.mergeDefaultAndTheme(t,a),Os(t,"label",["show"])},e.prototype.optionUpdated=function(){var t=this,n=this.option;n.regions=f5.getFilledRegions(n.regions,n.map,n.nameMap,n.nameProperty);var a={};this._optionModelMap=Za(n.regions||[],function(i,o){var s=o.name;return s&&(i.set(s,new De(o,t,t.ecModel)),o.selected&&(a[s]=!0)),i},Pt()),n.selectedMap||(n.selectedMap=a)},e.prototype.getRegionModel=function(t){return this._optionModelMap.get(t)||new De(null,this,this.ecModel)},e.prototype.getFormattedLabel=function(t,n){var a=this.getRegionModel(t),i=n==="normal"?a.get(["label","formatter"]):a.get(["emphasis","label","formatter"]),o={name:t};if(Nt(i))return o.status=n,i(o);if(Lt(i))return i.replace("{a}",t??"")},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.select=function(t){var n=this.option,a=n.selectedMode;if(a){a!=="multiple"&&(n.selectedMap=null);var i=n.selectedMap||(n.selectedMap={});i[t]=!0}},e.prototype.unSelect=function(t){var n=this.option.selectedMap;n&&(n[t]=!1)},e.prototype.toggleSelected=function(t){this[this.isSelected(t)?"unSelect":"select"](t)},e.prototype.isSelected=function(t){var n=this.option.selectedMap;return!!(n&&n[t])},e.type="geo",e.layoutMode="box",e.defaultOption={z:0,show:!0,left:"center",top:"center",aspectScale:null,silent:!1,map:"",boundingCoords:null,center:null,zoom:1,scaleLimit:null,label:{show:!1,color:"#000"},itemStyle:{borderWidth:.5,borderColor:"#444"},emphasis:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{color:"rgba(255,215,0,0.8)"}},select:{label:{show:!0,color:"rgb(100,0,0)"},itemStyle:{color:"rgba(255,215,0,0.8)"}},regions:[]},e}(le);function _L(r,e){return r.pointToProjected?r.pointToProjected(e):r.pointToData(e)}function qw(r,e,t,n){var a=r.getZoom(),i=r.getCenter(),o=e.zoom,s=r.projectedToPoint?r.projectedToPoint(i):r.dataToPoint(i);if(e.dx!=null&&e.dy!=null&&(s[0]-=e.dx,s[1]-=e.dy,r.setCenter(_L(r,s),n)),o!=null){if(t){var l=t.min||0,u=t.max||1/0;o=Math.max(Math.min(a*o,u),l)/a}r.scaleX*=o,r.scaleY*=o;var c=(e.originX-r.x)*(o-1),h=(e.originY-r.y)*(o-1);r.x-=c,r.y-=h,r.updateTransform(),r.setCenter(_L(r,s),n),r.setZoom(o*a)}return{center:r.getCenter(),zoom:r.getZoom()}}var Dj=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.focusBlurEnabled=!0,t}return e.prototype.init=function(t,n){this._api=n},e.prototype.render=function(t,n,a,i){if(this._model=t,!t.get("show")){this._mapDraw&&this._mapDraw.remove(),this._mapDraw=null;return}this._mapDraw||(this._mapDraw=new c5(a));var o=this._mapDraw;o.draw(t,n,a,this,i),o.group.on("click",this._handleRegionClick,this),o.group.silent=t.get("silent"),this.group.add(o.group),this.updateSelectStatus(t,n,a)},e.prototype._handleRegionClick=function(t){var n;bs(t.target,function(a){return(n=Ht(a).eventData)!=null},!0),n&&this._api.dispatchAction({type:"geoToggleSelect",geoId:this._model.id,name:n.name})},e.prototype.updateSelectStatus=function(t,n,a){var i=this;this._mapDraw.group.traverse(function(o){var s=Ht(o).eventData;if(s)return i._model.isSelected(s.name)?a.enterSelect(o):a.leaveSelect(o),!0})},e.prototype.findHighDownDispatchers=function(t){return this._mapDraw&&this._mapDraw.findHighDownDispatchers(t,this._model)},e.prototype.dispose=function(){this._mapDraw&&this._mapDraw.remove()},e.type="geo",e}(Ze);function Ij(r,e,t){Di.registerMap(r,e,t)}function v5(r){r.registerCoordinateSystem("geo",f5),r.registerComponentModel(Mj),r.registerComponentView(Dj),r.registerImpl("registerMap",Ij),r.registerImpl("getMap",function(t){return Di.getMapForUser(t)});function e(t,n){n.update="geo:updateSelectStatus",r.registerAction(n,function(a,i){var o={},s=[];return i.eachComponent({mainType:"geo",query:a},function(l){l[t](a.name);var u=l.coordinateSystem;B(u.regions,function(h){o[h.name]=l.isSelected(h.name)||!1});var c=[];B(o,function(h,d){o[d]&&c.push(d)}),s.push({geoIndex:l.componentIndex,name:c})}),{selected:o,allSelected:s,name:a.name}})}e("toggleSelected",{type:"geoToggleSelect",event:"geoselectchanged"}),e("select",{type:"geoSelect",event:"geoselected"}),e("unSelect",{type:"geoUnSelect",event:"geounselected"}),r.registerAction({type:"geoRoam",event:"geoRoam",update:"updateTransform"},function(t,n,a){var i=t.componentType||"series";n.eachComponent({mainType:i,query:t},function(o){var s=o.coordinateSystem;if(s.type==="geo"){var l=qw(s,t,o.get("scaleLimit"),a);o.setCenter&&o.setCenter(l.center),o.setZoom&&o.setZoom(l.zoom),i==="series"&&B(o.seriesGroup,function(u){u.setCenter(l.center),u.setZoom(l.zoom)})}})})}function Pj(r){ne(v5),r.registerChartView(wj),r.registerSeriesModel(xj),r.registerLayout(Aj),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,Sj),dR("map",r.registerAction)}function kj(r){var e=r;e.hierNode={defaultAncestor:null,ancestor:e,prelim:0,modifier:0,change:0,shift:0,i:0,thread:null};for(var t=[e],n,a;n=t.pop();)if(a=n.children,n.isExpand&&a.length)for(var i=a.length,o=i-1;o>=0;o--){var s=a[o];s.hierNode={defaultAncestor:null,ancestor:s,prelim:0,modifier:0,change:0,shift:0,i:o,thread:null},t.push(s)}}function Rj(r,e){var t=r.isExpand?r.children:[],n=r.parentNode.children,a=r.hierNode.i?n[r.hierNode.i-1]:null;if(t.length){Bj(r);var i=(t[0].hierNode.prelim+t[t.length-1].hierNode.prelim)/2;a?(r.hierNode.prelim=a.hierNode.prelim+e(r,a),r.hierNode.modifier=r.hierNode.prelim-i):r.hierNode.prelim=i}else a&&(r.hierNode.prelim=a.hierNode.prelim+e(r,a));r.parentNode.hierNode.defaultAncestor=Nj(r,a,r.parentNode.hierNode.defaultAncestor||n[0],e)}function Ej(r){var e=r.hierNode.prelim+r.parentNode.hierNode.modifier;r.setLayout({x:e},!0),r.hierNode.modifier+=r.parentNode.hierNode.modifier}function wL(r){return arguments.length?r:Vj}function Cc(r,e){return r-=Math.PI/2,{x:e*Math.cos(r),y:e*Math.sin(r)}}function Oj(r,e){return cr(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function Bj(r){for(var e=r.children,t=e.length,n=0,a=0;--t>=0;){var i=e[t];i.hierNode.prelim+=n,i.hierNode.modifier+=n,a+=i.hierNode.change,n+=i.hierNode.shift+a}}function Nj(r,e,t,n){if(e){for(var a=r,i=r,o=i.parentNode.children[0],s=e,l=a.hierNode.modifier,u=i.hierNode.modifier,c=o.hierNode.modifier,h=s.hierNode.modifier;s=Nm(s),i=zm(i),s&&i;){a=Nm(a),o=zm(o),a.hierNode.ancestor=r;var d=s.hierNode.prelim+h-i.hierNode.prelim-u+n(s,i);d>0&&(Fj(zj(s,r,t),r,d),u+=d,l+=d),h+=s.hierNode.modifier,u+=i.hierNode.modifier,l+=a.hierNode.modifier,c+=o.hierNode.modifier}s&&!Nm(a)&&(a.hierNode.thread=s,a.hierNode.modifier+=h-l),i&&!zm(o)&&(o.hierNode.thread=i,o.hierNode.modifier+=u-c,t=r)}return t}function Nm(r){var e=r.children;return e.length&&r.isExpand?e[e.length-1]:r.hierNode.thread}function zm(r){var e=r.children;return e.length&&r.isExpand?e[0]:r.hierNode.thread}function zj(r,e,t){return r.hierNode.ancestor.parentNode===e.parentNode?r.hierNode.ancestor:t}function Fj(r,e,t){var n=t/(e.hierNode.i-r.hierNode.i);e.hierNode.change-=n,e.hierNode.shift+=t,e.hierNode.modifier+=t,e.hierNode.prelim+=t,r.hierNode.change+=n}function Vj(r,e){return r.parentNode===e.parentNode?1:2}var Gj=function(){function r(){this.parentPoint=[],this.childPoints=[]}return r}(),Wj=function(r){rt(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new Gj},e.prototype.buildPath=function(t,n){var a=n.childPoints,i=a.length,o=n.parentPoint,s=a[0],l=a[i-1];if(i===1){t.moveTo(o[0],o[1]),t.lineTo(s[0],s[1]);return}var u=n.orient,c=u==="TB"||u==="BT"?0:1,h=1-c,d=At(n.forkPosition,1),v=[];v[c]=o[c],v[h]=o[h]+(l[h]-o[h])*d,t.moveTo(o[0],o[1]),t.lineTo(v[0],v[1]),t.moveTo(s[0],s[1]),v[c]=s[c],t.lineTo(v[0],v[1]),v[c]=l[c],t.lineTo(v[0],v[1]),t.lineTo(l[0],l[1]);for(var p=1;p<i-1;p++){var y=a[p];t.moveTo(y[0],y[1]),v[c]=y[c],t.lineTo(v[0],v[1])}},e}(ie),Hj=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._mainGroup=new Wt,t}return e.prototype.init=function(t,n){this._controller=new Hh(n.getZr()),this._controllerHost={target:this.group},this.group.add(this._mainGroup)},e.prototype.render=function(t,n,a){var i=t.getData(),o=t.layoutInfo,s=this._mainGroup,l=t.get("layout");l==="radial"?(s.x=o.x+o.width/2,s.y=o.y+o.height/2):(s.x=o.x,s.y=o.y),this._updateViewCoordSys(t,a),this._updateController(t,n,a);var u=this._data;i.diff(u).add(function(c){xL(i,c)&&bL(i,c,null,s,t)}).update(function(c,h){var d=u.getItemGraphicEl(h);if(!xL(i,c)){d&&AL(u,h,d,s,t);return}bL(i,c,d,s,t)}).remove(function(c){var h=u.getItemGraphicEl(c);h&&AL(u,c,h,s,t)}).execute(),this._nodeScaleRatio=t.get("nodeScaleRatio"),this._updateNodeAndLinkScale(t),t.get("expandAndCollapse")===!0&&i.eachItemGraphicEl(function(c,h){c.off("click").on("click",function(){a.dispatchAction({type:"treeExpandAndCollapse",seriesId:t.id,dataIndex:h})})}),this._data=i},e.prototype._updateViewCoordSys=function(t,n){var a=t.getData(),i=[];a.each(function(h){var d=a.getItemLayout(h);d&&!isNaN(d.x)&&!isNaN(d.y)&&i.push([+d.x,+d.y])});var o=[],s=[];wp(i,o,s);var l=this._min,u=this._max;s[0]-o[0]===0&&(o[0]=l?l[0]:o[0]-1,s[0]=u?u[0]:s[0]+1),s[1]-o[1]===0&&(o[1]=l?l[1]:o[1]-1,s[1]=u?u[1]:s[1]+1);var c=t.coordinateSystem=new Uh;c.zoomLimit=t.get("scaleLimit"),c.setBoundingRect(o[0],o[1],s[0]-o[0],s[1]-o[1]),c.setCenter(t.get("center"),n),c.setZoom(t.get("zoom")),this.group.attr({x:c.x,y:c.y,scaleX:c.scaleX,scaleY:c.scaleY}),this._min=o,this._max=s},e.prototype._updateController=function(t,n,a){var i=this,o=this._controller,s=this._controllerHost,l=this.group;o.setPointerChecker(function(u,c,h){var d=l.getBoundingRect();return d.applyTransform(l.transform),d.contain(c,h)&&!Up(u,a,t)}),o.enable(t.get("roam")),s.zoomLimit=t.get("scaleLimit"),s.zoom=t.coordinateSystem.getZoom(),o.off("pan").off("zoom").on("pan",function(u){Xw(s,u.dx,u.dy),a.dispatchAction({seriesId:t.id,type:"treeRoam",dx:u.dx,dy:u.dy})}).on("zoom",function(u){$w(s,u.scale,u.originX,u.originY),a.dispatchAction({seriesId:t.id,type:"treeRoam",zoom:u.scale,originX:u.originX,originY:u.originY}),i._updateNodeAndLinkScale(t),a.updateLabelLayout()})},e.prototype._updateNodeAndLinkScale=function(t){var n=t.getData(),a=this._getNodeGlobalScale(t);n.eachItemGraphicEl(function(i,o){i.setSymbolScale(a)})},e.prototype._getNodeGlobalScale=function(t){var n=t.coordinateSystem;if(n.type!=="view")return 1;var a=this._nodeScaleRatio,i=n.scaleX||1,o=n.getZoom(),s=(o-1)*a+1;return s/i},e.prototype.dispose=function(){this._controller&&this._controller.dispose(),this._controllerHost=null},e.prototype.remove=function(){this._mainGroup.removeAll(),this._data=null},e.type="tree",e}(Re);function xL(r,e){var t=r.getItemLayout(e);return t&&!isNaN(t.x)&&!isNaN(t.y)}function bL(r,e,t,n,a){var i=!t,o=r.tree.getNodeByDataIndex(e),s=o.getModel(),l=o.getVisual("style").fill,u=o.isExpand===!1&&o.children.length!==0?l:"#fff",c=r.tree.root,h=o.parentNode===c?o:o.parentNode||o,d=r.getItemGraphicEl(h.dataIndex),v=h.getLayout(),p=d?{x:d.__oldX,y:d.__oldY,rawX:d.__radialOldRawX,rawY:d.__radialOldRawY}:v,y=o.getLayout();i?(t=new Nh(r,e,null,{symbolInnerColor:u,useNameLabel:!0}),t.x=p.x,t.y=p.y):t.updateData(r,e,null,{symbolInnerColor:u,useNameLabel:!0}),t.__radialOldRawX=t.__radialRawX,t.__radialOldRawY=t.__radialRawY,t.__radialRawX=y.rawX,t.__radialRawY=y.rawY,n.add(t),r.setItemGraphicEl(e,t),t.__oldX=t.x,t.__oldY=t.y,_e(t,{x:y.x,y:y.y},a);var _=t.getSymbolPath();if(a.get("layout")==="radial"){var g=c.children[0],f=g.getLayout(),w=g.children.length,x=void 0,S=void 0;if(y.x===f.x&&o.isExpand===!0&&g.children.length){var A={x:(g.children[0].getLayout().x+g.children[w-1].getLayout().x)/2,y:(g.children[0].getLayout().y+g.children[w-1].getLayout().y)/2};x=Math.atan2(A.y-f.y,A.x-f.x),x<0&&(x=Math.PI*2+x),S=A.x<f.x,S&&(x=x-Math.PI)}else x=Math.atan2(y.y-f.y,y.x-f.x),x<0&&(x=Math.PI*2+x),o.children.length===0||o.children.length!==0&&o.isExpand===!1?(S=y.x<f.x,S&&(x=x-Math.PI)):(S=y.x>f.x,S||(x=x-Math.PI));var T=S?"left":"right",L=s.getModel("label"),M=L.get("rotate"),I=M*(Math.PI/180),R=_.getTextContent();R&&(_.setTextConfig({position:L.get("position")||T,rotation:M==null?-x:I,origin:"center"}),R.setStyle("verticalAlign","middle"))}var P=s.get(["emphasis","focus"]),E=P==="relative"?$c(o.getAncestorsIndices(),o.getDescendantIndices()):P==="ancestor"?o.getAncestorsIndices():P==="descendant"?o.getDescendantIndices():null;E&&(Ht(t).focus=E),Uj(a,o,c,t,p,v,y,n),t.__edge&&(t.onHoverStateChange=function(D){if(D!=="blur"){var N=o.parentNode&&r.getItemGraphicEl(o.parentNode.dataIndex);N&&N.hoverState===Lh||Sd(t.__edge,D)}})}function Uj(r,e,t,n,a,i,o,s){var l=e.getModel(),u=r.get("edgeShape"),c=r.get("layout"),h=r.getOrient(),d=r.get(["lineStyle","curveness"]),v=r.get("edgeForkPosition"),p=l.getModel("lineStyle").getLineStyle(),y=n.__edge;if(u==="curve")e.parentNode&&e.parentNode!==t&&(y||(y=n.__edge=new Dh({shape:J_(c,h,d,a,a)})),_e(y,{shape:J_(c,h,d,i,o)},r));else if(u==="polyline"&&c==="orthogonal"&&e!==t&&e.children&&e.children.length!==0&&e.isExpand===!0){for(var _=e.children,g=[],f=0;f<_.length;f++){var w=_[f].getLayout();g.push([w.x,w.y])}y||(y=n.__edge=new Wj({shape:{parentPoint:[o.x,o.y],childPoints:[[o.x,o.y]],orient:h,forkPosition:v}})),_e(y,{shape:{parentPoint:[o.x,o.y],childPoints:g}},r)}y&&!(u==="polyline"&&!e.isExpand)&&(y.useStyle(zt({strokeNoScale:!0,fill:null},p)),kr(y,l,"lineStyle"),zs(y),s.add(y))}function SL(r,e,t,n,a){var i=e.tree.root,o=d5(i,r),s=o.source,l=o.sourceLayout,u=e.getItemGraphicEl(r.dataIndex);if(u){var c=e.getItemGraphicEl(s.dataIndex),h=c.__edge,d=u.__edge||(s.isExpand===!1||s.children.length===1?h:void 0),v=n.get("edgeShape"),p=n.get("layout"),y=n.get("orient"),_=n.get(["lineStyle","curveness"]);d&&(v==="curve"?xo(d,{shape:J_(p,y,_,l,l),style:{opacity:0}},n,{cb:function(){t.remove(d)},removeOpt:a}):v==="polyline"&&n.get("layout")==="orthogonal"&&xo(d,{shape:{parentPoint:[l.x,l.y],childPoints:[[l.x,l.y]]},style:{opacity:0}},n,{cb:function(){t.remove(d)},removeOpt:a}))}}function d5(r,e){for(var t=e.parentNode===r?e:e.parentNode||e,n;n=t.getLayout(),n==null;)t=t.parentNode===r?t:t.parentNode||t;return{source:t,sourceLayout:n}}function AL(r,e,t,n,a){var i=r.tree.getNodeByDataIndex(e),o=r.tree.root,s=d5(o,i).sourceLayout,l={duration:a.get("animationDurationUpdate"),easing:a.get("animationEasingUpdate")};xo(t,{x:s.x+1,y:s.y+1},a,{cb:function(){n.remove(t),r.setItemGraphicEl(e,null)},removeOpt:l}),t.fadeOut(null,r.hostModel,{fadeLabel:!0,animation:l}),i.children.forEach(function(u){SL(u,r,n,a,l)}),SL(i,r,n,a,l)}function J_(r,e,t,n,a){var i,o,s,l,u,c,h,d;if(r==="radial"){u=n.rawX,h=n.rawY,c=a.rawX,d=a.rawY;var v=Cc(u,h),p=Cc(u,h+(d-h)*t),y=Cc(c,d+(h-d)*t),_=Cc(c,d);return{x1:v.x||0,y1:v.y||0,x2:_.x||0,y2:_.y||0,cpx1:p.x||0,cpy1:p.y||0,cpx2:y.x||0,cpy2:y.y||0}}else u=n.x,h=n.y,c=a.x,d=a.y,(e==="LR"||e==="RL")&&(i=u+(c-u)*t,o=h,s=c+(u-c)*t,l=d),(e==="TB"||e==="BT")&&(i=u,o=h+(d-h)*t,s=c,l=d+(h-d)*t);return{x1:u,y1:h,x2:c,y2:d,cpx1:i,cpy1:o,cpx2:s,cpy2:l}}var Jn=ve();function p5(r){var e=r.mainData,t=r.datas;t||(t={main:e},r.datasAttr={main:"data"}),r.datas=r.mainData=null,g5(e,t,r),B(t,function(n){B(e.TRANSFERABLE_METHODS,function(a){n.wrapMethod(a,Xt(Zj,r))})}),e.wrapMethod("cloneShallow",Xt(Xj,r)),B(e.CHANGABLE_METHODS,function(n){e.wrapMethod(n,Xt(Yj,r))}),Jr(t[e.dataType]===e)}function Zj(r,e){if(qj(this)){var t=lt({},Jn(this).datas);t[this.dataType]=e,g5(e,t,r)}else Kw(e,this.dataType,Jn(this).mainData,r);return e}function Yj(r,e){return r.struct&&r.struct.update(),e}function Xj(r,e){return B(Jn(e).datas,function(t,n){t!==e&&Kw(t.cloneShallow(),n,e,r)}),e}function $j(r){var e=Jn(this).mainData;return r==null||e==null?e:Jn(e).datas[r]}function jj(){var r=Jn(this).mainData;return r==null?[{data:r}]:ft(ue(Jn(r).datas),function(e){return{type:e,data:Jn(r).datas[e]}})}function qj(r){return Jn(r).mainData===r}function g5(r,e,t){Jn(r).datas={},B(e,function(n,a){Kw(n,a,r,t)})}function Kw(r,e,t,n){Jn(t).datas[e]=r,Jn(r).mainData=t,r.dataType=e,n.struct&&(r[n.structAttr]=n.struct,n.struct[n.datasAttr[e]]=r),r.getLinkedData=$j,r.getLinkedDataAll=jj}var Kj=function(){function r(e,t){this.depth=0,this.height=0,this.dataIndex=-1,this.children=[],this.viewChildren=[],this.isExpand=!1,this.name=e||"",this.hostTree=t}return r.prototype.isRemoved=function(){return this.dataIndex<0},r.prototype.eachNode=function(e,t,n){Nt(e)&&(n=t,t=e,e=null),e=e||{},Lt(e)&&(e={order:e});var a=e.order||"preorder",i=this[e.attr||"children"],o;a==="preorder"&&(o=t.call(n,this));for(var s=0;!o&&s<i.length;s++)i[s].eachNode(e,t,n);a==="postorder"&&t.call(n,this)},r.prototype.updateDepthAndHeight=function(e){var t=0;this.depth=e;for(var n=0;n<this.children.length;n++){var a=this.children[n];a.updateDepthAndHeight(e+1),a.height>t&&(t=a.height)}this.height=t+1},r.prototype.getNodeById=function(e){if(this.getId()===e)return this;for(var t=0,n=this.children,a=n.length;t<a;t++){var i=n[t].getNodeById(e);if(i)return i}},r.prototype.contains=function(e){if(e===this)return!0;for(var t=0,n=this.children,a=n.length;t<a;t++){var i=n[t].contains(e);if(i)return i}},r.prototype.getAncestors=function(e){for(var t=[],n=e?this:this.parentNode;n;)t.push(n),n=n.parentNode;return t.reverse(),t},r.prototype.getAncestorsIndices=function(){for(var e=[],t=this;t;)e.push(t.dataIndex),t=t.parentNode;return e.reverse(),e},r.prototype.getDescendantIndices=function(){var e=[];return this.eachNode(function(t){e.push(t.dataIndex)}),e},r.prototype.getValue=function(e){var t=this.hostTree.data;return t.getStore().get(t.getDimensionIndex(e||"value"),this.dataIndex)},r.prototype.setLayout=function(e,t){this.dataIndex>=0&&this.hostTree.data.setItemLayout(this.dataIndex,e,t)},r.prototype.getLayout=function(){return this.hostTree.data.getItemLayout(this.dataIndex)},r.prototype.getModel=function(e){if(!(this.dataIndex<0)){var t=this.hostTree,n=t.data.getItemModel(this.dataIndex);return n.getModel(e)}},r.prototype.getLevelModel=function(){return(this.hostTree.levelModels||[])[this.depth]},r.prototype.setVisual=function(e,t){this.dataIndex>=0&&this.hostTree.data.setItemVisual(this.dataIndex,e,t)},r.prototype.getVisual=function(e){return this.hostTree.data.getItemVisual(this.dataIndex,e)},r.prototype.getRawIndex=function(){return this.hostTree.data.getRawIndex(this.dataIndex)},r.prototype.getId=function(){return this.hostTree.data.getId(this.dataIndex)},r.prototype.getChildIndex=function(){if(this.parentNode){for(var e=this.parentNode.children,t=0;t<e.length;++t)if(e[t]===this)return t;return-1}return-1},r.prototype.isAncestorOf=function(e){for(var t=e.parentNode;t;){if(t===this)return!0;t=t.parentNode}return!1},r.prototype.isDescendantOf=function(e){return e!==this&&e.isAncestorOf(this)},r}(),Qw=function(){function r(e){this.type="tree",this._nodes=[],this.hostModel=e}return r.prototype.eachNode=function(e,t,n){this.root.eachNode(e,t,n)},r.prototype.getNodeByDataIndex=function(e){var t=this.data.getRawIndex(e);return this._nodes[t]},r.prototype.getNodeById=function(e){return this.root.getNodeById(e)},r.prototype.update=function(){for(var e=this.data,t=this._nodes,n=0,a=t.length;n<a;n++)t[n].dataIndex=-1;for(var n=0,a=e.count();n<a;n++)t[e.getRawIndex(n)].dataIndex=n},r.prototype.clearLayouts=function(){this.data.clearItemLayouts()},r.createTree=function(e,t,n){var a=new r(t),i=[],o=1;s(e);function s(c,h){var d=c.value;o=Math.max(o,ht(d)?d.length:1),i.push(c);var v=new Kj(ur(c.name,""),a);h?Qj(v,h):a.root=v,a._nodes.push(v);var p=c.children;if(p)for(var y=0;y<p.length;y++)s(p[y],v)}a.root.updateDepthAndHeight(0);var l=Oh(i,{coordDimensions:["value"],dimensionsCount:o}).dimensions,u=new Kr(l,t);return u.initData(i),n&&n(u),p5({mainData:u,struct:a,structAttr:"tree"}),a.update(),a},r}();function Qj(r,e){var t=e.children;r.parentNode!==e&&(t.push(r),r.parentNode=e)}function dh(r,e,t){if(r&&te(e,r.type)>=0){var n=t.getData().tree.root,a=r.targetNode;if(Lt(a)&&(a=n.getNodeById(a)),a&&n.contains(a))return{node:a};var i=r.targetNodeId;if(i!=null&&(a=n.getNodeById(i)))return{node:a}}}function y5(r){for(var e=[];r;)r=r.parentNode,r&&e.push(r);return e.reverse()}function Jw(r,e){var t=y5(r);return te(t,e)>=0}function Yp(r,e){for(var t=[];r;){var n=r.dataIndex;t.push({name:r.name,dataIndex:n,value:e.getRawValue(n)}),r=r.parentNode}return t.reverse(),t}var Jj=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.hasSymbolVisual=!0,t.ignoreStyleOnData=!0,t}return e.prototype.getInitialData=function(t){var n={name:t.name,children:t.data},a=t.leaves||{},i=new De(a,this,this.ecModel),o=Qw.createTree(n,this,s);function s(h){h.wrapMethod("getItemModel",function(d,v){var p=o.getNodeByDataIndex(v);return p&&p.children.length&&p.isExpand||(d.parentModel=i),d})}var l=0;o.eachNode("preorder",function(h){h.depth>l&&(l=h.depth)});var u=t.expandAndCollapse,c=u&&t.initialTreeDepth>=0?t.initialTreeDepth:l;return o.root.eachNode("preorder",function(h){var d=h.hostTree.data.getRawDataItem(h.dataIndex);h.isExpand=d&&d.collapsed!=null?!d.collapsed:h.depth<=c}),o.data},e.prototype.getOrient=function(){var t=this.get("orient");return t==="horizontal"?t="LR":t==="vertical"&&(t="TB"),t},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.formatTooltip=function(t,n,a){for(var i=this.getData().tree,o=i.root.children[0],s=i.getNodeByDataIndex(t),l=s.getValue(),u=s.name;s&&s!==o;)u=s.parentNode.name+"."+u,s=s.parentNode;return wr("nameValue",{name:u,value:l,noValue:isNaN(l)||l==null})},e.prototype.getDataParams=function(t){var n=r.prototype.getDataParams.apply(this,arguments),a=this.getData().tree.getNodeByDataIndex(t);return n.treeAncestors=Yp(a,this),n.collapsed=!a.isExpand,n},e.type="series.tree",e.layoutMode="box",e.defaultOption={z:2,coordinateSystem:"view",left:"12%",top:"12%",right:"12%",bottom:"12%",layout:"orthogonal",edgeShape:"curve",edgeForkPosition:"50%",roam:!1,nodeScaleRatio:.4,center:null,zoom:1,orient:"LR",symbol:"emptyCircle",symbolSize:7,expandAndCollapse:!0,initialTreeDepth:2,lineStyle:{color:"#ccc",width:1.5,curveness:.5},itemStyle:{color:"lightsteelblue",borderWidth:1.5},label:{show:!0},animationEasing:"linear",animationDuration:700,animationDurationUpdate:500},e}(Ve);function tq(r,e,t){for(var n=[r],a=[],i;i=n.pop();)if(a.push(i),i.isExpand){var o=i.children;if(o.length)for(var s=0;s<o.length;s++)n.push(o[s])}for(;i=a.pop();)e(i,t)}function sc(r,e){for(var t=[r],n;n=t.pop();)if(e(n),n.isExpand){var a=n.children;if(a.length)for(var i=a.length-1;i>=0;i--)t.push(a[i])}}function eq(r,e){r.eachSeriesByType("tree",function(t){rq(t,e)})}function rq(r,e){var t=Oj(r,e);r.layoutInfo=t;var n=r.get("layout"),a=0,i=0,o=null;n==="radial"?(a=2*Math.PI,i=Math.min(t.height,t.width)/2,o=wL(function(w,x){return(w.parentNode===x.parentNode?1:2)/w.depth})):(a=t.width,i=t.height,o=wL());var s=r.getData().tree.root,l=s.children[0];if(l){kj(s),tq(l,Rj,o),s.hierNode.modifier=-l.hierNode.prelim,sc(l,Ej);var u=l,c=l,h=l;sc(l,function(w){var x=w.getLayout().x;x<u.getLayout().x&&(u=w),x>c.getLayout().x&&(c=w),w.depth>h.depth&&(h=w)});var d=u===c?1:o(u,c)/2,v=d-u.getLayout().x,p=0,y=0,_=0,g=0;if(n==="radial")p=a/(c.getLayout().x+d+v),y=i/(h.depth-1||1),sc(l,function(w){_=(w.getLayout().x+v)*p,g=(w.depth-1)*y;var x=Cc(_,g);w.setLayout({x:x.x,y:x.y,rawX:_,rawY:g},!0)});else{var f=r.getOrient();f==="RL"||f==="LR"?(y=i/(c.getLayout().x+d+v),p=a/(h.depth-1||1),sc(l,function(w){g=(w.getLayout().x+v)*y,_=f==="LR"?(w.depth-1)*p:a-(w.depth-1)*p,w.setLayout({x:_,y:g},!0)})):(f==="TB"||f==="BT")&&(p=a/(c.getLayout().x+d+v),y=i/(h.depth-1||1),sc(l,function(w){_=(w.getLayout().x+v)*p,g=f==="TB"?(w.depth-1)*y:i-(w.depth-1)*y,w.setLayout({x:_,y:g},!0)}))}}}function nq(r){r.eachSeriesByType("tree",function(e){var t=e.getData(),n=t.tree;n.eachNode(function(a){var i=a.getModel(),o=i.getModel("itemStyle").getItemStyle(),s=t.ensureUniqueItemVisual(a.dataIndex,"style");lt(s,o)})})}function aq(r){r.registerAction({type:"treeExpandAndCollapse",event:"treeExpandAndCollapse",update:"update"},function(e,t){t.eachComponent({mainType:"series",subType:"tree",query:e},function(n){var a=e.dataIndex,i=n.getData().tree,o=i.getNodeByDataIndex(a);o.isExpand=!o.isExpand})}),r.registerAction({type:"treeRoam",event:"treeRoam",update:"none"},function(e,t,n){t.eachComponent({mainType:"series",subType:"tree",query:e},function(a){var i=a.coordinateSystem,o=qw(i,e,void 0,n);a.setCenter&&a.setCenter(o.center),a.setZoom&&a.setZoom(o.zoom)})})}function iq(r){r.registerChartView(Hj),r.registerSeriesModel(Jj),r.registerLayout(eq),r.registerVisual(nq),aq(r)}var TL=["treemapZoomToNode","treemapRender","treemapMove"];function oq(r){for(var e=0;e<TL.length;e++)r.registerAction({type:TL[e],update:"updateView"},tr);r.registerAction({type:"treemapRootToNode",update:"updateView"},function(t,n){n.eachComponent({mainType:"series",subType:"treemap",query:t},a);function a(i,o){var s=["treemapZoomToNode","treemapRootToNode"],l=dh(t,s,i);if(l){var u=i.getViewRoot();u&&(t.direction=Jw(u,l.node)?"rollUp":"drillDown"),i.resetViewRoot(l.node)}}})}function m5(r){var e=r.getData(),t=e.tree,n={};t.eachNode(function(a){for(var i=a;i&&i.depth>1;)i=i.parentNode;var o=L_(r.ecModel,i.name||i.dataIndex+"",n);a.setVisual("decal",o)})}var sq=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.preventUsingHoverLayer=!0,t}return e.prototype.getInitialData=function(t,n){var a={name:t.name,children:t.data};_5(a);var i=t.levels||[],o=this.designatedVisualItemStyle={},s=new De({itemStyle:o},this,n);i=t.levels=lq(i,n);var l=ft(i||[],function(h){return new De(h,s,n)},this),u=Qw.createTree(a,this,c);function c(h){h.wrapMethod("getItemModel",function(d,v){var p=u.getNodeByDataIndex(v),y=p?l[p.depth]:null;return d.parentModel=y||s,d})}return u.data},e.prototype.optionUpdated=function(){this.resetViewRoot()},e.prototype.formatTooltip=function(t,n,a){var i=this.getData(),o=this.getRawValue(t),s=i.getName(t);return wr("nameValue",{name:s,value:o})},e.prototype.getDataParams=function(t){var n=r.prototype.getDataParams.apply(this,arguments),a=this.getData().tree.getNodeByDataIndex(t);return n.treeAncestors=Yp(a,this),n.treePathInfo=n.treeAncestors,n},e.prototype.setLayoutInfo=function(t){this.layoutInfo=this.layoutInfo||{},lt(this.layoutInfo,t)},e.prototype.mapIdToIndex=function(t){var n=this._idIndexMap;n||(n=this._idIndexMap=Pt(),this._idIndexMapCount=0);var a=n.get(t);return a==null&&n.set(t,a=this._idIndexMapCount++),a},e.prototype.getViewRoot=function(){return this._viewRoot},e.prototype.resetViewRoot=function(t){t?this._viewRoot=t:t=this._viewRoot;var n=this.getRawData().tree.root;(!t||t!==n&&!n.contains(t))&&(this._viewRoot=n)},e.prototype.enableAriaDecal=function(){m5(this)},e.type="series.treemap",e.layoutMode="box",e.defaultOption={progressive:0,left:"center",top:"middle",width:"80%",height:"80%",sort:!0,clipWindow:"origin",squareRatio:.5*(1+Math.sqrt(5)),leafDepth:null,drillDownIcon:"▶",zoomToNodeRatio:.32*.32,scaleLimit:null,roam:!0,nodeClick:"zoomToNode",animation:!0,animationDurationUpdate:900,animationEasing:"quinticInOut",breadcrumb:{show:!0,height:22,left:"center",top:"bottom",emptyItemWidth:25,itemStyle:{color:"rgba(0,0,0,0.7)",textStyle:{color:"#fff"}},emphasis:{itemStyle:{color:"rgba(0,0,0,0.9)"}}},label:{show:!0,distance:0,padding:5,position:"inside",color:"#fff",overflow:"truncate"},upperLabel:{show:!1,position:[0,"50%"],height:20,overflow:"truncate",verticalAlign:"middle"},itemStyle:{color:null,colorAlpha:null,colorSaturation:null,borderWidth:0,gapWidth:0,borderColor:"#fff",borderColorSaturation:null},emphasis:{upperLabel:{show:!0,position:[0,"50%"],overflow:"truncate",verticalAlign:"middle"}},visualDimension:0,visualMin:null,visualMax:null,color:[],colorAlpha:null,colorSaturation:null,colorMappingBy:"index",visibleMin:10,childrenVisibleMin:null,levels:[]},e}(Ve);function _5(r){var e=0;B(r.children,function(n){_5(n);var a=n.value;ht(a)&&(a=a[0]),e+=a});var t=r.value;ht(t)&&(t=t[0]),(t==null||isNaN(t))&&(t=e),t<0&&(t=0),ht(r.value)?r.value[0]=t:r.value=t}function lq(r,e){var t=Ie(e.get("color")),n=Ie(e.get(["aria","decal","decals"]));if(t){r=r||[];var a,i;B(r,function(s){var l=new De(s),u=l.get("color"),c=l.get("decal");(l.get(["itemStyle","color"])||u&&u!=="none")&&(a=!0),(l.get(["itemStyle","decal"])||c&&c!=="none")&&(i=!0)});var o=r[0]||(r[0]={});return a||(o.color=t.slice()),!i&&n&&(o.decal=n.slice()),r}}var uq=8,CL=8,Fm=5,cq=function(){function r(e){this.group=new Wt,e.add(this.group)}return r.prototype.render=function(e,t,n,a){var i=e.getModel("breadcrumb"),o=this.group;if(o.removeAll(),!(!i.get("show")||!n)){var s=i.getModel("itemStyle"),l=i.getModel("emphasis"),u=s.getModel("textStyle"),c=l.getModel(["itemStyle","textStyle"]),h={pos:{left:i.get("left"),right:i.get("right"),top:i.get("top"),bottom:i.get("bottom")},box:{width:t.getWidth(),height:t.getHeight()},emptyItemWidth:i.get("emptyItemWidth"),totalWidth:0,renderList:[]};this._prepare(n,h,u),this._renderContent(e,h,s,l,u,c,a),Rp(o,h.pos,h.box)}},r.prototype._prepare=function(e,t,n){for(var a=e;a;a=a.parentNode){var i=ur(a.getModel().get("name"),""),o=n.getTextRect(i),s=Math.max(o.width+uq*2,t.emptyItemWidth);t.totalWidth+=s+CL,t.renderList.push({node:a,text:i,width:s})}},r.prototype._renderContent=function(e,t,n,a,i,o,s){for(var l=0,u=t.emptyItemWidth,c=e.get(["breadcrumb","height"]),h=mU(t.pos,t.box),d=t.totalWidth,v=t.renderList,p=a.getModel("itemStyle").getItemStyle(),y=v.length-1;y>=0;y--){var _=v[y],g=_.node,f=_.width,w=_.text;d>h.width&&(d-=f-u,f=u,w=null);var x=new rn({shape:{points:hq(l,0,f,c,y===v.length-1,y===0)},style:zt(n.getItemStyle(),{lineJoin:"bevel"}),textContent:new pe({style:Fe(i,{text:w})}),textConfig:{position:"inside"},z2:fu*1e4,onclick:Xt(s,g)});x.disableLabelAnimation=!0,x.getTextContent().ensureState("emphasis").style=Fe(o,{text:w}),x.ensureState("emphasis").style=p,Xe(x,a.get("focus"),a.get("blurScope"),a.get("disabled")),this.group.add(x),fq(x,e,g),l+=f+CL}},r.prototype.remove=function(){this.group.removeAll()},r}();function hq(r,e,t,n,a,i){var o=[[a?r:r-Fm,e],[r+t,e],[r+t,e+n],[a?r:r-Fm,e+n]];return!i&&o.splice(2,0,[r+t+Fm,e+n/2]),!a&&o.push([r,e+n/2]),o}function fq(r,e,t){Ht(r).eventData={componentType:"series",componentSubType:"treemap",componentIndex:e.componentIndex,seriesIndex:e.seriesIndex,seriesName:e.name,seriesType:"treemap",selfType:"breadcrumb",nodeData:{dataIndex:t&&t.dataIndex,name:t&&t.name},treePathInfo:t&&Yp(t,e)}}var vq=function(){function r(){this._storage=[],this._elExistsMap={}}return r.prototype.add=function(e,t,n,a,i){return this._elExistsMap[e.id]?!1:(this._elExistsMap[e.id]=!0,this._storage.push({el:e,target:t,duration:n,delay:a,easing:i}),!0)},r.prototype.finished=function(e){return this._finishedCallback=e,this},r.prototype.start=function(){for(var e=this,t=this._storage.length,n=function(){t--,t<=0&&(e._storage.length=0,e._elExistsMap={},e._finishedCallback&&e._finishedCallback())},a=0,i=this._storage.length;a<i;a++){var o=this._storage[a];o.el.animateTo(o.target,{duration:o.duration,delay:o.delay,easing:o.easing,setToFinal:!0,done:n,aborted:n})}return this},r}();function dq(){return new vq}var t1=Wt,LL=fe,ML=3,DL="label",IL="upperLabel",pq=fu*10,gq=fu*2,yq=fu*3,cs=Ns([["fill","color"],["stroke","strokeColor"],["lineWidth","strokeWidth"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"]]),PL=function(r){var e=cs(r);return e.stroke=e.fill=e.lineWidth=null,e},Zd=ve(),mq=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._state="ready",t._storage=lc(),t}return e.prototype.render=function(t,n,a,i){var o=n.findComponents({mainType:"series",subType:"treemap",query:i});if(!(te(o,t)<0)){this.seriesModel=t,this.api=a,this.ecModel=n;var s=["treemapZoomToNode","treemapRootToNode"],l=dh(i,s,t),u=i&&i.type,c=t.layoutInfo,h=!this._oldTree,d=this._storage,v=u==="treemapRootToNode"&&l&&d?{rootNodeGroup:d.nodeGroup[l.node.getRawIndex()],direction:i.direction}:null,p=this._giveContainerGroup(c),y=t.get("animation"),_=this._doRender(p,t,v);y&&!h&&(!u||u==="treemapZoomToNode"||u==="treemapRootToNode")?this._doAnimation(p,_,t,v):_.renderFinally(),this._resetController(a),this._renderBreadcrumb(t,a,l)}},e.prototype._giveContainerGroup=function(t){var n=this._containerGroup;return n||(n=this._containerGroup=new t1,this._initEvents(n),this.group.add(n)),n.x=t.x,n.y=t.y,n},e.prototype._doRender=function(t,n,a){var i=n.getData().tree,o=this._oldTree,s=lc(),l=lc(),u=this._storage,c=[];function h(f,w,x,S){return _q(n,l,u,a,s,c,f,w,x,S)}y(i.root?[i.root]:[],o&&o.root?[o.root]:[],t,i===o||!o,0);var d=_(u);if(this._oldTree=i,this._storage=l,this._controllerHost){var v=this.seriesModel.layoutInfo,p=i.root.getLayout();p.width===v.width&&p.height===v.height&&(this._controllerHost.zoom=1)}return{lastsForAnimation:s,willDeleteEls:d,renderFinally:g};function y(f,w,x,S,A){S?(w=f,B(f,function(M,I){!M.isRemoved()&&L(I,I)})):new Li(w,f,T,T).add(L).update(L).remove(Xt(L,null)).execute();function T(M){return M.getId()}function L(M,I){var R=M!=null?f[M]:null,P=I!=null?w[I]:null,E=h(R,P,x,A);E&&y(R&&R.viewChildren||[],P&&P.viewChildren||[],E,S,A+1)}}function _(f){var w=lc();return f&&B(f,function(x,S){var A=w[S];B(x,function(T){T&&(A.push(T),Zd(T).willDelete=!0)})}),w}function g(){B(d,function(f){B(f,function(w){w.parent&&w.parent.remove(w)})}),B(c,function(f){f.invisible=!0,f.dirty()})}},e.prototype._doAnimation=function(t,n,a,i){var o=a.get("animationDurationUpdate"),s=a.get("animationEasing"),l=(Nt(o)?0:o)||0,u=(Nt(s)?null:s)||"cubicOut",c=dq();B(n.willDeleteEls,function(h,d){B(h,function(v,p){if(!v.invisible){var y=v.parent,_,g=Zd(y);if(i&&i.direction==="drillDown")_=y===i.rootNodeGroup?{shape:{x:0,y:0,width:g.nodeWidth,height:g.nodeHeight},style:{opacity:0}}:{style:{opacity:0}};else{var f=0,w=0;g.willDelete||(f=g.nodeWidth/2,w=g.nodeHeight/2),_=d==="nodeGroup"?{x:f,y:w,style:{opacity:0}}:{shape:{x:f,y:w,width:0,height:0},style:{opacity:0}}}_&&c.add(v,_,l,0,u)}})}),B(this._storage,function(h,d){B(h,function(v,p){var y=n.lastsForAnimation[d][p],_={};y&&(v instanceof Wt?y.oldX!=null&&(_.x=v.x,_.y=v.y,v.x=y.oldX,v.y=y.oldY):(y.oldShape&&(_.shape=lt({},v.shape),v.setShape(y.oldShape)),y.fadein?(v.setStyle("opacity",0),_.style={opacity:1}):v.style.opacity!==1&&(_.style={opacity:1})),c.add(v,_,l,0,u))})},this),this._state="animating",c.finished(Mt(function(){this._state="ready",n.renderFinally()},this)).start()},e.prototype._resetController=function(t){var n=this._controller,a=this._controllerHost;a||(this._controllerHost={target:this.group},a=this._controllerHost),n||(n=this._controller=new Hh(t.getZr()),n.enable(this.seriesModel.get("roam")),a.zoomLimit=this.seriesModel.get("scaleLimit"),a.zoom=this.seriesModel.get("zoom"),n.on("pan",Mt(this._onPan,this)),n.on("zoom",Mt(this._onZoom,this)));var i=new Qt(0,0,t.getWidth(),t.getHeight());n.setPointerChecker(function(o,s,l){return i.contain(s,l)})},e.prototype._clearController=function(){var t=this._controller;this._controllerHost=null,t&&(t.dispose(),t=null)},e.prototype._onPan=function(t){if(this._state!=="animating"&&(Math.abs(t.dx)>ML||Math.abs(t.dy)>ML)){var n=this.seriesModel.getData().tree.root;if(!n)return;var a=n.getLayout();if(!a)return;this.api.dispatchAction({type:"treemapMove",from:this.uid,seriesId:this.seriesModel.id,rootRect:{x:a.x+t.dx,y:a.y+t.dy,width:a.width,height:a.height}})}},e.prototype._onZoom=function(t){var n=t.originX,a=t.originY,i=t.scale;if(this._state!=="animating"){var o=this.seriesModel.getData().tree.root;if(!o)return;var s=o.getLayout();if(!s)return;var l=new Qt(s.x,s.y,s.width,s.height),u=null,c=this._controllerHost;u=c.zoomLimit;var h=c.zoom=c.zoom||1;if(h*=i,u){var d=u.min||0,v=u.max||1/0;h=Math.max(Math.min(v,h),d)}var p=h/c.zoom;c.zoom=h;var y=this.seriesModel.layoutInfo;n-=y.x,a-=y.y;var _=Ln();Ya(_,_,[-n,-a]),H1(_,_,[p,p]),Ya(_,_,[n,a]),l.applyTransform(_),this.api.dispatchAction({type:"treemapRender",from:this.uid,seriesId:this.seriesModel.id,rootRect:{x:l.x,y:l.y,width:l.width,height:l.height}})}},e.prototype._initEvents=function(t){var n=this;t.on("click",function(a){if(n._state==="ready"){var i=n.seriesModel.get("nodeClick",!0);if(i){var o=n.findTarget(a.offsetX,a.offsetY);if(o){var s=o.node;if(s.getLayout().isLeafRoot)n._rootToNode(o);else if(i==="zoomToNode")n._zoomToNode(o);else if(i==="link"){var l=s.hostTree.data.getItemModel(s.dataIndex),u=l.get("link",!0),c=l.get("target",!0)||"blank";u&&Dd(u,c)}}}}},this)},e.prototype._renderBreadcrumb=function(t,n,a){var i=this;a||(a=t.get("leafDepth",!0)!=null?{node:t.getViewRoot()}:this.findTarget(n.getWidth()/2,n.getHeight()/2),a||(a={node:t.getData().tree.root})),(this._breadcrumb||(this._breadcrumb=new cq(this.group))).render(t,n,a.node,function(o){i._state!=="animating"&&(Jw(t.getViewRoot(),o)?i._rootToNode({node:o}):i._zoomToNode({node:o}))})},e.prototype.remove=function(){this._clearController(),this._containerGroup&&this._containerGroup.removeAll(),this._storage=lc(),this._state="ready",this._breadcrumb&&this._breadcrumb.remove()},e.prototype.dispose=function(){this._clearController()},e.prototype._zoomToNode=function(t){this.api.dispatchAction({type:"treemapZoomToNode",from:this.uid,seriesId:this.seriesModel.id,targetNode:t.node})},e.prototype._rootToNode=function(t){this.api.dispatchAction({type:"treemapRootToNode",from:this.uid,seriesId:this.seriesModel.id,targetNode:t.node})},e.prototype.findTarget=function(t,n){var a,i=this.seriesModel.getViewRoot();return i.eachNode({attr:"viewChildren",order:"preorder"},function(o){var s=this._storage.background[o.getRawIndex()];if(s){var l=s.transformCoordToLocal(t,n),u=s.shape;if(u.x<=l[0]&&l[0]<=u.x+u.width&&u.y<=l[1]&&l[1]<=u.y+u.height)a={node:o,offsetX:l[0],offsetY:l[1]};else return!1}},this),a},e.type="treemap",e}(Re);function lc(){return{nodeGroup:[],background:[],content:[]}}function _q(r,e,t,n,a,i,o,s,l,u){if(!o)return;var c=o.getLayout(),h=r.getData(),d=o.getModel();if(h.setItemGraphicEl(o.dataIndex,null),!c||!c.isInView)return;var v=c.width,p=c.height,y=c.borderWidth,_=c.invisible,g=o.getRawIndex(),f=s&&s.getRawIndex(),w=o.viewChildren,x=c.upperHeight,S=w&&w.length,A=d.getModel("itemStyle"),T=d.getModel(["emphasis","itemStyle"]),L=d.getModel(["blur","itemStyle"]),M=d.getModel(["select","itemStyle"]),I=A.get("borderRadius")||0,R=it("nodeGroup",t1);if(!R)return;if(l.add(R),R.x=c.x||0,R.y=c.y||0,R.markRedraw(),Zd(R).nodeWidth=v,Zd(R).nodeHeight=p,c.isAboveViewRoot)return R;var P=it("background",LL,u,gq);P&&K(R,P,S&&c.upperLabelHeight);var E=d.getModel("emphasis"),D=E.get("focus"),N=E.get("blurScope"),V=E.get("disabled"),W=D==="ancestor"?o.getAncestorsIndices():D==="descendant"?o.getDescendantIndices():D;if(S)eh(R)&&ws(R,!1),P&&(ws(P,!V),h.setItemGraphicEl(o.dataIndex,P),__(P,W,N));else{var $=it("content",LL,u,yq);$&&U(R,$),P.disableMorphing=!0,P&&eh(P)&&ws(P,!1),ws(R,!V),h.setItemGraphicEl(o.dataIndex,R);var H=d.getShallow("cursor");H&&$.attr("cursor",H),__(R,W,N)}return R;function K(bt,wt,Ot){var xt=Ht(wt);if(xt.dataIndex=o.dataIndex,xt.seriesIndex=r.seriesIndex,wt.setShape({x:0,y:0,width:v,height:p,r:I}),_)j(wt);else{wt.invisible=!1;var kt=o.getVisual("style"),ae=kt.stroke,O=PL(A);O.fill=ae;var st=cs(T);st.fill=T.get("borderColor");var nt=cs(L);nt.fill=L.get("borderColor");var X=cs(M);if(X.fill=M.get("borderColor"),Ot){var Z=v-2*y;ut(wt,ae,kt.opacity,{x:y,y:0,width:Z,height:x})}else wt.removeTextContent();wt.setStyle(O),wt.ensureState("emphasis").style=st,wt.ensureState("blur").style=nt,wt.ensureState("select").style=X,zs(wt)}bt.add(wt)}function U(bt,wt){var Ot=Ht(wt);Ot.dataIndex=o.dataIndex,Ot.seriesIndex=r.seriesIndex;var xt=Math.max(v-2*y,0),kt=Math.max(p-2*y,0);if(wt.culling=!0,wt.setShape({x:y,y,width:xt,height:kt,r:I}),_)j(wt);else{wt.invisible=!1;var ae=o.getVisual("style"),O=ae.fill,st=PL(A);st.fill=O,st.decal=ae.decal;var nt=cs(T),X=cs(L),Z=cs(M);ut(wt,O,ae.opacity,null),wt.setStyle(st),wt.ensureState("emphasis").style=nt,wt.ensureState("blur").style=X,wt.ensureState("select").style=Z,zs(wt)}bt.add(wt)}function j(bt){!bt.invisible&&i.push(bt)}function ut(bt,wt,Ot,xt){var kt=d.getModel(xt?IL:DL),ae=ur(d.get("name"),null),O=kt.getShallow("show");Rr(bt,_r(d,xt?IL:DL),{defaultText:O?ae:null,inheritColor:wt,defaultOpacity:Ot,labelFetcher:r,labelDataIndex:o.dataIndex});var st=bt.getTextContent();if(st){var nt=st.style,X=V1(nt.padding||0);xt&&(bt.setTextConfig({layoutRect:xt}),st.disableLabelLayout=!0),st.beforeUpdate=function(){var J=Math.max((xt?xt.width:bt.shape.width)-X[1]-X[3],0),pt=Math.max((xt?xt.height:bt.shape.height)-X[0]-X[2],0);(nt.width!==J||nt.height!==pt)&&st.setStyle({width:J,height:pt})},nt.truncateMinChar=2,nt.lineOverflow="truncate",ot(nt,xt,c);var Z=st.getState("emphasis");ot(Z?Z.style:null,xt,c)}}function ot(bt,wt,Ot){var xt=bt?bt.text:null;if(!wt&&Ot.isLeafRoot&&xt!=null){var kt=r.get("drillDownIcon",!0);bt.text=kt?kt+" "+xt:xt}}function it(bt,wt,Ot,xt){var kt=f!=null&&t[bt][f],ae=a[bt];return kt?(t[bt][f]=null,Et(ae,kt)):_||(kt=new wt,kt instanceof ta&&(kt.z2=wq(Ot,xt)),jt(ae,kt)),e[bt][g]=kt}function Et(bt,wt){var Ot=bt[g]={};wt instanceof t1?(Ot.oldX=wt.x,Ot.oldY=wt.y):Ot.oldShape=lt({},wt.shape)}function jt(bt,wt){var Ot=bt[g]={},xt=o.parentNode,kt=wt instanceof Wt;if(xt&&(!n||n.direction==="drillDown")){var ae=0,O=0,st=a.background[xt.getRawIndex()];!n&&st&&st.oldShape&&(ae=st.oldShape.width,O=st.oldShape.height),kt?(Ot.oldX=0,Ot.oldY=O):Ot.oldShape={x:ae,y:O,width:0,height:0}}Ot.fadein=!kt}}function wq(r,e){return r*pq+e}var ph=B,xq=Vt,Yd=-1,mr=function(){function r(e){var t=e.mappingMethod,n=e.type,a=this.option=Gt(e);this.type=n,this.mappingMethod=t,this._normalizeData=Aq[t];var i=r.visualHandlers[n];this.applyVisual=i.applyVisual,this.getColorMapper=i.getColorMapper,this._normalizedToVisual=i._normalizedToVisual[t],t==="piecewise"?(Vm(a),bq(a)):t==="category"?a.categories?Sq(a):Vm(a,!0):(Jr(t!=="linear"||a.dataExtent),Vm(a))}return r.prototype.mapValueToVisual=function(e){var t=this._normalizeData(e);return this._normalizedToVisual(t,e)},r.prototype.getNormalizer=function(){return Mt(this._normalizeData,this)},r.listVisualTypes=function(){return ue(r.visualHandlers)},r.isValidType=function(e){return r.visualHandlers.hasOwnProperty(e)},r.eachVisual=function(e,t,n){Vt(e)?B(e,t,n):t.call(n,e)},r.mapVisual=function(e,t,n){var a,i=ht(e)?[]:Vt(e)?{}:(a=!0,null);return r.eachVisual(e,function(o,s){var l=t.call(n,o,s);a?i=l:i[s]=l}),i},r.retrieveVisuals=function(e){var t={},n;return e&&ph(r.visualHandlers,function(a,i){e.hasOwnProperty(i)&&(t[i]=e[i],n=!0)}),n?t:null},r.prepareVisualTypes=function(e){if(ht(e))e=e.slice();else if(xq(e)){var t=[];ph(e,function(n,a){t.push(a)}),e=t}else return[];return e.sort(function(n,a){return a==="color"&&n!=="color"&&n.indexOf("color")===0?1:-1}),e},r.dependsOn=function(e,t){return t==="color"?!!(e&&e.indexOf(t)===0):e===t},r.findPieceIndex=function(e,t,n){for(var a,i=1/0,o=0,s=t.length;o<s;o++){var l=t[o].value;if(l!=null){if(l===e||Lt(l)&&l===e+"")return o;n&&d(l,o)}}for(var o=0,s=t.length;o<s;o++){var u=t[o],c=u.interval,h=u.close;if(c){if(c[0]===-1/0){if(Dv(h[1],e,c[1]))return o}else if(c[1]===1/0){if(Dv(h[0],c[0],e))return o}else if(Dv(h[0],c[0],e)&&Dv(h[1],e,c[1]))return o;n&&d(c[0],o),n&&d(c[1],o)}}if(n)return e===1/0?t.length-1:e===-1/0?0:a;function d(v,p){var y=Math.abs(v-e);y<i&&(i=y,a=p)}},r.visualHandlers={color:{applyVisual:uc("color"),getColorMapper:function(){var e=this.option;return Mt(e.mappingMethod==="category"?function(t,n){return!n&&(t=this._normalizeData(t)),Lc.call(this,t)}:function(t,n,a){var i=!!a;return!n&&(t=this._normalizeData(t)),a=wy(t,e.parsedVisual,a),i?a:wi(a,"rgba")},this)},_normalizedToVisual:{linear:function(e){return wi(wy(e,this.option.parsedVisual),"rgba")},category:Lc,piecewise:function(e,t){var n=r1.call(this,t);return n==null&&(n=wi(wy(e,this.option.parsedVisual),"rgba")),n},fixed:hs}},colorHue:Mv(function(e,t){return Rc(e,t)}),colorSaturation:Mv(function(e,t){return Rc(e,null,t)}),colorLightness:Mv(function(e,t){return Rc(e,null,null,t)}),colorAlpha:Mv(function(e,t){return yd(e,t)}),decal:{applyVisual:uc("decal"),_normalizedToVisual:{linear:null,category:Lc,piecewise:null,fixed:null}},opacity:{applyVisual:uc("opacity"),_normalizedToVisual:e1([0,1])},liftZ:{applyVisual:uc("liftZ"),_normalizedToVisual:{linear:hs,category:hs,piecewise:hs,fixed:hs}},symbol:{applyVisual:function(e,t,n){var a=this.mapValueToVisual(e);n("symbol",a)},_normalizedToVisual:{linear:kL,category:Lc,piecewise:function(e,t){var n=r1.call(this,t);return n==null&&(n=kL.call(this,e)),n},fixed:hs}},symbolSize:{applyVisual:uc("symbolSize"),_normalizedToVisual:e1([0,1])}},r}();function bq(r){var e=r.pieceList;r.hasSpecialVisual=!1,B(e,function(t,n){t.originIndex=n,t.visual!=null&&(r.hasSpecialVisual=!0)})}function Sq(r){var e=r.categories,t=r.categoryMap={},n=r.visual;if(ph(e,function(o,s){t[o]=s}),!ht(n)){var a=[];Vt(n)?ph(n,function(o,s){var l=t[s];a[l??Yd]=o}):a[Yd]=n,n=w5(r,a)}for(var i=e.length-1;i>=0;i--)n[i]==null&&(delete t[e[i]],e.pop())}function Vm(r,e){var t=r.visual,n=[];Vt(t)?ph(t,function(i){n.push(i)}):t!=null&&n.push(t);var a={color:1,symbol:1};!e&&n.length===1&&!a.hasOwnProperty(r.type)&&(n[1]=n[0]),w5(r,n)}function Mv(r){return{applyVisual:function(e,t,n){var a=this.mapValueToVisual(e);n("color",r(t("color"),a))},_normalizedToVisual:e1([0,1])}}function kL(r){var e=this.option.visual;return e[Math.round(Me(r,[0,1],[0,e.length-1],!0))]||{}}function uc(r){return function(e,t,n){n(r,this.mapValueToVisual(e))}}function Lc(r){var e=this.option.visual;return e[this.option.loop&&r!==Yd?r%e.length:r]}function hs(){return this.option.visual[0]}function e1(r){return{linear:function(e){return Me(e,r,this.option.visual,!0)},category:Lc,piecewise:function(e,t){var n=r1.call(this,t);return n==null&&(n=Me(e,r,this.option.visual,!0)),n},fixed:hs}}function r1(r){var e=this.option,t=e.pieceList;if(e.hasSpecialVisual){var n=mr.findPieceIndex(r,t),a=t[n];if(a&&a.visual)return a.visual[this.type]}}function w5(r,e){return r.visual=e,r.type==="color"&&(r.parsedVisual=ft(e,function(t){var n=Mn(t);return n||[0,0,0,1]})),e}var Aq={linear:function(r){return Me(r,this.option.dataExtent,[0,1],!0)},piecewise:function(r){var e=this.option.pieceList,t=mr.findPieceIndex(r,e,!0);if(t!=null)return Me(t,[0,e.length-1],[0,1],!0)},category:function(r){var e=this.option.categories?this.option.categoryMap[r]:r;return e??Yd},fixed:tr};function Dv(r,e,t){return r?e<=t:e<t}var Tq="itemStyle",x5=ve();const Cq={seriesType:"treemap",reset:function(r){var e=r.getData().tree,t=e.root;t.isRemoved()||b5(t,{},r.getViewRoot().getAncestors(),r)}};function b5(r,e,t,n){var a=r.getModel(),i=r.getLayout(),o=r.hostTree.data;if(!(!i||i.invisible||!i.isInView)){var s=a.getModel(Tq),l=Lq(s,e,n),u=o.ensureUniqueItemVisual(r.dataIndex,"style"),c=s.get("borderColor"),h=s.get("borderColorSaturation"),d;h!=null&&(d=RL(l),c=Mq(h,d)),u.stroke=c;var v=r.viewChildren;if(!v||!v.length)d=RL(l),u.fill=d;else{var p=Dq(r,a,i,s,l,v);B(v,function(y,_){if(y.depth>=t.length||y===t[y.depth]){var g=Iq(a,l,y,_,p,n);b5(y,g,t,n)}})}}}function Lq(r,e,t){var n=lt({},e),a=t.designatedVisualItemStyle;return B(["color","colorAlpha","colorSaturation"],function(i){a[i]=e[i];var o=r.get(i);a[i]=null,o!=null&&(n[i]=o)}),n}function RL(r){var e=Gm(r,"color");if(e){var t=Gm(r,"colorAlpha"),n=Gm(r,"colorSaturation");return n&&(e=Rc(e,null,null,n)),t&&(e=yd(e,t)),e}}function Mq(r,e){return e!=null?Rc(e,null,null,r):null}function Gm(r,e){var t=r[e];if(t!=null&&t!=="none")return t}function Dq(r,e,t,n,a,i){if(!(!i||!i.length)){var o=Wm(e,"color")||a.color!=null&&a.color!=="none"&&(Wm(e,"colorAlpha")||Wm(e,"colorSaturation"));if(o){var s=e.get("visualMin"),l=e.get("visualMax"),u=t.dataExtent.slice();s!=null&&s<u[0]&&(u[0]=s),l!=null&&l>u[1]&&(u[1]=l);var c=e.get("colorMappingBy"),h={type:o.name,dataExtent:u,visual:o.range};h.type==="color"&&(c==="index"||c==="id")?(h.mappingMethod="category",h.loop=!0):h.mappingMethod="linear";var d=new mr(h);return x5(d).drColorMappingBy=c,d}}}function Wm(r,e){var t=r.get(e);return ht(t)&&t.length?{name:e,range:t}:null}function Iq(r,e,t,n,a,i){var o=lt({},e);if(a){var s=a.type,l=s==="color"&&x5(a).drColorMappingBy,u=l==="index"?n:l==="id"?i.mapIdToIndex(t.getId()):t.getValue(r.get("visualDimension"));o[s]=a.mapValueToVisual(u)}return o}var gh=Math.max,Xd=Math.min,EL=Ar,tx=B,S5=["itemStyle","borderWidth"],Pq=["itemStyle","gapWidth"],kq=["upperLabel","show"],Rq=["upperLabel","height"];const Eq={seriesType:"treemap",reset:function(r,e,t,n){var a=t.getWidth(),i=t.getHeight(),o=r.option,s=cr(r.getBoxLayoutParams(),{width:t.getWidth(),height:t.getHeight()}),l=o.size||[],u=At(EL(s.width,l[0]),a),c=At(EL(s.height,l[1]),i),h=n&&n.type,d=["treemapZoomToNode","treemapRootToNode"],v=dh(n,d,r),p=h==="treemapRender"||h==="treemapMove"?n.rootRect:null,y=r.getViewRoot(),_=y5(y);if(h!=="treemapMove"){var g=h==="treemapZoomToNode"?Vq(r,v,y,u,c):p?[p.width,p.height]:[u,c],f=o.sort;f&&f!=="asc"&&f!=="desc"&&(f="desc");var w={squareRatio:o.squareRatio,sort:f,leafDepth:o.leafDepth};y.hostTree.clearLayouts();var x={x:0,y:0,width:g[0],height:g[1],area:g[0]*g[1]};y.setLayout(x),A5(y,w,!1,0),x=y.getLayout(),tx(_,function(A,T){var L=(_[T+1]||y).getValue();A.setLayout(lt({dataExtent:[L,L],borderWidth:0,upperHeight:0},x))})}var S=r.getData().tree.root;S.setLayout(Gq(s,p,v),!0),r.setLayoutInfo(s),T5(S,new Qt(-s.x,-s.y,a,i),_,y,0)}};function A5(r,e,t,n){var a,i;if(!r.isRemoved()){var o=r.getLayout();a=o.width,i=o.height;var s=r.getModel(),l=s.get(S5),u=s.get(Pq)/2,c=C5(s),h=Math.max(l,c),d=l-u,v=h-u;r.setLayout({borderWidth:l,upperHeight:h,upperLabelHeight:c},!0),a=gh(a-2*d,0),i=gh(i-d-v,0);var p=a*i,y=Oq(r,s,p,e,t,n);if(y.length){var _={x:d,y:v,width:a,height:i},g=Xd(a,i),f=1/0,w=[];w.area=0;for(var x=0,S=y.length;x<S;){var A=y[x];w.push(A),w.area+=A.getLayout().area;var T=Fq(w,g,e.squareRatio);T<=f?(x++,f=T):(w.area-=w.pop().getLayout().area,OL(w,g,_,u,!1),g=Xd(_.width,_.height),w.length=w.area=0,f=1/0)}if(w.length&&OL(w,g,_,u,!0),!t){var L=s.get("childrenVisibleMin");L!=null&&p<L&&(t=!0)}for(var x=0,S=y.length;x<S;x++)A5(y[x],e,t,n+1)}}}function Oq(r,e,t,n,a,i){var o=r.children||[],s=n.sort;s!=="asc"&&s!=="desc"&&(s=null);var l=n.leafDepth!=null&&n.leafDepth<=i;if(a&&!l)return r.viewChildren=[];o=Te(o,function(v){return!v.isRemoved()}),Nq(o,s);var u=zq(e,o,s);if(u.sum===0)return r.viewChildren=[];if(u.sum=Bq(e,t,u.sum,s,o),u.sum===0)return r.viewChildren=[];for(var c=0,h=o.length;c<h;c++){var d=o[c].getValue()/u.sum*t;o[c].setLayout({area:d})}return l&&(o.length&&r.setLayout({isLeafRoot:!0},!0),o.length=0),r.viewChildren=o,r.setLayout({dataExtent:u.dataExtent},!0),o}function Bq(r,e,t,n,a){if(!n)return t;for(var i=r.get("visibleMin"),o=a.length,s=o,l=o-1;l>=0;l--){var u=a[n==="asc"?o-l-1:l].getValue();u/t*e<i&&(s=l,t-=u)}return n==="asc"?a.splice(0,o-s):a.splice(s,o-s),t}function Nq(r,e){return e&&r.sort(function(t,n){var a=e==="asc"?t.getValue()-n.getValue():n.getValue()-t.getValue();return a===0?e==="asc"?t.dataIndex-n.dataIndex:n.dataIndex-t.dataIndex:a}),r}function zq(r,e,t){for(var n=0,a=0,i=e.length;a<i;a++)n+=e[a].getValue();var o=r.get("visualDimension"),s;return!e||!e.length?s=[NaN,NaN]:o==="value"&&t?(s=[e[e.length-1].getValue(),e[0].getValue()],t==="asc"&&s.reverse()):(s=[1/0,-1/0],tx(e,function(l){var u=l.getValue(o);u<s[0]&&(s[0]=u),u>s[1]&&(s[1]=u)})),{sum:n,dataExtent:s}}function Fq(r,e,t){for(var n=0,a=1/0,i=0,o=void 0,s=r.length;i<s;i++)o=r[i].getLayout().area,o&&(o<a&&(a=o),o>n&&(n=o));var l=r.area*r.area,u=e*e*t;return l?gh(u*n/l,l/(u*a)):1/0}function OL(r,e,t,n,a){var i=e===t.width?0:1,o=1-i,s=["x","y"],l=["width","height"],u=t[s[i]],c=e?r.area/e:0;(a||c>t[l[o]])&&(c=t[l[o]]);for(var h=0,d=r.length;h<d;h++){var v=r[h],p={},y=c?v.getLayout().area/c:0,_=p[l[o]]=gh(c-2*n,0),g=t[s[i]]+t[l[i]]-u,f=h===d-1||g<y?g:y,w=p[l[i]]=gh(f-2*n,0);p[s[o]]=t[s[o]]+Xd(n,_/2),p[s[i]]=u+Xd(n,w/2),u+=f,v.setLayout(p,!0)}t[s[o]]+=c,t[l[o]]-=c}function Vq(r,e,t,n,a){var i=(e||{}).node,o=[n,a];if(!i||i===t)return o;for(var s,l=n*a,u=l*r.option.zoomToNodeRatio;s=i.parentNode;){for(var c=0,h=s.children,d=0,v=h.length;d<v;d++)c+=h[d].getValue();var p=i.getValue();if(p===0)return o;u*=c/p;var y=s.getModel(),_=y.get(S5),g=Math.max(_,C5(y));u+=4*_*_+(3*_+g)*Math.pow(u,.5),u>$2&&(u=$2),i=s}u<l&&(u=l);var f=Math.pow(u/l,.5);return[n*f,a*f]}function Gq(r,e,t){if(e)return{x:e.x,y:e.y};var n={x:0,y:0};if(!t)return n;var a=t.node,i=a.getLayout();if(!i)return n;for(var o=[i.width/2,i.height/2],s=a;s;){var l=s.getLayout();o[0]+=l.x,o[1]+=l.y,s=s.parentNode}return{x:r.width/2-o[0],y:r.height/2-o[1]}}function T5(r,e,t,n,a){var i=r.getLayout(),o=t[a],s=o&&o===r;if(!(o&&!s||a===t.length&&r!==n)){r.setLayout({isInView:!0,invisible:!s&&!e.intersect(i),isAboveViewRoot:s},!0);var l=new Qt(e.x-i.x,e.y-i.y,e.width,e.height);tx(r.viewChildren||[],function(u){T5(u,l,t,n,a+1)})}}function C5(r){return r.get(kq)?r.get(Rq):0}function Wq(r){r.registerSeriesModel(sq),r.registerChartView(mq),r.registerVisual(Cq),r.registerLayout(Eq),oq(r)}function Hq(r){var e=r.findComponents({mainType:"legend"});!e||!e.length||r.eachSeriesByType("graph",function(t){var n=t.getCategoriesData(),a=t.getGraph(),i=a.data,o=n.mapArray(n.getName);i.filterSelf(function(s){var l=i.getItemModel(s),u=l.getShallow("category");if(u!=null){ye(u)&&(u=o[u]);for(var c=0;c<e.length;c++)if(!e[c].isSelected(u))return!1}return!0})})}function Uq(r){var e={};r.eachSeriesByType("graph",function(t){var n=t.getCategoriesData(),a=t.getData(),i={};n.each(function(o){var s=n.getName(o);i["ec-"+s]=o;var l=n.getItemModel(o),u=l.getModel("itemStyle").getItemStyle();u.fill||(u.fill=t.getColorFromPalette(s,e)),n.setItemVisual(o,"style",u);for(var c=["symbol","symbolSize","symbolKeepAspect"],h=0;h<c.length;h++){var d=l.getShallow(c[h],!0);d!=null&&n.setItemVisual(o,c[h],d)}}),n.count()&&a.each(function(o){var s=a.getItemModel(o),l=s.getShallow("category");if(l!=null){Lt(l)&&(l=i["ec-"+l]);var u=n.getItemVisual(l,"style"),c=a.ensureUniqueItemVisual(o,"style");lt(c,u);for(var h=["symbol","symbolSize","symbolKeepAspect"],d=0;d<h.length;d++)a.setItemVisual(o,h[d],n.getItemVisual(l,h[d]))}})})}function Iv(r){return r instanceof Array||(r=[r,r]),r}function Zq(r){r.eachSeriesByType("graph",function(e){var t=e.getGraph(),n=e.getEdgeData(),a=Iv(e.get("edgeSymbol")),i=Iv(e.get("edgeSymbolSize"));n.setVisual("fromSymbol",a&&a[0]),n.setVisual("toSymbol",a&&a[1]),n.setVisual("fromSymbolSize",i&&i[0]),n.setVisual("toSymbolSize",i&&i[1]),n.setVisual("style",e.getModel("lineStyle").getLineStyle()),n.each(function(o){var s=n.getItemModel(o),l=t.getEdgeByIndex(o),u=Iv(s.getShallow("symbol",!0)),c=Iv(s.getShallow("symbolSize",!0)),h=s.getModel("lineStyle").getLineStyle(),d=n.ensureUniqueItemVisual(o,"style");switch(lt(d,h),d.stroke){case"source":{var v=l.node1.getVisual("style");d.stroke=v&&v.fill;break}case"target":{var v=l.node2.getVisual("style");d.stroke=v&&v.fill;break}}u[0]&&l.setVisual("fromSymbol",u[0]),u[1]&&l.setVisual("toSymbol",u[1]),c[0]&&l.setVisual("fromSymbolSize",c[0]),c[1]&&l.setVisual("toSymbolSize",c[1])})})}var n1="-->",Xp=function(r){return r.get("autoCurveness")||null},L5=function(r,e){var t=Xp(r),n=20,a=[];if(ye(t))n=t;else if(ht(t)){r.__curvenessList=t;return}e>n&&(n=e);var i=n%2?n+2:n+3;a=[];for(var o=0;o<i;o++)a.push((o%2?o+1:o)/10*(o%2?-1:1));r.__curvenessList=a},yh=function(r,e,t){var n=[r.id,r.dataIndex].join("."),a=[e.id,e.dataIndex].join(".");return[t.uid,n,a].join(n1)},M5=function(r){var e=r.split(n1);return[e[0],e[2],e[1]].join(n1)},Yq=function(r,e){var t=yh(r.node1,r.node2,e);return e.__edgeMap[t]},Xq=function(r,e){var t=a1(yh(r.node1,r.node2,e),e),n=a1(yh(r.node2,r.node1,e),e);return t+n},a1=function(r,e){var t=e.__edgeMap;return t[r]?t[r].length:0};function $q(r){Xp(r)&&(r.__curvenessList=[],r.__edgeMap={},L5(r))}function jq(r,e,t,n){if(Xp(t)){var a=yh(r,e,t),i=t.__edgeMap,o=i[M5(a)];i[a]&&!o?i[a].isForward=!0:o&&i[a]&&(o.isForward=!0,i[a].isForward=!1),i[a]=i[a]||[],i[a].push(n)}}function ex(r,e,t,n){var a=Xp(e),i=ht(a);if(!a)return null;var o=Yq(r,e);if(!o)return null;for(var s=-1,l=0;l<o.length;l++)if(o[l]===t){s=l;break}var u=Xq(r,e);L5(e,u),r.lineStyle=r.lineStyle||{};var c=yh(r.node1,r.node2,e),h=e.__curvenessList,d=i||u%2?0:1;if(o.isForward)return h[d+s];var v=M5(c),p=a1(v,e),y=h[s+p+d];return n?i?a&&a[0]===0?(p+d)%2?y:-y:((p%2?0:1)+d)%2?y:-y:(p+d)%2?y:-y:h[s+p+d]}function D5(r){var e=r.coordinateSystem;if(!(e&&e.type!=="view")){var t=r.getGraph();t.eachNode(function(n){var a=n.getModel();n.setLayout([+a.get("x"),+a.get("y")])}),rx(t,r)}}function rx(r,e){r.eachEdge(function(t,n){var a=Ha(t.getModel().get(["lineStyle","curveness"]),-ex(t,e,n,!0),0),i=mi(t.node1.getLayout()),o=mi(t.node2.getLayout()),s=[i,o];+a&&s.push([(i[0]+o[0])/2-(i[1]-o[1])*a,(i[1]+o[1])/2-(o[0]-i[0])*a]),t.setLayout(s)})}function qq(r,e){r.eachSeriesByType("graph",function(t){var n=t.get("layout"),a=t.coordinateSystem;if(a&&a.type!=="view"){var i=t.getData(),o=[];B(a.dimensions,function(d){o=o.concat(i.mapDimensionsAll(d))});for(var s=0;s<i.count();s++){for(var l=[],u=!1,c=0;c<o.length;c++){var h=i.get(o[c],s);isNaN(h)||(u=!0),l.push(h)}u?i.setItemLayout(s,a.dataToPoint(l)):i.setItemLayout(s,[NaN,NaN])}rx(i.graph,t)}else(!n||n==="none")&&D5(t)})}function Mc(r){var e=r.coordinateSystem;if(e.type!=="view")return 1;var t=r.option.nodeScaleRatio,n=e.scaleX,a=e.getZoom(),i=(a-1)*t+1;return i/n}function Dc(r){var e=r.getVisual("symbolSize");return e instanceof Array&&(e=(e[0]+e[1])/2),+e}var BL=Math.PI,Hm=[];function nx(r,e,t,n){var a=r.coordinateSystem;if(!(a&&a.type!=="view")){var i=a.getBoundingRect(),o=r.getData(),s=o.graph,l=i.width/2+i.x,u=i.height/2+i.y,c=Math.min(i.width,i.height)/2,h=o.count();if(o.setLayout({cx:l,cy:u}),!!h){if(t){var d=a.pointToData(n),v=d[0],p=d[1],y=[v-l,p-u];uu(y,y),Zv(y,y,c),t.setLayout([l+y[0],u+y[1]],!0);var _=r.get(["circular","rotateLabel"]);I5(t,_,l,u)}Kq[e](r,s,o,c,l,u,h),s.eachEdge(function(g,f){var w=Ha(g.getModel().get(["lineStyle","curveness"]),ex(g,r,f),0),x=mi(g.node1.getLayout()),S=mi(g.node2.getLayout()),A,T=(x[0]+S[0])/2,L=(x[1]+S[1])/2;+w&&(w*=3,A=[l*w+T*(1-w),u*w+L*(1-w)]),g.setLayout([x,S,A])})}}}var Kq={value:function(r,e,t,n,a,i,o){var s=0,l=t.getSum("value"),u=Math.PI*2/(l||o);e.eachNode(function(c){var h=c.getValue("value"),d=u*(l?h:1)/2;s+=d,c.setLayout([n*Math.cos(s)+a,n*Math.sin(s)+i]),s+=d})},symbolSize:function(r,e,t,n,a,i,o){var s=0;Hm.length=o;var l=Mc(r);e.eachNode(function(h){var d=Dc(h);isNaN(d)&&(d=2),d<0&&(d=0),d*=l;var v=Math.asin(d/2/n);isNaN(v)&&(v=BL/2),Hm[h.dataIndex]=v,s+=v*2});var u=(2*BL-s)/o/2,c=0;e.eachNode(function(h){var d=u+Hm[h.dataIndex];c+=d,(!h.getLayout()||!h.getLayout().fixed)&&h.setLayout([n*Math.cos(c)+a,n*Math.sin(c)+i]),c+=d})}};function I5(r,e,t,n){var a=r.getGraphicEl();if(a){var i=r.getModel(),o=i.get(["label","rotate"])||0,s=a.getSymbolPath();if(e){var l=r.getLayout(),u=Math.atan2(l[1]-n,l[0]-t);u<0&&(u=Math.PI*2+u);var c=l[0]<t;c&&(u=u-Math.PI);var h=c?"left":"right";s.setTextConfig({rotation:-u,position:h,origin:"center"});var d=s.ensureState("emphasis");lt(d.textConfig||(d.textConfig={}),{position:h})}else s.setTextConfig({rotation:o*=Math.PI/180})}}function Qq(r){r.eachSeriesByType("graph",function(e){e.get("layout")==="circular"&&nx(e,"symbolSize")})}var Cl=U0;function Jq(r,e,t){for(var n=r,a=e,i=t.rect,o=i.width,s=i.height,l=[i.x+o/2,i.y+s/2],u=t.gravity==null?.1:t.gravity,c=0;c<n.length;c++){var h=n[c];h.p||(h.p=Ws(o*(Math.random()-.5)+l[0],s*(Math.random()-.5)+l[1])),h.pp=mi(h.p),h.edges=null}var d=t.friction==null?.6:t.friction,v=d,p,y;return{warmUp:function(){v=d*.8},setFixed:function(_){n[_].fixed=!0},setUnfixed:function(_){n[_].fixed=!1},beforeStep:function(_){p=_},afterStep:function(_){y=_},step:function(_){p&&p(n,a);for(var g=[],f=n.length,w=0;w<a.length;w++){var x=a[w];if(!x.ignoreForceLayout){var S=x.n1,A=x.n2;ms(g,A.p,S.p);var T=Z0(g)-x.d,L=A.w/(S.w+A.w);isNaN(L)&&(L=0),uu(g,g),!S.fixed&&Cl(S.p,S.p,g,L*T*v),!A.fixed&&Cl(A.p,A.p,g,-(1-L)*T*v)}}for(var w=0;w<f;w++){var M=n[w];M.fixed||(ms(g,l,M.p),Cl(M.p,M.p,g,u*v))}for(var w=0;w<f;w++)for(var S=n[w],I=w+1;I<f;I++){var A=n[I];ms(g,A.p,S.p);var T=Z0(g);T===0&&(L6(g,Math.random()-.5,Math.random()-.5),T=1);var R=(S.rep+A.rep)/T/T;!S.fixed&&Cl(S.pp,S.pp,g,R),!A.fixed&&Cl(A.pp,A.pp,g,-R)}for(var P=[],w=0;w<f;w++){var M=n[w];M.fixed||(ms(P,M.p,M.pp),Cl(M.p,M.p,P,v),Xr(M.pp,M.p))}v=v*.992;var E=v<.01;y&&y(n,a,E),_&&_(E)}}}function tK(r){r.eachSeriesByType("graph",function(e){var t=e.coordinateSystem;if(!(t&&t.type!=="view"))if(e.get("layout")==="force"){var n=e.preservedPoints||{},a=e.getGraph(),i=a.data,o=a.edgeData,s=e.getModel("force"),l=s.get("initLayout");e.preservedPoints?i.each(function(w){var x=i.getId(w);i.setItemLayout(w,n[x]||[NaN,NaN])}):!l||l==="none"?D5(e):l==="circular"&&nx(e,"value");var u=i.getDataExtent("value"),c=o.getDataExtent("value"),h=s.get("repulsion"),d=s.get("edgeLength"),v=ht(h)?h:[h,h],p=ht(d)?d:[d,d];p=[p[1],p[0]];var y=i.mapArray("value",function(w,x){var S=i.getItemLayout(x),A=Me(w,u,v);return isNaN(A)&&(A=(v[0]+v[1])/2),{w:A,rep:A,fixed:i.getItemModel(x).get("fixed"),p:!S||isNaN(S[0])||isNaN(S[1])?null:S}}),_=o.mapArray("value",function(w,x){var S=a.getEdgeByIndex(x),A=Me(w,c,p);isNaN(A)&&(A=(p[0]+p[1])/2);var T=S.getModel(),L=Ha(S.getModel().get(["lineStyle","curveness"]),-ex(S,e,x,!0),0);return{n1:y[S.node1.dataIndex],n2:y[S.node2.dataIndex],d:A,curveness:L,ignoreForceLayout:T.get("ignoreForceLayout")}}),g=t.getBoundingRect(),f=Jq(y,_,{rect:g,gravity:s.get("gravity"),friction:s.get("friction")});f.beforeStep(function(w,x){for(var S=0,A=w.length;S<A;S++)w[S].fixed&&Xr(w[S].p,a.getNodeByIndex(S).getLayout())}),f.afterStep(function(w,x,S){for(var A=0,T=w.length;A<T;A++)w[A].fixed||a.getNodeByIndex(A).setLayout(w[A].p),n[i.getId(A)]=w[A].p;for(var A=0,T=x.length;A<T;A++){var L=x[A],M=a.getEdgeByIndex(A),I=L.n1.p,R=L.n2.p,P=M.getLayout();P=P?P.slice():[],P[0]=P[0]||[],P[1]=P[1]||[],Xr(P[0],I),Xr(P[1],R),+L.curveness&&(P[2]=[(I[0]+R[0])/2-(I[1]-R[1])*L.curveness,(I[1]+R[1])/2-(R[0]-I[0])*L.curveness]),M.setLayout(P)}}),e.forceLayout=f,e.preservedPoints=n,f.step()}else e.forceLayout=null})}function eK(r,e,t){var n=lt(r.getBoxLayoutParams(),{aspect:t});return cr(n,{width:e.getWidth(),height:e.getHeight()})}function rK(r,e){var t=[];return r.eachSeriesByType("graph",function(n){var a=n.get("coordinateSystem");if(!a||a==="view"){var i=n.getData(),o=i.mapArray(function(_){var g=i.getItemModel(_);return[+g.get("x"),+g.get("y")]}),s=[],l=[];wp(o,s,l),l[0]-s[0]===0&&(l[0]+=1,s[0]-=1),l[1]-s[1]===0&&(l[1]+=1,s[1]-=1);var u=(l[0]-s[0])/(l[1]-s[1]),c=eK(n,e,u);isNaN(u)&&(s=[c.x,c.y],l=[c.x+c.width,c.y+c.height]);var h=l[0]-s[0],d=l[1]-s[1],v=c.width,p=c.height,y=n.coordinateSystem=new Uh;y.zoomLimit=n.get("scaleLimit"),y.setBoundingRect(s[0],s[1],h,d),y.setViewRect(c.x,c.y,v,p),y.setCenter(n.get("center"),e),y.setZoom(n.get("zoom")),t.push(y)}}),t}var NL=gr.prototype,Um=Dh.prototype,P5=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}();(function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e})(P5);function Zm(r){return isNaN(+r.cpx1)||isNaN(+r.cpy1)}var nK=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="ec-line",n}return e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new P5},e.prototype.buildPath=function(t,n){Zm(n)?NL.buildPath.call(this,t,n):Um.buildPath.call(this,t,n)},e.prototype.pointAt=function(t){return Zm(this.shape)?NL.pointAt.call(this,t):Um.pointAt.call(this,t)},e.prototype.tangentAt=function(t){var n=this.shape,a=Zm(n)?[n.x2-n.x1,n.y2-n.y1]:Um.tangentAt.call(this,t);return uu(a,a)},e}(ie),Ym=["fromSymbol","toSymbol"];function zL(r){return"_"+r+"Type"}function FL(r,e,t){var n=e.getItemVisual(t,r);if(!n||n==="none")return n;var a=e.getItemVisual(t,r+"Size"),i=e.getItemVisual(t,r+"Rotate"),o=e.getItemVisual(t,r+"Offset"),s=e.getItemVisual(t,r+"KeepAspect"),l=xu(a),u=Ys(o||0,l);return n+l+u+(i||"")+(s||"")}function VL(r,e,t){var n=e.getItemVisual(t,r);if(!(!n||n==="none")){var a=e.getItemVisual(t,r+"Size"),i=e.getItemVisual(t,r+"Rotate"),o=e.getItemVisual(t,r+"Offset"),s=e.getItemVisual(t,r+"KeepAspect"),l=xu(a),u=Ys(o||0,l),c=or(n,-l[0]/2+u[0],-l[1]/2+u[1],l[0],l[1],null,s);return c.__specifiedRotation=i==null||isNaN(i)?void 0:+i*Math.PI/180||0,c.name=r,c}}function aK(r){var e=new nK({name:"line",subPixelOptimize:!0});return i1(e.shape,r),e}function i1(r,e){r.x1=e[0][0],r.y1=e[0][1],r.x2=e[1][0],r.y2=e[1][1],r.percent=1;var t=e[2];t?(r.cpx1=t[0],r.cpy1=t[1]):(r.cpx1=NaN,r.cpy1=NaN)}var ax=function(r){rt(e,r);function e(t,n,a){var i=r.call(this)||this;return i._createLine(t,n,a),i}return e.prototype._createLine=function(t,n,a){var i=t.hostModel,o=t.getItemLayout(n),s=aK(o);s.shape.percent=0,He(s,{shape:{percent:1}},i,n),this.add(s),B(Ym,function(l){var u=VL(l,t,n);this.add(u),this[zL(l)]=FL(l,t,n)},this),this._updateCommonStl(t,n,a)},e.prototype.updateData=function(t,n,a){var i=t.hostModel,o=this.childOfName("line"),s=t.getItemLayout(n),l={shape:{}};i1(l.shape,s),_e(o,l,i,n),B(Ym,function(u){var c=FL(u,t,n),h=zL(u);if(this[h]!==c){this.remove(this.childOfName(u));var d=VL(u,t,n);this.add(d)}this[h]=c},this),this._updateCommonStl(t,n,a)},e.prototype.getLinePath=function(){return this.childAt(0)},e.prototype._updateCommonStl=function(t,n,a){var i=t.hostModel,o=this.childOfName("line"),s=a&&a.emphasisLineStyle,l=a&&a.blurLineStyle,u=a&&a.selectLineStyle,c=a&&a.labelStatesModels,h=a&&a.emphasisDisabled,d=a&&a.focus,v=a&&a.blurScope;if(!a||t.hasItemOption){var p=t.getItemModel(n),y=p.getModel("emphasis");s=y.getModel("lineStyle").getLineStyle(),l=p.getModel(["blur","lineStyle"]).getLineStyle(),u=p.getModel(["select","lineStyle"]).getLineStyle(),h=y.get("disabled"),d=y.get("focus"),v=y.get("blurScope"),c=_r(p)}var _=t.getItemVisual(n,"style"),g=_.stroke;o.useStyle(_),o.style.fill=null,o.style.strokeNoScale=!0,o.ensureState("emphasis").style=s,o.ensureState("blur").style=l,o.ensureState("select").style=u,B(Ym,function(A){var T=this.childOfName(A);if(T){T.setColor(g),T.style.opacity=_.opacity;for(var L=0;L<tn.length;L++){var M=tn[L],I=o.getState(M);if(I){var R=I.style||{},P=T.ensureState(M),E=P.style||(P.style={});R.stroke!=null&&(E[T.__isEmptyBrush?"stroke":"fill"]=R.stroke),R.opacity!=null&&(E.opacity=R.opacity)}}T.markRedraw()}},this);var f=i.getRawValue(n);Rr(this,c,{labelDataIndex:n,labelFetcher:{getFormattedLabel:function(A,T){return i.getFormattedLabel(A,T,t.dataType)}},inheritColor:g||"#000",defaultOpacity:_.opacity,defaultText:(f==null?t.getName(n):isFinite(f)?qe(f):f)+""});var w=this.getTextContent();if(w){var x=c.normal;w.__align=w.style.align,w.__verticalAlign=w.style.verticalAlign,w.__position=x.get("position")||"middle";var S=x.get("distance");ht(S)||(S=[S,S]),w.__labelDistance=S}this.setTextConfig({position:null,local:!0,inside:!1}),Xe(this,d,v,h)},e.prototype.highlight=function(){Ti(this)},e.prototype.downplay=function(){Ci(this)},e.prototype.updateLayout=function(t,n){this.setLinePoints(t.getItemLayout(n))},e.prototype.setLinePoints=function(t){var n=this.childOfName("line");i1(n.shape,t),n.dirty()},e.prototype.beforeUpdate=function(){var t=this,n=t.childOfName("fromSymbol"),a=t.childOfName("toSymbol"),i=t.getTextContent();if(!n&&!a&&(!i||i.ignore))return;for(var o=1,s=this.parent;s;)s.scaleX&&(o/=s.scaleX),s=s.parent;var l=t.childOfName("line");if(!this.__dirty&&!l.__dirty)return;var u=l.shape.percent,c=l.pointAt(0),h=l.pointAt(u),d=ms([],h,c);uu(d,d);function v(I,R){var P=I.__specifiedRotation;if(P==null){var E=l.tangentAt(R);I.attr("rotation",(R===1?-1:1)*Math.PI/2-Math.atan2(E[1],E[0]))}else I.attr("rotation",P)}if(n&&(n.setPosition(c),v(n,0),n.scaleX=n.scaleY=o*u,n.markRedraw()),a&&(a.setPosition(h),v(a,1),a.scaleX=a.scaleY=o*u,a.markRedraw()),i&&!i.ignore){i.x=i.y=0,i.originX=i.originY=0;var p=void 0,y=void 0,_=i.__labelDistance,g=_[0]*o,f=_[1]*o,w=u/2,x=l.tangentAt(w),S=[x[1],-x[0]],A=l.pointAt(w);S[1]>0&&(S[0]=-S[0],S[1]=-S[1]);var T=x[0]<0?-1:1;if(i.__position!=="start"&&i.__position!=="end"){var L=-Math.atan2(x[1],x[0]);h[0]<c[0]&&(L=Math.PI+L),i.rotation=L}var M=void 0;switch(i.__position){case"insideStartTop":case"insideMiddleTop":case"insideEndTop":case"middle":M=-f,y="bottom";break;case"insideStartBottom":case"insideMiddleBottom":case"insideEndBottom":M=f,y="top";break;default:M=0,y="middle"}switch(i.__position){case"end":i.x=d[0]*g+h[0],i.y=d[1]*f+h[1],p=d[0]>.8?"left":d[0]<-.8?"right":"center",y=d[1]>.8?"top":d[1]<-.8?"bottom":"middle";break;case"start":i.x=-d[0]*g+c[0],i.y=-d[1]*f+c[1],p=d[0]>.8?"right":d[0]<-.8?"left":"center",y=d[1]>.8?"bottom":d[1]<-.8?"top":"middle";break;case"insideStartTop":case"insideStart":case"insideStartBottom":i.x=g*T+c[0],i.y=c[1]+M,p=x[0]<0?"right":"left",i.originX=-g*T,i.originY=-M;break;case"insideMiddleTop":case"insideMiddle":case"insideMiddleBottom":case"middle":i.x=A[0],i.y=A[1]+M,p="center",i.originY=-M;break;case"insideEndTop":case"insideEnd":case"insideEndBottom":i.x=-g*T+h[0],i.y=h[1]+M,p=x[0]>=0?"right":"left",i.originX=g*T,i.originY=-M;break}i.scaleX=i.scaleY=o,i.setStyle({verticalAlign:i.__verticalAlign||y,align:i.__align||p})}},e}(Wt),ix=function(){function r(e){this.group=new Wt,this._LineCtor=e||ax}return r.prototype.updateData=function(e){var t=this;this._progressiveEls=null;var n=this,a=n.group,i=n._lineData;n._lineData=e,i||a.removeAll();var o=GL(e);e.diff(i).add(function(s){t._doAdd(e,s,o)}).update(function(s,l){t._doUpdate(i,e,l,s,o)}).remove(function(s){a.remove(i.getItemGraphicEl(s))}).execute()},r.prototype.updateLayout=function(){var e=this._lineData;e&&e.eachItemGraphicEl(function(t,n){t.updateLayout(e,n)},this)},r.prototype.incrementalPrepareUpdate=function(e){this._seriesScope=GL(e),this._lineData=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(e,t){this._progressiveEls=[];function n(s){!s.isGroup&&!iK(s)&&(s.incremental=!0,s.ensureState("emphasis").hoverLayer=!0)}for(var a=e.start;a<e.end;a++){var i=t.getItemLayout(a);if(Xm(i)){var o=new this._LineCtor(t,a,this._seriesScope);o.traverse(n),this.group.add(o),t.setItemGraphicEl(a,o),this._progressiveEls.push(o)}}},r.prototype.remove=function(){this.group.removeAll()},r.prototype.eachRendered=function(e){Co(this._progressiveEls||this.group,e)},r.prototype._doAdd=function(e,t,n){var a=e.getItemLayout(t);if(Xm(a)){var i=new this._LineCtor(e,t,n);e.setItemGraphicEl(t,i),this.group.add(i)}},r.prototype._doUpdate=function(e,t,n,a,i){var o=e.getItemGraphicEl(n);if(!Xm(t.getItemLayout(a))){this.group.remove(o);return}o?o.updateData(t,a,i):o=new this._LineCtor(t,a,i),t.setItemGraphicEl(a,o),this.group.add(o)},r}();function iK(r){return r.animators&&r.animators.length>0}function GL(r){var e=r.hostModel,t=e.getModel("emphasis");return{lineStyle:e.getModel("lineStyle").getLineStyle(),emphasisLineStyle:t.getModel(["lineStyle"]).getLineStyle(),blurLineStyle:e.getModel(["blur","lineStyle"]).getLineStyle(),selectLineStyle:e.getModel(["select","lineStyle"]).getLineStyle(),emphasisDisabled:t.get("disabled"),blurScope:t.get("blurScope"),focus:t.get("focus"),labelStatesModels:_r(e)}}function WL(r){return isNaN(r[0])||isNaN(r[1])}function Xm(r){return r&&!WL(r[0])&&!WL(r[1])}var $m=[],jm=[],qm=[],Ll=Sr,Km=Cs,HL=Math.abs;function UL(r,e,t){for(var n=r[0],a=r[1],i=r[2],o=1/0,s,l=t*t,u=.1,c=.1;c<=.9;c+=.1){$m[0]=Ll(n[0],a[0],i[0],c),$m[1]=Ll(n[1],a[1],i[1],c);var h=HL(Km($m,e)-l);h<o&&(o=h,s=c)}for(var d=0;d<32;d++){var v=s+u;jm[0]=Ll(n[0],a[0],i[0],s),jm[1]=Ll(n[1],a[1],i[1],s),qm[0]=Ll(n[0],a[0],i[0],v),qm[1]=Ll(n[1],a[1],i[1],v);var h=Km(jm,e)-l;if(HL(h)<.01)break;var p=Km(qm,e)-l;u/=2,h<0?p>=0?s=s+u:s=s-u:p>=0?s=s-u:s=s+u}return s}function Qm(r,e){var t=[],n=jc,a=[[],[],[]],i=[[],[]],o=[];e/=2,r.eachEdge(function(s,l){var u=s.getLayout(),c=s.getVisual("fromSymbol"),h=s.getVisual("toSymbol");u.__original||(u.__original=[mi(u[0]),mi(u[1])],u[2]&&u.__original.push(mi(u[2])));var d=u.__original;if(u[2]!=null){if(Xr(a[0],d[0]),Xr(a[1],d[2]),Xr(a[2],d[1]),c&&c!=="none"){var v=Dc(s.node1),p=UL(a,d[0],v*e);n(a[0][0],a[1][0],a[2][0],p,t),a[0][0]=t[3],a[1][0]=t[4],n(a[0][1],a[1][1],a[2][1],p,t),a[0][1]=t[3],a[1][1]=t[4]}if(h&&h!=="none"){var v=Dc(s.node2),p=UL(a,d[1],v*e);n(a[0][0],a[1][0],a[2][0],p,t),a[1][0]=t[1],a[2][0]=t[2],n(a[0][1],a[1][1],a[2][1],p,t),a[1][1]=t[1],a[2][1]=t[2]}Xr(u[0],a[0]),Xr(u[1],a[2]),Xr(u[2],a[1])}else{if(Xr(i[0],d[0]),Xr(i[1],d[1]),ms(o,i[1],i[0]),uu(o,o),c&&c!=="none"){var v=Dc(s.node1);U0(i[0],i[0],o,v*e)}if(h&&h!=="none"){var v=Dc(s.node2);U0(i[1],i[1],o,-v*e)}Xr(u[0],i[0]),Xr(u[1],i[1])}})}function ZL(r){return r.type==="view"}var oK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n){var a=new zh,i=new ix,o=this.group;this._controller=new Hh(n.getZr()),this._controllerHost={target:o},o.add(a.group),o.add(i.group),this._symbolDraw=a,this._lineDraw=i,this._firstRender=!0},e.prototype.render=function(t,n,a){var i=this,o=t.coordinateSystem;this._model=t;var s=this._symbolDraw,l=this._lineDraw,u=this.group;if(ZL(o)){var c={x:o.x,y:o.y,scaleX:o.scaleX,scaleY:o.scaleY};this._firstRender?u.attr(c):_e(u,c,t)}Qm(t.getGraph(),Mc(t));var h=t.getData();s.updateData(h);var d=t.getEdgeData();l.updateData(d),this._updateNodeAndLinkScale(),this._updateController(t,n,a),clearTimeout(this._layoutTimeout);var v=t.forceLayout,p=t.get(["force","layoutAnimation"]);v&&this._startForceLayoutIteration(v,p);var y=t.get("layout");h.graph.eachNode(function(w){var x=w.dataIndex,S=w.getGraphicEl(),A=w.getModel();if(S){S.off("drag").off("dragend");var T=A.get("draggable");T&&S.on("drag",function(M){switch(y){case"force":v.warmUp(),!i._layouting&&i._startForceLayoutIteration(v,p),v.setFixed(x),h.setItemLayout(x,[S.x,S.y]);break;case"circular":h.setItemLayout(x,[S.x,S.y]),w.setLayout({fixed:!0},!0),nx(t,"symbolSize",w,[M.offsetX,M.offsetY]),i.updateLayout(t);break;case"none":default:h.setItemLayout(x,[S.x,S.y]),rx(t.getGraph(),t),i.updateLayout(t);break}}).on("dragend",function(){v&&v.setUnfixed(x)}),S.setDraggable(T,!!A.get("cursor"));var L=A.get(["emphasis","focus"]);L==="adjacency"&&(Ht(S).focus=w.getAdjacentDataIndices())}}),h.graph.eachEdge(function(w){var x=w.getGraphicEl(),S=w.getModel().get(["emphasis","focus"]);x&&S==="adjacency"&&(Ht(x).focus={edge:[w.dataIndex],node:[w.node1.dataIndex,w.node2.dataIndex]})});var _=t.get("layout")==="circular"&&t.get(["circular","rotateLabel"]),g=h.getLayout("cx"),f=h.getLayout("cy");h.graph.eachNode(function(w){I5(w,_,g,f)}),this._firstRender=!1},e.prototype.dispose=function(){this.remove(),this._controller&&this._controller.dispose(),this._controllerHost=null},e.prototype._startForceLayoutIteration=function(t,n){var a=this;(function i(){t.step(function(o){a.updateLayout(a._model),(a._layouting=!o)&&(n?a._layoutTimeout=setTimeout(i,16):i())})})()},e.prototype._updateController=function(t,n,a){var i=this,o=this._controller,s=this._controllerHost,l=this.group;if(o.setPointerChecker(function(u,c,h){var d=l.getBoundingRect();return d.applyTransform(l.transform),d.contain(c,h)&&!Up(u,a,t)}),!ZL(t.coordinateSystem)){o.disable();return}o.enable(t.get("roam")),s.zoomLimit=t.get("scaleLimit"),s.zoom=t.coordinateSystem.getZoom(),o.off("pan").off("zoom").on("pan",function(u){Xw(s,u.dx,u.dy),a.dispatchAction({seriesId:t.id,type:"graphRoam",dx:u.dx,dy:u.dy})}).on("zoom",function(u){$w(s,u.scale,u.originX,u.originY),a.dispatchAction({seriesId:t.id,type:"graphRoam",zoom:u.scale,originX:u.originX,originY:u.originY}),i._updateNodeAndLinkScale(),Qm(t.getGraph(),Mc(t)),i._lineDraw.updateLayout(),a.updateLabelLayout()})},e.prototype._updateNodeAndLinkScale=function(){var t=this._model,n=t.getData(),a=Mc(t);n.eachItemGraphicEl(function(i,o){i&&i.setSymbolScale(a)})},e.prototype.updateLayout=function(t){Qm(t.getGraph(),Mc(t)),this._symbolDraw.updateLayout(),this._lineDraw.updateLayout()},e.prototype.remove=function(){clearTimeout(this._layoutTimeout),this._layouting=!1,this._layoutTimeout=null,this._symbolDraw&&this._symbolDraw.remove(),this._lineDraw&&this._lineDraw.remove()},e.type="graph",e}(Re);function Ml(r){return"_EC_"+r}var sK=function(){function r(e){this.type="graph",this.nodes=[],this.edges=[],this._nodesMap={},this._edgesMap={},this._directed=e||!1}return r.prototype.isDirected=function(){return this._directed},r.prototype.addNode=function(e,t){e=e==null?""+t:""+e;var n=this._nodesMap;if(!n[Ml(e)]){var a=new fs(e,t);return a.hostGraph=this,this.nodes.push(a),n[Ml(e)]=a,a}},r.prototype.getNodeByIndex=function(e){var t=this.data.getRawIndex(e);return this.nodes[t]},r.prototype.getNodeById=function(e){return this._nodesMap[Ml(e)]},r.prototype.addEdge=function(e,t,n){var a=this._nodesMap,i=this._edgesMap;if(ye(e)&&(e=this.nodes[e]),ye(t)&&(t=this.nodes[t]),e instanceof fs||(e=a[Ml(e)]),t instanceof fs||(t=a[Ml(t)]),!(!e||!t)){var o=e.id+"-"+t.id,s=new k5(e,t,n);return s.hostGraph=this,this._directed&&(e.outEdges.push(s),t.inEdges.push(s)),e.edges.push(s),e!==t&&t.edges.push(s),this.edges.push(s),i[o]=s,s}},r.prototype.getEdgeByIndex=function(e){var t=this.edgeData.getRawIndex(e);return this.edges[t]},r.prototype.getEdge=function(e,t){e instanceof fs&&(e=e.id),t instanceof fs&&(t=t.id);var n=this._edgesMap;return this._directed?n[e+"-"+t]:n[e+"-"+t]||n[t+"-"+e]},r.prototype.eachNode=function(e,t){for(var n=this.nodes,a=n.length,i=0;i<a;i++)n[i].dataIndex>=0&&e.call(t,n[i],i)},r.prototype.eachEdge=function(e,t){for(var n=this.edges,a=n.length,i=0;i<a;i++)n[i].dataIndex>=0&&n[i].node1.dataIndex>=0&&n[i].node2.dataIndex>=0&&e.call(t,n[i],i)},r.prototype.breadthFirstTraverse=function(e,t,n,a){if(t instanceof fs||(t=this._nodesMap[Ml(t)]),!!t){for(var i=n==="out"?"outEdges":n==="in"?"inEdges":"edges",o=0;o<this.nodes.length;o++)this.nodes[o].__visited=!1;if(!e.call(a,t,null))for(var s=[t];s.length;)for(var l=s.shift(),u=l[i],o=0;o<u.length;o++){var c=u[o],h=c.node1===l?c.node2:c.node1;if(!h.__visited){if(e.call(a,h,l))return;s.push(h),h.__visited=!0}}}},r.prototype.update=function(){for(var e=this.data,t=this.edgeData,n=this.nodes,a=this.edges,i=0,o=n.length;i<o;i++)n[i].dataIndex=-1;for(var i=0,o=e.count();i<o;i++)n[e.getRawIndex(i)].dataIndex=i;t.filterSelf(function(s){var l=a[t.getRawIndex(s)];return l.node1.dataIndex>=0&&l.node2.dataIndex>=0});for(var i=0,o=a.length;i<o;i++)a[i].dataIndex=-1;for(var i=0,o=t.count();i<o;i++)a[t.getRawIndex(i)].dataIndex=i},r.prototype.clone=function(){for(var e=new r(this._directed),t=this.nodes,n=this.edges,a=0;a<t.length;a++)e.addNode(t[a].id,t[a].dataIndex);for(var a=0;a<n.length;a++){var i=n[a];e.addEdge(i.node1.id,i.node2.id,i.dataIndex)}return e},r}(),fs=function(){function r(e,t){this.inEdges=[],this.outEdges=[],this.edges=[],this.dataIndex=-1,this.id=e??"",this.dataIndex=t??-1}return r.prototype.degree=function(){return this.edges.length},r.prototype.inDegree=function(){return this.inEdges.length},r.prototype.outDegree=function(){return this.outEdges.length},r.prototype.getModel=function(e){if(!(this.dataIndex<0)){var t=this.hostGraph,n=t.data.getItemModel(this.dataIndex);return n.getModel(e)}},r.prototype.getAdjacentDataIndices=function(){for(var e={edge:[],node:[]},t=0;t<this.edges.length;t++){var n=this.edges[t];n.dataIndex<0||(e.edge.push(n.dataIndex),e.node.push(n.node1.dataIndex,n.node2.dataIndex))}return e},r.prototype.getTrajectoryDataIndices=function(){for(var e=Pt(),t=Pt(),n=0;n<this.edges.length;n++){var a=this.edges[n];if(!(a.dataIndex<0)){e.set(a.dataIndex,!0);for(var i=[a.node1],o=[a.node2],s=0;s<i.length;){var l=i[s];s++,t.set(l.dataIndex,!0);for(var u=0;u<l.inEdges.length;u++)e.set(l.inEdges[u].dataIndex,!0),i.push(l.inEdges[u].node1)}for(s=0;s<o.length;){var c=o[s];s++,t.set(c.dataIndex,!0);for(var u=0;u<c.outEdges.length;u++)e.set(c.outEdges[u].dataIndex,!0),o.push(c.outEdges[u].node2)}}}return{edge:e.keys(),node:t.keys()}},r}(),k5=function(){function r(e,t,n){this.dataIndex=-1,this.node1=e,this.node2=t,this.dataIndex=n??-1}return r.prototype.getModel=function(e){if(!(this.dataIndex<0)){var t=this.hostGraph,n=t.edgeData.getItemModel(this.dataIndex);return n.getModel(e)}},r.prototype.getAdjacentDataIndices=function(){return{edge:[this.dataIndex],node:[this.node1.dataIndex,this.node2.dataIndex]}},r.prototype.getTrajectoryDataIndices=function(){var e=Pt(),t=Pt();e.set(this.dataIndex,!0);for(var n=[this.node1],a=[this.node2],i=0;i<n.length;){var o=n[i];i++,t.set(o.dataIndex,!0);for(var s=0;s<o.inEdges.length;s++)e.set(o.inEdges[s].dataIndex,!0),n.push(o.inEdges[s].node1)}for(i=0;i<a.length;){var l=a[i];i++,t.set(l.dataIndex,!0);for(var s=0;s<l.outEdges.length;s++)e.set(l.outEdges[s].dataIndex,!0),a.push(l.outEdges[s].node2)}return{edge:e.keys(),node:t.keys()}},r}();function R5(r,e){return{getValue:function(t){var n=this[r][e];return n.getStore().get(n.getDimensionIndex(t||"value"),this.dataIndex)},setVisual:function(t,n){this.dataIndex>=0&&this[r][e].setItemVisual(this.dataIndex,t,n)},getVisual:function(t){return this[r][e].getItemVisual(this.dataIndex,t)},setLayout:function(t,n){this.dataIndex>=0&&this[r][e].setItemLayout(this.dataIndex,t,n)},getLayout:function(){return this[r][e].getItemLayout(this.dataIndex)},getGraphicEl:function(){return this[r][e].getItemGraphicEl(this.dataIndex)},getRawIndex:function(){return this[r][e].getRawIndex(this.dataIndex)}}}sr(fs,R5("hostGraph","data"));sr(k5,R5("hostGraph","edgeData"));function E5(r,e,t,n,a){for(var i=new sK(n),o=0;o<r.length;o++)i.addNode(Ar(r[o].id,r[o].name,o),o);for(var s=[],l=[],u=0,o=0;o<e.length;o++){var c=e[o],h=c.source,d=c.target;i.addEdge(h,d,u)&&(l.push(c),s.push(Ar(ur(c.id,null),h+" > "+d)),u++)}var v=t.get("coordinateSystem"),p;if(v==="cartesian2d"||v==="polar")p=Ri(r,t);else{var y=Rh.get(v),_=y?y.dimensions||[]:[];te(_,"value")<0&&_.concat(["value"]);var g=Oh(r,{coordDimensions:_,encodeDefine:t.getEncode()}).dimensions;p=new Kr(g,t),p.initData(r)}var f=new Kr(["value"],t);return f.initData(l,s),a&&a(p,f),p5({mainData:p,struct:i,structAttr:"graph",datas:{node:p,edge:f},datasAttr:{node:"data",edge:"edgeData"}}),i.update(),i}var lK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments);var n=this;function a(){return n._categoriesData}this.legendVisualProvider=new Wh(a,a),this.fillDataTextStyle(t.edges||t.links),this._updateCategoriesData()},e.prototype.mergeOption=function(t){r.prototype.mergeOption.apply(this,arguments),this.fillDataTextStyle(t.edges||t.links),this._updateCategoriesData()},e.prototype.mergeDefaultAndTheme=function(t){r.prototype.mergeDefaultAndTheme.apply(this,arguments),Os(t,"edgeLabel",["show"])},e.prototype.getInitialData=function(t,n){var a=t.edges||t.links||[],i=t.data||t.nodes||[],o=this;if(i&&a){$q(this);var s=E5(i,a,this,!0,l);return B(s.edges,function(u){jq(u.node1,u.node2,this,u.dataIndex)},this),s.data}function l(u,c){u.wrapMethod("getItemModel",function(p){var y=o._categoriesModels,_=p.getShallow("category"),g=y[_];return g&&(g.parentModel=p.parentModel,p.parentModel=g),p});var h=De.prototype.getModel;function d(p,y){var _=h.call(this,p,y);return _.resolveParentPath=v,_}c.wrapMethod("getItemModel",function(p){return p.resolveParentPath=v,p.getModel=d,p});function v(p){if(p&&(p[0]==="label"||p[1]==="label")){var y=p.slice();return p[0]==="label"?y[0]="edgeLabel":p[1]==="label"&&(y[1]="edgeLabel"),y}return p}}},e.prototype.getGraph=function(){return this.getData().graph},e.prototype.getEdgeData=function(){return this.getGraph().edgeData},e.prototype.getCategoriesData=function(){return this._categoriesData},e.prototype.formatTooltip=function(t,n,a){if(a==="edge"){var i=this.getData(),o=this.getDataParams(t,a),s=i.graph.getEdgeByIndex(t),l=i.getName(s.node1.dataIndex),u=i.getName(s.node2.dataIndex),c=[];return l!=null&&c.push(l),u!=null&&c.push(u),wr("nameValue",{name:c.join(" > "),value:o.value,noValue:o.value==null})}var h=aR({series:this,dataIndex:t,multipleSeries:n});return h},e.prototype._updateCategoriesData=function(){var t=ft(this.option.categories||[],function(a){return a.value!=null?a:lt({value:0},a)}),n=new Kr(["value"],this);n.initData(t),this._categoriesData=n,this._categoriesModels=n.mapArray(function(a){return n.getItemModel(a)})},e.prototype.setZoom=function(t){this.option.zoom=t},e.prototype.setCenter=function(t){this.option.center=t},e.prototype.isAnimationEnabled=function(){return r.prototype.isAnimationEnabled.call(this)&&!(this.get("layout")==="force"&&this.get(["force","layoutAnimation"]))},e.type="series.graph",e.dependencies=["grid","polar","geo","singleAxis","calendar"],e.defaultOption={z:2,coordinateSystem:"view",legendHoverLink:!0,layout:null,circular:{rotateLabel:!1},force:{initLayout:null,repulsion:[0,50],gravity:.1,friction:.6,edgeLength:30,layoutAnimation:!0},left:"center",top:"center",symbol:"circle",symbolSize:10,edgeSymbol:["none","none"],edgeSymbolSize:10,edgeLabel:{position:"middle",distance:5},draggable:!1,roam:!1,center:null,zoom:1,nodeScaleRatio:.6,label:{show:!1,formatter:"{b}"},itemStyle:{},lineStyle:{color:"#aaa",width:1,opacity:.5},emphasis:{scale:!0,label:{show:!0}},select:{itemStyle:{borderColor:"#212121"}}},e}(Ve),uK={type:"graphRoam",event:"graphRoam",update:"none"};function cK(r){r.registerChartView(oK),r.registerSeriesModel(lK),r.registerProcessor(Hq),r.registerVisual(Uq),r.registerVisual(Zq),r.registerLayout(qq),r.registerLayout(r.PRIORITY.VISUAL.POST_CHART_LAYOUT,Qq),r.registerLayout(tK),r.registerCoordinateSystem("graphView",{dimensions:Uh.dimensions,create:rK}),r.registerAction({type:"focusNodeAdjacency",event:"focusNodeAdjacency",update:"series:focusNodeAdjacency"},tr),r.registerAction({type:"unfocusNodeAdjacency",event:"unfocusNodeAdjacency",update:"series:unfocusNodeAdjacency"},tr),r.registerAction(uK,function(e,t,n){t.eachComponent({mainType:"series",query:e},function(a){var i=a.coordinateSystem,o=qw(i,e,void 0,n);a.setCenter&&a.setCenter(o.center),a.setZoom&&a.setZoom(o.zoom)})})}var hK=function(){function r(){this.angle=0,this.width=10,this.r=10,this.x=0,this.y=0}return r}(),fK=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="pointer",n}return e.prototype.getDefaultShape=function(){return new hK},e.prototype.buildPath=function(t,n){var a=Math.cos,i=Math.sin,o=n.r,s=n.width,l=n.angle,u=n.x-a(l)*s*(s>=o/3?1:2),c=n.y-i(l)*s*(s>=o/3?1:2);l=n.angle-Math.PI/2,t.moveTo(u,c),t.lineTo(n.x+a(l)*s,n.y+i(l)*s),t.lineTo(n.x+a(n.angle)*o,n.y+i(n.angle)*o),t.lineTo(n.x-a(l)*s,n.y-i(l)*s),t.lineTo(u,c)},e}(ie);function vK(r,e){var t=r.get("center"),n=e.getWidth(),a=e.getHeight(),i=Math.min(n,a),o=At(t[0],e.getWidth()),s=At(t[1],e.getHeight()),l=At(r.get("radius"),i/2);return{cx:o,cy:s,r:l}}function Pv(r,e){var t=r==null?"":r+"";return e&&(Lt(e)?t=e.replace("{value}",t):Nt(e)&&(t=e(r))),t}var dK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){this.group.removeAll();var i=t.get(["axisLine","lineStyle","color"]),o=vK(t,a);this._renderMain(t,n,a,i,o),this._data=t.getData()},e.prototype.dispose=function(){},e.prototype._renderMain=function(t,n,a,i,o){var s=this.group,l=t.get("clockwise"),u=-t.get("startAngle")/180*Math.PI,c=-t.get("endAngle")/180*Math.PI,h=t.getModel("axisLine"),d=h.get("roundCap"),v=d?Wd:en,p=h.get("show"),y=h.getModel("lineStyle"),_=y.get("width"),g=[u,c];Q1(g,!l),u=g[0],c=g[1];for(var f=c-u,w=u,x=[],S=0;p&&S<i.length;S++){var A=Math.min(Math.max(i[S][0],0),1);c=u+f*A;var T=new v({shape:{startAngle:w,endAngle:c,cx:o.cx,cy:o.cy,clockwise:l,r0:o.r-_,r:o.r},silent:!0});T.setStyle({fill:i[S][1]}),T.setStyle(y.getLineStyle(["color","width"])),x.push(T),w=c}x.reverse(),B(x,function(M){return s.add(M)});var L=function(M){if(M<=0)return i[0][1];var I;for(I=0;I<i.length;I++)if(i[I][0]>=M&&(I===0?0:i[I-1][0])<M)return i[I][1];return i[I-1][1]};this._renderTicks(t,n,a,L,o,u,c,l,_),this._renderTitleAndDetail(t,n,a,L,o),this._renderAnchor(t,o),this._renderPointer(t,n,a,L,o,u,c,l,_)},e.prototype._renderTicks=function(t,n,a,i,o,s,l,u,c){for(var h=this.group,d=o.cx,v=o.cy,p=o.r,y=+t.get("min"),_=+t.get("max"),g=t.getModel("splitLine"),f=t.getModel("axisTick"),w=t.getModel("axisLabel"),x=t.get("splitNumber"),S=f.get("splitNumber"),A=At(g.get("length"),p),T=At(f.get("length"),p),L=s,M=(l-s)/x,I=M/S,R=g.getModel("lineStyle").getLineStyle(),P=f.getModel("lineStyle").getLineStyle(),E=g.get("distance"),D,N,V=0;V<=x;V++){if(D=Math.cos(L),N=Math.sin(L),g.get("show")){var W=E?E+c:c,$=new gr({shape:{x1:D*(p-W)+d,y1:N*(p-W)+v,x2:D*(p-A-W)+d,y2:N*(p-A-W)+v},style:R,silent:!0});R.stroke==="auto"&&$.setStyle({stroke:i(V/x)}),h.add($)}if(w.get("show")){var W=w.get("distance")+E,H=Pv(qe(V/x*(_-y)+y),w.get("formatter")),K=i(V/x),U=D*(p-A-W)+d,j=N*(p-A-W)+v,ut=w.get("rotate"),ot=0;ut==="radial"?(ot=-L+2*Math.PI,ot>Math.PI/2&&(ot+=Math.PI)):ut==="tangential"?ot=-L-Math.PI/2:ye(ut)&&(ot=ut*Math.PI/180),ot===0?h.add(new pe({style:Fe(w,{text:H,x:U,y:j,verticalAlign:N<-.8?"top":N>.8?"bottom":"middle",align:D<-.4?"left":D>.4?"right":"center"},{inheritColor:K}),silent:!0})):h.add(new pe({style:Fe(w,{text:H,x:U,y:j,verticalAlign:"middle",align:"center"},{inheritColor:K}),silent:!0,originX:U,originY:j,rotation:ot}))}if(f.get("show")&&V!==x){var W=f.get("distance");W=W?W+c:c;for(var it=0;it<=S;it++){D=Math.cos(L),N=Math.sin(L);var Et=new gr({shape:{x1:D*(p-W)+d,y1:N*(p-W)+v,x2:D*(p-T-W)+d,y2:N*(p-T-W)+v},silent:!0,style:P});P.stroke==="auto"&&Et.setStyle({stroke:i((V+it/S)/x)}),h.add(Et),L+=I}L-=I}else L+=M}},e.prototype._renderPointer=function(t,n,a,i,o,s,l,u,c){var h=this.group,d=this._data,v=this._progressEls,p=[],y=t.get(["pointer","show"]),_=t.getModel("progress"),g=_.get("show"),f=t.getData(),w=f.mapDimension("value"),x=+t.get("min"),S=+t.get("max"),A=[x,S],T=[s,l];function L(I,R){var P=f.getItemModel(I),E=P.getModel("pointer"),D=At(E.get("width"),o.r),N=At(E.get("length"),o.r),V=t.get(["pointer","icon"]),W=E.get("offsetCenter"),$=At(W[0],o.r),H=At(W[1],o.r),K=E.get("keepAspect"),U;return V?U=or(V,$-D/2,H-N,D,N,null,K):U=new fK({shape:{angle:-Math.PI/2,width:D,r:N,x:$,y:H}}),U.rotation=-(R+Math.PI/2),U.x=o.cx,U.y=o.cy,U}function M(I,R){var P=_.get("roundCap"),E=P?Wd:en,D=_.get("overlap"),N=D?_.get("width"):c/f.count(),V=D?o.r-N:o.r-(I+1)*N,W=D?o.r:o.r-I*N,$=new E({shape:{startAngle:s,endAngle:R,cx:o.cx,cy:o.cy,clockwise:u,r0:V,r:W}});return D&&($.z2=Me(f.get(w,I),[x,S],[100,0],!0)),$}(g||y)&&(f.diff(d).add(function(I){var R=f.get(w,I);if(y){var P=L(I,s);He(P,{rotation:-((isNaN(+R)?T[0]:Me(R,A,T,!0))+Math.PI/2)},t),h.add(P),f.setItemGraphicEl(I,P)}if(g){var E=M(I,s),D=_.get("clip");He(E,{shape:{endAngle:Me(R,A,T,D)}},t),h.add(E),g_(t.seriesIndex,f.dataType,I,E),p[I]=E}}).update(function(I,R){var P=f.get(w,I);if(y){var E=d.getItemGraphicEl(R),D=E?E.rotation:s,N=L(I,D);N.rotation=D,_e(N,{rotation:-((isNaN(+P)?T[0]:Me(P,A,T,!0))+Math.PI/2)},t),h.add(N),f.setItemGraphicEl(I,N)}if(g){var V=v[R],W=V?V.shape.endAngle:s,$=M(I,W),H=_.get("clip");_e($,{shape:{endAngle:Me(P,A,T,H)}},t),h.add($),g_(t.seriesIndex,f.dataType,I,$),p[I]=$}}).execute(),f.each(function(I){var R=f.getItemModel(I),P=R.getModel("emphasis"),E=P.get("focus"),D=P.get("blurScope"),N=P.get("disabled");if(y){var V=f.getItemGraphicEl(I),W=f.getItemVisual(I,"style"),$=W.fill;if(V instanceof Tr){var H=V.style;V.useStyle(lt({image:H.image,x:H.x,y:H.y,width:H.width,height:H.height},W))}else V.useStyle(W),V.type!=="pointer"&&V.setColor($);V.setStyle(R.getModel(["pointer","itemStyle"]).getItemStyle()),V.style.fill==="auto"&&V.setStyle("fill",i(Me(f.get(w,I),A,[0,1],!0))),V.z2EmphasisLift=0,kr(V,R),Xe(V,E,D,N)}if(g){var K=p[I];K.useStyle(f.getItemVisual(I,"style")),K.setStyle(R.getModel(["progress","itemStyle"]).getItemStyle()),K.z2EmphasisLift=0,kr(K,R),Xe(K,E,D,N)}}),this._progressEls=p)},e.prototype._renderAnchor=function(t,n){var a=t.getModel("anchor"),i=a.get("show");if(i){var o=a.get("size"),s=a.get("icon"),l=a.get("offsetCenter"),u=a.get("keepAspect"),c=or(s,n.cx-o/2+At(l[0],n.r),n.cy-o/2+At(l[1],n.r),o,o,null,u);c.z2=a.get("showAbove")?1:0,c.setStyle(a.getModel("itemStyle").getItemStyle()),this.group.add(c)}},e.prototype._renderTitleAndDetail=function(t,n,a,i,o){var s=this,l=t.getData(),u=l.mapDimension("value"),c=+t.get("min"),h=+t.get("max"),d=new Wt,v=[],p=[],y=t.isAnimationEnabled(),_=t.get(["pointer","showAbove"]);l.diff(this._data).add(function(g){v[g]=new pe({silent:!0}),p[g]=new pe({silent:!0})}).update(function(g,f){v[g]=s._titleEls[f],p[g]=s._detailEls[f]}).execute(),l.each(function(g){var f=l.getItemModel(g),w=l.get(u,g),x=new Wt,S=i(Me(w,[c,h],[0,1],!0)),A=f.getModel("title");if(A.get("show")){var T=A.get("offsetCenter"),L=o.cx+At(T[0],o.r),M=o.cy+At(T[1],o.r),I=v[g];I.attr({z2:_?0:2,style:Fe(A,{x:L,y:M,text:l.getName(g),align:"center",verticalAlign:"middle"},{inheritColor:S})}),x.add(I)}var R=f.getModel("detail");if(R.get("show")){var P=R.get("offsetCenter"),E=o.cx+At(P[0],o.r),D=o.cy+At(P[1],o.r),N=At(R.get("width"),o.r),V=At(R.get("height"),o.r),W=t.get(["progress","show"])?l.getItemVisual(g,"style").fill:S,I=p[g],$=R.get("formatter");I.attr({z2:_?0:2,style:Fe(R,{x:E,y:D,text:Pv(w,$),width:isNaN(N)?null:N,height:isNaN(V)?null:V,align:"center",verticalAlign:"middle"},{inheritColor:W})}),lk(I,{normal:R},w,function(K){return Pv(K,$)}),y&&uk(I,g,l,t,{getFormattedLabel:function(K,U,j,ut,ot,it){return Pv(it?it.interpolatedValue:w,$)}}),x.add(I)}d.add(x)}),this.group.add(d),this._titleEls=v,this._detailEls=p},e.type="gauge",e}(Re),pK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.visualStyleAccessPath="itemStyle",t}return e.prototype.getInitialData=function(t,n){return Su(this,["value"])},e.type="series.gauge",e.defaultOption={z:2,colorBy:"data",center:["50%","50%"],legendHoverLink:!0,radius:"75%",startAngle:225,endAngle:-45,clockwise:!0,min:0,max:100,splitNumber:10,axisLine:{show:!0,roundCap:!1,lineStyle:{color:[[1,"#E6EBF8"]],width:10}},progress:{show:!1,overlap:!0,width:10,roundCap:!1,clip:!0},splitLine:{show:!0,length:10,distance:10,lineStyle:{color:"#63677A",width:3,type:"solid"}},axisTick:{show:!0,splitNumber:5,length:6,distance:10,lineStyle:{color:"#63677A",width:1,type:"solid"}},axisLabel:{show:!0,distance:15,color:"#464646",fontSize:12,rotate:0},pointer:{icon:null,offsetCenter:[0,0],show:!0,showAbove:!0,length:"60%",width:6,keepAspect:!1},anchor:{show:!1,showAbove:!1,size:6,icon:"circle",offsetCenter:[0,0],keepAspect:!1,itemStyle:{color:"#fff",borderWidth:0,borderColor:"#5470c6"}},title:{show:!0,offsetCenter:[0,"20%"],color:"#464646",fontSize:16,valueAnimation:!1},detail:{show:!0,backgroundColor:"rgba(0,0,0,0)",borderWidth:0,borderColor:"#ccc",width:100,height:null,padding:[5,10],offsetCenter:[0,"40%"],color:"#464646",fontSize:30,fontWeight:"bold",lineHeight:30,valueAnimation:!1}},e}(Ve);function gK(r){r.registerChartView(dK),r.registerSeriesModel(pK)}var yK=["itemStyle","opacity"],mK=function(r){rt(e,r);function e(t,n){var a=r.call(this)||this,i=a,o=new nn,s=new pe;return i.setTextContent(s),a.setTextGuideLine(o),a.updateData(t,n,!0),a}return e.prototype.updateData=function(t,n,a){var i=this,o=t.hostModel,s=t.getItemModel(n),l=t.getItemLayout(n),u=s.getModel("emphasis"),c=s.get(yK);c=c??1,a||xa(i),i.useStyle(t.getItemVisual(n,"style")),i.style.lineJoin="round",a?(i.setShape({points:l.points}),i.style.opacity=0,He(i,{style:{opacity:c}},o,n)):_e(i,{style:{opacity:c},shape:{points:l.points}},o,n),kr(i,s),this._updateLabel(t,n),Xe(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},e.prototype._updateLabel=function(t,n){var a=this,i=this.getTextGuideLine(),o=a.getTextContent(),s=t.hostModel,l=t.getItemModel(n),u=t.getItemLayout(n),c=u.label,h=t.getItemVisual(n,"style"),d=h.fill;Rr(o,_r(l),{labelFetcher:t.hostModel,labelDataIndex:n,defaultOpacity:h.opacity,defaultText:t.getName(n)},{normal:{align:c.textAlign,verticalAlign:c.verticalAlign}}),a.setTextConfig({local:!0,inside:!!c.inside,insideStroke:d,outsideFill:d});var v=c.linePoints;i.setShape({points:v}),a.textGuideLineConfig={anchor:v?new Kt(v[0][0],v[0][1]):null},_e(o,{style:{x:c.x,y:c.y}},s,n),o.attr({rotation:c.rotation,originX:c.x,originY:c.y,z2:10}),Bw(a,Nw(l),{stroke:d})},e}(rn),_K=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.ignoreLabelLineUpdate=!0,t}return e.prototype.render=function(t,n,a){var i=t.getData(),o=this._data,s=this.group;i.diff(o).add(function(l){var u=new mK(i,l);i.setItemGraphicEl(l,u),s.add(u)}).update(function(l,u){var c=o.getItemGraphicEl(u);c.updateData(i,l),s.add(c),i.setItemGraphicEl(l,c)}).remove(function(l){var u=o.getItemGraphicEl(l);rh(u,t,l)}).execute(),this._data=i},e.prototype.remove=function(){this.group.removeAll(),this._data=null},e.prototype.dispose=function(){},e.type="funnel",e}(Re),wK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Wh(Mt(this.getData,this),Mt(this.getRawData,this)),this._defaultLabelLine(t)},e.prototype.getInitialData=function(t,n){return Su(this,{coordDimensions:["value"],encodeDefaulter:Xt(pw,this)})},e.prototype._defaultLabelLine=function(t){Os(t,"labelLine",["show"]);var n=t.labelLine,a=t.emphasis.labelLine;n.show=n.show&&t.label.show,a.show=a.show&&t.emphasis.label.show},e.prototype.getDataParams=function(t){var n=this.getData(),a=r.prototype.getDataParams.call(this,t),i=n.mapDimension("value"),o=n.getSum(i);return a.percent=o?+(n.get(i,t)/o*100).toFixed(2):0,a.$vars.push("percent"),a},e.type="series.funnel",e.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",left:80,top:60,right:80,bottom:60,minSize:"0%",maxSize:"100%",sort:"descending",orient:"vertical",gap:0,funnelAlign:"center",label:{show:!0,position:"outer"},labelLine:{show:!0,length:20,lineStyle:{width:1}},itemStyle:{borderColor:"#fff",borderWidth:1},emphasis:{label:{show:!0}},select:{itemStyle:{borderColor:"#212121"}}},e}(Ve);function xK(r,e){return cr(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function bK(r,e){for(var t=r.mapDimension("value"),n=r.mapArray(t,function(l){return l}),a=[],i=e==="ascending",o=0,s=r.count();o<s;o++)a[o]=o;return Nt(e)?a.sort(e):e!=="none"&&a.sort(function(l,u){return i?n[l]-n[u]:n[u]-n[l]}),a}function SK(r){var e=r.hostModel,t=e.get("orient");r.each(function(n){var a=r.getItemModel(n),i=a.getModel("label"),o=i.get("position"),s=a.getModel("labelLine"),l=r.getItemLayout(n),u=l.points,c=o==="inner"||o==="inside"||o==="center"||o==="insideLeft"||o==="insideRight",h,d,v,p;if(c)o==="insideLeft"?(d=(u[0][0]+u[3][0])/2+5,v=(u[0][1]+u[3][1])/2,h="left"):o==="insideRight"?(d=(u[1][0]+u[2][0])/2-5,v=(u[1][1]+u[2][1])/2,h="right"):(d=(u[0][0]+u[1][0]+u[2][0]+u[3][0])/4,v=(u[0][1]+u[1][1]+u[2][1]+u[3][1])/4,h="center"),p=[[d,v],[d,v]];else{var y=void 0,_=void 0,g=void 0,f=void 0,w=s.get("length");o==="left"?(y=(u[3][0]+u[0][0])/2,_=(u[3][1]+u[0][1])/2,g=y-w,d=g-5,h="right"):o==="right"?(y=(u[1][0]+u[2][0])/2,_=(u[1][1]+u[2][1])/2,g=y+w,d=g+5,h="left"):o==="top"?(y=(u[3][0]+u[0][0])/2,_=(u[3][1]+u[0][1])/2,f=_-w,v=f-5,h="center"):o==="bottom"?(y=(u[1][0]+u[2][0])/2,_=(u[1][1]+u[2][1])/2,f=_+w,v=f+5,h="center"):o==="rightTop"?(y=t==="horizontal"?u[3][0]:u[1][0],_=t==="horizontal"?u[3][1]:u[1][1],t==="horizontal"?(f=_-w,v=f-5,h="center"):(g=y+w,d=g+5,h="top")):o==="rightBottom"?(y=u[2][0],_=u[2][1],t==="horizontal"?(f=_+w,v=f+5,h="center"):(g=y+w,d=g+5,h="bottom")):o==="leftTop"?(y=u[0][0],_=t==="horizontal"?u[0][1]:u[1][1],t==="horizontal"?(f=_-w,v=f-5,h="center"):(g=y-w,d=g-5,h="right")):o==="leftBottom"?(y=t==="horizontal"?u[1][0]:u[3][0],_=t==="horizontal"?u[1][1]:u[2][1],t==="horizontal"?(f=_+w,v=f+5,h="center"):(g=y-w,d=g-5,h="right")):(y=(u[1][0]+u[2][0])/2,_=(u[1][1]+u[2][1])/2,t==="horizontal"?(f=_+w,v=f+5,h="center"):(g=y+w,d=g+5,h="left")),t==="horizontal"?(g=y,d=g):(f=_,v=f),p=[[y,_],[g,f]]}l.label={linePoints:p,x:d,y:v,verticalAlign:"middle",textAlign:h,inside:c}})}function AK(r,e){r.eachSeriesByType("funnel",function(t){var n=t.getData(),a=n.mapDimension("value"),i=t.get("sort"),o=xK(t,e),s=t.get("orient"),l=o.width,u=o.height,c=bK(n,i),h=o.x,d=o.y,v=s==="horizontal"?[At(t.get("minSize"),u),At(t.get("maxSize"),u)]:[At(t.get("minSize"),l),At(t.get("maxSize"),l)],p=n.getDataExtent(a),y=t.get("min"),_=t.get("max");y==null&&(y=Math.min(p[0],0)),_==null&&(_=p[1]);var g=t.get("funnelAlign"),f=t.get("gap"),w=s==="horizontal"?l:u,x=(w-f*(n.count()-1))/n.count(),S=function(D,N){if(s==="horizontal"){var V=n.get(a,D)||0,W=Me(V,[y,_],v,!0),$=void 0;switch(g){case"top":$=d;break;case"center":$=d+(u-W)/2;break;case"bottom":$=d+(u-W);break}return[[N,$],[N,$+W]]}var H=n.get(a,D)||0,K=Me(H,[y,_],v,!0),U;switch(g){case"left":U=h;break;case"center":U=h+(l-K)/2;break;case"right":U=h+l-K;break}return[[U,N],[U+K,N]]};i==="ascending"&&(x=-x,f=-f,s==="horizontal"?h+=l:d+=u,c=c.reverse());for(var A=0;A<c.length;A++){var T=c[A],L=c[A+1],M=n.getItemModel(T);if(s==="horizontal"){var I=M.get(["itemStyle","width"]);I==null?I=x:(I=At(I,l),i==="ascending"&&(I=-I));var R=S(T,h),P=S(L,h+I);h+=I+f,n.setItemLayout(T,{points:R.concat(P.slice().reverse())})}else{var E=M.get(["itemStyle","height"]);E==null?E=x:(E=At(E,u),i==="ascending"&&(E=-E));var R=S(T,d),P=S(L,d+E);d+=E+f,n.setItemLayout(T,{points:R.concat(P.slice().reverse())})}}SK(n)})}function TK(r){r.registerChartView(_K),r.registerSeriesModel(wK),r.registerLayout(AK),r.registerProcessor(Gh("funnel"))}var CK=.3,LK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._dataGroup=new Wt,t._initialized=!1,t}return e.prototype.init=function(){this.group.add(this._dataGroup)},e.prototype.render=function(t,n,a,i){this._progressiveEls=null;var o=this._dataGroup,s=t.getData(),l=this._data,u=t.coordinateSystem,c=u.dimensions,h=XL(t);s.diff(l).add(d).update(v).remove(p).execute();function d(_){var g=YL(s,o,_,c,u);Jm(g,s,_,h)}function v(_,g){var f=l.getItemGraphicEl(g),w=O5(s,_,c,u);s.setItemGraphicEl(_,f),_e(f,{shape:{points:w}},t,_),xa(f),Jm(f,s,_,h)}function p(_){var g=l.getItemGraphicEl(_);o.remove(g)}if(!this._initialized){this._initialized=!0;var y=MK(u,t,function(){setTimeout(function(){o.removeClipPath()})});o.setClipPath(y)}this._data=s},e.prototype.incrementalPrepareRender=function(t,n,a){this._initialized=!0,this._data=null,this._dataGroup.removeAll()},e.prototype.incrementalRender=function(t,n,a){for(var i=n.getData(),o=n.coordinateSystem,s=o.dimensions,l=XL(n),u=this._progressiveEls=[],c=t.start;c<t.end;c++){var h=YL(i,this._dataGroup,c,s,o);h.incremental=!0,Jm(h,i,c,l),u.push(h)}},e.prototype.remove=function(){this._dataGroup&&this._dataGroup.removeAll(),this._data=null},e.type="parallel",e}(Re);function MK(r,e,t){var n=r.model,a=r.getRect(),i=new fe({shape:{x:a.x,y:a.y,width:a.width,height:a.height}}),o=n.get("layout")==="horizontal"?"width":"height";return i.setShape(o,0),He(i,{shape:{width:a.width,height:a.height}},e,t),i}function O5(r,e,t,n){for(var a=[],i=0;i<t.length;i++){var o=t[i],s=r.get(r.mapDimension(o),e);DK(s,n.getAxis(o).type)||a.push(n.dataToPoint(s,o))}return a}function YL(r,e,t,n,a){var i=O5(r,t,n,a),o=new nn({shape:{points:i},z2:10});return e.add(o),r.setItemGraphicEl(t,o),o}function XL(r){var e=r.get("smooth",!0);return e===!0&&(e=CK),e=Ai(e),Xc(e)&&(e=0),{smooth:e}}function Jm(r,e,t,n){r.useStyle(e.getItemVisual(t,"style")),r.style.fill=null,r.setShape("smooth",n.smooth);var a=e.getItemModel(t),i=a.getModel("emphasis");kr(r,a,"lineStyle"),Xe(r,i.get("focus"),i.get("blurScope"),i.get("disabled"))}function DK(r,e){return e==="category"?r==null:r==null||isNaN(r)}var IK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.visualStyleAccessPath="lineStyle",t.visualDrawType="stroke",t}return e.prototype.getInitialData=function(t,n){return Ri(null,this,{useEncodeDefaulter:Mt(PK,null,this)})},e.prototype.getRawIndicesByActiveState=function(t){var n=this.coordinateSystem,a=this.getData(),i=[];return n.eachActiveState(a,function(o,s){t===o&&i.push(a.getRawIndex(s))}),i},e.type="series.parallel",e.dependencies=["parallel"],e.defaultOption={z:2,coordinateSystem:"parallel",parallelIndex:0,label:{show:!1},inactiveOpacity:.05,activeOpacity:1,lineStyle:{width:1,opacity:.45,type:"solid"},emphasis:{label:{show:!1}},progressive:500,smooth:!1,animationEasing:"linear"},e}(Ve);function PK(r){var e=r.ecModel.getComponent("parallel",r.get("parallelIndex"));if(e){var t={};return B(e.dimensions,function(n){var a=kK(n);t[n]=a}),t}}function kK(r){return+r.replace("dim","")}var RK=["lineStyle","opacity"],EK={seriesType:"parallel",reset:function(r,e){var t=r.coordinateSystem,n={normal:r.get(["lineStyle","opacity"]),active:r.get("activeOpacity"),inactive:r.get("inactiveOpacity")};return{progress:function(a,i){t.eachActiveState(i,function(o,s){var l=n[o];if(o==="normal"&&i.hasItemOption){var u=i.getItemModel(s).get(RK,!0);u!=null&&(l=u)}var c=i.ensureUniqueItemVisual(s,"style");c.opacity=l},a.start,a.end)}}}};function OK(r){BK(r),NK(r)}function BK(r){if(!r.parallel){var e=!1;B(r.series,function(t){t&&t.type==="parallel"&&(e=!0)}),e&&(r.parallel=[{}])}}function NK(r){var e=Ie(r.parallelAxis);B(e,function(t){if(Vt(t)){var n=t.parallelIndex||0,a=Ie(r.parallel)[n];a&&a.parallelAxisDefault&&qt(t,a.parallelAxisDefault,!1)}})}var zK=5,FK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){this._model=t,this._api=a,this._handlers||(this._handlers={},B(VK,function(i,o){a.getZr().on(o,this._handlers[o]=Mt(i,this))},this)),wu(this,"_throttledDispatchExpand",t.get("axisExpandRate"),"fixRate")},e.prototype.dispose=function(t,n){oh(this,"_throttledDispatchExpand"),B(this._handlers,function(a,i){n.getZr().off(i,a)}),this._handlers=null},e.prototype._throttledDispatchExpand=function(t){this._dispatchExpand(t)},e.prototype._dispatchExpand=function(t){t&&this._api.dispatchAction(lt({type:"parallelAxisExpand"},t))},e.type="parallel",e}(Ze),VK={mousedown:function(r){t0(this,"click")&&(this._mouseDownPoint=[r.offsetX,r.offsetY])},mouseup:function(r){var e=this._mouseDownPoint;if(t0(this,"click")&&e){var t=[r.offsetX,r.offsetY],n=Math.pow(e[0]-t[0],2)+Math.pow(e[1]-t[1],2);if(n>zK)return;var a=this._model.coordinateSystem.getSlidedAxisExpandWindow([r.offsetX,r.offsetY]);a.behavior!=="none"&&this._dispatchExpand({axisExpandWindow:a.axisExpandWindow})}this._mouseDownPoint=null},mousemove:function(r){if(!(this._mouseDownPoint||!t0(this,"mousemove"))){var e=this._model,t=e.coordinateSystem.getSlidedAxisExpandWindow([r.offsetX,r.offsetY]),n=t.behavior;n==="jump"&&this._throttledDispatchExpand.debounceNextCall(e.get("axisExpandDebounce")),this._throttledDispatchExpand(n==="none"?null:{axisExpandWindow:t.axisExpandWindow,animation:n==="jump"?null:{duration:0}})}}};function t0(r,e){var t=r._model;return t.get("axisExpandable")&&t.get("axisExpandTriggerOn")===e}var GK=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){r.prototype.init.apply(this,arguments),this.mergeOption({})},e.prototype.mergeOption=function(t){var n=this.option;t&&qt(n,t,!0),this._initDimensions()},e.prototype.contains=function(t,n){var a=t.get("parallelIndex");return a!=null&&n.getComponent("parallel",a)===this},e.prototype.setAxisExpand=function(t){B(["axisExpandable","axisExpandCenter","axisExpandCount","axisExpandWidth","axisExpandWindow"],function(n){t.hasOwnProperty(n)&&(this.option[n]=t[n])},this)},e.prototype._initDimensions=function(){var t=this.dimensions=[],n=this.parallelAxisIndex=[],a=Te(this.ecModel.queryComponents({mainType:"parallelAxis"}),function(i){return(i.get("parallelIndex")||0)===this.componentIndex},this);B(a,function(i){t.push("dim"+i.get("dim")),n.push(i.componentIndex)})},e.type="parallel",e.dependencies=["parallelAxis"],e.layoutMode="box",e.defaultOption={z:0,left:80,top:60,right:80,bottom:60,layout:"horizontal",axisExpandable:!1,axisExpandCenter:null,axisExpandCount:0,axisExpandWidth:50,axisExpandRate:17,axisExpandDebounce:50,axisExpandSlideTriggerArea:[-.15,.05,.4],axisExpandTriggerOn:"click",parallelAxisDefault:null},e}(le),WK=function(r){rt(e,r);function e(t,n,a,i,o){var s=r.call(this,t,n,a)||this;return s.type=i||"value",s.axisIndex=o,s}return e.prototype.isHorizontal=function(){return this.coordinateSystem.getModel().get("layout")!=="horizontal"},e}(Sa);function qs(r,e,t,n,a,i){r=r||0;var o=t[1]-t[0];if(a!=null&&(a=Dl(a,[0,o])),i!=null&&(i=Math.max(i,a??0)),n==="all"){var s=Math.abs(e[1]-e[0]);s=Dl(s,[0,o]),a=i=Dl(s,[a,i]),n=0}e[0]=Dl(e[0],t),e[1]=Dl(e[1],t);var l=e0(e,n);e[n]+=r;var u=a||0,c=t.slice();l.sign<0?c[0]+=u:c[1]-=u,e[n]=Dl(e[n],c);var h;return h=e0(e,n),a!=null&&(h.sign!==l.sign||h.span<a)&&(e[1-n]=e[n]+l.sign*a),h=e0(e,n),i!=null&&h.span>i&&(e[1-n]=e[n]+h.sign*i),e}function e0(r,e){var t=r[e]-r[1-e];return{span:Math.abs(t),sign:t>0?-1:t<0?1:e?-1:1}}function Dl(r,e){return Math.min(e[1]!=null?e[1]:1/0,Math.max(e[0]!=null?e[0]:-1/0,r))}var r0=B,B5=Math.min,N5=Math.max,$L=Math.floor,HK=Math.ceil,jL=qe,UK=Math.PI,ZK=function(){function r(e,t,n){this.type="parallel",this._axesMap=Pt(),this._axesLayout={},this.dimensions=e.dimensions,this._model=e,this._init(e,t,n)}return r.prototype._init=function(e,t,n){var a=e.dimensions,i=e.parallelAxisIndex;r0(a,function(o,s){var l=i[s],u=t.getComponent("parallelAxis",l),c=this._axesMap.set(o,new WK(o,Wp(u),[0,0],u.get("type"),l)),h=c.type==="category";c.onBand=h&&u.get("boundaryGap"),c.inverse=u.get("inverse"),u.axis=c,c.model=u,c.coordinateSystem=u.coordinateSystem=this},this)},r.prototype.update=function(e,t){this._updateAxesFromSeries(this._model,e)},r.prototype.containPoint=function(e){var t=this._makeLayoutInfo(),n=t.axisBase,a=t.layoutBase,i=t.pixelDimIndex,o=e[1-i],s=e[i];return o>=n&&o<=n+t.axisLength&&s>=a&&s<=a+t.layoutLength},r.prototype.getModel=function(){return this._model},r.prototype._updateAxesFromSeries=function(e,t){t.eachSeries(function(n){if(e.contains(n,t)){var a=n.getData();r0(this.dimensions,function(i){var o=this._axesMap.get(i);o.scale.unionExtentFromData(a,a.mapDimension(i)),ru(o.scale,o.model)},this)}},this)},r.prototype.resize=function(e,t){this._rect=cr(e.getBoxLayoutParams(),{width:t.getWidth(),height:t.getHeight()}),this._layoutAxes()},r.prototype.getRect=function(){return this._rect},r.prototype._makeLayoutInfo=function(){var e=this._model,t=this._rect,n=["x","y"],a=["width","height"],i=e.get("layout"),o=i==="horizontal"?0:1,s=t[a[o]],l=[0,s],u=this.dimensions.length,c=kv(e.get("axisExpandWidth"),l),h=kv(e.get("axisExpandCount")||0,[0,u]),d=e.get("axisExpandable")&&u>3&&u>h&&h>1&&c>0&&s>0,v=e.get("axisExpandWindow"),p;if(v)p=kv(v[1]-v[0],l),v[1]=v[0]+p;else{p=kv(c*(h-1),l);var y=e.get("axisExpandCenter")||$L(u/2);v=[c*y-p/2],v[1]=v[0]+p}var _=(s-p)/(u-h);_<3&&(_=0);var g=[$L(jL(v[0]/c,1))+1,HK(jL(v[1]/c,1))-1],f=_/c*v[0];return{layout:i,pixelDimIndex:o,layoutBase:t[n[o]],layoutLength:s,axisBase:t[n[1-o]],axisLength:t[a[1-o]],axisExpandable:d,axisExpandWidth:c,axisCollapseWidth:_,axisExpandWindow:v,axisCount:u,winInnerIndices:g,axisExpandWindow0Pos:f}},r.prototype._layoutAxes=function(){var e=this._rect,t=this._axesMap,n=this.dimensions,a=this._makeLayoutInfo(),i=a.layout;t.each(function(o){var s=[0,a.axisLength],l=o.inverse?1:0;o.setExtent(s[l],s[1-l])}),r0(n,function(o,s){var l=(a.axisExpandable?XK:YK)(s,a),u={horizontal:{x:l.position,y:a.axisLength},vertical:{x:0,y:l.position}},c={horizontal:UK/2,vertical:0},h=[u[i].x+e.x,u[i].y+e.y],d=c[i],v=Ln();Hs(v,v,d),Ya(v,v,h),this._axesLayout[o]={position:h,rotation:d,transform:v,axisNameAvailableWidth:l.axisNameAvailableWidth,axisLabelShow:l.axisLabelShow,nameTruncateMaxWidth:l.nameTruncateMaxWidth,tickDirection:1,labelDirection:1}},this)},r.prototype.getAxis=function(e){return this._axesMap.get(e)},r.prototype.dataToPoint=function(e,t){return this.axisCoordToPoint(this._axesMap.get(t).dataToCoord(e),t)},r.prototype.eachActiveState=function(e,t,n,a){n==null&&(n=0),a==null&&(a=e.count());var i=this._axesMap,o=this.dimensions,s=[],l=[];B(o,function(_){s.push(e.mapDimension(_)),l.push(i.get(_).model)});for(var u=this.hasAxisBrushed(),c=n;c<a;c++){var h=void 0;if(!u)h="normal";else{h="active";for(var d=e.getValues(s,c),v=0,p=o.length;v<p;v++){var y=l[v].getActiveState(d[v]);if(y==="inactive"){h="inactive";break}}}t(h,c)}},r.prototype.hasAxisBrushed=function(){for(var e=this.dimensions,t=this._axesMap,n=!1,a=0,i=e.length;a<i;a++)t.get(e[a]).model.getActiveState()!=="normal"&&(n=!0);return n},r.prototype.axisCoordToPoint=function(e,t){var n=this._axesLayout[t];return _a([e,0],n.transform)},r.prototype.getAxisLayout=function(e){return Gt(this._axesLayout[e])},r.prototype.getSlidedAxisExpandWindow=function(e){var t=this._makeLayoutInfo(),n=t.pixelDimIndex,a=t.axisExpandWindow.slice(),i=a[1]-a[0],o=[0,t.axisExpandWidth*(t.axisCount-1)];if(!this.containPoint(e))return{behavior:"none",axisExpandWindow:a};var s=e[n]-t.layoutBase-t.axisExpandWindow0Pos,l,u="slide",c=t.axisCollapseWidth,h=this._model.get("axisExpandSlideTriggerArea"),d=h[0]!=null;if(c)d&&c&&s<i*h[0]?(u="jump",l=s-i*h[2]):d&&c&&s>i*(1-h[0])?(u="jump",l=s-i*(1-h[2])):(l=s-i*h[1])>=0&&(l=s-i*(1-h[1]))<=0&&(l=0),l*=t.axisExpandWidth/c,l?qs(l,a,o,"all"):u="none";else{var v=a[1]-a[0],p=o[1]*s/v;a=[N5(0,p-v/2)],a[1]=B5(o[1],a[0]+v),a[0]=a[1]-v}return{axisExpandWindow:a,behavior:u}},r}();function kv(r,e){return B5(N5(r,e[0]),e[1])}function YK(r,e){var t=e.layoutLength/(e.axisCount-1);return{position:t*r,axisNameAvailableWidth:t,axisLabelShow:!0}}function XK(r,e){var t=e.layoutLength,n=e.axisExpandWidth,a=e.axisCount,i=e.axisCollapseWidth,o=e.winInnerIndices,s,l=i,u=!1,c;return r<o[0]?(s=r*i,c=i):r<=o[1]?(s=e.axisExpandWindow0Pos+r*n-e.axisExpandWindow[0],l=n,u=!0):(s=t-(a-1-r)*i,c=i),{position:s,axisNameAvailableWidth:l,axisLabelShow:u,nameTruncateMaxWidth:c}}function $K(r,e){var t=[];return r.eachComponent("parallel",function(n,a){var i=new ZK(n,r,e);i.name="parallel_"+a,i.resize(n,e),n.coordinateSystem=i,i.model=n,t.push(i)}),r.eachSeries(function(n){if(n.get("coordinateSystem")==="parallel"){var a=n.getReferringComponents("parallel",ir).models[0];n.coordinateSystem=a.coordinateSystem}}),t}var jK={create:$K},o1=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.activeIntervals=[],t}return e.prototype.getAreaSelectStyle=function(){return Ns([["fill","color"],["lineWidth","borderWidth"],["stroke","borderColor"],["width","width"],["opacity","opacity"]])(this.getModel("areaSelectStyle"))},e.prototype.setActiveIntervals=function(t){var n=this.activeIntervals=Gt(t);if(n)for(var a=n.length-1;a>=0;a--)Qn(n[a])},e.prototype.getActiveState=function(t){var n=this.activeIntervals;if(!n.length)return"normal";if(t==null||isNaN(+t))return"inactive";if(n.length===1){var a=n[0];if(a[0]<=t&&t<=a[1])return"active"}else for(var i=0,o=n.length;i<o;i++)if(n[i][0]<=t&&t<=n[i][1])return"active";return"inactive"},e}(le);sr(o1,Bh);var Vs=!0,mh=Math.min,iu=Math.max,qK=Math.pow,KK=1e4,QK=6,JK=6,qL="globalPan",tQ={w:[0,0],e:[0,1],n:[1,0],s:[1,1]},eQ={w:"ew",e:"ew",n:"ns",s:"ns",ne:"nesw",sw:"nesw",nw:"nwse",se:"nwse"},KL={brushStyle:{lineWidth:2,stroke:"rgba(210,219,238,0.3)",fill:"#D2DBEE"},transformable:!0,brushMode:"single",removeOnClick:!1},rQ=0,ox=function(r){rt(e,r);function e(t){var n=r.call(this)||this;return n._track=[],n._covers=[],n._handlers={},n._zr=t,n.group=new Wt,n._uid="brushController_"+rQ++,B(uQ,function(a,i){this._handlers[i]=Mt(a,this)},n),n}return e.prototype.enableBrush=function(t){return this._brushType&&this._doDisableBrush(),t.brushType&&this._doEnableBrush(t),this},e.prototype._doEnableBrush=function(t){var n=this._zr;this._enableGlobalPan||Y$(n,qL,this._uid),B(this._handlers,function(a,i){n.on(i,a)}),this._brushType=t.brushType,this._brushOption=qt(Gt(KL),t,!0)},e.prototype._doDisableBrush=function(){var t=this._zr;X$(t,qL,this._uid),B(this._handlers,function(n,a){t.off(a,n)}),this._brushType=this._brushOption=null},e.prototype.setPanels=function(t){if(t&&t.length){var n=this._panels={};B(t,function(a){n[a.panelId]=Gt(a)})}else this._panels=null;return this},e.prototype.mount=function(t){t=t||{},this._enableGlobalPan=t.enableGlobalPan;var n=this.group;return this._zr.add(n),n.attr({x:t.x||0,y:t.y||0,rotation:t.rotation||0,scaleX:t.scaleX||1,scaleY:t.scaleY||1}),this._transform=n.getLocalTransform(),this},e.prototype.updateCovers=function(t){t=ft(t,function(d){return qt(Gt(KL),d,!0)});var n="\0-brush-index-",a=this._covers,i=this._covers=[],o=this,s=this._creatingCover;return new Li(a,t,u,l).add(c).update(c).remove(h).execute(),this;function l(d,v){return(d.id!=null?d.id:n+v)+"-"+d.brushType}function u(d,v){return l(d.__brushOption,v)}function c(d,v){var p=t[d];if(v!=null&&a[v]===s)i[d]=a[v];else{var y=i[d]=v!=null?(a[v].__brushOption=p,a[v]):F5(o,z5(o,p));sx(o,y)}}function h(d){a[d]!==s&&o.group.remove(a[d])}},e.prototype.unmount=function(){return this.enableBrush(!1),s1(this),this._zr.remove(this.group),this},e.prototype.dispose=function(){this.unmount(),this.off()},e}(ea);function z5(r,e){var t=$p[e.brushType].createCover(r,e);return t.__brushOption=e,G5(t,e),r.group.add(t),t}function F5(r,e){var t=lx(e);return t.endCreating&&(t.endCreating(r,e),G5(e,e.__brushOption)),e}function V5(r,e){var t=e.__brushOption;lx(e).updateCoverShape(r,e,t.range,t)}function G5(r,e){var t=e.z;t==null&&(t=KK),r.traverse(function(n){n.z=t,n.z2=t})}function sx(r,e){lx(e).updateCommon(r,e),V5(r,e)}function lx(r){return $p[r.__brushOption.brushType]}function ux(r,e,t){var n=r._panels;if(!n)return Vs;var a,i=r._transform;return B(n,function(o){o.isTargetByCursor(e,t,i)&&(a=o)}),a}function W5(r,e){var t=r._panels;if(!t)return Vs;var n=e.__brushOption.panelId;return n!=null?t[n]:Vs}function s1(r){var e=r._covers,t=e.length;return B(e,function(n){r.group.remove(n)},r),e.length=0,!!t}function Gs(r,e){var t=ft(r._covers,function(n){var a=n.__brushOption,i=Gt(a.range);return{brushType:a.brushType,panelId:a.panelId,range:i}});r.trigger("brush",{areas:t,isEnd:!!e.isEnd,removeOnClick:!!e.removeOnClick})}function nQ(r){var e=r._track;if(!e.length)return!1;var t=e[e.length-1],n=e[0],a=t[0]-n[0],i=t[1]-n[1],o=qK(a*a+i*i,.5);return o>QK}function H5(r){var e=r.length-1;return e<0&&(e=0),[r[0],r[e]]}function U5(r,e,t,n){var a=new Wt;return a.add(new fe({name:"main",style:cx(t),silent:!0,draggable:!0,cursor:"move",drift:Xt(QL,r,e,a,["n","s","w","e"]),ondragend:Xt(Gs,e,{isEnd:!0})})),B(n,function(i){a.add(new fe({name:i.join(""),style:{opacity:0},draggable:!0,silent:!0,invisible:!0,drift:Xt(QL,r,e,a,i),ondragend:Xt(Gs,e,{isEnd:!0})}))}),a}function Z5(r,e,t,n){var a=n.brushStyle.lineWidth||0,i=iu(a,JK),o=t[0][0],s=t[1][0],l=o-a/2,u=s-a/2,c=t[0][1],h=t[1][1],d=c-i+a/2,v=h-i+a/2,p=c-o,y=h-s,_=p+a,g=y+a;hi(r,e,"main",o,s,p,y),n.transformable&&(hi(r,e,"w",l,u,i,g),hi(r,e,"e",d,u,i,g),hi(r,e,"n",l,u,_,i),hi(r,e,"s",l,v,_,i),hi(r,e,"nw",l,u,i,i),hi(r,e,"ne",d,u,i,i),hi(r,e,"sw",l,v,i,i),hi(r,e,"se",d,v,i,i))}function l1(r,e){var t=e.__brushOption,n=t.transformable,a=e.childAt(0);a.useStyle(cx(t)),a.attr({silent:!n,cursor:n?"move":"default"}),B([["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]],function(i){var o=e.childOfName(i.join("")),s=i.length===1?u1(r,i[0]):iQ(r,i);o&&o.attr({silent:!n,invisible:!n,cursor:n?eQ[s]+"-resize":null})})}function hi(r,e,t,n,a,i,o){var s=e.childOfName(t);s&&s.setShape(sQ(hx(r,e,[[n,a],[n+i,a+o]])))}function cx(r){return zt({strokeNoScale:!0},r.brushStyle)}function Y5(r,e,t,n){var a=[mh(r,t),mh(e,n)],i=[iu(r,t),iu(e,n)];return[[a[0],i[0]],[a[1],i[1]]]}function aQ(r){return Ps(r.group)}function u1(r,e){var t={w:"left",e:"right",n:"top",s:"bottom"},n={left:"w",right:"e",top:"n",bottom:"s"},a=Cp(t[e],aQ(r));return n[a]}function iQ(r,e){var t=[u1(r,e[0]),u1(r,e[1])];return(t[0]==="e"||t[0]==="w")&&t.reverse(),t.join("")}function QL(r,e,t,n,a,i){var o=t.__brushOption,s=r.toRectRange(o.range),l=X5(e,a,i);B(n,function(u){var c=tQ[u];s[c[0]][c[1]]+=l[c[0]]}),o.range=r.fromRectRange(Y5(s[0][0],s[1][0],s[0][1],s[1][1])),sx(e,t),Gs(e,{isEnd:!1})}function oQ(r,e,t,n){var a=e.__brushOption.range,i=X5(r,t,n);B(a,function(o){o[0]+=i[0],o[1]+=i[1]}),sx(r,e),Gs(r,{isEnd:!1})}function X5(r,e,t){var n=r.group,a=n.transformCoordToLocal(e,t),i=n.transformCoordToLocal(0,0);return[a[0]-i[0],a[1]-i[1]]}function hx(r,e,t){var n=W5(r,e);return n&&n!==Vs?n.clipPath(t,r._transform):Gt(t)}function sQ(r){var e=mh(r[0][0],r[1][0]),t=mh(r[0][1],r[1][1]),n=iu(r[0][0],r[1][0]),a=iu(r[0][1],r[1][1]);return{x:e,y:t,width:n-e,height:a-t}}function lQ(r,e,t){if(!(!r._brushType||cQ(r,e.offsetX,e.offsetY))){var n=r._zr,a=r._covers,i=ux(r,e,t);if(!r._dragging)for(var o=0;o<a.length;o++){var s=a[o].__brushOption;if(i&&(i===Vs||s.panelId===i.panelId)&&$p[s.brushType].contain(a[o],t[0],t[1]))return}i&&n.setCursorStyle("crosshair")}}function c1(r){var e=r.event;e.preventDefault&&e.preventDefault()}function h1(r,e,t){return r.childOfName("main").contain(e,t)}function $5(r,e,t,n){var a=r._creatingCover,i=r._creatingPanel,o=r._brushOption,s;if(r._track.push(t.slice()),nQ(r)||a){if(i&&!a){o.brushMode==="single"&&s1(r);var l=Gt(o);l.brushType=JL(l.brushType,i),l.panelId=i===Vs?null:i.panelId,a=r._creatingCover=z5(r,l),r._covers.push(a)}if(a){var u=$p[JL(r._brushType,i)],c=a.__brushOption;c.range=u.getCreatingRange(hx(r,a,r._track)),n&&(F5(r,a),u.updateCommon(r,a)),V5(r,a),s={isEnd:n}}}else n&&o.brushMode==="single"&&o.removeOnClick&&ux(r,e,t)&&s1(r)&&(s={isEnd:n,removeOnClick:!0});return s}function JL(r,e){return r==="auto"?e.defaultBrushType:r}var uQ={mousedown:function(r){if(this._dragging)tM(this,r);else if(!r.target||!r.target.draggable){c1(r);var e=this.group.transformCoordToLocal(r.offsetX,r.offsetY);this._creatingCover=null;var t=this._creatingPanel=ux(this,r,e);t&&(this._dragging=!0,this._track=[e.slice()])}},mousemove:function(r){var e=r.offsetX,t=r.offsetY,n=this.group.transformCoordToLocal(e,t);if(lQ(this,r,n),this._dragging){c1(r);var a=$5(this,r,n,!1);a&&Gs(this,a)}},mouseup:function(r){tM(this,r)}};function tM(r,e){if(r._dragging){c1(e);var t=e.offsetX,n=e.offsetY,a=r.group.transformCoordToLocal(t,n),i=$5(r,e,a,!0);r._dragging=!1,r._track=[],r._creatingCover=null,i&&Gs(r,i)}}function cQ(r,e,t){var n=r._zr;return e<0||e>n.getWidth()||t<0||t>n.getHeight()}var $p={lineX:eM(0),lineY:eM(1),rect:{createCover:function(r,e){function t(n){return n}return U5({toRectRange:t,fromRectRange:t},r,e,[["w"],["e"],["n"],["s"],["s","e"],["s","w"],["n","e"],["n","w"]])},getCreatingRange:function(r){var e=H5(r);return Y5(e[1][0],e[1][1],e[0][0],e[0][1])},updateCoverShape:function(r,e,t,n){Z5(r,e,t,n)},updateCommon:l1,contain:h1},polygon:{createCover:function(r,e){var t=new Wt;return t.add(new nn({name:"main",style:cx(e),silent:!0})),t},getCreatingRange:function(r){return r},endCreating:function(r,e){e.remove(e.childAt(0)),e.add(new rn({name:"main",draggable:!0,drift:Xt(oQ,r,e),ondragend:Xt(Gs,r,{isEnd:!0})}))},updateCoverShape:function(r,e,t,n){e.childAt(0).setShape({points:hx(r,e,t)})},updateCommon:l1,contain:h1}};function eM(r){return{createCover:function(e,t){return U5({toRectRange:function(n){var a=[n,[0,100]];return r&&a.reverse(),a},fromRectRange:function(n){return n[r]}},e,t,[[["w"],["e"]],[["n"],["s"]]][r])},getCreatingRange:function(e){var t=H5(e),n=mh(t[0][r],t[1][r]),a=iu(t[0][r],t[1][r]);return[n,a]},updateCoverShape:function(e,t,n,a){var i,o=W5(e,t);if(o!==Vs&&o.getLinearBrushOtherExtent)i=o.getLinearBrushOtherExtent(r);else{var s=e._zr;i=[0,[s.getWidth(),s.getHeight()][1-r]]}var l=[n,i];r&&l.reverse(),Z5(e,t,l,a)},updateCommon:l1,contain:h1}}function j5(r){return r=fx(r),function(e){return ik(e,r)}}function q5(r,e){return r=fx(r),function(t){var n=e??t,a=n?r.width:r.height,i=n?r.x:r.y;return[i,i+(a||0)]}}function K5(r,e,t){var n=fx(r);return function(a,i){return n.contain(i[0],i[1])&&!Up(a,e,t)}}function fx(r){return Qt.create(r)}var hQ=["axisLine","axisTickLabel","axisName"],fQ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n){r.prototype.init.apply(this,arguments),(this._brushController=new ox(n.getZr())).on("brush",Mt(this._onBrush,this))},e.prototype.render=function(t,n,a,i){if(!vQ(t,n,i)){this.axisModel=t,this.api=a,this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new Wt,this.group.add(this._axisGroup),!!t.get("show")){var s=pQ(t,n),l=s.coordinateSystem,u=t.getAreaSelectStyle(),c=u.width,h=t.axis.dim,d=l.getAxisLayout(h),v=lt({strokeContainThreshold:c},d),p=new Qr(t,v);B(hQ,p.add,p),this._axisGroup.add(p.getGroup()),this._refreshBrushController(v,u,t,s,c,a),Ph(o,this._axisGroup,t)}}},e.prototype._refreshBrushController=function(t,n,a,i,o,s){var l=a.axis.getExtent(),u=l[1]-l[0],c=Math.min(30,Math.abs(u)*.1),h=Qt.create({x:l[0],y:-o/2,width:u,height:o});h.x-=c,h.width+=2*c,this._brushController.mount({enableGlobalPan:!0,rotation:t.rotation,x:t.position[0],y:t.position[1]}).setPanels([{panelId:"pl",clipPath:j5(h),isTargetByCursor:K5(h,s,i),getLinearBrushOtherExtent:q5(h,0)}]).enableBrush({brushType:"lineX",brushStyle:n,removeOnClick:!0}).updateCovers(dQ(a))},e.prototype._onBrush=function(t){var n=t.areas,a=this.axisModel,i=a.axis,o=ft(n,function(s){return[i.coordToData(s.range[0],!0),i.coordToData(s.range[1],!0)]});(!a.option.realtime===t.isEnd||t.removeOnClick)&&this.api.dispatchAction({type:"axisAreaSelect",parallelAxisId:a.id,intervals:o})},e.prototype.dispose=function(){this._brushController.dispose()},e.type="parallelAxis",e}(Ze);function vQ(r,e,t){return t&&t.type==="axisAreaSelect"&&e.findComponents({mainType:"parallelAxis",query:t})[0]===r}function dQ(r){var e=r.axis;return ft(r.activeIntervals,function(t){return{brushType:"lineX",panelId:"pl",range:[e.dataToCoord(t[0],!0),e.dataToCoord(t[1],!0)]}})}function pQ(r,e){return e.getComponent("parallel",r.get("parallelIndex"))}var gQ={type:"axisAreaSelect",event:"axisAreaSelected"};function yQ(r){r.registerAction(gQ,function(e,t){t.eachComponent({mainType:"parallelAxis",query:e},function(n){n.axis.model.setActiveIntervals(e.intervals)})}),r.registerAction("parallelAxisExpand",function(e,t){t.eachComponent({mainType:"parallel",query:e},function(n){n.setAxisExpand(e)})})}var mQ={type:"value",areaSelectStyle:{width:20,borderWidth:1,borderColor:"rgba(160,197,232)",color:"rgba(160,197,232)",opacity:.3},realtime:!0,z:10};function Q5(r){r.registerComponentView(FK),r.registerComponentModel(GK),r.registerCoordinateSystem("parallel",jK),r.registerPreprocessor(OK),r.registerComponentModel(o1),r.registerComponentView(fQ),au(r,"parallel",o1,mQ),yQ(r)}function _Q(r){ne(Q5),r.registerChartView(LK),r.registerSeriesModel(IK),r.registerVisual(r.PRIORITY.VISUAL.BRUSH,EK)}var wQ=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.cpx2=0,this.cpy2=0,this.extent=0}return r}(),xQ=function(r){rt(e,r);function e(t){return r.call(this,t)||this}return e.prototype.getDefaultShape=function(){return new wQ},e.prototype.buildPath=function(t,n){var a=n.extent;t.moveTo(n.x1,n.y1),t.bezierCurveTo(n.cpx1,n.cpy1,n.cpx2,n.cpy2,n.x2,n.y2),n.orient==="vertical"?(t.lineTo(n.x2+a,n.y2),t.bezierCurveTo(n.cpx2+a,n.cpy2,n.cpx1+a,n.cpy1,n.x1+a,n.y1)):(t.lineTo(n.x2,n.y2+a),t.bezierCurveTo(n.cpx2,n.cpy2+a,n.cpx1,n.cpy1+a,n.x1,n.y1+a)),t.closePath()},e.prototype.highlight=function(){Ti(this)},e.prototype.downplay=function(){Ci(this)},e}(ie),bQ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._focusAdjacencyDisabled=!1,t}return e.prototype.render=function(t,n,a){var i=this,o=t.getGraph(),s=this.group,l=t.layoutInfo,u=l.width,c=l.height,h=t.getData(),d=t.getData("edge"),v=t.get("orient");this._model=t,s.removeAll(),s.x=l.x,s.y=l.y,o.eachEdge(function(p){var y=new xQ,_=Ht(y);_.dataIndex=p.dataIndex,_.seriesIndex=t.seriesIndex,_.dataType="edge";var g=p.getModel(),f=g.getModel("lineStyle"),w=f.get("curveness"),x=p.node1.getLayout(),S=p.node1.getModel(),A=S.get("localX"),T=S.get("localY"),L=p.node2.getLayout(),M=p.node2.getModel(),I=M.get("localX"),R=M.get("localY"),P=p.getLayout(),E,D,N,V,W,$,H,K;y.shape.extent=Math.max(1,P.dy),y.shape.orient=v,v==="vertical"?(E=(A!=null?A*u:x.x)+P.sy,D=(T!=null?T*c:x.y)+x.dy,N=(I!=null?I*u:L.x)+P.ty,V=R!=null?R*c:L.y,W=E,$=D*(1-w)+V*w,H=N,K=D*w+V*(1-w)):(E=(A!=null?A*u:x.x)+x.dx,D=(T!=null?T*c:x.y)+P.sy,N=I!=null?I*u:L.x,V=(R!=null?R*c:L.y)+P.ty,W=E*(1-w)+N*w,$=D,H=E*w+N*(1-w),K=V),y.setShape({x1:E,y1:D,x2:N,y2:V,cpx1:W,cpy1:$,cpx2:H,cpy2:K}),y.useStyle(f.getItemStyle()),rM(y.style,v,p);var U=""+g.get("value"),j=_r(g,"edgeLabel");Rr(y,j,{labelFetcher:{getFormattedLabel:function(it,Et,jt,bt,wt,Ot){return t.getFormattedLabel(it,Et,"edge",bt,Ha(wt,j.normal&&j.normal.get("formatter"),U),Ot)}},labelDataIndex:p.dataIndex,defaultText:U}),y.setTextConfig({position:"inside"});var ut=g.getModel("emphasis");kr(y,g,"lineStyle",function(it){var Et=it.getItemStyle();return rM(Et,v,p),Et}),s.add(y),d.setItemGraphicEl(p.dataIndex,y);var ot=ut.get("focus");Xe(y,ot==="adjacency"?p.getAdjacentDataIndices():ot==="trajectory"?p.getTrajectoryDataIndices():ot,ut.get("blurScope"),ut.get("disabled"))}),o.eachNode(function(p){var y=p.getLayout(),_=p.getModel(),g=_.get("localX"),f=_.get("localY"),w=_.getModel("emphasis"),x=_.get(["itemStyle","borderRadius"])||0,S=new fe({shape:{x:g!=null?g*u:y.x,y:f!=null?f*c:y.y,width:y.dx,height:y.dy,r:x},style:_.getModel("itemStyle").getItemStyle(),z2:10});Rr(S,_r(_),{labelFetcher:{getFormattedLabel:function(T,L){return t.getFormattedLabel(T,L,"node")}},labelDataIndex:p.dataIndex,defaultText:p.id}),S.disableLabelAnimation=!0,S.setStyle("fill",p.getVisual("color")),S.setStyle("decal",p.getVisual("style").decal),kr(S,_),s.add(S),h.setItemGraphicEl(p.dataIndex,S),Ht(S).dataType="node";var A=w.get("focus");Xe(S,A==="adjacency"?p.getAdjacentDataIndices():A==="trajectory"?p.getTrajectoryDataIndices():A,w.get("blurScope"),w.get("disabled"))}),h.eachItemGraphicEl(function(p,y){var _=h.getItemModel(y);_.get("draggable")&&(p.drift=function(g,f){i._focusAdjacencyDisabled=!0,this.shape.x+=g,this.shape.y+=f,this.dirty(),a.dispatchAction({type:"dragNode",seriesId:t.id,dataIndex:h.getRawIndex(y),localX:this.shape.x/u,localY:this.shape.y/c})},p.ondragend=function(){i._focusAdjacencyDisabled=!1},p.draggable=!0,p.cursor="move")}),!this._data&&t.isAnimationEnabled()&&s.setClipPath(SQ(s.getBoundingRect(),t,function(){s.removeClipPath()})),this._data=t.getData()},e.prototype.dispose=function(){},e.type="sankey",e}(Re);function rM(r,e,t){switch(r.fill){case"source":r.fill=t.node1.getVisual("color"),r.decal=t.node1.getVisual("style").decal;break;case"target":r.fill=t.node2.getVisual("color"),r.decal=t.node2.getVisual("style").decal;break;case"gradient":var n=t.node1.getVisual("color"),a=t.node2.getVisual("color");Lt(n)&&Lt(a)&&(r.fill=new Ih(0,0,+(e==="horizontal"),+(e==="vertical"),[{color:n,offset:0},{color:a,offset:1}]))}}function SQ(r,e,t){var n=new fe({shape:{x:r.x-10,y:r.y-10,width:0,height:r.height+20}});return He(n,{shape:{width:r.width+20}},e,t),n}var AQ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(t,n){var a=t.edges||t.links||[],i=t.data||t.nodes||[],o=t.levels||[];this.levelModels=[];for(var s=this.levelModels,l=0;l<o.length;l++)o[l].depth!=null&&o[l].depth>=0&&(s[o[l].depth]=new De(o[l],this,n));var u=E5(i,a,this,!0,c);return u.data;function c(h,d){h.wrapMethod("getItemModel",function(v,p){var y=v.parentModel,_=y.getData().getItemLayout(p);if(_){var g=_.depth,f=y.levelModels[g];f&&(v.parentModel=f)}return v}),d.wrapMethod("getItemModel",function(v,p){var y=v.parentModel,_=y.getGraph().getEdgeByIndex(p),g=_.node1.getLayout();if(g){var f=g.depth,w=y.levelModels[f];w&&(v.parentModel=w)}return v})}},e.prototype.setNodePosition=function(t,n){var a=this.option.data||this.option.nodes,i=a[t];i.localX=n[0],i.localY=n[1]},e.prototype.getGraph=function(){return this.getData().graph},e.prototype.getEdgeData=function(){return this.getGraph().edgeData},e.prototype.formatTooltip=function(t,n,a){function i(v){return isNaN(v)||v==null}if(a==="edge"){var o=this.getDataParams(t,a),s=o.data,l=o.value,u=s.source+" -- "+s.target;return wr("nameValue",{name:u,value:l,noValue:i(l)})}else{var c=this.getGraph().getNodeByIndex(t),h=c.getLayout().value,d=this.getDataParams(t,a).data.name;return wr("nameValue",{name:d!=null?d+"":null,value:h,noValue:i(h)})}},e.prototype.optionUpdated=function(){},e.prototype.getDataParams=function(t,n){var a=r.prototype.getDataParams.call(this,t,n);if(a.value==null&&n==="node"){var i=this.getGraph().getNodeByIndex(t),o=i.getLayout().value;a.value=o}return a},e.type="series.sankey",e.defaultOption={z:2,coordinateSystem:"view",left:"5%",top:"5%",right:"20%",bottom:"5%",orient:"horizontal",nodeWidth:20,nodeGap:8,draggable:!0,layoutIterations:32,label:{show:!0,position:"right",fontSize:12},edgeLabel:{show:!1,fontSize:12},levels:[],nodeAlign:"justify",lineStyle:{color:"#314656",opacity:.2,curveness:.5},emphasis:{label:{show:!0},lineStyle:{opacity:.5}},select:{itemStyle:{borderColor:"#212121"}},animationEasing:"linear",animationDuration:1e3},e}(Ve);function TQ(r,e){r.eachSeriesByType("sankey",function(t){var n=t.get("nodeWidth"),a=t.get("nodeGap"),i=CQ(t,e);t.layoutInfo=i;var o=i.width,s=i.height,l=t.getGraph(),u=l.nodes,c=l.edges;MQ(u);var h=Te(u,function(y){return y.getLayout().value===0}),d=h.length!==0?0:t.get("layoutIterations"),v=t.get("orient"),p=t.get("nodeAlign");LQ(u,c,n,a,o,s,d,v,p)})}function CQ(r,e){return cr(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()})}function LQ(r,e,t,n,a,i,o,s,l){DQ(r,e,t,a,i,s,l),RQ(r,e,i,a,n,o,s),WQ(r,s)}function MQ(r){B(r,function(e){var t=yo(e.outEdges,$d),n=yo(e.inEdges,$d),a=e.getValue()||0,i=Math.max(t,n,a);e.setLayout({value:i},!0)})}function DQ(r,e,t,n,a,i,o){for(var s=[],l=[],u=[],c=[],h=0,d=0;d<e.length;d++)s[d]=1;for(var d=0;d<r.length;d++)l[d]=r[d].inEdges.length,l[d]===0&&u.push(r[d]);for(var v=-1;u.length;){for(var p=0;p<u.length;p++){var y=u[p],_=y.hostGraph.data.getRawDataItem(y.dataIndex),g=_.depth!=null&&_.depth>=0;g&&_.depth>v&&(v=_.depth),y.setLayout({depth:g?_.depth:h},!0),i==="vertical"?y.setLayout({dy:t},!0):y.setLayout({dx:t},!0);for(var f=0;f<y.outEdges.length;f++){var w=y.outEdges[f],x=e.indexOf(w);s[x]=0;var S=w.node2,A=r.indexOf(S);--l[A]===0&&c.indexOf(S)<0&&c.push(S)}}++h,u=c,c=[]}for(var d=0;d<s.length;d++)if(s[d]===1)throw new Error("Sankey is a DAG, the original data has cycle!");var T=v>h-1?v:h-1;o&&o!=="left"&&IQ(r,o,i,T);var L=i==="vertical"?(a-t)/T:(n-t)/T;kQ(r,L,i)}function J5(r){var e=r.hostGraph.data.getRawDataItem(r.dataIndex);return e.depth!=null&&e.depth>=0}function IQ(r,e,t,n){if(e==="right"){for(var a=[],i=r,o=0;i.length;){for(var s=0;s<i.length;s++){var l=i[s];l.setLayout({skNodeHeight:o},!0);for(var u=0;u<l.inEdges.length;u++){var c=l.inEdges[u];a.indexOf(c.node1)<0&&a.push(c.node1)}}i=a,a=[],++o}B(r,function(h){J5(h)||h.setLayout({depth:Math.max(0,n-h.getLayout().skNodeHeight)},!0)})}else e==="justify"&&PQ(r,n)}function PQ(r,e){B(r,function(t){!J5(t)&&!t.outEdges.length&&t.setLayout({depth:e},!0)})}function kQ(r,e,t){B(r,function(n){var a=n.getLayout().depth*e;t==="vertical"?n.setLayout({y:a},!0):n.setLayout({x:a},!0)})}function RQ(r,e,t,n,a,i,o){var s=EQ(r,o);OQ(s,e,t,n,a,o),n0(s,a,t,n,o);for(var l=1;i>0;i--)l*=.99,BQ(s,l,o),n0(s,a,t,n,o),GQ(s,l,o),n0(s,a,t,n,o)}function EQ(r,e){var t=[],n=e==="vertical"?"y":"x",a=f_(r,function(i){return i.getLayout()[n]});return a.keys.sort(function(i,o){return i-o}),B(a.keys,function(i){t.push(a.buckets.get(i))}),t}function OQ(r,e,t,n,a,i){var o=1/0;B(r,function(s){var l=s.length,u=0;B(s,function(h){u+=h.getLayout().value});var c=i==="vertical"?(n-(l-1)*a)/u:(t-(l-1)*a)/u;c<o&&(o=c)}),B(r,function(s){B(s,function(l,u){var c=l.getLayout().value*o;i==="vertical"?(l.setLayout({x:u},!0),l.setLayout({dx:c},!0)):(l.setLayout({y:u},!0),l.setLayout({dy:c},!0))})}),B(e,function(s){var l=+s.getValue()*o;s.setLayout({dy:l},!0)})}function n0(r,e,t,n,a){var i=a==="vertical"?"x":"y";B(r,function(o){o.sort(function(y,_){return y.getLayout()[i]-_.getLayout()[i]});for(var s,l,u,c=0,h=o.length,d=a==="vertical"?"dx":"dy",v=0;v<h;v++)l=o[v],u=c-l.getLayout()[i],u>0&&(s=l.getLayout()[i]+u,a==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0)),c=l.getLayout()[i]+l.getLayout()[d]+e;var p=a==="vertical"?n:t;if(u=c-e-p,u>0){s=l.getLayout()[i]-u,a==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0),c=s;for(var v=h-2;v>=0;--v)l=o[v],u=l.getLayout()[i]+l.getLayout()[d]+e-c,u>0&&(s=l.getLayout()[i]-u,a==="vertical"?l.setLayout({x:s},!0):l.setLayout({y:s},!0)),c=l.getLayout()[i]}})}function BQ(r,e,t){B(r.slice().reverse(),function(n){B(n,function(a){if(a.outEdges.length){var i=yo(a.outEdges,NQ,t)/yo(a.outEdges,$d);if(isNaN(i)){var o=a.outEdges.length;i=o?yo(a.outEdges,zQ,t)/o:0}if(t==="vertical"){var s=a.getLayout().x+(i-Ao(a,t))*e;a.setLayout({x:s},!0)}else{var l=a.getLayout().y+(i-Ao(a,t))*e;a.setLayout({y:l},!0)}}})})}function NQ(r,e){return Ao(r.node2,e)*r.getValue()}function zQ(r,e){return Ao(r.node2,e)}function FQ(r,e){return Ao(r.node1,e)*r.getValue()}function VQ(r,e){return Ao(r.node1,e)}function Ao(r,e){return e==="vertical"?r.getLayout().x+r.getLayout().dx/2:r.getLayout().y+r.getLayout().dy/2}function $d(r){return r.getValue()}function yo(r,e,t){for(var n=0,a=r.length,i=-1;++i<a;){var o=+e(r[i],t);isNaN(o)||(n+=o)}return n}function GQ(r,e,t){B(r,function(n){B(n,function(a){if(a.inEdges.length){var i=yo(a.inEdges,FQ,t)/yo(a.inEdges,$d);if(isNaN(i)){var o=a.inEdges.length;i=o?yo(a.inEdges,VQ,t)/o:0}if(t==="vertical"){var s=a.getLayout().x+(i-Ao(a,t))*e;a.setLayout({x:s},!0)}else{var l=a.getLayout().y+(i-Ao(a,t))*e;a.setLayout({y:l},!0)}}})})}function WQ(r,e){var t=e==="vertical"?"x":"y";B(r,function(n){n.outEdges.sort(function(a,i){return a.node2.getLayout()[t]-i.node2.getLayout()[t]}),n.inEdges.sort(function(a,i){return a.node1.getLayout()[t]-i.node1.getLayout()[t]})}),B(r,function(n){var a=0,i=0;B(n.outEdges,function(o){o.setLayout({sy:a},!0),a+=o.getLayout().dy}),B(n.inEdges,function(o){o.setLayout({ty:i},!0),i+=o.getLayout().dy})})}function HQ(r){r.eachSeriesByType("sankey",function(e){var t=e.getGraph(),n=t.nodes,a=t.edges;if(n.length){var i=1/0,o=-1/0;B(n,function(s){var l=s.getLayout().value;l<i&&(i=l),l>o&&(o=l)}),B(n,function(s){var l=new mr({type:"color",mappingMethod:"linear",dataExtent:[i,o],visual:e.get("color")}),u=l.mapValueToVisual(s.getLayout().value),c=s.getModel().get(["itemStyle","color"]);c!=null?(s.setVisual("color",c),s.setVisual("style",{fill:c})):(s.setVisual("color",u),s.setVisual("style",{fill:u}))})}a.length&&B(a,function(s){var l=s.getModel().get("lineStyle");s.setVisual("style",l)})})}function UQ(r){r.registerChartView(bQ),r.registerSeriesModel(AQ),r.registerLayout(TQ),r.registerVisual(HQ),r.registerAction({type:"dragNode",event:"dragnode",update:"update"},function(e,t){t.eachComponent({mainType:"series",subType:"sankey",query:e},function(n){n.setNodePosition(e.dataIndex,[e.localX,e.localY])})})}var tO=function(){function r(){}return r.prototype._hasEncodeRule=function(e){var t=this.getEncode();return t&&t.get(e)!=null},r.prototype.getInitialData=function(e,t){var n,a=t.getComponent("xAxis",this.get("xAxisIndex")),i=t.getComponent("yAxis",this.get("yAxisIndex")),o=a.get("type"),s=i.get("type"),l;o==="category"?(e.layout="horizontal",n=a.getOrdinalMeta(),l=!this._hasEncodeRule("x")):s==="category"?(e.layout="vertical",n=i.getOrdinalMeta(),l=!this._hasEncodeRule("y")):e.layout=e.layout||"horizontal";var u=["x","y"],c=e.layout==="horizontal"?0:1,h=this._baseAxisDim=u[c],d=u[1-c],v=[a,i],p=v[c].get("type"),y=v[1-c].get("type"),_=e.data;if(_&&l){var g=[];B(_,function(x,S){var A;ht(x)?(A=x.slice(),x.unshift(S)):ht(x.value)?(A=lt({},x),A.value=A.value.slice(),x.value.unshift(S)):A=x,g.push(A)}),e.data=g}var f=this.defaultValueDimensions,w=[{name:h,type:Nd(p),ordinalMeta:n,otherDims:{tooltip:!1,itemName:0},dimsDef:["base"]},{name:d,type:Nd(y),dimsDef:f.slice()}];return Su(this,{coordDimensions:w,dimensionsCount:f.length+1,encodeDefaulter:Xt(Pk,w,this)})},r.prototype.getBaseAxis=function(){var e=this._baseAxisDim;return this.ecModel.getComponent(e+"Axis",this.get(e+"AxisIndex")).axis},r}(),eO=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.defaultValueDimensions=[{name:"min",defaultTooltip:!0},{name:"Q1",defaultTooltip:!0},{name:"median",defaultTooltip:!0},{name:"Q3",defaultTooltip:!0},{name:"max",defaultTooltip:!0}],t.visualDrawType="stroke",t}return e.type="series.boxplot",e.dependencies=["xAxis","yAxis","grid"],e.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,layout:null,boxWidth:[7,50],itemStyle:{color:"#fff",borderWidth:1},emphasis:{scale:!0,itemStyle:{borderWidth:2,shadowBlur:5,shadowOffsetX:1,shadowOffsetY:1,shadowColor:"rgba(0,0,0,0.2)"}},animationDuration:800},e}(Ve);sr(eO,tO,!0);var ZQ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=t.getData(),o=this.group,s=this._data;this._data||o.removeAll();var l=t.get("layout")==="horizontal"?1:0;i.diff(s).add(function(u){if(i.hasValue(u)){var c=i.getItemLayout(u),h=nM(c,i,u,l,!0);i.setItemGraphicEl(u,h),o.add(h)}}).update(function(u,c){var h=s.getItemGraphicEl(c);if(!i.hasValue(u)){o.remove(h);return}var d=i.getItemLayout(u);h?(xa(h),rO(d,h,i,u)):h=nM(d,i,u,l),o.add(h),i.setItemGraphicEl(u,h)}).remove(function(u){var c=s.getItemGraphicEl(u);c&&o.remove(c)}).execute(),this._data=i},e.prototype.remove=function(t){var n=this.group,a=this._data;this._data=null,a&&a.eachItemGraphicEl(function(i){i&&n.remove(i)})},e.type="boxplot",e}(Re),YQ=function(){function r(){}return r}(),XQ=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="boxplotBoxPath",n}return e.prototype.getDefaultShape=function(){return new YQ},e.prototype.buildPath=function(t,n){var a=n.points,i=0;for(t.moveTo(a[i][0],a[i][1]),i++;i<4;i++)t.lineTo(a[i][0],a[i][1]);for(t.closePath();i<a.length;i++)t.moveTo(a[i][0],a[i][1]),i++,t.lineTo(a[i][0],a[i][1])},e}(ie);function nM(r,e,t,n,a){var i=r.ends,o=new XQ({shape:{points:a?$Q(i,n,r):i}});return rO(r,o,e,t,a),o}function rO(r,e,t,n,a){var i=t.hostModel,o=Zs[a?"initProps":"updateProps"];o(e,{shape:{points:r.ends}},i,n),e.useStyle(t.getItemVisual(n,"style")),e.style.strokeNoScale=!0,e.z2=100;var s=t.getItemModel(n),l=s.getModel("emphasis");kr(e,s),Xe(e,l.get("focus"),l.get("blurScope"),l.get("disabled"))}function $Q(r,e,t){return ft(r,function(n){return n=n.slice(),n[e]=t.initBaseline,n})}var Zc=B;function jQ(r){var e=qQ(r);Zc(e,function(t){var n=t.seriesModels;n.length&&(KQ(t),Zc(n,function(a,i){QQ(a,t.boxOffsetList[i],t.boxWidthList[i])}))})}function qQ(r){var e=[],t=[];return r.eachSeriesByType("boxplot",function(n){var a=n.getBaseAxis(),i=te(t,a);i<0&&(i=t.length,t[i]=a,e[i]={axis:a,seriesModels:[]}),e[i].seriesModels.push(n)}),e}function KQ(r){var e=r.axis,t=r.seriesModels,n=t.length,a=r.boxWidthList=[],i=r.boxOffsetList=[],o=[],s;if(e.type==="category")s=e.getBandWidth();else{var l=0;Zc(t,function(p){l=Math.max(l,p.getData().count())});var u=e.getExtent();s=Math.abs(u[1]-u[0])/l}Zc(t,function(p){var y=p.get("boxWidth");ht(y)||(y=[y,y]),o.push([At(y[0],s)||0,At(y[1],s)||0])});var c=s*.8-2,h=c/n*.3,d=(c-h*(n-1))/n,v=d/2-c/2;Zc(t,function(p,y){i.push(v),v+=h+d,a.push(Math.min(Math.max(d,o[y][0]),o[y][1]))})}function QQ(r,e,t){var n=r.coordinateSystem,a=r.getData(),i=t/2,o=r.get("layout")==="horizontal"?0:1,s=1-o,l=["x","y"],u=a.mapDimension(l[o]),c=a.mapDimensionsAll(l[s]);if(u==null||c.length<5)return;for(var h=0;h<a.count();h++){var d=a.get(u,h),v=w(d,c[2],h),p=w(d,c[0],h),y=w(d,c[1],h),_=w(d,c[3],h),g=w(d,c[4],h),f=[];x(f,y,!1),x(f,_,!0),f.push(p,y,g,_),S(f,p),S(f,g),S(f,v),a.setItemLayout(h,{initBaseline:v[s],ends:f})}function w(A,T,L){var M=a.get(T,L),I=[];I[o]=A,I[s]=M;var R;return isNaN(A)||isNaN(M)?R=[NaN,NaN]:(R=n.dataToPoint(I),R[o]+=e),R}function x(A,T,L){var M=T.slice(),I=T.slice();M[o]+=i,I[o]-=i,L?A.push(M,I):A.push(I,M)}function S(A,T){var L=T.slice(),M=T.slice();L[o]-=i,M[o]+=i,A.push(L,M)}}function JQ(r,e){e=e||{};for(var t=[],n=[],a=e.boundIQR,i=a==="none"||a===0,o=0;o<r.length;o++){var s=Qn(r[o].slice()),l=ky(s,.25),u=ky(s,.5),c=ky(s,.75),h=s[0],d=s[s.length-1],v=(a??1.5)*(c-l),p=i?h:Math.max(h,l-v),y=i?d:Math.min(d,c+v),_=e.itemNameFormatter,g=Nt(_)?_({value:o}):Lt(_)?_.replace("{value}",o+""):o+"";t.push([g,p,l,u,c,y]);for(var f=0;f<s.length;f++){var w=s[f];if(w<p||w>y){var x=[g,w];n.push(x)}}}return{boxData:t,outliers:n}}var tJ={type:"echarts:boxplot",transform:function(e){var t=e.upstream;if(t.sourceFormat!==Wr){var n="";Ae(n)}var a=JQ(t.getRawData(),e.config);return[{dimensions:["ItemName","Low","Q1","Q2","Q3","High"],data:a.boxData},{data:a.outliers}]}};function eJ(r){r.registerSeriesModel(eO),r.registerChartView(ZQ),r.registerLayout(jQ),r.registerTransform(tJ)}var rJ=["itemStyle","borderColor"],nJ=["itemStyle","borderColor0"],aJ=["itemStyle","borderColorDoji"],iJ=["itemStyle","color"],oJ=["itemStyle","color0"];function vx(r,e){return e.get(r>0?iJ:oJ)}function dx(r,e){return e.get(r===0?aJ:r>0?rJ:nJ)}var sJ={seriesType:"candlestick",plan:_u(),performRawSeries:!0,reset:function(r,e){if(!e.isSeriesFiltered(r)){var t=r.pipelineContext.large;return!t&&{progress:function(n,a){for(var i;(i=n.next())!=null;){var o=a.getItemModel(i),s=a.getItemLayout(i).sign,l=o.getItemStyle();l.fill=vx(s,o),l.stroke=dx(s,o)||l.fill;var u=a.ensureUniqueItemVisual(i,"style");lt(u,l)}}}}}},lJ=["color","borderColor"],uJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){this.group.removeClipPath(),this._progressiveEls=null,this._updateDrawMode(t),this._isLargeDraw?this._renderLarge(t):this._renderNormal(t)},e.prototype.incrementalPrepareRender=function(t,n,a){this._clear(),this._updateDrawMode(t)},e.prototype.incrementalRender=function(t,n,a,i){this._progressiveEls=[],this._isLargeDraw?this._incrementalRenderLarge(t,n):this._incrementalRenderNormal(t,n)},e.prototype.eachRendered=function(t){Co(this._progressiveEls||this.group,t)},e.prototype._updateDrawMode=function(t){var n=t.pipelineContext.large;(this._isLargeDraw==null||n!==this._isLargeDraw)&&(this._isLargeDraw=n,this._clear())},e.prototype._renderNormal=function(t){var n=t.getData(),a=this._data,i=this.group,o=n.getLayout("isSimpleBox"),s=t.get("clip",!0),l=t.coordinateSystem,u=l.getArea&&l.getArea();this._data||i.removeAll(),n.diff(a).add(function(c){if(n.hasValue(c)){var h=n.getItemLayout(c);if(s&&aM(u,h))return;var d=a0(h,c,!0);He(d,{shape:{points:h.ends}},t,c),i0(d,n,c,o),i.add(d),n.setItemGraphicEl(c,d)}}).update(function(c,h){var d=a.getItemGraphicEl(h);if(!n.hasValue(c)){i.remove(d);return}var v=n.getItemLayout(c);if(s&&aM(u,v)){i.remove(d);return}d?(_e(d,{shape:{points:v.ends}},t,c),xa(d)):d=a0(v),i0(d,n,c,o),i.add(d),n.setItemGraphicEl(c,d)}).remove(function(c){var h=a.getItemGraphicEl(c);h&&i.remove(h)}).execute(),this._data=n},e.prototype._renderLarge=function(t){this._clear(),iM(t,this.group);var n=t.get("clip",!0)?Fh(t.coordinateSystem,!1,t):null;n?this.group.setClipPath(n):this.group.removeClipPath()},e.prototype._incrementalRenderNormal=function(t,n){for(var a=n.getData(),i=a.getLayout("isSimpleBox"),o;(o=t.next())!=null;){var s=a.getItemLayout(o),l=a0(s);i0(l,a,o,i),l.incremental=!0,this.group.add(l),this._progressiveEls.push(l)}},e.prototype._incrementalRenderLarge=function(t,n){iM(n,this.group,this._progressiveEls,!0)},e.prototype.remove=function(t){this._clear()},e.prototype._clear=function(){this.group.removeAll(),this._data=null},e.type="candlestick",e}(Re),cJ=function(){function r(){}return r}(),hJ=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="normalCandlestickBox",n}return e.prototype.getDefaultShape=function(){return new cJ},e.prototype.buildPath=function(t,n){var a=n.points;this.__simpleBox?(t.moveTo(a[4][0],a[4][1]),t.lineTo(a[6][0],a[6][1])):(t.moveTo(a[0][0],a[0][1]),t.lineTo(a[1][0],a[1][1]),t.lineTo(a[2][0],a[2][1]),t.lineTo(a[3][0],a[3][1]),t.closePath(),t.moveTo(a[4][0],a[4][1]),t.lineTo(a[5][0],a[5][1]),t.moveTo(a[6][0],a[6][1]),t.lineTo(a[7][0],a[7][1]))},e}(ie);function a0(r,e,t){var n=r.ends;return new hJ({shape:{points:t?fJ(n,r):n},z2:100})}function aM(r,e){for(var t=!0,n=0;n<e.ends.length;n++)if(r.contain(e.ends[n][0],e.ends[n][1])){t=!1;break}return t}function i0(r,e,t,n){var a=e.getItemModel(t);r.useStyle(e.getItemVisual(t,"style")),r.style.strokeNoScale=!0,r.__simpleBox=n,kr(r,a);var i=e.getItemLayout(t).sign;B(r.states,function(s,l){var u=a.getModel(l),c=vx(i,u),h=dx(i,u)||c,d=s.style||(s.style={});c&&(d.fill=c),h&&(d.stroke=h)});var o=a.getModel("emphasis");Xe(r,o.get("focus"),o.get("blurScope"),o.get("disabled"))}function fJ(r,e){return ft(r,function(t){return t=t.slice(),t[1]=e.initBaseline,t})}var vJ=function(){function r(){}return r}(),o0=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n.type="largeCandlestickBox",n}return e.prototype.getDefaultShape=function(){return new vJ},e.prototype.buildPath=function(t,n){for(var a=n.points,i=0;i<a.length;)if(this.__sign===a[i++]){var o=a[i++];t.moveTo(o,a[i++]),t.lineTo(o,a[i++])}else i+=3},e}(ie);function iM(r,e,t,n){var a=r.getData(),i=a.getLayout("largePoints"),o=new o0({shape:{points:i},__sign:1,ignoreCoarsePointer:!0});e.add(o);var s=new o0({shape:{points:i},__sign:-1,ignoreCoarsePointer:!0});e.add(s);var l=new o0({shape:{points:i},__sign:0,ignoreCoarsePointer:!0});e.add(l),s0(1,o,r),s0(-1,s,r),s0(0,l,r),n&&(o.incremental=!0,s.incremental=!0),t&&t.push(o,s)}function s0(r,e,t,n){var a=dx(r,t)||vx(r,t),i=t.getModel("itemStyle").getItemStyle(lJ);e.useStyle(i),e.style.fill=null,e.style.stroke=a}var nO=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.defaultValueDimensions=[{name:"open",defaultTooltip:!0},{name:"close",defaultTooltip:!0},{name:"lowest",defaultTooltip:!0},{name:"highest",defaultTooltip:!0}],t}return e.prototype.getShadowDim=function(){return"open"},e.prototype.brushSelector=function(t,n,a){var i=n.getItemLayout(t);return i&&a.rect(i.brushRect)},e.type="series.candlestick",e.dependencies=["xAxis","yAxis","grid"],e.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,layout:null,clip:!0,itemStyle:{color:"#eb5454",color0:"#47b262",borderColor:"#eb5454",borderColor0:"#47b262",borderColorDoji:null,borderWidth:1},emphasis:{itemStyle:{borderWidth:2}},barMaxWidth:null,barMinWidth:null,barWidth:null,large:!0,largeThreshold:600,progressive:3e3,progressiveThreshold:1e4,progressiveChunkMode:"mod",animationEasing:"linear",animationDuration:300},e}(Ve);sr(nO,tO,!0);function dJ(r){!r||!ht(r.series)||B(r.series,function(e){Vt(e)&&e.type==="k"&&(e.type="candlestick")})}var pJ={seriesType:"candlestick",plan:_u(),reset:function(r){var e=r.coordinateSystem,t=r.getData(),n=gJ(r,t),a=0,i=1,o=["x","y"],s=t.getDimensionIndex(t.mapDimension(o[a])),l=ft(t.mapDimensionsAll(o[i]),t.getDimensionIndex,t),u=l[0],c=l[1],h=l[2],d=l[3];if(t.setLayout({candleWidth:n,isSimpleBox:n<=1.3}),s<0||l.length<4)return;return{progress:r.pipelineContext.large?p:v};function v(y,_){for(var g,f=_.getStore();(g=y.next())!=null;){var w=f.get(s,g),x=f.get(u,g),S=f.get(c,g),A=f.get(h,g),T=f.get(d,g),L=Math.min(x,S),M=Math.max(x,S),I=W(L,w),R=W(M,w),P=W(A,w),E=W(T,w),D=[];$(D,R,0),$(D,I,1),D.push(K(E),K(R),K(P),K(I));var N=_.getItemModel(g),V=!!N.get(["itemStyle","borderColorDoji"]);_.setItemLayout(g,{sign:oM(f,g,x,S,c,V),initBaseline:x>S?R[i]:I[i],ends:D,brushRect:H(A,T,w)})}function W(U,j){var ut=[];return ut[a]=j,ut[i]=U,isNaN(j)||isNaN(U)?[NaN,NaN]:e.dataToPoint(ut)}function $(U,j,ut){var ot=j.slice(),it=j.slice();ot[a]=td(ot[a]+n/2,1,!1),it[a]=td(it[a]-n/2,1,!0),ut?U.push(ot,it):U.push(it,ot)}function H(U,j,ut){var ot=W(U,ut),it=W(j,ut);return ot[a]-=n/2,it[a]-=n/2,{x:ot[0],y:ot[1],width:n,height:it[1]-ot[1]}}function K(U){return U[a]=td(U[a],1),U}}function p(y,_){for(var g=Ga(y.count*4),f=0,w,x=[],S=[],A,T=_.getStore(),L=!!r.get(["itemStyle","borderColorDoji"]);(A=y.next())!=null;){var M=T.get(s,A),I=T.get(u,A),R=T.get(c,A),P=T.get(h,A),E=T.get(d,A);if(isNaN(M)||isNaN(P)||isNaN(E)){g[f++]=NaN,f+=3;continue}g[f++]=oM(T,A,I,R,c,L),x[a]=M,x[i]=P,w=e.dataToPoint(x,null,S),g[f++]=w?w[0]:NaN,g[f++]=w?w[1]:NaN,x[i]=E,w=e.dataToPoint(x,null,S),g[f++]=w?w[1]:NaN}_.setLayout("largePoints",g)}}};function oM(r,e,t,n,a,i){var o;return t>n?o=-1:t<n?o=1:o=i?0:e>0?r.get(a,e-1)<=n?1:-1:1,o}function gJ(r,e){var t=r.getBaseAxis(),n,a=t.type==="category"?t.getBandWidth():(n=t.getExtent(),Math.abs(n[1]-n[0])/e.count()),i=At(Zt(r.get("barMaxWidth"),a),a),o=At(Zt(r.get("barMinWidth"),1),a),s=r.get("barWidth");return s!=null?At(s,a):Math.max(Math.min(a/2,i),o)}function yJ(r){r.registerChartView(uJ),r.registerSeriesModel(nO),r.registerPreprocessor(dJ),r.registerVisual(sJ),r.registerLayout(pJ)}function sM(r,e){var t=e.rippleEffectColor||e.color;r.eachChild(function(n){n.attr({z:e.z,zlevel:e.zlevel,style:{stroke:e.brushType==="stroke"?t:null,fill:e.brushType==="fill"?t:null}})})}var mJ=function(r){rt(e,r);function e(t,n){var a=r.call(this)||this,i=new Nh(t,n),o=new Wt;return a.add(i),a.add(o),a.updateData(t,n),a}return e.prototype.stopEffectAnimation=function(){this.childAt(1).removeAll()},e.prototype.startEffectAnimation=function(t){for(var n=t.symbolType,a=t.color,i=t.rippleNumber,o=this.childAt(1),s=0;s<i;s++){var l=or(n,-1,-1,2,2,a);l.attr({style:{strokeNoScale:!0},z2:99,silent:!0,scaleX:.5,scaleY:.5});var u=-s/i*t.period+t.effectOffset;l.animate("",!0).when(t.period,{scaleX:t.rippleScale/2,scaleY:t.rippleScale/2}).delay(u).start(),l.animateStyle(!0).when(t.period,{opacity:0}).delay(u).start(),o.add(l)}sM(o,t)},e.prototype.updateEffectAnimation=function(t){for(var n=this._effectCfg,a=this.childAt(1),i=["symbolType","period","rippleScale","rippleNumber"],o=0;o<i.length;o++){var s=i[o];if(n[s]!==t[s]){this.stopEffectAnimation(),this.startEffectAnimation(t);return}}sM(a,t)},e.prototype.highlight=function(){Ti(this)},e.prototype.downplay=function(){Ci(this)},e.prototype.getSymbolType=function(){var t=this.childAt(0);return t&&t.getSymbolType()},e.prototype.updateData=function(t,n){var a=this,i=t.hostModel;this.childAt(0).updateData(t,n);var o=this.childAt(1),s=t.getItemModel(n),l=t.getItemVisual(n,"symbol"),u=xu(t.getItemVisual(n,"symbolSize")),c=t.getItemVisual(n,"style"),h=c&&c.fill,d=s.getModel("emphasis");o.setScale(u),o.traverse(function(_){_.setStyle("fill",h)});var v=Ys(t.getItemVisual(n,"symbolOffset"),u);v&&(o.x=v[0],o.y=v[1]);var p=t.getItemVisual(n,"symbolRotate");o.rotation=(p||0)*Math.PI/180||0;var y={};y.showEffectOn=i.get("showEffectOn"),y.rippleScale=s.get(["rippleEffect","scale"]),y.brushType=s.get(["rippleEffect","brushType"]),y.period=s.get(["rippleEffect","period"])*1e3,y.effectOffset=n/t.count(),y.z=i.getShallow("z")||0,y.zlevel=i.getShallow("zlevel")||0,y.symbolType=l,y.color=h,y.rippleEffectColor=s.get(["rippleEffect","color"]),y.rippleNumber=s.get(["rippleEffect","number"]),y.showEffectOn==="render"?(this._effectCfg?this.updateEffectAnimation(y):this.startEffectAnimation(y),this._effectCfg=y):(this._effectCfg=null,this.stopEffectAnimation(),this.onHoverStateChange=function(_){_==="emphasis"?y.showEffectOn!=="render"&&a.startEffectAnimation(y):_==="normal"&&y.showEffectOn!=="render"&&a.stopEffectAnimation()}),this._effectCfg=y,Xe(this,d.get("focus"),d.get("blurScope"),d.get("disabled"))},e.prototype.fadeOut=function(t){t&&t()},e}(Wt),_J=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){this._symbolDraw=new zh(mJ)},e.prototype.render=function(t,n,a){var i=t.getData(),o=this._symbolDraw;o.updateData(i,{clipShape:this._getClipShape(t)}),this.group.add(o.group)},e.prototype._getClipShape=function(t){var n=t.coordinateSystem,a=n&&n.getArea&&n.getArea();return t.get("clip",!0)?a:null},e.prototype.updateTransform=function(t,n,a){var i=t.getData();this.group.dirty();var o=Vh("").reset(t,n,a);o.progress&&o.progress({start:0,end:i.count(),count:i.count()},i),this._symbolDraw.updateLayout()},e.prototype._updateGroupTransform=function(t){var n=t.coordinateSystem;n&&n.getRoamTransform&&(this.group.transform=H6(n.getRoamTransform()),this.group.decomposeTransform())},e.prototype.remove=function(t,n){this._symbolDraw&&this._symbolDraw.remove(!0)},e.type="effectScatter",e}(Re),wJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t}return e.prototype.getInitialData=function(t,n){return Ri(null,this,{useEncodeDefaulter:!0})},e.prototype.brushSelector=function(t,n,a){return a.point(n.getItemLayout(t))},e.type="series.effectScatter",e.dependencies=["grid","polar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,effectType:"ripple",progressive:0,showEffectOn:"render",clip:!0,rippleEffect:{period:4,scale:2.5,brushType:"fill",number:3},universalTransition:{divideShape:"clone"},symbolSize:10},e}(Ve);function xJ(r){r.registerChartView(_J),r.registerSeriesModel(wJ),r.registerLayout(Vh("effectScatter"))}var aO=function(r){rt(e,r);function e(t,n,a){var i=r.call(this)||this;return i.add(i.createLine(t,n,a)),i._updateEffectSymbol(t,n),i}return e.prototype.createLine=function(t,n,a){return new ax(t,n,a)},e.prototype._updateEffectSymbol=function(t,n){var a=t.getItemModel(n),i=a.getModel("effect"),o=i.get("symbolSize"),s=i.get("symbol");ht(o)||(o=[o,o]);var l=t.getItemVisual(n,"style"),u=i.get("color")||l&&l.stroke,c=this.childAt(1);this._symbolType!==s&&(this.remove(c),c=or(s,-.5,-.5,1,1,u),c.z2=100,c.culling=!0,this.add(c)),c&&(c.setStyle("shadowColor",u),c.setStyle(i.getItemStyle(["color"])),c.scaleX=o[0],c.scaleY=o[1],c.setColor(u),this._symbolType=s,this._symbolScale=o,this._updateEffectAnimation(t,i,n))},e.prototype._updateEffectAnimation=function(t,n,a){var i=this.childAt(1);if(i){var o=t.getItemLayout(a),s=n.get("period")*1e3,l=n.get("loop"),u=n.get("roundTrip"),c=n.get("constantSpeed"),h=Ar(n.get("delay"),function(v){return v/t.count()*s/3});if(i.ignore=!0,this._updateAnimationPoints(i,o),c>0&&(s=this._getLineLength(i)/c*1e3),s!==this._period||l!==this._loop||u!==this._roundTrip){i.stopAnimation();var d=void 0;Nt(h)?d=h(a):d=h,i.__t>0&&(d=-s*i.__t),this._animateSymbol(i,s,d,l,u)}this._period=s,this._loop=l,this._roundTrip=u}},e.prototype._animateSymbol=function(t,n,a,i,o){if(n>0){t.__t=0;var s=this,l=t.animate("",i).when(o?n*2:n,{__t:o?2:1}).delay(a).during(function(){s._updateSymbolPosition(t)});i||l.done(function(){s.remove(t)}),l.start()}},e.prototype._getLineLength=function(t){return ao(t.__p1,t.__cp1)+ao(t.__cp1,t.__p2)},e.prototype._updateAnimationPoints=function(t,n){t.__p1=n[0],t.__p2=n[1],t.__cp1=n[2]||[(n[0][0]+n[1][0])/2,(n[0][1]+n[1][1])/2]},e.prototype.updateData=function(t,n,a){this.childAt(0).updateData(t,n,a),this._updateEffectSymbol(t,n)},e.prototype._updateSymbolPosition=function(t){var n=t.__p1,a=t.__p2,i=t.__cp1,o=t.__t<1?t.__t:2-t.__t,s=[t.x,t.y],l=s.slice(),u=Sr,c=K0;s[0]=u(n[0],i[0],a[0],o),s[1]=u(n[1],i[1],a[1],o);var h=t.__t<1?c(n[0],i[0],a[0],o):c(a[0],i[0],n[0],1-o),d=t.__t<1?c(n[1],i[1],a[1],o):c(a[1],i[1],n[1],1-o);t.rotation=-Math.atan2(d,h)-Math.PI/2,(this._symbolType==="line"||this._symbolType==="rect"||this._symbolType==="roundRect")&&(t.__lastT!==void 0&&t.__lastT<t.__t?(t.scaleY=ao(l,s)*1.05,o===1&&(s[0]=l[0]+(s[0]-l[0])/2,s[1]=l[1]+(s[1]-l[1])/2)):t.__lastT===1?t.scaleY=2*ao(n,s):t.scaleY=this._symbolScale[1]),t.__lastT=t.__t,t.ignore=!1,t.x=s[0],t.y=s[1]},e.prototype.updateLayout=function(t,n){this.childAt(0).updateLayout(t,n);var a=t.getItemModel(n).getModel("effect");this._updateEffectAnimation(t,a,n)},e}(Wt),iO=function(r){rt(e,r);function e(t,n,a){var i=r.call(this)||this;return i._createPolyline(t,n,a),i}return e.prototype._createPolyline=function(t,n,a){var i=t.getItemLayout(n),o=new nn({shape:{points:i}});this.add(o),this._updateCommonStl(t,n,a)},e.prototype.updateData=function(t,n,a){var i=t.hostModel,o=this.childAt(0),s={shape:{points:t.getItemLayout(n)}};_e(o,s,i,n),this._updateCommonStl(t,n,a)},e.prototype._updateCommonStl=function(t,n,a){var i=this.childAt(0),o=t.getItemModel(n),s=a&&a.emphasisLineStyle,l=a&&a.focus,u=a&&a.blurScope,c=a&&a.emphasisDisabled;if(!a||t.hasItemOption){var h=o.getModel("emphasis");s=h.getModel("lineStyle").getLineStyle(),c=h.get("disabled"),l=h.get("focus"),u=h.get("blurScope")}i.useStyle(t.getItemVisual(n,"style")),i.style.fill=null,i.style.strokeNoScale=!0;var d=i.ensureState("emphasis");d.style=s,Xe(this,l,u,c)},e.prototype.updateLayout=function(t,n){var a=this.childAt(0);a.setShape("points",t.getItemLayout(n))},e}(Wt),bJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t._lastFrame=0,t._lastFramePercent=0,t}return e.prototype.createLine=function(t,n,a){return new iO(t,n,a)},e.prototype._updateAnimationPoints=function(t,n){this._points=n;for(var a=[0],i=0,o=1;o<n.length;o++){var s=n[o-1],l=n[o];i+=ao(s,l),a.push(i)}if(i===0){this._length=0;return}for(var o=0;o<a.length;o++)a[o]/=i;this._offsets=a,this._length=i},e.prototype._getLineLength=function(){return this._length},e.prototype._updateSymbolPosition=function(t){var n=t.__t<1?t.__t:2-t.__t,a=this._points,i=this._offsets,o=a.length;if(i){var s=this._lastFrame,l;if(n<this._lastFramePercent){var u=Math.min(s+1,o-1);for(l=u;l>=0&&!(i[l]<=n);l--);l=Math.min(l,o-2)}else{for(l=s;l<o&&!(i[l]>n);l++);l=Math.min(l-1,o-2)}var c=(n-i[l])/(i[l+1]-i[l]),h=a[l],d=a[l+1];t.x=h[0]*(1-c)+c*d[0],t.y=h[1]*(1-c)+c*d[1];var v=t.__t<1?d[0]-h[0]:h[0]-d[0],p=t.__t<1?d[1]-h[1]:h[1]-d[1];t.rotation=-Math.atan2(p,v)-Math.PI/2,this._lastFrame=l,this._lastFramePercent=n,t.ignore=!1}},e}(aO),SJ=function(){function r(){this.polyline=!1,this.curveness=0,this.segs=[]}return r}(),AJ=function(r){rt(e,r);function e(t){var n=r.call(this,t)||this;return n._off=0,n.hoverDataIdx=-1,n}return e.prototype.reset=function(){this.notClear=!1,this._off=0},e.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},e.prototype.getDefaultShape=function(){return new SJ},e.prototype.buildPath=function(t,n){var a=n.segs,i=n.curveness,o;if(n.polyline)for(o=this._off;o<a.length;){var s=a[o++];if(s>0){t.moveTo(a[o++],a[o++]);for(var l=1;l<s;l++)t.lineTo(a[o++],a[o++])}}else for(o=this._off;o<a.length;){var u=a[o++],c=a[o++],h=a[o++],d=a[o++];if(t.moveTo(u,c),i>0){var v=(u+h)/2-(c-d)*i,p=(c+d)/2-(h-u)*i;t.quadraticCurveTo(v,p,h,d)}else t.lineTo(h,d)}this.incremental&&(this._off=o,this.notClear=!0)},e.prototype.findDataIndex=function(t,n){var a=this.shape,i=a.segs,o=a.curveness,s=this.style.lineWidth;if(a.polyline)for(var l=0,u=0;u<i.length;){var c=i[u++];if(c>0)for(var h=i[u++],d=i[u++],v=1;v<c;v++){var p=i[u++],y=i[u++];if(eo(h,d,p,y,s,t,n))return l}l++}else for(var l=0,u=0;u<i.length;){var h=i[u++],d=i[u++],p=i[u++],y=i[u++];if(o>0){var _=(h+p)/2-(d-y)*o,g=(d+y)/2-(p-h)*o;if(PP(h,d,_,g,p,y,s,t,n))return l}else if(eo(h,d,p,y,s,t,n))return l;l++}return-1},e.prototype.contain=function(t,n){var a=this.transformCoordToLocal(t,n),i=this.getBoundingRect();if(t=a[0],n=a[1],i.contain(t,n)){var o=this.hoverDataIdx=this.findDataIndex(t,n);return o>=0}return this.hoverDataIdx=-1,!1},e.prototype.getBoundingRect=function(){var t=this._rect;if(!t){for(var n=this.shape,a=n.segs,i=1/0,o=1/0,s=-1/0,l=-1/0,u=0;u<a.length;){var c=a[u++],h=a[u++];i=Math.min(c,i),s=Math.max(c,s),o=Math.min(h,o),l=Math.max(h,l)}t=this._rect=new Qt(i,o,s,l)}return t},e}(ie),TJ=function(){function r(){this.group=new Wt}return r.prototype.updateData=function(e){this._clear();var t=this._create();t.setShape({segs:e.getLayout("linesPoints")}),this._setCommon(t,e)},r.prototype.incrementalPrepareUpdate=function(e){this.group.removeAll(),this._clear()},r.prototype.incrementalUpdate=function(e,t){var n=this._newAdded[0],a=t.getLayout("linesPoints"),i=n&&n.shape.segs;if(i&&i.length<2e4){var o=i.length,s=new Float32Array(o+a.length);s.set(i),s.set(a,o),n.setShape({segs:s})}else{this._newAdded=[];var l=this._create();l.incremental=!0,l.setShape({segs:a}),this._setCommon(l,t),l.__startIndex=e.start}},r.prototype.remove=function(){this._clear()},r.prototype.eachRendered=function(e){this._newAdded[0]&&e(this._newAdded[0])},r.prototype._create=function(){var e=new AJ({cursor:"default",ignoreCoarsePointer:!0});return this._newAdded.push(e),this.group.add(e),e},r.prototype._setCommon=function(e,t,n){var a=t.hostModel;e.setShape({polyline:a.get("polyline"),curveness:a.get(["lineStyle","curveness"])}),e.useStyle(a.getModel("lineStyle").getLineStyle()),e.style.strokeNoScale=!0;var i=t.getVisual("style");i&&i.stroke&&e.setStyle("stroke",i.stroke),e.setStyle("fill",null);var o=Ht(e);o.seriesIndex=a.seriesIndex,e.on("mousemove",function(s){o.dataIndex=null;var l=e.hoverDataIdx;l>0&&(o.dataIndex=l+e.__startIndex)})},r.prototype._clear=function(){this._newAdded=[],this.group.removeAll()},r}(),oO={seriesType:"lines",plan:_u(),reset:function(r){var e=r.coordinateSystem;if(e){var t=r.get("polyline"),n=r.pipelineContext.large;return{progress:function(a,i){var o=[];if(n){var s=void 0,l=a.end-a.start;if(t){for(var u=0,c=a.start;c<a.end;c++)u+=r.getLineCoordsCount(c);s=new Float32Array(l+u*2)}else s=new Float32Array(l*4);for(var h=0,d=[],c=a.start;c<a.end;c++){var v=r.getLineCoords(c,o);t&&(s[h++]=v);for(var p=0;p<v;p++)d=e.dataToPoint(o[p],!1,d),s[h++]=d[0],s[h++]=d[1]}i.setLayout("linesPoints",s)}else for(var c=a.start;c<a.end;c++){var y=i.getItemModel(c),v=r.getLineCoords(c,o),_=[];if(t)for(var g=0;g<v;g++)_.push(e.dataToPoint(o[g]));else{_[0]=e.dataToPoint(o[0]),_[1]=e.dataToPoint(o[1]);var f=y.get(["lineStyle","curveness"]);+f&&(_[2]=[(_[0][0]+_[1][0])/2-(_[0][1]-_[1][1])*f,(_[0][1]+_[1][1])/2-(_[1][0]-_[0][0])*f])}i.setItemLayout(c,_)}}}}}},CJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=t.getData(),o=this._updateLineDraw(i,t),s=t.get("zlevel"),l=t.get(["effect","trailLength"]),u=a.getZr(),c=u.painter.getType()==="svg";c||u.painter.getLayer(s).clear(!0),this._lastZlevel!=null&&!c&&u.configLayer(this._lastZlevel,{motionBlur:!1}),this._showEffect(t)&&l>0&&(c||u.configLayer(s,{motionBlur:!0,lastFrameAlpha:Math.max(Math.min(l/10+.9,1),0)})),o.updateData(i);var h=t.get("clip",!0)&&Fh(t.coordinateSystem,!1,t);h?this.group.setClipPath(h):this.group.removeClipPath(),this._lastZlevel=s,this._finished=!0},e.prototype.incrementalPrepareRender=function(t,n,a){var i=t.getData(),o=this._updateLineDraw(i,t);o.incrementalPrepareUpdate(i),this._clearLayer(a),this._finished=!1},e.prototype.incrementalRender=function(t,n,a){this._lineDraw.incrementalUpdate(t,n.getData()),this._finished=t.end===n.getData().count()},e.prototype.eachRendered=function(t){this._lineDraw&&this._lineDraw.eachRendered(t)},e.prototype.updateTransform=function(t,n,a){var i=t.getData(),o=t.pipelineContext;if(!this._finished||o.large||o.progressiveRender)return{update:!0};var s=oO.reset(t,n,a);s.progress&&s.progress({start:0,end:i.count(),count:i.count()},i),this._lineDraw.updateLayout(),this._clearLayer(a)},e.prototype._updateLineDraw=function(t,n){var a=this._lineDraw,i=this._showEffect(n),o=!!n.get("polyline"),s=n.pipelineContext,l=s.large;return(!a||i!==this._hasEffet||o!==this._isPolyline||l!==this._isLargeDraw)&&(a&&a.remove(),a=this._lineDraw=l?new TJ:new ix(o?i?bJ:iO:i?aO:ax),this._hasEffet=i,this._isPolyline=o,this._isLargeDraw=l),this.group.add(a.group),a},e.prototype._showEffect=function(t){return!!t.get(["effect","show"])},e.prototype._clearLayer=function(t){var n=t.getZr(),a=n.painter.getType()==="svg";!a&&this._lastZlevel!=null&&n.painter.getLayer(this._lastZlevel).clear(!0)},e.prototype.remove=function(t,n){this._lineDraw&&this._lineDraw.remove(),this._lineDraw=null,this._clearLayer(n)},e.prototype.dispose=function(t,n){this.remove(t,n)},e.type="lines",e}(Re),LJ=typeof Uint32Array>"u"?Array:Uint32Array,MJ=typeof Float64Array>"u"?Array:Float64Array;function lM(r){var e=r.data;e&&e[0]&&e[0][0]&&e[0][0].coord&&(r.data=ft(e,function(t){var n=[t[0].coord,t[1].coord],a={coords:n};return t[0].name&&(a.fromName=t[0].name),t[1].name&&(a.toName=t[1].name),z1([a,t[0],t[1]])}))}var DJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.visualStyleAccessPath="lineStyle",t.visualDrawType="stroke",t}return e.prototype.init=function(t){t.data=t.data||[],lM(t);var n=this._processFlatCoordsArray(t.data);this._flatCoords=n.flatCoords,this._flatCoordsOffset=n.flatCoordsOffset,n.flatCoords&&(t.data=new Float32Array(n.count)),r.prototype.init.apply(this,arguments)},e.prototype.mergeOption=function(t){if(lM(t),t.data){var n=this._processFlatCoordsArray(t.data);this._flatCoords=n.flatCoords,this._flatCoordsOffset=n.flatCoordsOffset,n.flatCoords&&(t.data=new Float32Array(n.count))}r.prototype.mergeOption.apply(this,arguments)},e.prototype.appendData=function(t){var n=this._processFlatCoordsArray(t.data);n.flatCoords&&(this._flatCoords?(this._flatCoords=$c(this._flatCoords,n.flatCoords),this._flatCoordsOffset=$c(this._flatCoordsOffset,n.flatCoordsOffset)):(this._flatCoords=n.flatCoords,this._flatCoordsOffset=n.flatCoordsOffset),t.data=new Float32Array(n.count)),this.getRawData().appendData(t.data)},e.prototype._getCoordsFromItemModel=function(t){var n=this.getData().getItemModel(t),a=n.option instanceof Array?n.option:n.getShallow("coords");return a},e.prototype.getLineCoordsCount=function(t){return this._flatCoordsOffset?this._flatCoordsOffset[t*2+1]:this._getCoordsFromItemModel(t).length},e.prototype.getLineCoords=function(t,n){if(this._flatCoordsOffset){for(var a=this._flatCoordsOffset[t*2],i=this._flatCoordsOffset[t*2+1],o=0;o<i;o++)n[o]=n[o]||[],n[o][0]=this._flatCoords[a+o*2],n[o][1]=this._flatCoords[a+o*2+1];return i}else{for(var s=this._getCoordsFromItemModel(t),o=0;o<s.length;o++)n[o]=n[o]||[],n[o][0]=s[o][0],n[o][1]=s[o][1];return s.length}},e.prototype._processFlatCoordsArray=function(t){var n=0;if(this._flatCoords&&(n=this._flatCoords.length),ye(t[0])){for(var a=t.length,i=new LJ(a),o=new MJ(a),s=0,l=0,u=0,c=0;c<a;){u++;var h=t[c++];i[l++]=s+n,i[l++]=h;for(var d=0;d<h;d++){var v=t[c++],p=t[c++];o[s++]=v,o[s++]=p}}return{flatCoordsOffset:new Uint32Array(i.buffer,0,l),flatCoords:o,count:u}}return{flatCoordsOffset:null,flatCoords:null,count:t.length}},e.prototype.getInitialData=function(t,n){var a=new Kr(["value"],this);return a.hasItemOption=!1,a.initData(t.data,[],function(i,o,s,l){if(i instanceof Array)return NaN;a.hasItemOption=!0;var u=i.value;if(u!=null)return u instanceof Array?u[l]:u}),a},e.prototype.formatTooltip=function(t,n,a){var i=this.getData(),o=i.getItemModel(t),s=o.get("name");if(s)return s;var l=o.get("fromName"),u=o.get("toName"),c=[];return l!=null&&c.push(l),u!=null&&c.push(u),wr("nameValue",{name:c.join(" > ")})},e.prototype.preventIncremental=function(){return!!this.get(["effect","show"])},e.prototype.getProgressive=function(){var t=this.option.progressive;return t??(this.option.large?1e4:this.get("progressive"))},e.prototype.getProgressiveThreshold=function(){var t=this.option.progressiveThreshold;return t??(this.option.large?2e4:this.get("progressiveThreshold"))},e.prototype.getZLevelKey=function(){var t=this.getModel("effect"),n=t.get("trailLength");return this.getData().count()>this.getProgressiveThreshold()?this.id:t.get("show")&&n>0?n+"":""},e.type="series.lines",e.dependencies=["grid","polar","geo","calendar"],e.defaultOption={coordinateSystem:"geo",z:2,legendHoverLink:!0,xAxisIndex:0,yAxisIndex:0,symbol:["none","none"],symbolSize:[10,10],geoIndex:0,effect:{show:!1,period:4,constantSpeed:0,symbol:"circle",symbolSize:3,loop:!0,trailLength:.2},large:!1,largeThreshold:2e3,polyline:!1,clip:!0,label:{show:!1,position:"end"},lineStyle:{opacity:.5}},e}(Ve);function Rv(r){return r instanceof Array||(r=[r,r]),r}var IJ={seriesType:"lines",reset:function(r){var e=Rv(r.get("symbol")),t=Rv(r.get("symbolSize")),n=r.getData();n.setVisual("fromSymbol",e&&e[0]),n.setVisual("toSymbol",e&&e[1]),n.setVisual("fromSymbolSize",t&&t[0]),n.setVisual("toSymbolSize",t&&t[1]);function a(i,o){var s=i.getItemModel(o),l=Rv(s.getShallow("symbol",!0)),u=Rv(s.getShallow("symbolSize",!0));l[0]&&i.setItemVisual(o,"fromSymbol",l[0]),l[1]&&i.setItemVisual(o,"toSymbol",l[1]),u[0]&&i.setItemVisual(o,"fromSymbolSize",u[0]),u[1]&&i.setItemVisual(o,"toSymbolSize",u[1])}return{dataEach:n.hasItemOption?a:null}}};function PJ(r){r.registerChartView(CJ),r.registerSeriesModel(DJ),r.registerLayout(oO),r.registerVisual(IJ)}var kJ=256,RJ=function(){function r(){this.blurSize=30,this.pointSize=20,this.maxOpacity=1,this.minOpacity=0,this._gradientPixels={inRange:null,outOfRange:null};var e=_o.createCanvas();this.canvas=e}return r.prototype.update=function(e,t,n,a,i,o){var s=this._getBrush(),l=this._getGradient(i,"inRange"),u=this._getGradient(i,"outOfRange"),c=this.pointSize+this.blurSize,h=this.canvas,d=h.getContext("2d"),v=e.length;h.width=t,h.height=n;for(var p=0;p<v;++p){var y=e[p],_=y[0],g=y[1],f=y[2],w=a(f);d.globalAlpha=w,d.drawImage(s,_-c,g-c)}if(!h.width||!h.height)return h;for(var x=d.getImageData(0,0,h.width,h.height),S=x.data,A=0,T=S.length,L=this.minOpacity,M=this.maxOpacity,I=M-L;A<T;){var w=S[A+3]/256,R=Math.floor(w*(kJ-1))*4;if(w>0){var P=o(w)?l:u;w>0&&(w=w*I+L),S[A++]=P[R],S[A++]=P[R+1],S[A++]=P[R+2],S[A++]=P[R+3]*w*256}else A+=4}return d.putImageData(x,0,0),h},r.prototype._getBrush=function(){var e=this._brushCanvas||(this._brushCanvas=_o.createCanvas()),t=this.pointSize+this.blurSize,n=t*2;e.width=n,e.height=n;var a=e.getContext("2d");return a.clearRect(0,0,n,n),a.shadowOffsetX=n,a.shadowBlur=this.blurSize,a.shadowColor="#000",a.beginPath(),a.arc(-t,t,this.pointSize,0,Math.PI*2,!0),a.closePath(),a.fill(),e},r.prototype._getGradient=function(e,t){for(var n=this._gradientPixels,a=n[t]||(n[t]=new Uint8ClampedArray(256*4)),i=[0,0,0,0],o=0,s=0;s<256;s++)e[t](s/255,!0,i),a[o++]=i[0],a[o++]=i[1],a[o++]=i[2],a[o++]=i[3];return a},r}();function EJ(r,e,t){var n=r[1]-r[0];e=ft(e,function(o){return{interval:[(o.interval[0]-r[0])/n,(o.interval[1]-r[0])/n]}});var a=e.length,i=0;return function(o){var s;for(s=i;s<a;s++){var l=e[s].interval;if(l[0]<=o&&o<=l[1]){i=s;break}}if(s===a)for(s=i-1;s>=0;s--){var l=e[s].interval;if(l[0]<=o&&o<=l[1]){i=s;break}}return s>=0&&s<a&&t[s]}}function OJ(r,e){var t=r[1]-r[0];return e=[(e[0]-r[0])/t,(e[1]-r[0])/t],function(n){return n>=e[0]&&n<=e[1]}}function uM(r){var e=r.dimensions;return e[0]==="lng"&&e[1]==="lat"}var BJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i;n.eachComponent("visualMap",function(s){s.eachTargetSeries(function(l){l===t&&(i=s)})}),this._progressiveEls=null,this.group.removeAll();var o=t.coordinateSystem;o.type==="cartesian2d"||o.type==="calendar"?this._renderOnCartesianAndCalendar(t,a,0,t.getData().count()):uM(o)&&this._renderOnGeo(o,t,i,a)},e.prototype.incrementalPrepareRender=function(t,n,a){this.group.removeAll()},e.prototype.incrementalRender=function(t,n,a,i){var o=n.coordinateSystem;o&&(uM(o)?this.render(n,a,i):(this._progressiveEls=[],this._renderOnCartesianAndCalendar(n,i,t.start,t.end,!0)))},e.prototype.eachRendered=function(t){Co(this._progressiveEls||this.group,t)},e.prototype._renderOnCartesianAndCalendar=function(t,n,a,i,o){var s=t.coordinateSystem,l=$s(s,"cartesian2d"),u,c,h,d;if(l){var v=s.getAxis("x"),p=s.getAxis("y");u=v.getBandWidth()+.5,c=p.getBandWidth()+.5,h=v.scale.getExtent(),d=p.scale.getExtent()}for(var y=this.group,_=t.getData(),g=t.getModel(["emphasis","itemStyle"]).getItemStyle(),f=t.getModel(["blur","itemStyle"]).getItemStyle(),w=t.getModel(["select","itemStyle"]).getItemStyle(),x=t.get(["itemStyle","borderRadius"]),S=_r(t),A=t.getModel("emphasis"),T=A.get("focus"),L=A.get("blurScope"),M=A.get("disabled"),I=l?[_.mapDimension("x"),_.mapDimension("y"),_.mapDimension("value")]:[_.mapDimension("time"),_.mapDimension("value")],R=a;R<i;R++){var P=void 0,E=_.getItemVisual(R,"style");if(l){var D=_.get(I[0],R),N=_.get(I[1],R);if(isNaN(_.get(I[2],R))||isNaN(D)||isNaN(N)||D<h[0]||D>h[1]||N<d[0]||N>d[1])continue;var V=s.dataToPoint([D,N]);P=new fe({shape:{x:V[0]-u/2,y:V[1]-c/2,width:u,height:c},style:E})}else{if(isNaN(_.get(I[1],R)))continue;P=new fe({z2:1,shape:s.dataToRect([_.get(I[0],R)]).contentShape,style:E})}if(_.hasItemOption){var W=_.getItemModel(R),$=W.getModel("emphasis");g=$.getModel("itemStyle").getItemStyle(),f=W.getModel(["blur","itemStyle"]).getItemStyle(),w=W.getModel(["select","itemStyle"]).getItemStyle(),x=W.get(["itemStyle","borderRadius"]),T=$.get("focus"),L=$.get("blurScope"),M=$.get("disabled"),S=_r(W)}P.shape.r=x;var H=t.getRawValue(R),K="-";H&&H[2]!=null&&(K=H[2]+""),Rr(P,S,{labelFetcher:t,labelDataIndex:R,defaultOpacity:E.opacity,defaultText:K}),P.ensureState("emphasis").style=g,P.ensureState("blur").style=f,P.ensureState("select").style=w,Xe(P,T,L,M),P.incremental=o,o&&(P.states.emphasis.hoverLayer=!0),y.add(P),_.setItemGraphicEl(R,P),this._progressiveEls&&this._progressiveEls.push(P)}},e.prototype._renderOnGeo=function(t,n,a,i){var o=a.targetVisuals.inRange,s=a.targetVisuals.outOfRange,l=n.getData(),u=this._hmLayer||this._hmLayer||new RJ;u.blurSize=n.get("blurSize"),u.pointSize=n.get("pointSize"),u.minOpacity=n.get("minOpacity"),u.maxOpacity=n.get("maxOpacity");var c=t.getViewRect().clone(),h=t.getRoamTransform();c.applyTransform(h);var d=Math.max(c.x,0),v=Math.max(c.y,0),p=Math.min(c.width+c.x,i.getWidth()),y=Math.min(c.height+c.y,i.getHeight()),_=p-d,g=y-v,f=[l.mapDimension("lng"),l.mapDimension("lat"),l.mapDimension("value")],w=l.mapArray(f,function(T,L,M){var I=t.dataToPoint([T,L]);return I[0]-=d,I[1]-=v,I.push(M),I}),x=a.getExtent(),S=a.type==="visualMap.continuous"?OJ(x,a.option.range):EJ(x,a.getPieceList(),a.option.selected);u.update(w,_,g,o.color.getNormalizer(),{inRange:o.color.getColorMapper(),outOfRange:s.color.getColorMapper()},S);var A=new Tr({style:{width:_,height:g,x:d,y:v,image:u.canvas},silent:!0});this.group.add(A)},e.type="heatmap",e}(Re),NJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getInitialData=function(t,n){return Ri(null,this,{generateCoord:"value"})},e.prototype.preventIncremental=function(){var t=Rh.get(this.get("coordinateSystem"));if(t&&t.dimensions)return t.dimensions[0]==="lng"&&t.dimensions[1]==="lat"},e.type="series.heatmap",e.dependencies=["grid","geo","calendar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,geoIndex:0,blurSize:30,pointSize:20,maxOpacity:1,minOpacity:0,select:{itemStyle:{borderColor:"#212121"}}},e}(Ve);function zJ(r){r.registerChartView(BJ),r.registerSeriesModel(NJ)}var FJ=["itemStyle","borderWidth"],cM=[{xy:"x",wh:"width",index:0,posDesc:["left","right"]},{xy:"y",wh:"height",index:1,posDesc:["top","bottom"]}],l0=new ki,VJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=this.group,o=t.getData(),s=this._data,l=t.coordinateSystem,u=l.getBaseAxis(),c=u.isHorizontal(),h=l.master.getRect(),d={ecSize:{width:a.getWidth(),height:a.getHeight()},seriesModel:t,coordSys:l,coordSysExtent:[[h.x,h.x+h.width],[h.y,h.y+h.height]],isHorizontal:c,valueDim:cM[+c],categoryDim:cM[1-+c]};o.diff(s).add(function(p){if(o.hasValue(p)){var y=fM(o,p),_=hM(o,p,y,d),g=vM(o,d,_);o.setItemGraphicEl(p,g),i.add(g),pM(g,d,_)}}).update(function(p,y){var _=s.getItemGraphicEl(y);if(!o.hasValue(p)){i.remove(_);return}var g=fM(o,p),f=hM(o,p,g,d),w=fO(o,f);_&&w!==_.__pictorialShapeStr&&(i.remove(_),o.setItemGraphicEl(p,null),_=null),_?XJ(_,d,f):_=vM(o,d,f,!0),o.setItemGraphicEl(p,_),_.__pictorialSymbolMeta=f,i.add(_),pM(_,d,f)}).remove(function(p){var y=s.getItemGraphicEl(p);y&&dM(s,p,y.__pictorialSymbolMeta.animationModel,y)}).execute();var v=t.get("clip",!0)?Fh(t.coordinateSystem,!1,t):null;return v?i.setClipPath(v):i.removeClipPath(),this._data=o,this.group},e.prototype.remove=function(t,n){var a=this.group,i=this._data;t.get("animation")?i&&i.eachItemGraphicEl(function(o){dM(i,Ht(o).dataIndex,t,o)}):a.removeAll()},e.type="pictorialBar",e}(Re);function hM(r,e,t,n){var a=r.getItemLayout(e),i=t.get("symbolRepeat"),o=t.get("symbolClip"),s=t.get("symbolPosition")||"start",l=t.get("symbolRotate"),u=(l||0)*Math.PI/180||0,c=t.get("symbolPatternSize")||2,h=t.isAnimationEnabled(),d={dataIndex:e,layout:a,itemModel:t,symbolType:r.getItemVisual(e,"symbol")||"circle",style:r.getItemVisual(e,"style"),symbolClip:o,symbolRepeat:i,symbolRepeatDirection:t.get("symbolRepeatDirection"),symbolPatternSize:c,rotation:u,animationModel:h?t:null,hoverScale:h&&t.get(["emphasis","scale"]),z2:t.getShallow("z",!0)||0};GJ(t,i,a,n,d),WJ(r,e,a,i,o,d.boundingLength,d.pxSign,c,n,d),HJ(t,d.symbolScale,u,n,d);var v=d.symbolSize,p=Ys(t.get("symbolOffset"),v);return UJ(t,v,a,i,o,p,s,d.valueLineWidth,d.boundingLength,d.repeatCutLength,n,d),d}function GJ(r,e,t,n,a){var i=n.valueDim,o=r.get("symbolBoundingData"),s=n.coordSys.getOtherAxis(n.coordSys.getBaseAxis()),l=s.toGlobalCoord(s.dataToCoord(0)),u=1-+(t[i.wh]<=0),c;if(ht(o)){var h=[u0(s,o[0])-l,u0(s,o[1])-l];h[1]<h[0]&&h.reverse(),c=h[u]}else o!=null?c=u0(s,o)-l:e?c=n.coordSysExtent[i.index][u]-l:c=t[i.wh];a.boundingLength=c,e&&(a.repeatCutLength=t[i.wh]);var d=i.xy==="x",v=s.inverse;a.pxSign=d&&!v||!d&&v?c>=0?1:-1:c>0?1:-1}function u0(r,e){return r.toGlobalCoord(r.dataToCoord(r.scale.parse(e)))}function WJ(r,e,t,n,a,i,o,s,l,u){var c=l.valueDim,h=l.categoryDim,d=Math.abs(t[h.wh]),v=r.getItemVisual(e,"symbolSize"),p;ht(v)?p=v.slice():v==null?p=["100%","100%"]:p=[v,v],p[h.index]=At(p[h.index],d),p[c.index]=At(p[c.index],n?d:Math.abs(i)),u.symbolSize=p;var y=u.symbolScale=[p[0]/s,p[1]/s];y[c.index]*=(l.isHorizontal?-1:1)*o}function HJ(r,e,t,n,a){var i=r.get(FJ)||0;i&&(l0.attr({scaleX:e[0],scaleY:e[1],rotation:t}),l0.updateTransform(),i/=l0.getLineScale(),i*=e[n.valueDim.index]),a.valueLineWidth=i||0}function UJ(r,e,t,n,a,i,o,s,l,u,c,h){var d=c.categoryDim,v=c.valueDim,p=h.pxSign,y=Math.max(e[v.index]+s,0),_=y;if(n){var g=Math.abs(l),f=Ar(r.get("symbolMargin"),"15%")+"",w=!1;f.lastIndexOf("!")===f.length-1&&(w=!0,f=f.slice(0,f.length-1));var x=At(f,e[v.index]),S=Math.max(y+x*2,0),A=w?0:x*2,T=yP(n),L=T?n:gM((g+A)/S),M=g-L*y;x=M/2/(w?L:Math.max(L-1,1)),S=y+x*2,A=w?0:x*2,!T&&n!=="fixed"&&(L=u?gM((Math.abs(u)+A)/S):0),_=L*S-A,h.repeatTimes=L,h.symbolMargin=x}var I=p*(_/2),R=h.pathPosition=[];R[d.index]=t[d.wh]/2,R[v.index]=o==="start"?I:o==="end"?l-I:l/2,i&&(R[0]+=i[0],R[1]+=i[1]);var P=h.bundlePosition=[];P[d.index]=t[d.xy],P[v.index]=t[v.xy];var E=h.barRectShape=lt({},t);E[v.wh]=p*Math.max(Math.abs(t[v.wh]),Math.abs(R[v.index]+I)),E[d.wh]=t[d.wh];var D=h.clipShape={};D[d.xy]=-t[d.xy],D[d.wh]=c.ecSize[d.wh],D[v.xy]=0,D[v.wh]=t[v.wh]}function sO(r){var e=r.symbolPatternSize,t=or(r.symbolType,-e/2,-e/2,e,e);return t.attr({culling:!0}),t.type!=="image"&&t.setStyle({strokeNoScale:!0}),t}function lO(r,e,t,n){var a=r.__pictorialBundle,i=t.symbolSize,o=t.valueLineWidth,s=t.pathPosition,l=e.valueDim,u=t.repeatTimes||0,c=0,h=i[e.valueDim.index]+o+t.symbolMargin*2;for(px(r,function(y){y.__pictorialAnimationIndex=c,y.__pictorialRepeatTimes=u,c<u?ql(y,null,p(c),t,n):ql(y,null,{scaleX:0,scaleY:0},t,n,function(){a.remove(y)}),c++});c<u;c++){var d=sO(t);d.__pictorialAnimationIndex=c,d.__pictorialRepeatTimes=u,a.add(d);var v=p(c);ql(d,{x:v.x,y:v.y,scaleX:0,scaleY:0},{scaleX:v.scaleX,scaleY:v.scaleY,rotation:v.rotation},t,n)}function p(y){var _=s.slice(),g=t.pxSign,f=y;return(t.symbolRepeatDirection==="start"?g>0:g<0)&&(f=u-1-y),_[l.index]=h*(f-u/2+.5)+s[l.index],{x:_[0],y:_[1],scaleX:t.symbolScale[0],scaleY:t.symbolScale[1],rotation:t.rotation}}}function uO(r,e,t,n){var a=r.__pictorialBundle,i=r.__pictorialMainPath;i?ql(i,null,{x:t.pathPosition[0],y:t.pathPosition[1],scaleX:t.symbolScale[0],scaleY:t.symbolScale[1],rotation:t.rotation},t,n):(i=r.__pictorialMainPath=sO(t),a.add(i),ql(i,{x:t.pathPosition[0],y:t.pathPosition[1],scaleX:0,scaleY:0,rotation:t.rotation},{scaleX:t.symbolScale[0],scaleY:t.symbolScale[1]},t,n))}function cO(r,e,t){var n=lt({},e.barRectShape),a=r.__pictorialBarRect;a?ql(a,null,{shape:n},e,t):(a=r.__pictorialBarRect=new fe({z2:2,shape:n,silent:!0,style:{stroke:"transparent",fill:"transparent",lineWidth:0}}),a.disableMorphing=!0,r.add(a))}function hO(r,e,t,n){if(t.symbolClip){var a=r.__pictorialClipPath,i=lt({},t.clipShape),o=e.valueDim,s=t.animationModel,l=t.dataIndex;if(a)_e(a,{shape:i},s,l);else{i[o.wh]=0,a=new fe({shape:i}),r.__pictorialBundle.setClipPath(a),r.__pictorialClipPath=a;var u={};u[o.wh]=t.clipShape[o.wh],Zs[n?"updateProps":"initProps"](a,{shape:u},s,l)}}}function fM(r,e){var t=r.getItemModel(e);return t.getAnimationDelayParams=ZJ,t.isAnimationEnabled=YJ,t}function ZJ(r){return{index:r.__pictorialAnimationIndex,count:r.__pictorialRepeatTimes}}function YJ(){return this.parentModel.isAnimationEnabled()&&!!this.getShallow("animation")}function vM(r,e,t,n){var a=new Wt,i=new Wt;return a.add(i),a.__pictorialBundle=i,i.x=t.bundlePosition[0],i.y=t.bundlePosition[1],t.symbolRepeat?lO(a,e,t):uO(a,e,t),cO(a,t,n),hO(a,e,t,n),a.__pictorialShapeStr=fO(r,t),a.__pictorialSymbolMeta=t,a}function XJ(r,e,t){var n=t.animationModel,a=t.dataIndex,i=r.__pictorialBundle;_e(i,{x:t.bundlePosition[0],y:t.bundlePosition[1]},n,a),t.symbolRepeat?lO(r,e,t,!0):uO(r,e,t,!0),cO(r,t,!0),hO(r,e,t,!0)}function dM(r,e,t,n){var a=n.__pictorialBarRect;a&&a.removeTextContent();var i=[];px(n,function(o){i.push(o)}),n.__pictorialMainPath&&i.push(n.__pictorialMainPath),n.__pictorialClipPath&&(t=null),B(i,function(o){xo(o,{scaleX:0,scaleY:0},t,e,function(){n.parent&&n.parent.remove(n)})}),r.setItemGraphicEl(e,null)}function fO(r,e){return[r.getItemVisual(e.dataIndex,"symbol")||"none",!!e.symbolRepeat,!!e.symbolClip].join(":")}function px(r,e,t){B(r.__pictorialBundle.children(),function(n){n!==r.__pictorialBarRect&&e.call(t,n)})}function ql(r,e,t,n,a,i){e&&r.attr(e),n.symbolClip&&!a?t&&r.attr(t):t&&Zs[a?"updateProps":"initProps"](r,t,n.animationModel,n.dataIndex,i)}function pM(r,e,t){var n=t.dataIndex,a=t.itemModel,i=a.getModel("emphasis"),o=i.getModel("itemStyle").getItemStyle(),s=a.getModel(["blur","itemStyle"]).getItemStyle(),l=a.getModel(["select","itemStyle"]).getItemStyle(),u=a.getShallow("cursor"),c=i.get("focus"),h=i.get("blurScope"),d=i.get("scale");px(r,function(y){if(y instanceof Tr){var _=y.style;y.useStyle(lt({image:_.image,x:_.x,y:_.y,width:_.width,height:_.height},t.style))}else y.useStyle(t.style);var g=y.ensureState("emphasis");g.style=o,d&&(g.scaleX=y.scaleX*1.1,g.scaleY=y.scaleY*1.1),y.ensureState("blur").style=s,y.ensureState("select").style=l,u&&(y.cursor=u),y.z2=t.z2});var v=e.valueDim.posDesc[+(t.boundingLength>0)],p=r.__pictorialBarRect;p.ignoreClip=!0,Rr(p,_r(a),{labelFetcher:e.seriesModel,labelDataIndex:n,defaultText:nu(e.seriesModel.getData(),n),inheritColor:t.style.fill,defaultOpacity:t.style.opacity,defaultOutsidePosition:v}),Xe(r,c,h,i.get("disabled"))}function gM(r){var e=Math.round(r);return Math.abs(r-e)<1e-4?e:Math.ceil(r)}var $J=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.hasSymbolVisual=!0,t.defaultSymbol="roundRect",t}return e.prototype.getInitialData=function(t){return t.stack=null,r.prototype.getInitialData.apply(this,arguments)},e.type="series.pictorialBar",e.dependencies=["grid"],e.defaultOption=Lo(fh.defaultOption,{symbol:"circle",symbolSize:null,symbolRotate:null,symbolPosition:null,symbolOffset:null,symbolMargin:null,symbolRepeat:!1,symbolRepeatDirection:"end",symbolClip:!1,symbolBoundingData:null,symbolPatternSize:400,barGap:"-100%",clip:!1,progressive:0,emphasis:{scale:!1},select:{itemStyle:{borderColor:"#212121"}}}),e}(fh);function jJ(r){r.registerChartView(VJ),r.registerSeriesModel($J),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,Xt(jR,"pictorialBar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,qR("pictorialBar"))}var qJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._layers=[],t}return e.prototype.render=function(t,n,a){var i=t.getData(),o=this,s=this.group,l=t.getLayerSeries(),u=i.getLayout("layoutInfo"),c=u.rect,h=u.boundaryGap;s.x=0,s.y=c.y+h[0];function d(_){return _.name}var v=new Li(this._layersSeries||[],l,d,d),p=[];v.add(Mt(y,this,"add")).update(Mt(y,this,"update")).remove(Mt(y,this,"remove")).execute();function y(_,g,f){var w=o._layers;if(_==="remove"){s.remove(w[g]);return}for(var x=[],S=[],A,T=l[g].indices,L=0;L<T.length;L++){var M=i.getItemLayout(T[L]),I=M.x,R=M.y0,P=M.y;x.push(I,R),S.push(I,R+P),A=i.getItemVisual(T[L],"style")}var E,D=i.getItemLayout(T[0]),N=t.getModel("label"),V=N.get("margin"),W=t.getModel("emphasis");if(_==="add"){var $=p[g]=new Wt;E=new zE({shape:{points:x,stackedOnPoints:S,smooth:.4,stackedOnSmooth:.4,smoothConstraint:!1},z2:0}),$.add(E),s.add($),t.isAnimationEnabled()&&E.setClipPath(KJ(E.getBoundingRect(),t,function(){E.removeClipPath()}))}else{var $=w[f];E=$.childAt(0),s.add($),p[g]=$,_e(E,{shape:{points:x,stackedOnPoints:S}},t),xa(E)}Rr(E,_r(t),{labelDataIndex:T[L-1],defaultText:i.getName(T[L-1]),inheritColor:A.fill},{normal:{verticalAlign:"middle"}}),E.setTextConfig({position:null,local:!0});var H=E.getTextContent();H&&(H.x=D.x-V,H.y=D.y0+D.y/2),E.useStyle(A),i.setItemGraphicEl(g,E),kr(E,t),Xe(E,W.get("focus"),W.get("blurScope"),W.get("disabled"))}this._layersSeries=l,this._layers=p},e.type="themeRiver",e}(Re);function KJ(r,e,t){var n=new fe({shape:{x:r.x-10,y:r.y-10,width:0,height:r.height+20}});return He(n,{shape:{x:r.x-50,width:r.width+100,height:r.height+20}},e,t),n}var c0=2,QJ=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new Wh(Mt(this.getData,this),Mt(this.getRawData,this))},e.prototype.fixData=function(t){var n=t.length,a={},i=f_(t,function(d){return a.hasOwnProperty(d[0]+"")||(a[d[0]+""]=-1),d[2]}),o=[];i.buckets.each(function(d,v){o.push({name:v,dataList:d})});for(var s=o.length,l=0;l<s;++l){for(var u=o[l].name,c=0;c<o[l].dataList.length;++c){var h=o[l].dataList[c][0]+"";a[h]=l}for(var h in a)a.hasOwnProperty(h)&&a[h]!==l&&(a[h]=l,t[n]=[h,0,u],n++)}return t},e.prototype.getInitialData=function(t,n){for(var a=this.getReferringComponents("singleAxis",ir).models[0],i=a.get("type"),o=Te(t.data,function(p){return p[2]!==void 0}),s=this.fixData(o||[]),l=[],u=this.nameMap=Pt(),c=0,h=0;h<s.length;++h)l.push(s[h][c0]),u.get(s[h][c0])||(u.set(s[h][c0],c),c++);var d=Oh(s,{coordDimensions:["single"],dimensionsDefine:[{name:"time",type:Nd(i)},{name:"value",type:"float"},{name:"name",type:"ordinal"}],encodeDefine:{single:0,value:1,itemName:2}}).dimensions,v=new Kr(d,this);return v.initData(s),v},e.prototype.getLayerSeries=function(){for(var t=this.getData(),n=t.count(),a=[],i=0;i<n;++i)a[i]=i;var o=t.mapDimension("single"),s=f_(a,function(u){return t.get("name",u)}),l=[];return s.buckets.each(function(u,c){u.sort(function(h,d){return t.get(o,h)-t.get(o,d)}),l.push({name:c,indices:u})}),l},e.prototype.getAxisTooltipData=function(t,n,a){ht(t)||(t=t?[t]:[]);for(var i=this.getData(),o=this.getLayerSeries(),s=[],l=o.length,u,c=0;c<l;++c){for(var h=Number.MAX_VALUE,d=-1,v=o[c].indices.length,p=0;p<v;++p){var y=i.get(t[0],o[c].indices[p]),_=Math.abs(y-n);_<=h&&(u=y,h=_,d=o[c].indices[p])}s.push(d)}return{dataIndices:s,nestestValue:u}},e.prototype.formatTooltip=function(t,n,a){var i=this.getData(),o=i.getName(t),s=i.get(i.mapDimension("value"),t);return wr("nameValue",{name:o,value:s})},e.type="series.themeRiver",e.dependencies=["singleAxis"],e.defaultOption={z:2,colorBy:"data",coordinateSystem:"singleAxis",boundaryGap:["10%","10%"],singleAxisIndex:0,animationEasing:"linear",label:{margin:4,show:!0,position:"left",fontSize:11},emphasis:{label:{show:!0}}},e}(Ve);function JJ(r,e){r.eachSeriesByType("themeRiver",function(t){var n=t.getData(),a=t.coordinateSystem,i={},o=a.getRect();i.rect=o;var s=t.get("boundaryGap"),l=a.getAxis();if(i.boundaryGap=s,l.orient==="horizontal"){s[0]=At(s[0],o.height),s[1]=At(s[1],o.height);var u=o.height-s[0]-s[1];yM(n,t,u)}else{s[0]=At(s[0],o.width),s[1]=At(s[1],o.width);var c=o.width-s[0]-s[1];yM(n,t,c)}n.setLayout("layoutInfo",i)})}function yM(r,e,t){if(r.count())for(var n=e.coordinateSystem,a=e.getLayerSeries(),i=r.mapDimension("single"),o=r.mapDimension("value"),s=ft(a,function(_){return ft(_.indices,function(g){var f=n.dataToPoint(r.get(i,g));return f[1]=r.get(o,g),f})}),l=ttt(s),u=l.y0,c=t/l.max,h=a.length,d=a[0].indices.length,v,p=0;p<d;++p){v=u[p]*c,r.setItemLayout(a[0].indices[p],{layerIndex:0,x:s[0][p][0],y0:v,y:s[0][p][1]*c});for(var y=1;y<h;++y)v+=s[y-1][p][1]*c,r.setItemLayout(a[y].indices[p],{layerIndex:y,x:s[y][p][0],y0:v,y:s[y][p][1]*c})}}function ttt(r){for(var e=r.length,t=r[0].length,n=[],a=[],i=0,o=0;o<t;++o){for(var s=0,l=0;l<e;++l)s+=r[l][o][1];s>i&&(i=s),n.push(s)}for(var u=0;u<t;++u)a[u]=(i-n[u])/2;i=0;for(var c=0;c<t;++c){var h=n[c]+a[c];h>i&&(i=h)}return{y0:a,max:i}}function ett(r){r.registerChartView(qJ),r.registerSeriesModel(QJ),r.registerLayout(JJ),r.registerProcessor(Gh("themeRiver"))}var rtt=2,ntt=4,mM=function(r){rt(e,r);function e(t,n,a,i){var o=r.call(this)||this;o.z2=rtt,o.textConfig={inside:!0},Ht(o).seriesIndex=n.seriesIndex;var s=new pe({z2:ntt,silent:t.getModel().get(["label","silent"])});return o.setTextContent(s),o.updateData(!0,t,n,a,i),o}return e.prototype.updateData=function(t,n,a,i,o){this.node=n,n.piece=this,a=a||this._seriesModel,i=i||this._ecModel;var s=this;Ht(s).dataIndex=n.dataIndex;var l=n.getModel(),u=l.getModel("emphasis"),c=n.getLayout(),h=lt({},c);h.label=null;var d=n.getVisual("style");d.lineJoin="bevel";var v=n.getVisual("decal");v&&(d.decal=eu(v,o));var p=Ts(l.getModel("itemStyle"),h,!0);lt(h,p),B(tn,function(f){var w=s.ensureState(f),x=l.getModel([f,"itemStyle"]);w.style=x.getItemStyle();var S=Ts(x,h);S&&(w.shape=S)}),t?(s.setShape(h),s.shape.r=c.r0,He(s,{shape:{r:c.r}},a,n.dataIndex)):(_e(s,{shape:h},a),xa(s)),s.useStyle(d),this._updateLabel(a);var y=l.getShallow("cursor");y&&s.attr("cursor",y),this._seriesModel=a||this._seriesModel,this._ecModel=i||this._ecModel;var _=u.get("focus"),g=_==="relative"?$c(n.getAncestorsIndices(),n.getDescendantIndices()):_==="ancestor"?n.getAncestorsIndices():_==="descendant"?n.getDescendantIndices():_;Xe(this,g,u.get("blurScope"),u.get("disabled"))},e.prototype._updateLabel=function(t){var n=this,a=this.node.getModel(),i=a.getModel("label"),o=this.node.getLayout(),s=o.endAngle-o.startAngle,l=(o.startAngle+o.endAngle)/2,u=Math.cos(l),c=Math.sin(l),h=this,d=h.getTextContent(),v=this.node.dataIndex,p=i.get("minAngle")/180*Math.PI,y=i.get("show")&&!(p!=null&&Math.abs(s)<p);d.ignore=!y,B(th,function(g){var f=g==="normal"?a.getModel("label"):a.getModel([g,"label"]),w=g==="normal",x=w?d:d.ensureState(g),S=t.getFormattedLabel(v,g);w&&(S=S||n.node.name),x.style=Fe(f,{},null,g!=="normal",!0),S&&(x.style.text=S);var A=f.get("show");A!=null&&!w&&(x.ignore=!A);var T=_(f,"position"),L=w?h:h.states[g],M=L.style.fill;L.textConfig={outsideFill:f.get("color")==="inherit"?M:null,inside:T!=="outside"};var I,R=_(f,"distance")||0,P=_(f,"align"),E=_(f,"rotate"),D=Math.PI*.5,N=Math.PI*1.5,V=Cn(E==="tangential"?Math.PI/2-l:l),W=V>D&&!Qc(V-D)&&V<N;T==="outside"?(I=o.r+R,P=W?"right":"left"):!P||P==="center"?(s===2*Math.PI&&o.r0===0?I=0:I=(o.r+o.r0)/2,P="center"):P==="left"?(I=o.r0+R,P=W?"right":"left"):P==="right"&&(I=o.r-R,P=W?"left":"right"),x.style.align=P,x.style.verticalAlign=_(f,"verticalAlign")||"middle",x.x=I*u+o.cx,x.y=I*c+o.cy;var $=0;E==="radial"?$=Cn(-l)+(W?Math.PI:0):E==="tangential"?$=Cn(Math.PI/2-l)+(W?Math.PI:0):ye(E)&&($=E*Math.PI/180),x.rotation=Cn($)});function _(g,f){var w=g.get(f);return w??i.get(f)}d.dirtyStyle()},e}(en),f1="sunburstRootToNode",_M="sunburstHighlight",att="sunburstUnhighlight";function itt(r){r.registerAction({type:f1,update:"updateView"},function(e,t){t.eachComponent({mainType:"series",subType:"sunburst",query:e},n);function n(a,i){var o=dh(e,[f1],a);if(o){var s=a.getViewRoot();s&&(e.direction=Jw(s,o.node)?"rollUp":"drillDown"),a.resetViewRoot(o.node)}}}),r.registerAction({type:_M,update:"none"},function(e,t,n){e=lt({},e),t.eachComponent({mainType:"series",subType:"sunburst",query:e},a);function a(i){var o=dh(e,[_M],i);o&&(e.dataIndex=o.node.dataIndex)}n.dispatchAction(lt(e,{type:"highlight"}))}),r.registerAction({type:att,update:"updateView"},function(e,t,n){e=lt({},e),n.dispatchAction(lt(e,{type:"downplay"}))})}var ott=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a,i){var o=this;this.seriesModel=t,this.api=a,this.ecModel=n;var s=t.getData(),l=s.tree.root,u=t.getViewRoot(),c=this.group,h=t.get("renderLabelForZeroData"),d=[];u.eachNode(function(f){d.push(f)});var v=this._oldChildren||[];p(d,v),g(l,u),this._initEvents(),this._oldChildren=d;function p(f,w){if(f.length===0&&w.length===0)return;new Li(w,f,x,x).add(S).update(S).remove(Xt(S,null)).execute();function x(A){return A.getId()}function S(A,T){var L=A==null?null:f[A],M=T==null?null:w[T];y(L,M)}}function y(f,w){if(!h&&f&&!f.getValue()&&(f=null),f!==l&&w!==l){if(w&&w.piece)f?(w.piece.updateData(!1,f,t,n,a),s.setItemGraphicEl(f.dataIndex,w.piece)):_(w);else if(f){var x=new mM(f,t,n,a);c.add(x),s.setItemGraphicEl(f.dataIndex,x)}}}function _(f){f&&f.piece&&(c.remove(f.piece),f.piece=null)}function g(f,w){w.depth>0?(o.virtualPiece?o.virtualPiece.updateData(!1,f,t,n,a):(o.virtualPiece=new mM(f,t,n,a),c.add(o.virtualPiece)),w.piece.off("click"),o.virtualPiece.on("click",function(x){o._rootToNode(w.parentNode)})):o.virtualPiece&&(c.remove(o.virtualPiece),o.virtualPiece=null)}},e.prototype._initEvents=function(){var t=this;this.group.off("click"),this.group.on("click",function(n){var a=!1,i=t.seriesModel.getViewRoot();i.eachNode(function(o){if(!a&&o.piece&&o.piece===n.target){var s=o.getModel().get("nodeClick");if(s==="rootToNode")t._rootToNode(o);else if(s==="link"){var l=o.getModel(),u=l.get("link");if(u){var c=l.get("target",!0)||"_blank";Dd(u,c)}}a=!0}})})},e.prototype._rootToNode=function(t){t!==this.seriesModel.getViewRoot()&&this.api.dispatchAction({type:f1,from:this.uid,seriesId:this.seriesModel.id,targetNode:t})},e.prototype.containPoint=function(t,n){var a=n.getData(),i=a.getItemLayout(0);if(i){var o=t[0]-i.cx,s=t[1]-i.cy,l=Math.sqrt(o*o+s*s);return l<=i.r&&l>=i.r0}},e.type="sunburst",e}(Re),stt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.ignoreStyleOnData=!0,t}return e.prototype.getInitialData=function(t,n){var a={name:t.name,children:t.data};vO(a);var i=this._levelModels=ft(t.levels||[],function(l){return new De(l,this,n)},this),o=Qw.createTree(a,this,s);function s(l){l.wrapMethod("getItemModel",function(u,c){var h=o.getNodeByDataIndex(c),d=i[h.depth];return d&&(u.parentModel=d),u})}return o.data},e.prototype.optionUpdated=function(){this.resetViewRoot()},e.prototype.getDataParams=function(t){var n=r.prototype.getDataParams.apply(this,arguments),a=this.getData().tree.getNodeByDataIndex(t);return n.treePathInfo=Yp(a,this),n},e.prototype.getLevelModel=function(t){return this._levelModels&&this._levelModels[t.depth]},e.prototype.getViewRoot=function(){return this._viewRoot},e.prototype.resetViewRoot=function(t){t?this._viewRoot=t:t=this._viewRoot;var n=this.getRawData().tree.root;(!t||t!==n&&!n.contains(t))&&(this._viewRoot=n)},e.prototype.enableAriaDecal=function(){m5(this)},e.type="series.sunburst",e.defaultOption={z:2,center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,minAngle:0,stillShowZeroSum:!0,nodeClick:"rootToNode",renderLabelForZeroData:!1,label:{rotate:"radial",show:!0,opacity:1,align:"center",position:"inside",distance:5,silent:!0},itemStyle:{borderWidth:1,borderColor:"white",borderType:"solid",shadowBlur:0,shadowColor:"rgba(0, 0, 0, 0.2)",shadowOffsetX:0,shadowOffsetY:0,opacity:1},emphasis:{focus:"descendant"},blur:{itemStyle:{opacity:.2},label:{opacity:.1}},animationType:"expansion",animationDuration:1e3,animationDurationUpdate:500,data:[],sort:"desc"},e}(Ve);function vO(r){var e=0;B(r.children,function(n){vO(n);var a=n.value;ht(a)&&(a=a[0]),e+=a});var t=r.value;ht(t)&&(t=t[0]),(t==null||isNaN(t))&&(t=e),t<0&&(t=0),ht(r.value)?r.value[0]=t:r.value=t}var wM=Math.PI/180;function ltt(r,e,t){e.eachSeriesByType(r,function(n){var a=n.get("center"),i=n.get("radius");ht(i)||(i=[0,i]),ht(a)||(a=[a,a]);var o=t.getWidth(),s=t.getHeight(),l=Math.min(o,s),u=At(a[0],o),c=At(a[1],s),h=At(i[0],l/2),d=At(i[1],l/2),v=-n.get("startAngle")*wM,p=n.get("minAngle")*wM,y=n.getData().tree.root,_=n.getViewRoot(),g=_.depth,f=n.get("sort");f!=null&&dO(_,f);var w=0;B(_.children,function(V){!isNaN(V.getValue())&&w++});var x=_.getValue(),S=Math.PI/(x||w)*2,A=_.depth>0,T=_.height-(A?-1:1),L=(d-h)/(T||1),M=n.get("clockwise"),I=n.get("stillShowZeroSum"),R=M?1:-1,P=function(V,W){if(V){var $=W;if(V!==y){var H=V.getValue(),K=x===0&&I?S:H*S;K<p&&(K=p),$=W+R*K;var U=V.depth-g-(A?-1:1),j=h+L*U,ut=h+L*(U+1),ot=n.getLevelModel(V);if(ot){var it=ot.get("r0",!0),Et=ot.get("r",!0),jt=ot.get("radius",!0);jt!=null&&(it=jt[0],Et=jt[1]),it!=null&&(j=At(it,l/2)),Et!=null&&(ut=At(Et,l/2))}V.setLayout({angle:K,startAngle:W,endAngle:$,clockwise:M,cx:u,cy:c,r0:j,r:ut})}if(V.children&&V.children.length){var bt=0;B(V.children,function(wt){bt+=P(wt,W+bt)})}return $-W}};if(A){var E=h,D=h+L,N=Math.PI*2;y.setLayout({angle:N,startAngle:v,endAngle:v+N,clockwise:M,cx:u,cy:c,r0:E,r:D})}P(_,v)})}function dO(r,e){var t=r.children||[];r.children=utt(t,e),t.length&&B(r.children,function(n){dO(n,e)})}function utt(r,e){if(Nt(e)){var t=ft(r,function(a,i){var o=a.getValue();return{params:{depth:a.depth,height:a.height,dataIndex:a.dataIndex,getValue:function(){return o}},index:i}});return t.sort(function(a,i){return e(a.params,i.params)}),ft(t,function(a){return r[a.index]})}else{var n=e==="asc";return r.sort(function(a,i){var o=(a.getValue()-i.getValue())*(n?1:-1);return o===0?(a.dataIndex-i.dataIndex)*(n?-1:1):o})}}function ctt(r){var e={};function t(n,a,i){for(var o=n;o&&o.depth>1;)o=o.parentNode;var s=a.getColorFromPalette(o.name||o.dataIndex+"",e);return n.depth>1&&Lt(s)&&(s=t_(s,(n.depth-1)/(i-1)*.5)),s}r.eachSeriesByType("sunburst",function(n){var a=n.getData(),i=a.tree;i.eachNode(function(o){var s=o.getModel(),l=s.getModel("itemStyle").getItemStyle();l.fill||(l.fill=t(o,n,i.root.height));var u=a.ensureUniqueItemVisual(o.dataIndex,"style");lt(u,l)})})}function htt(r){r.registerChartView(ott),r.registerSeriesModel(stt),r.registerLayout(Xt(ltt,"sunburst")),r.registerProcessor(Xt(Gh,"sunburst")),r.registerVisual(ctt),itt(r)}var xM={color:"fill",borderColor:"stroke"},ftt={symbol:1,symbolSize:1,symbolKeepAspect:1,legendIcon:1,visualMeta:1,liftZ:1,decal:1},xi=ve(),vtt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(){this.currentZLevel=this.get("zlevel",!0),this.currentZ=this.get("z",!0)},e.prototype.getInitialData=function(t,n){return Ri(null,this)},e.prototype.getDataParams=function(t,n,a){var i=r.prototype.getDataParams.call(this,t,n);return a&&(i.info=xi(a).info),i},e.type="series.custom",e.dependencies=["grid","polar","geo","singleAxis","calendar"],e.defaultOption={coordinateSystem:"cartesian2d",z:2,legendHoverLink:!0,clip:!1},e}(Ve);function dtt(r,e){return e=e||[0,0],ft(["x","y"],function(t,n){var a=this.getAxis(t),i=e[n],o=r[n]/2;return a.type==="category"?a.getBandWidth():Math.abs(a.dataToCoord(i-o)-a.dataToCoord(i+o))},this)}function ptt(r){var e=r.master.getRect();return{coordSys:{type:"cartesian2d",x:e.x,y:e.y,width:e.width,height:e.height},api:{coord:function(t){return r.dataToPoint(t)},size:Mt(dtt,r)}}}function gtt(r,e){return e=e||[0,0],ft([0,1],function(t){var n=e[t],a=r[t]/2,i=[],o=[];return i[t]=n-a,o[t]=n+a,i[1-t]=o[1-t]=e[1-t],Math.abs(this.dataToPoint(i)[t]-this.dataToPoint(o)[t])},this)}function ytt(r){var e=r.getBoundingRect();return{coordSys:{type:"geo",x:e.x,y:e.y,width:e.width,height:e.height,zoom:r.getZoom()},api:{coord:function(t){return r.dataToPoint(t)},size:Mt(gtt,r)}}}function mtt(r,e){var t=this.getAxis(),n=e instanceof Array?e[0]:e,a=(r instanceof Array?r[0]:r)/2;return t.type==="category"?t.getBandWidth():Math.abs(t.dataToCoord(n-a)-t.dataToCoord(n+a))}function _tt(r){var e=r.getRect();return{coordSys:{type:"singleAxis",x:e.x,y:e.y,width:e.width,height:e.height},api:{coord:function(t){return r.dataToPoint(t)},size:Mt(mtt,r)}}}function wtt(r,e){return e=e||[0,0],ft(["Radius","Angle"],function(t,n){var a="get"+t+"Axis",i=this[a](),o=e[n],s=r[n]/2,l=i.type==="category"?i.getBandWidth():Math.abs(i.dataToCoord(o-s)-i.dataToCoord(o+s));return t==="Angle"&&(l=l*Math.PI/180),l},this)}function xtt(r){var e=r.getRadiusAxis(),t=r.getAngleAxis(),n=e.getExtent();return n[0]>n[1]&&n.reverse(),{coordSys:{type:"polar",cx:r.cx,cy:r.cy,r:n[1],r0:n[0]},api:{coord:function(a){var i=e.dataToRadius(a[0]),o=t.dataToAngle(a[1]),s=r.coordToPoint([i,o]);return s.push(i,o*Math.PI/180),s},size:Mt(wtt,r)}}}function btt(r){var e=r.getRect(),t=r.getRangeInfo();return{coordSys:{type:"calendar",x:e.x,y:e.y,width:e.width,height:e.height,cellWidth:r.getCellWidth(),cellHeight:r.getCellHeight(),rangeInfo:{start:t.start,end:t.end,weeks:t.weeks,dayCount:t.allDay}},api:{coord:function(n,a){return r.dataToPoint(n,a)}}}}function pO(r,e,t,n){return r&&(r.legacy||r.legacy!==!1&&!t&&!n&&e!=="tspan"&&(e==="text"||It(r,"text")))}function gO(r,e,t){var n=r,a,i,o;if(e==="text")o=n;else{o={},It(n,"text")&&(o.text=n.text),It(n,"rich")&&(o.rich=n.rich),It(n,"textFill")&&(o.fill=n.textFill),It(n,"textStroke")&&(o.stroke=n.textStroke),It(n,"fontFamily")&&(o.fontFamily=n.fontFamily),It(n,"fontSize")&&(o.fontSize=n.fontSize),It(n,"fontStyle")&&(o.fontStyle=n.fontStyle),It(n,"fontWeight")&&(o.fontWeight=n.fontWeight),i={type:"text",style:o,silent:!0},a={};var s=It(n,"textPosition");t?a.position=s?n.textPosition:"inside":s&&(a.position=n.textPosition),It(n,"textPosition")&&(a.position=n.textPosition),It(n,"textOffset")&&(a.offset=n.textOffset),It(n,"textRotation")&&(a.rotation=n.textRotation),It(n,"textDistance")&&(a.distance=n.textDistance)}return bM(o,r),B(o.rich,function(l){bM(l,l)}),{textConfig:a,textContent:i}}function bM(r,e){e&&(e.font=e.textFont||e.font,It(e,"textStrokeWidth")&&(r.lineWidth=e.textStrokeWidth),It(e,"textAlign")&&(r.align=e.textAlign),It(e,"textVerticalAlign")&&(r.verticalAlign=e.textVerticalAlign),It(e,"textLineHeight")&&(r.lineHeight=e.textLineHeight),It(e,"textWidth")&&(r.width=e.textWidth),It(e,"textHeight")&&(r.height=e.textHeight),It(e,"textBackgroundColor")&&(r.backgroundColor=e.textBackgroundColor),It(e,"textPadding")&&(r.padding=e.textPadding),It(e,"textBorderColor")&&(r.borderColor=e.textBorderColor),It(e,"textBorderWidth")&&(r.borderWidth=e.textBorderWidth),It(e,"textBorderRadius")&&(r.borderRadius=e.textBorderRadius),It(e,"textBoxShadowColor")&&(r.shadowColor=e.textBoxShadowColor),It(e,"textBoxShadowBlur")&&(r.shadowBlur=e.textBoxShadowBlur),It(e,"textBoxShadowOffsetX")&&(r.shadowOffsetX=e.textBoxShadowOffsetX),It(e,"textBoxShadowOffsetY")&&(r.shadowOffsetY=e.textBoxShadowOffsetY))}function SM(r,e,t){var n=r;n.textPosition=n.textPosition||t.position||"inside",t.offset!=null&&(n.textOffset=t.offset),t.rotation!=null&&(n.textRotation=t.rotation),t.distance!=null&&(n.textDistance=t.distance);var a=n.textPosition.indexOf("inside")>=0,i=r.fill||"#000";AM(n,e);var o=n.textFill==null;return a?o&&(n.textFill=t.insideFill||"#fff",!n.textStroke&&t.insideStroke&&(n.textStroke=t.insideStroke),!n.textStroke&&(n.textStroke=i),n.textStrokeWidth==null&&(n.textStrokeWidth=2)):(o&&(n.textFill=r.fill||t.outsideFill||"#000"),!n.textStroke&&t.outsideStroke&&(n.textStroke=t.outsideStroke)),n.text=e.text,n.rich=e.rich,B(e.rich,function(s){AM(s,s)}),n}function AM(r,e){e&&(It(e,"fill")&&(r.textFill=e.fill),It(e,"stroke")&&(r.textStroke=e.fill),It(e,"lineWidth")&&(r.textStrokeWidth=e.lineWidth),It(e,"font")&&(r.font=e.font),It(e,"fontStyle")&&(r.fontStyle=e.fontStyle),It(e,"fontWeight")&&(r.fontWeight=e.fontWeight),It(e,"fontSize")&&(r.fontSize=e.fontSize),It(e,"fontFamily")&&(r.fontFamily=e.fontFamily),It(e,"align")&&(r.textAlign=e.align),It(e,"verticalAlign")&&(r.textVerticalAlign=e.verticalAlign),It(e,"lineHeight")&&(r.textLineHeight=e.lineHeight),It(e,"width")&&(r.textWidth=e.width),It(e,"height")&&(r.textHeight=e.height),It(e,"backgroundColor")&&(r.textBackgroundColor=e.backgroundColor),It(e,"padding")&&(r.textPadding=e.padding),It(e,"borderColor")&&(r.textBorderColor=e.borderColor),It(e,"borderWidth")&&(r.textBorderWidth=e.borderWidth),It(e,"borderRadius")&&(r.textBorderRadius=e.borderRadius),It(e,"shadowColor")&&(r.textBoxShadowColor=e.shadowColor),It(e,"shadowBlur")&&(r.textBoxShadowBlur=e.shadowBlur),It(e,"shadowOffsetX")&&(r.textBoxShadowOffsetX=e.shadowOffsetX),It(e,"shadowOffsetY")&&(r.textBoxShadowOffsetY=e.shadowOffsetY),It(e,"textShadowColor")&&(r.textShadowColor=e.textShadowColor),It(e,"textShadowBlur")&&(r.textShadowBlur=e.textShadowBlur),It(e,"textShadowOffsetX")&&(r.textShadowOffsetX=e.textShadowOffsetX),It(e,"textShadowOffsetY")&&(r.textShadowOffsetY=e.textShadowOffsetY))}var yO={position:["x","y"],scale:["scaleX","scaleY"],origin:["originX","originY"]},TM=ue(yO);Za(Xa,function(r,e){return r[e]=1,r},{});Xa.join(", ");var jd=["","style","shape","extra"],ou=ve();function gx(r,e,t,n,a){var i=r+"Animation",o=vu(r,n,a)||{},s=ou(e).userDuring;return o.duration>0&&(o.during=s?Mt(Ltt,{el:e,userDuring:s}):null,o.setToFinal=!0,o.scope=r),lt(o,t[i]),o}function od(r,e,t,n){n=n||{};var a=n.dataIndex,i=n.isInit,o=n.clearStyle,s=t.isAnimationEnabled(),l=ou(r),u=e.style;l.userDuring=e.during;var c={},h={};if(Dtt(r,e,h),LM("shape",e,h),LM("extra",e,h),!i&&s&&(Mtt(r,e,c),CM("shape",r,e,c),CM("extra",r,e,c),Itt(r,e,u,c)),h.style=u,Stt(r,h,o),Ttt(r,e),s)if(i){var d={};B(jd,function(p){var y=p?e[p]:e;y&&y.enterFrom&&(p&&(d[p]=d[p]||{}),lt(p?d[p]:d,y.enterFrom))});var v=gx("enter",r,e,t,a);v.duration>0&&r.animateFrom(d,v)}else Att(r,e,a||0,t,c);mO(r,e),u?r.dirty():r.markRedraw()}function mO(r,e){for(var t=ou(r).leaveToProps,n=0;n<jd.length;n++){var a=jd[n],i=a?e[a]:e;i&&i.leaveTo&&(t||(t=ou(r).leaveToProps={}),a&&(t[a]=t[a]||{}),lt(a?t[a]:t,i.leaveTo))}}function jp(r,e,t,n){if(r){var a=r.parent,i=ou(r).leaveToProps;if(i){var o=gx("update",r,e,t,0);o.done=function(){a.remove(r)},r.animateTo(i,o)}else a.remove(r)}}function Es(r){return r==="all"}function Stt(r,e,t){var n=e.style;if(!r.isGroup&&n){if(t){r.useStyle({});for(var a=r.animators,i=0;i<a.length;i++){var o=a[i];o.targetName==="style"&&o.changeTarget(r.style)}}r.setStyle(n)}e&&(e.style=null,e&&r.attr(e),e.style=n)}function Att(r,e,t,n,a){if(a){var i=gx("update",r,e,n,t);i.duration>0&&r.animateFrom(a,i)}}function Ttt(r,e){It(e,"silent")&&(r.silent=e.silent),It(e,"ignore")&&(r.ignore=e.ignore),r instanceof ta&&It(e,"invisible")&&(r.invisible=e.invisible),r instanceof ie&&It(e,"autoBatch")&&(r.autoBatch=e.autoBatch)}var Ra={},Ctt={setTransform:function(r,e){return Ra.el[r]=e,this},getTransform:function(r){return Ra.el[r]},setShape:function(r,e){var t=Ra.el,n=t.shape||(t.shape={});return n[r]=e,t.dirtyShape&&t.dirtyShape(),this},getShape:function(r){var e=Ra.el.shape;if(e)return e[r]},setStyle:function(r,e){var t=Ra.el,n=t.style;return n&&(n[r]=e,t.dirtyStyle&&t.dirtyStyle()),this},getStyle:function(r){var e=Ra.el.style;if(e)return e[r]},setExtra:function(r,e){var t=Ra.el.extra||(Ra.el.extra={});return t[r]=e,this},getExtra:function(r){var e=Ra.el.extra;if(e)return e[r]}};function Ltt(){var r=this,e=r.el;if(e){var t=ou(e).userDuring,n=r.userDuring;if(t!==n){r.el=r.userDuring=null;return}Ra.el=e,n(Ctt)}}function CM(r,e,t,n){var a=t[r];if(a){var i=e[r],o;if(i){var s=t.transition,l=a.transition;if(l)if(!o&&(o=n[r]={}),Es(l))lt(o,i);else for(var u=Ie(l),c=0;c<u.length;c++){var h=u[c],d=i[h];o[h]=d}else if(Es(s)||te(s,r)>=0){!o&&(o=n[r]={});for(var v=ue(i),c=0;c<v.length;c++){var h=v[c],d=i[h];Ptt(a[h],d)&&(o[h]=d)}}}}}function LM(r,e,t){var n=e[r];if(n)for(var a=t[r]={},i=ue(n),o=0;o<i.length;o++){var s=i[o];a[s]=Ec(n[s])}}function Mtt(r,e,t){for(var n=e.transition,a=Es(n)?Xa:Ie(n||[]),i=0;i<a.length;i++){var o=a[i];if(!(o==="style"||o==="shape"||o==="extra")){var s=r[o];t[o]=s}}}function Dtt(r,e,t){for(var n=0;n<TM.length;n++){var a=TM[n],i=yO[a],o=e[a];o&&(t[i[0]]=o[0],t[i[1]]=o[1])}for(var n=0;n<Xa.length;n++){var s=Xa[n];e[s]!=null&&(t[s]=e[s])}}function Itt(r,e,t,n){if(t){var a=r.style,i;if(a){var o=t.transition,s=e.transition;if(o&&!Es(o)){var l=Ie(o);!i&&(i=n.style={});for(var u=0;u<l.length;u++){var c=l[u],h=a[c];i[c]=h}}else if(r.getAnimationStyleProps&&(Es(s)||Es(o)||te(s,"style")>=0)){var d=r.getAnimationStyleProps(),v=d?d.style:null;if(v){!i&&(i=n.style={});for(var p=ue(t),u=0;u<p.length;u++){var c=p[u];if(v[c]){var h=a[c];i[c]=h}}}}}}}function Ptt(r,e){return Gr(r)?r!==e:r!=null&&isFinite(r)}var _O=ve(),ktt=["percent","easing","shape","style","extra"];function wO(r){r.stopAnimation("keyframe"),r.attr(_O(r))}function qd(r,e,t){if(!(!t.isAnimationEnabled()||!e)){if(ht(e)){B(e,function(s){qd(r,s,t)});return}var n=e.keyframes,a=e.duration;if(t&&a==null){var i=vu("enter",t,0);a=i&&i.duration}if(!(!n||!a)){var o=_O(r);B(jd,function(s){if(!(s&&!r[s])){var l;n.sort(function(u,c){return u.percent-c.percent}),B(n,function(u){var c=r.animators,h=s?u[s]:u;if(h){var d=ue(h);if(s||(d=Te(d,function(y){return te(ktt,y)<0})),!!d.length){l||(l=r.animate(s,e.loop,!0),l.scope="keyframe");for(var v=0;v<c.length;v++)c[v]!==l&&c[v].targetName===l.targetName&&c[v].stopTracks(d);s&&(o[s]=o[s]||{});var p=s?o[s]:o;B(d,function(y){p[y]=((s?r[s]:r)||{})[y]}),l.whenWithKeys(a*u.percent,h,d,u.easing)}}}),l&&l.delay(e.delay||0).duration(a).start(e.easing)}})}}}var bi="emphasis",ho="normal",yx="blur",mx="select",To=[ho,bi,yx,mx],h0={normal:["itemStyle"],emphasis:[bi,"itemStyle"],blur:[yx,"itemStyle"],select:[mx,"itemStyle"]},f0={normal:["label"],emphasis:[bi,"label"],blur:[yx,"label"],select:[mx,"label"]},Rtt=["x","y"],Ett="e\0\0",Wn={normal:{},emphasis:{},blur:{},select:{}},Ott={cartesian2d:ptt,geo:ytt,single:_tt,polar:xtt,calendar:btt};function v1(r){return r instanceof ie}function d1(r){return r instanceof ta}function Btt(r,e){e.copyTransform(r),d1(e)&&d1(r)&&(e.setStyle(r.style),e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel,e.invisible=r.invisible,e.ignore=r.ignore,v1(e)&&v1(r)&&e.setShape(r.shape))}var Ntt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a,i){this._progressiveEls=null;var o=this._data,s=t.getData(),l=this.group,u=MM(t,s,n,a);o||l.removeAll(),s.diff(o).add(function(h){v0(a,null,h,u(h,i),t,l,s)}).remove(function(h){var d=o.getItemGraphicEl(h);d&&jp(d,xi(d).option,t)}).update(function(h,d){var v=o.getItemGraphicEl(d);v0(a,v,h,u(h,i),t,l,s)}).execute();var c=t.get("clip",!0)?Fh(t.coordinateSystem,!1,t):null;c?l.setClipPath(c):l.removeClipPath(),this._data=s},e.prototype.incrementalPrepareRender=function(t,n,a){this.group.removeAll(),this._data=null},e.prototype.incrementalRender=function(t,n,a,i,o){var s=n.getData(),l=MM(n,s,a,i),u=this._progressiveEls=[];function c(v){v.isGroup||(v.incremental=!0,v.ensureState("emphasis").hoverLayer=!0)}for(var h=t.start;h<t.end;h++){var d=v0(null,null,h,l(h,o),n,this.group,s);d&&(d.traverse(c),u.push(d))}},e.prototype.eachRendered=function(t){Co(this._progressiveEls||this.group,t)},e.prototype.filterForExposedEvent=function(t,n,a,i){var o=n.element;if(o==null||a.name===o)return!0;for(;(a=a.__hostTarget||a.parent)&&a!==this.group;)if(a.name===o)return!0;return!1},e.type="custom",e}(Re);function _x(r){var e=r.type,t;if(e==="path"){var n=r.shape,a=n.width!=null&&n.height!=null?{x:n.x||0,y:n.y||0,width:n.width,height:n.height}:null,i=SO(n);t=Tp(i,null,a,n.layout||"center"),xi(t).customPathData=i}else if(e==="image")t=new Tr({}),xi(t).customImagePath=r.style.image;else if(e==="text")t=new pe({});else if(e==="group")t=new Wt;else{if(e==="compoundPath")throw new Error('"compoundPath" is not supported yet.');var o=sw(e);if(!o){var s="";Ae(s)}t=new o}return xi(t).customGraphicType=e,t.name=r.name,t.z2EmphasisLift=1,t.z2SelectLift=1,t}function xx(r,e,t,n,a,i,o){wO(e);var s=a&&a.normal.cfg;s&&e.setTextConfig(s),n&&n.transition==null&&(n.transition=Rtt);var l=n&&n.style;if(l){if(e.type==="text"){var u=l;It(u,"textFill")&&(u.fill=u.textFill),It(u,"textStroke")&&(u.stroke=u.textStroke)}var c=void 0,h=v1(e)?l.decal:null;r&&h&&(h.dirty=!0,c=eu(h,r)),l.__decalPattern=c}if(d1(e)&&l){var c=l.__decalPattern;c&&(l.decal=c)}od(e,n,i,{dataIndex:t,isInit:o,clearStyle:!0}),qd(e,n.keyframeAnimation,i)}function xO(r,e,t,n,a){var i=e.isGroup?null:e,o=a&&a[r].cfg;if(i){var s=i.ensureState(r);if(n===!1){var l=i.getState(r);l&&(l.style=null)}else s.style=n||null;o&&(s.textConfig=o),zs(i)}}function ztt(r,e,t){if(!r.isGroup){var n=r,a=t.currentZ,i=t.currentZLevel;n.z=a,n.zlevel=i;var o=e.z2;o!=null&&(n.z2=o||0);for(var s=0;s<To.length;s++)Ftt(n,e,To[s])}}function Ftt(r,e,t){var n=t===ho,a=n?e:Kd(e,t),i=a?a.z2:null,o;i!=null&&(o=n?r:r.ensureState(t),o.z2=i||0)}function MM(r,e,t,n){var a=r.get("renderItem"),i=r.coordinateSystem,o={};i&&(o=i.prepareCustoms?i.prepareCustoms(i):Ott[i.type](i));for(var s=zt({getWidth:n.getWidth,getHeight:n.getHeight,getZr:n.getZr,getDevicePixelRatio:n.getDevicePixelRatio,value:x,style:A,ordinalRawValue:S,styleEmphasis:T,visual:I,barLayout:R,currentSeriesIndices:P,font:E},o.api||{}),l={context:{},seriesId:r.id,seriesName:r.name,seriesIndex:r.seriesIndex,coordSys:o.coordSys,dataInsideLength:e.count(),encode:Vtt(r.getData())},u,c,h={},d={},v={},p={},y=0;y<To.length;y++){var _=To[y];v[_]=r.getModel(h0[_]),p[_]=r.getModel(f0[_])}function g(D){return D===u?c||(c=e.getItemModel(D)):e.getItemModel(D)}function f(D,N){return e.hasItemOption?D===u?h[N]||(h[N]=g(D).getModel(h0[N])):g(D).getModel(h0[N]):v[N]}function w(D,N){return e.hasItemOption?D===u?d[N]||(d[N]=g(D).getModel(f0[N])):g(D).getModel(f0[N]):p[N]}return function(D,N){return u=D,c=null,h={},d={},a&&a(zt({dataIndexInside:D,dataIndex:e.getRawIndex(D),actionType:N?N.type:null},l),s)};function x(D,N){return N==null&&(N=u),e.getStore().get(e.getDimensionIndex(D||0),N)}function S(D,N){N==null&&(N=u),D=D||0;var V=e.getDimensionInfo(D);if(!V){var W=e.getDimensionIndex(D);return W>=0?e.getStore().get(W,N):void 0}var $=e.get(V.name,N),H=V&&V.ordinalMeta;return H?H.categories[$]:$}function A(D,N){N==null&&(N=u);var V=e.getItemVisual(N,"style"),W=V&&V.fill,$=V&&V.opacity,H=f(N,ho).getItemStyle();W!=null&&(H.fill=W),$!=null&&(H.opacity=$);var K={inheritColor:Lt(W)?W:"#000"},U=w(N,ho),j=Fe(U,null,K,!1,!0);j.text=U.getShallow("show")?Zt(r.getFormattedLabel(N,ho),nu(e,N)):null;var ut=Ld(U,K,!1);return M(D,H),H=SM(H,j,ut),D&&L(H,D),H.legacy=!0,H}function T(D,N){N==null&&(N=u);var V=f(N,bi).getItemStyle(),W=w(N,bi),$=Fe(W,null,null,!0,!0);$.text=W.getShallow("show")?Ha(r.getFormattedLabel(N,bi),r.getFormattedLabel(N,ho),nu(e,N)):null;var H=Ld(W,null,!0);return M(D,V),V=SM(V,$,H),D&&L(V,D),V.legacy=!0,V}function L(D,N){for(var V in N)It(N,V)&&(D[V]=N[V])}function M(D,N){D&&(D.textFill&&(N.textFill=D.textFill),D.textPosition&&(N.textPosition=D.textPosition))}function I(D,N){if(N==null&&(N=u),It(xM,D)){var V=e.getItemVisual(N,"style");return V?V[xM[D]]:null}if(It(ftt,D))return e.getItemVisual(N,D)}function R(D){if(i.type==="cartesian2d"){var N=i.getBaseAxis();return DZ(zt({axis:N},D))}}function P(){return t.getCurrentSeriesIndices()}function E(D){return lw(D,t)}}function Vtt(r){var e={};return B(r.dimensions,function(t){var n=r.getDimensionInfo(t);if(!n.isExtraCoord){var a=n.coordDim,i=e[a]=e[a]||[];i[n.coordDimIndex]=r.getDimensionIndex(t)}}),e}function v0(r,e,t,n,a,i,o){if(!n){i.remove(e);return}var s=bx(r,e,t,n,a,i);return s&&o.setItemGraphicEl(t,s),s&&Xe(s,n.focus,n.blurScope,n.emphasisDisabled),s}function bx(r,e,t,n,a,i){var o=-1,s=e;e&&bO(e,n,a)&&(o=te(i.childrenRef(),e),e=null);var l=!e,u=e;u?u.clearStates():(u=_x(n),s&&Btt(s,u)),n.morph===!1?u.disableMorphing=!0:u.disableMorphing&&(u.disableMorphing=!1),Wn.normal.cfg=Wn.normal.conOpt=Wn.emphasis.cfg=Wn.emphasis.conOpt=Wn.blur.cfg=Wn.blur.conOpt=Wn.select.cfg=Wn.select.conOpt=null,Wn.isLegacy=!1,Wtt(u,t,n,a,l,Wn),Gtt(u,t,n,a,l),xx(r,u,t,n,Wn,a,l),It(n,"info")&&(xi(u).info=n.info);for(var c=0;c<To.length;c++){var h=To[c];if(h!==ho){var d=Kd(n,h),v=Sx(n,d,h);xO(h,u,d,v,Wn)}}return ztt(u,n,a),n.type==="group"&&Htt(r,u,t,n,a),o>=0?i.replaceAt(u,o):i.add(u),u}function bO(r,e,t){var n=xi(r),a=e.type,i=e.shape,o=e.style;return t.isUniversalTransitionEnabled()||a!=null&&a!==n.customGraphicType||a==="path"&&Xtt(i)&&SO(i)!==n.customPathData||a==="image"&&It(o,"image")&&o.image!==n.customImagePath}function Gtt(r,e,t,n,a){var i=t.clipPath;if(i===!1)r&&r.getClipPath()&&r.removeClipPath();else if(i){var o=r.getClipPath();o&&bO(o,i,n)&&(o=null),o||(o=_x(i),r.setClipPath(o)),xx(null,o,e,i,null,n,a)}}function Wtt(r,e,t,n,a,i){if(!r.isGroup){DM(t,null,i),DM(t,bi,i);var o=i.normal.conOpt,s=i.emphasis.conOpt,l=i.blur.conOpt,u=i.select.conOpt;if(o!=null||s!=null||u!=null||l!=null){var c=r.getTextContent();if(o===!1)c&&r.removeTextContent();else{o=i.normal.conOpt=o||{type:"text"},c?c.clearStates():(c=_x(o),r.setTextContent(c)),xx(null,c,e,o,null,n,a);for(var h=o&&o.style,d=0;d<To.length;d++){var v=To[d];if(v!==ho){var p=i[v].conOpt;xO(v,c,p,Sx(o,p,v),null)}}h?c.dirty():c.markRedraw()}}}}function DM(r,e,t){var n=e?Kd(r,e):r,a=e?Sx(r,n,bi):r.style,i=r.type,o=n?n.textConfig:null,s=r.textContent,l=s?e?Kd(s,e):s:null;if(a&&(t.isLegacy||pO(a,i,!!o,!!l))){t.isLegacy=!0;var u=gO(a,i,!e);!o&&u.textConfig&&(o=u.textConfig),!l&&u.textContent&&(l=u.textContent)}if(!e&&l){var c=l;!c.type&&(c.type="text")}var h=e?t[e]:t.normal;h.cfg=o,h.conOpt=l}function Kd(r,e){return e?r?r[e]:null:r}function Sx(r,e,t){var n=e&&e.style;return n==null&&t===bi&&r&&(n=r.styleEmphasis),n}function Htt(r,e,t,n,a){var i=n.children,o=i?i.length:0,s=n.$mergeChildren,l=s==="byName"||n.diffChildrenByName,u=s===!1;if(!(!o&&!l&&!u)){if(l){Ztt({api:r,oldChildren:e.children()||[],newChildren:i||[],dataIndex:t,seriesModel:a,group:e});return}u&&e.removeAll();for(var c=0;c<o;c++){var h=i[c],d=e.childAt(c);h?(h.ignore==null&&(h.ignore=!1),bx(r,d,t,h,a,e)):d.ignore=!0}for(var v=e.childCount()-1;v>=c;v--){var p=e.childAt(v);Utt(e,p,a)}}}function Utt(r,e,t){e&&jp(e,xi(r).option,t)}function Ztt(r){new Li(r.oldChildren,r.newChildren,IM,IM,r).add(PM).update(PM).remove(Ytt).execute()}function IM(r,e){var t=r&&r.name;return t??Ett+e}function PM(r,e){var t=this.context,n=r!=null?t.newChildren[r]:null,a=e!=null?t.oldChildren[e]:null;bx(t.api,a,t.dataIndex,n,t.seriesModel,t.group)}function Ytt(r){var e=this.context,t=e.oldChildren[r];t&&jp(t,xi(t).option,e.seriesModel)}function SO(r){return r&&(r.pathData||r.d)}function Xtt(r){return r&&(It(r,"pathData")||It(r,"d"))}function $tt(r){r.registerChartView(Ntt),r.registerSeriesModel(vtt)}var gs=ve(),kM=Gt,d0=Mt,Ax=function(){function r(){this._dragging=!1,this.animationThreshold=15}return r.prototype.render=function(e,t,n,a){var i=t.get("value"),o=t.get("status");if(this._axisModel=e,this._axisPointerModel=t,this._api=n,!(!a&&this._lastValue===i&&this._lastStatus===o)){this._lastValue=i,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,i,e,t,n);var c=u.graphicKey;c!==this._lastGraphicKey&&this.clear(n),this._lastGraphicKey=c;var h=this._moveAnimation=this.determineAnimation(e,t);if(!s)s=this._group=new Wt,this.createPointerEl(s,u,e,t),this.createLabelEl(s,u,e,t),n.getZr().add(s);else{var d=Xt(RM,t,h);this.updatePointerEl(s,u,d),this.updateLabelEl(s,u,d,t)}OM(s,t,!0),this._renderHandle(i)}},r.prototype.remove=function(e){this.clear(e)},r.prototype.dispose=function(e){this.clear(e)},r.prototype.determineAnimation=function(e,t){var n=t.get("animation"),a=e.axis,i=a.type==="category",o=t.get("snap");if(!o&&!i)return!1;if(n==="auto"||n==null){var s=this.animationThreshold;if(i&&a.getBandWidth()>s)return!0;if(o){var l=Zw(e).seriesDataCount,u=a.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return n===!0},r.prototype.makeElOption=function(e,t,n,a,i){},r.prototype.createPointerEl=function(e,t,n,a){var i=t.pointer;if(i){var o=gs(e).pointerEl=new Zs[i.type](kM(t.pointer));e.add(o)}},r.prototype.createLabelEl=function(e,t,n,a){if(t.label){var i=gs(e).labelEl=new pe(kM(t.label));e.add(i),EM(i,a)}},r.prototype.updatePointerEl=function(e,t,n){var a=gs(e).pointerEl;a&&t.pointer&&(a.setStyle(t.pointer.style),n(a,{shape:t.pointer.shape}))},r.prototype.updateLabelEl=function(e,t,n,a){var i=gs(e).labelEl;i&&(i.setStyle(t.label.style),n(i,{x:t.label.x,y:t.label.y}),EM(i,a))},r.prototype._renderHandle=function(e){if(!(this._dragging||!this.updateHandleTransform)){var t=this._axisPointerModel,n=this._api.getZr(),a=this._handle,i=t.getModel("handle"),o=t.get("status");if(!i.get("show")||!o||o==="hide"){a&&n.remove(a),this._handle=null;return}var s;this._handle||(s=!0,a=this._handle=kh(i.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){Si(u.event)},onmousedown:d0(this._onHandleDragMove,this,0,0),drift:d0(this._onHandleDragMove,this),ondragend:d0(this._onHandleDragEnd,this)}),n.add(a)),OM(a,t,!1),a.setStyle(i.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=i.get("size");ht(l)||(l=[l,l]),a.scaleX=l[0]/2,a.scaleY=l[1]/2,wu(this,"_doDispatchAxisPointer",i.get("throttle")||0,"fixRate"),this._moveHandleToValue(e,s)}},r.prototype._moveHandleToValue=function(e,t){RM(this._axisPointerModel,!t&&this._moveAnimation,this._handle,p0(this.getHandleTransform(e,this._axisModel,this._axisPointerModel)))},r.prototype._onHandleDragMove=function(e,t){var n=this._handle;if(n){this._dragging=!0;var a=this.updateHandleTransform(p0(n),[e,t],this._axisModel,this._axisPointerModel);this._payloadInfo=a,n.stopAnimation(),n.attr(p0(a)),gs(n).lastProp=null,this._doDispatchAxisPointer()}},r.prototype._doDispatchAxisPointer=function(){var e=this._handle;if(e){var t=this._payloadInfo,n=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:t.cursorPoint[0],y:t.cursorPoint[1],tooltipOption:t.tooltipOption,axesInfo:[{axisDim:n.axis.dim,axisIndex:n.componentIndex}]})}},r.prototype._onHandleDragEnd=function(){this._dragging=!1;var e=this._handle;if(e){var t=this._axisPointerModel.get("value");this._moveHandleToValue(t),this._api.dispatchAction({type:"hideTip"})}},r.prototype.clear=function(e){this._lastValue=null,this._lastStatus=null;var t=e.getZr(),n=this._group,a=this._handle;t&&n&&(this._lastGraphicKey=null,n&&t.remove(n),a&&t.remove(a),this._group=null,this._handle=null,this._payloadInfo=null),oh(this,"_doDispatchAxisPointer")},r.prototype.doClear=function(){},r.prototype.buildLabel=function(e,t,n){return n=n||0,{x:e[n],y:e[1-n],width:t[n],height:t[1-n]}},r}();function RM(r,e,t,n){AO(gs(t).lastProp,n)||(gs(t).lastProp=n,e?_e(t,n,r):(t.stopAnimation(),t.attr(n)))}function AO(r,e){if(Vt(r)&&Vt(e)){var t=!0;return B(e,function(n,a){t=t&&AO(r[a],n)}),!!t}else return r===e}function EM(r,e){r[e.get(["label","show"])?"show":"hide"]()}function p0(r){return{x:r.x||0,y:r.y||0,rotation:r.rotation||0}}function OM(r,e,t){var n=e.get("z"),a=e.get("zlevel");r&&r.traverse(function(i){i.type!=="group"&&(n!=null&&(i.z=n),a!=null&&(i.zlevel=a),i.silent=t)})}function Tx(r){var e=r.get("type"),t=r.getModel(e+"Style"),n;return e==="line"?(n=t.getLineStyle(),n.fill=null):e==="shadow"&&(n=t.getAreaStyle(),n.stroke=null),n}function TO(r,e,t,n,a){var i=t.get("value"),o=CO(i,e.axis,e.ecModel,t.get("seriesDataIndices"),{precision:t.get(["label","precision"]),formatter:t.get(["label","formatter"])}),s=t.getModel("label"),l=gu(s.get("padding")||0),u=s.getFont(),c=Th(o,u),h=a.position,d=c.width+l[1]+l[3],v=c.height+l[0]+l[2],p=a.align;p==="right"&&(h[0]-=d),p==="center"&&(h[0]-=d/2);var y=a.verticalAlign;y==="bottom"&&(h[1]-=v),y==="middle"&&(h[1]-=v/2),jtt(h,d,v,n);var _=s.get("backgroundColor");(!_||_==="auto")&&(_=e.get(["axisLine","lineStyle","color"])),r.label={x:h[0],y:h[1],style:Fe(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:_}),z2:10}}function jtt(r,e,t,n){var a=n.getWidth(),i=n.getHeight();r[0]=Math.min(r[0]+e,a)-e,r[1]=Math.min(r[1]+t,i)-t,r[0]=Math.max(r[0],0),r[1]=Math.max(r[1],0)}function CO(r,e,t,n,a){r=e.scale.parse(r);var i=e.scale.getLabel({value:r},{precision:a.precision}),o=a.formatter;if(o){var s={value:Ew(e,{value:r}),axisDimension:e.dim,axisIndex:e.index,seriesData:[]};B(n,function(l){var u=t.getSeriesByIndex(l.seriesIndex),c=l.dataIndexInside,h=u&&u.getDataParams(c);h&&s.seriesData.push(h)}),Lt(o)?i=o.replace("{value}",i):Nt(o)&&(i=o(s))}return i}function Cx(r,e,t){var n=Ln();return Hs(n,n,t.rotation),Ya(n,n,t.position),_a([r.dataToCoord(e),(t.labelOffset||0)+(t.labelDirection||1)*(t.labelMargin||0)],n)}function LO(r,e,t,n,a,i){var o=Qr.innerTextLayout(t.rotation,0,t.labelDirection);t.labelMargin=a.get(["label","margin"]),TO(e,n,a,i,{position:Cx(n.axis,r,t),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function Lx(r,e,t){return t=t||0,{x1:r[t],y1:r[1-t],x2:e[t],y2:e[1-t]}}function MO(r,e,t){return t=t||0,{x:r[t],y:r[1-t],width:e[t],height:e[1-t]}}function BM(r,e,t,n,a,i){return{cx:r,cy:e,r0:t,r:n,startAngle:a,endAngle:i,clockwise:!0}}var qtt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.makeElOption=function(t,n,a,i,o){var s=a.axis,l=s.grid,u=i.get("type"),c=NM(l,s).getOtherAxis(s).getGlobalExtent(),h=s.toGlobalCoord(s.dataToCoord(n,!0));if(u&&u!=="none"){var d=Tx(i),v=Ktt[u](s,h,c);v.style=d,t.graphicKey=v.type,t.pointer=v}var p=$_(l.model,a);LO(n,t,p,a,i,o)},e.prototype.getHandleTransform=function(t,n,a){var i=$_(n.axis.grid.model,n,{labelInside:!1});i.labelMargin=a.get(["handle","margin"]);var o=Cx(n.axis,t,i);return{x:o[0],y:o[1],rotation:i.rotation+(i.labelDirection<0?Math.PI:0)}},e.prototype.updateHandleTransform=function(t,n,a,i){var o=a.axis,s=o.grid,l=o.getGlobalExtent(!0),u=NM(s,o).getOtherAxis(o).getGlobalExtent(),c=o.dim==="x"?0:1,h=[t.x,t.y];h[c]+=n[c],h[c]=Math.min(l[1],h[c]),h[c]=Math.max(l[0],h[c]);var d=(u[1]+u[0])/2,v=[d,d];v[c]=h[c];var p=[{verticalAlign:"middle"},{align:"center"}];return{x:h[0],y:h[1],rotation:t.rotation,cursorPoint:v,tooltipOption:p[c]}},e}(Ax);function NM(r,e){var t={};return t[e.dim+"AxisIndex"]=e.index,r.getCartesian(t)}var Ktt={line:function(r,e,t){var n=Lx([e,t[0]],[e,t[1]],zM(r));return{type:"Line",subPixelOptimize:!0,shape:n}},shadow:function(r,e,t){var n=Math.max(1,r.getBandWidth()),a=t[1]-t[0];return{type:"Rect",shape:MO([e-n/2,t[0]],[n,a],zM(r))}}};function zM(r){return r.dim==="x"?0:1}var Qtt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="axisPointer",e.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:"#B9BEC9",width:1,type:"dashed"},shadowStyle:{color:"rgba(210,219,238,0.2)"},label:{show:!0,formatter:null,precision:"auto",margin:3,color:"#fff",padding:[5,7,5,7],backgroundColor:"auto",borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:"#333",shadowBlur:3,shadowColor:"#aaa",shadowOffsetX:0,shadowOffsetY:2,throttle:40}},e}(le),yi=ve(),Jtt=B;function DO(r,e,t){if(!oe.node){var n=e.getZr();yi(n).records||(yi(n).records={}),tet(n,e);var a=yi(n).records[r]||(yi(n).records[r]={});a.handler=t}}function tet(r,e){if(yi(r).initialized)return;yi(r).initialized=!0,t("click",Xt(FM,"click")),t("mousemove",Xt(FM,"mousemove")),t("globalout",ret);function t(n,a){r.on(n,function(i){var o=net(e);Jtt(yi(r).records,function(s){s&&a(s,i,o.dispatchAction)}),eet(o.pendings,e)})}}function eet(r,e){var t=r.showTip.length,n=r.hideTip.length,a;t?a=r.showTip[t-1]:n&&(a=r.hideTip[n-1]),a&&(a.dispatchAction=null,e.dispatchAction(a))}function ret(r,e,t){r.handler("leave",null,t)}function FM(r,e,t,n){e.handler(r,t,n)}function net(r){var e={showTip:[],hideTip:[]},t=function(n){var a=e[n.type];a?a.push(n):(n.dispatchAction=t,r.dispatchAction(n))};return{dispatchAction:t,pendings:e}}function p1(r,e){if(!oe.node){var t=e.getZr(),n=(yi(t).records||{})[r];n&&(yi(t).records[r]=null)}}var aet=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=n.getComponent("tooltip"),o=t.get("triggerOn")||i&&i.get("triggerOn")||"mousemove|click";DO("axisPointer",a,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},e.prototype.remove=function(t,n){p1("axisPointer",n)},e.prototype.dispose=function(t,n){p1("axisPointer",n)},e.type="axisPointer",e}(Ze);function IO(r,e){var t=[],n=r.seriesIndex,a;if(n==null||!(a=e.getSeriesByIndex(n)))return{point:[]};var i=a.getData(),o=Bs(i,r);if(o==null||o<0||ht(o))return{point:[]};var s=i.getItemGraphicEl(o),l=a.coordinateSystem;if(a.getTooltipPosition)t=a.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(r.isStacked){var u=l.getBaseAxis(),c=l.getOtherAxis(u),h=c.dim,d=u.dim,v=h==="x"||h==="radius"?1:0,p=i.mapDimension(d),y=[];y[v]=i.get(p,o),y[1-v]=i.get(i.getCalculationInfo("stackResultDimension"),o),t=l.dataToPoint(y)||[]}else t=l.dataToPoint(i.getValues(ft(l.dimensions,function(g){return i.mapDimension(g)}),o))||[];else if(s){var _=s.getBoundingRect().clone();_.applyTransform(s.transform),t=[_.x+_.width/2,_.y+_.height/2]}return{point:t,el:s}}var VM=ve();function iet(r,e,t){var n=r.currTrigger,a=[r.x,r.y],i=r,o=r.dispatchAction||Mt(t.dispatchAction,t),s=e.getComponent("axisPointer").coordSysAxesInfo;if(s){sd(a)&&(a=IO({seriesIndex:i.seriesIndex,dataIndex:i.dataIndex},e).point);var l=sd(a),u=i.axesInfo,c=s.axesInfo,h=n==="leave"||sd(a),d={},v={},p={list:[],map:{}},y={showPointer:Xt(set,v),showTooltip:Xt(uet,p)};B(s.coordSysMap,function(g,f){var w=l||g.containPoint(a);B(s.coordSysAxesInfo[f],function(x,S){var A=x.axis,T=vet(u,x);if(!h&&w&&(!u||T)){var L=T&&T.value;L==null&&!l&&(L=A.pointToData(a)),L!=null&&GM(x,L,y,!1,d)}})});var _={};return B(c,function(g,f){var w=g.linkGroup;w&&!v[f]&&B(w.axesInfo,function(x,S){var A=v[S];if(x!==g&&A){var T=A.value;w.mapper&&(T=g.axis.scale.parse(w.mapper(T,WM(x),WM(g)))),_[g.key]=T}})}),B(_,function(g,f){GM(c[f],g,y,!0,d)}),cet(v,c,d),het(p,a,r,o),fet(c,o,t),d}}function GM(r,e,t,n,a){var i=r.axis;if(!(i.scale.isBlank()||!i.containData(e))){if(!r.involveSeries){t.showPointer(r,e);return}var o=oet(e,r),s=o.payloadBatch,l=o.snapToValue;s[0]&&a.seriesIndex==null&&lt(a,s[0]),!n&&r.snap&&i.containData(l)&&l!=null&&(e=l),t.showPointer(r,e,s),t.showTooltip(r,o,l)}}function oet(r,e){var t=e.axis,n=t.dim,a=r,i=[],o=Number.MAX_VALUE,s=-1;return B(e.seriesModels,function(l,u){var c=l.getData().mapDimensionsAll(n),h,d;if(l.getAxisTooltipData){var v=l.getAxisTooltipData(c,r,t);d=v.dataIndices,h=v.nestestValue}else{if(d=l.getData().indicesOfNearest(c[0],r,t.type==="category"?.5:null),!d.length)return;h=l.getData().get(c[0],d[0])}if(!(h==null||!isFinite(h))){var p=r-h,y=Math.abs(p);y<=o&&((y<o||p>=0&&s<0)&&(o=y,s=p,a=h,i.length=0),B(d,function(_){i.push({seriesIndex:l.seriesIndex,dataIndexInside:_,dataIndex:l.getData().getRawIndex(_)})}))}}),{payloadBatch:i,snapToValue:a}}function set(r,e,t,n){r[e.key]={value:t,payloadBatch:n}}function uet(r,e,t,n){var a=t.payloadBatch,i=e.axis,o=i.model,s=e.axisPointerModel;if(!(!e.triggerTooltip||!a.length)){var l=e.coordSys.model,u=vh(l),c=r.map[u];c||(c=r.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},r.list.push(c)),c.dataByAxis.push({axisDim:i.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:n,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:a.slice()})}}function cet(r,e,t){var n=t.axesInfo=[];B(e,function(a,i){var o=a.axisPointerModel.option,s=r[i];s?(!a.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!a.useHandle&&(o.status="hide"),o.status==="show"&&n.push({axisDim:a.axis.dim,axisIndex:a.axis.model.componentIndex,value:o.value})})}function het(r,e,t,n){if(sd(e)||!r.list.length){n({type:"hideTip"});return}var a=((r.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};n({type:"showTip",escapeConnect:!0,x:e[0],y:e[1],tooltipOption:t.tooltipOption,position:t.position,dataIndexInside:a.dataIndexInside,dataIndex:a.dataIndex,seriesIndex:a.seriesIndex,dataByCoordSys:r.list})}function fet(r,e,t){var n=t.getZr(),a="axisPointerLastHighlights",i=VM(n)[a]||{},o=VM(n)[a]={};B(r,function(u,c){var h=u.axisPointerModel.option;h.status==="show"&&u.triggerEmphasis&&B(h.seriesDataIndices,function(d){var v=d.seriesIndex+" | "+d.dataIndex;o[v]=d})});var s=[],l=[];B(i,function(u,c){!o[c]&&l.push(u)}),B(o,function(u,c){!i[c]&&s.push(u)}),l.length&&t.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&t.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function vet(r,e){for(var t=0;t<(r||[]).length;t++){var n=r[t];if(e.axis.dim===n.axisDim&&e.axis.model.componentIndex===n.axisIndex)return n}}function WM(r){var e=r.axis.model,t={},n=t.axisDim=r.axis.dim;return t.axisIndex=t[n+"AxisIndex"]=e.componentIndex,t.axisName=t[n+"AxisName"]=e.name,t.axisId=t[n+"AxisId"]=e.id,t}function sd(r){return!r||r[0]==null||isNaN(r[0])||r[1]==null||isNaN(r[1])}function Zh(r){js.registerAxisPointerClass("CartesianAxisPointer",qtt),r.registerComponentModel(Qtt),r.registerComponentView(aet),r.registerPreprocessor(function(e){if(e){(!e.axisPointer||e.axisPointer.length===0)&&(e.axisPointer={});var t=e.axisPointer.link;t&&!ht(t)&&(e.axisPointer.link=[t])}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,function(e,t){e.getComponent("axisPointer").coordSysAxesInfo=b$(e,t)}),r.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},iet)}function det(r){ne(a5),ne(Zh)}var pet=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.makeElOption=function(t,n,a,i,o){var s=a.axis;s.dim==="angle"&&(this.animationThreshold=Math.PI/18);var l=s.polar,u=l.getOtherAxis(s),c=u.getExtent(),h=s.dataToCoord(n),d=i.get("type");if(d&&d!=="none"){var v=Tx(i),p=yet[d](s,l,h,c);p.style=v,t.graphicKey=p.type,t.pointer=p}var y=i.get(["label","margin"]),_=get(n,a,i,l,y);TO(t,a,i,o,_)},e}(Ax);function get(r,e,t,n,a){var i=e.axis,o=i.dataToCoord(r),s=n.getAngleAxis().getExtent()[0];s=s/180*Math.PI;var l=n.getRadiusAxis().getExtent(),u,c,h;if(i.dim==="radius"){var d=Ln();Hs(d,d,s),Ya(d,d,[n.cx,n.cy]),u=_a([o,-a],d);var v=e.getModel("axisLabel").get("rotate")||0,p=Qr.innerTextLayout(s,v*Math.PI/180,-1);c=p.textAlign,h=p.textVerticalAlign}else{var y=l[1];u=n.coordToPoint([y+a,o]);var _=n.cx,g=n.cy;c=Math.abs(u[0]-_)/y<.3?"center":u[0]>_?"left":"right",h=Math.abs(u[1]-g)/y<.3?"middle":u[1]>g?"top":"bottom"}return{position:u,align:c,verticalAlign:h}}var yet={line:function(r,e,t,n){return r.dim==="angle"?{type:"Line",shape:Lx(e.coordToPoint([n[0],t]),e.coordToPoint([n[1],t]))}:{type:"Circle",shape:{cx:e.cx,cy:e.cy,r:t}}},shadow:function(r,e,t,n){var a=Math.max(1,r.getBandWidth()),i=Math.PI/180;return r.dim==="angle"?{type:"Sector",shape:BM(e.cx,e.cy,n[0],n[1],(-t-a/2)*i,(-t+a/2)*i)}:{type:"Sector",shape:BM(e.cx,e.cy,t-a/2,t+a/2,0,Math.PI*2)}}},met=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.findAxisModel=function(t){var n,a=this.ecModel;return a.eachComponent(t,function(i){i.getCoordSysModel()===this&&(n=i)},this),n},e.type="polar",e.dependencies=["radiusAxis","angleAxis"],e.defaultOption={z:0,center:["50%","50%"],radius:"80%"},e}(le),Mx=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.getCoordSysModel=function(){return this.getReferringComponents("polar",ir).models[0]},e.type="polarAxis",e}(le);sr(Mx,Bh);var _et=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="angleAxis",e}(Mx),wet=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="radiusAxis",e}(Mx),Dx=function(r){rt(e,r);function e(t,n){return r.call(this,"radius",t,n)||this}return e.prototype.pointToData=function(t,n){return this.polar.pointToData(t,n)[this.dim==="radius"?0:1]},e}(Sa);Dx.prototype.dataToRadius=Sa.prototype.dataToCoord;Dx.prototype.radiusToData=Sa.prototype.coordToData;var xet=ve(),Ix=function(r){rt(e,r);function e(t,n){return r.call(this,"angle",t,n||[0,360])||this}return e.prototype.pointToData=function(t,n){return this.polar.pointToData(t,n)[this.dim==="radius"?0:1]},e.prototype.calculateCategoryInterval=function(){var t=this,n=t.getLabelModel(),a=t.scale,i=a.getExtent(),o=a.count();if(i[1]-i[0]<1)return 0;var s=i[0],l=t.dataToCoord(s+1)-t.dataToCoord(s),u=Math.abs(l),c=Th(s==null?"":s+"",n.getFont(),"center","top"),h=Math.max(c.height,7),d=h/u;isNaN(d)&&(d=1/0);var v=Math.max(0,Math.floor(d)),p=xet(t.model),y=p.lastAutoInterval,_=p.lastTickCount;return y!=null&&_!=null&&Math.abs(y-v)<=1&&Math.abs(_-o)<=1&&y>v?v=y:(p.lastTickCount=o,p.lastAutoInterval=v),v},e}(Sa);Ix.prototype.dataToAngle=Sa.prototype.dataToCoord;Ix.prototype.angleToData=Sa.prototype.coordToData;var PO=["radius","angle"],bet=function(){function r(e){this.dimensions=PO,this.type="polar",this.cx=0,this.cy=0,this._radiusAxis=new Dx,this._angleAxis=new Ix,this.axisPointerEnabled=!0,this.name=e||"",this._radiusAxis.polar=this._angleAxis.polar=this}return r.prototype.containPoint=function(e){var t=this.pointToCoord(e);return this._radiusAxis.contain(t[0])&&this._angleAxis.contain(t[1])},r.prototype.containData=function(e){return this._radiusAxis.containData(e[0])&&this._angleAxis.containData(e[1])},r.prototype.getAxis=function(e){var t="_"+e+"Axis";return this[t]},r.prototype.getAxes=function(){return[this._radiusAxis,this._angleAxis]},r.prototype.getAxesByScale=function(e){var t=[],n=this._angleAxis,a=this._radiusAxis;return n.scale.type===e&&t.push(n),a.scale.type===e&&t.push(a),t},r.prototype.getAngleAxis=function(){return this._angleAxis},r.prototype.getRadiusAxis=function(){return this._radiusAxis},r.prototype.getOtherAxis=function(e){var t=this._angleAxis;return e===t?this._radiusAxis:t},r.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAngleAxis()},r.prototype.getTooltipAxes=function(e){var t=e!=null&&e!=="auto"?this.getAxis(e):this.getBaseAxis();return{baseAxes:[t],otherAxes:[this.getOtherAxis(t)]}},r.prototype.dataToPoint=function(e,t){return this.coordToPoint([this._radiusAxis.dataToRadius(e[0],t),this._angleAxis.dataToAngle(e[1],t)])},r.prototype.pointToData=function(e,t){var n=this.pointToCoord(e);return[this._radiusAxis.radiusToData(n[0],t),this._angleAxis.angleToData(n[1],t)]},r.prototype.pointToCoord=function(e){var t=e[0]-this.cx,n=e[1]-this.cy,a=this.getAngleAxis(),i=a.getExtent(),o=Math.min(i[0],i[1]),s=Math.max(i[0],i[1]);a.inverse?o=s-360:s=o+360;var l=Math.sqrt(t*t+n*n);t/=l,n/=l;for(var u=Math.atan2(-n,t)/Math.PI*180,c=u<o?1:-1;u<o||u>s;)u+=c*360;return[l,u]},r.prototype.coordToPoint=function(e){var t=e[0],n=e[1]/180*Math.PI,a=Math.cos(n)*t+this.cx,i=-Math.sin(n)*t+this.cy;return[a,i]},r.prototype.getArea=function(){var e=this.getAngleAxis(),t=this.getRadiusAxis(),n=t.getExtent().slice();n[0]>n[1]&&n.reverse();var a=e.getExtent(),i=Math.PI/180,o=1e-4;return{cx:this.cx,cy:this.cy,r0:n[0],r:n[1],startAngle:-a[0]*i,endAngle:-a[1]*i,clockwise:e.inverse,contain:function(s,l){var u=s-this.cx,c=l-this.cy,h=u*u+c*c,d=this.r,v=this.r0;return d!==v&&h-o<=d*d&&h+o>=v*v}}},r.prototype.convertToPixel=function(e,t,n){var a=HM(t);return a===this?this.dataToPoint(n):null},r.prototype.convertFromPixel=function(e,t,n){var a=HM(t);return a===this?this.pointToData(n):null},r}();function HM(r){var e=r.seriesModel,t=r.polarModel;return t&&t.coordinateSystem||e&&e.coordinateSystem}function Set(r,e,t){var n=e.get("center"),a=t.getWidth(),i=t.getHeight();r.cx=At(n[0],a),r.cy=At(n[1],i);var o=r.getRadiusAxis(),s=Math.min(a,i)/2,l=e.get("radius");l==null?l=[0,"100%"]:ht(l)||(l=[0,l]);var u=[At(l[0],s),At(l[1],s)];o.inverse?o.setExtent(u[1],u[0]):o.setExtent(u[0],u[1])}function Aet(r,e){var t=this,n=t.getAngleAxis(),a=t.getRadiusAxis();if(n.scale.setExtent(1/0,-1/0),a.scale.setExtent(1/0,-1/0),r.eachSeries(function(s){if(s.coordinateSystem===t){var l=s.getData();B(zd(l,"radius"),function(u){a.scale.unionExtentFromData(l,u)}),B(zd(l,"angle"),function(u){n.scale.unionExtentFromData(l,u)})}}),ru(n.scale,n.model),ru(a.scale,a.model),n.type==="category"&&!n.onBand){var i=n.getExtent(),o=360/n.scale.count();n.inverse?i[1]+=o:i[1]-=o,n.setExtent(i[0],i[1])}}function Tet(r){return r.mainType==="angleAxis"}function UM(r,e){var t;if(r.type=e.get("type"),r.scale=Wp(e),r.onBand=e.get("boundaryGap")&&r.type==="category",r.inverse=e.get("inverse"),Tet(e)){r.inverse=r.inverse!==e.get("clockwise");var n=e.get("startAngle"),a=(t=e.get("endAngle"))!==null&&t!==void 0?t:n+(r.inverse?-360:360);r.setExtent(n,a)}e.axis=r,r.model=e}var Cet={dimensions:PO,create:function(r,e){var t=[];return r.eachComponent("polar",function(n,a){var i=new bet(a+"");i.update=Aet;var o=i.getRadiusAxis(),s=i.getAngleAxis(),l=n.findAxisModel("radiusAxis"),u=n.findAxisModel("angleAxis");UM(o,l),UM(s,u),Set(i,n,e),t.push(i),n.coordinateSystem=i,i.model=n}),r.eachSeries(function(n){if(n.get("coordinateSystem")==="polar"){var a=n.getReferringComponents("polar",ir).models[0];n.coordinateSystem=a.coordinateSystem}}),t}},Let=["axisLine","axisLabel","axisTick","minorTick","splitLine","minorSplitLine","splitArea"];function Ev(r,e,t){e[1]>e[0]&&(e=e.slice().reverse());var n=r.coordToPoint([e[0],t]),a=r.coordToPoint([e[1],t]);return{x1:n[0],y1:n[1],x2:a[0],y2:a[1]}}function Ov(r){var e=r.getRadiusAxis();return e.inverse?0:1}function ZM(r){var e=r[0],t=r[r.length-1];e&&t&&Math.abs(Math.abs(e.coord-t.coord)-360)<1e-4&&r.pop()}var Met=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="PolarAxisPointer",t}return e.prototype.render=function(t,n){if(this.group.removeAll(),!!t.get("show")){var a=t.axis,i=a.polar,o=i.getRadiusAxis().getExtent(),s=a.getTicksCoords(),l=a.getMinorTicksCoords(),u=ft(a.getViewLabels(),function(c){c=Gt(c);var h=a.scale,d=h.type==="ordinal"?h.getRawOrdinalNumber(c.tickValue):c.tickValue;return c.coord=a.dataToCoord(d),c});ZM(u),ZM(s),B(Let,function(c){t.get([c,"show"])&&(!a.scale.isBlank()||c==="axisLine")&&Det[c](this.group,t,i,s,l,o,u)},this)}},e.type="angleAxis",e}(js),Det={axisLine:function(r,e,t,n,a,i){var o=e.getModel(["axisLine","lineStyle"]),s=t.getAngleAxis(),l=Math.PI/180,u=s.getExtent(),c=Ov(t),h=c?0:1,d,v=Math.abs(u[1]-u[0])===360?"Circle":"Arc";i[h]===0?d=new Zs[v]({shape:{cx:t.cx,cy:t.cy,r:i[c],startAngle:-u[0]*l,endAngle:-u[1]*l,clockwise:s.inverse},style:o.getLineStyle(),z2:1,silent:!0}):d=new Mh({shape:{cx:t.cx,cy:t.cy,r:i[c],r0:i[h]},style:o.getLineStyle(),z2:1,silent:!0}),d.style.fill=null,r.add(d)},axisTick:function(r,e,t,n,a,i){var o=e.getModel("axisTick"),s=(o.get("inside")?-1:1)*o.get("length"),l=i[Ov(t)],u=ft(n,function(c){return new gr({shape:Ev(t,[l,l+s],c.coord)})});r.add(qn(u,{style:zt(o.getModel("lineStyle").getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])})}))},minorTick:function(r,e,t,n,a,i){if(a.length){for(var o=e.getModel("axisTick"),s=e.getModel("minorTick"),l=(o.get("inside")?-1:1)*s.get("length"),u=i[Ov(t)],c=[],h=0;h<a.length;h++)for(var d=0;d<a[h].length;d++)c.push(new gr({shape:Ev(t,[u,u+l],a[h][d].coord)}));r.add(qn(c,{style:zt(s.getModel("lineStyle").getLineStyle(),zt(o.getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])}))}))}},axisLabel:function(r,e,t,n,a,i,o){var s=e.getCategories(!0),l=e.getModel("axisLabel"),u=l.get("margin"),c=e.get("triggerEvent");B(o,function(h,d){var v=l,p=h.tickValue,y=i[Ov(t)],_=t.coordToPoint([y+u,h.coord]),g=t.cx,f=t.cy,w=Math.abs(_[0]-g)/y<.3?"center":_[0]>g?"left":"right",x=Math.abs(_[1]-f)/y<.3?"middle":_[1]>f?"top":"bottom";if(s&&s[p]){var S=s[p];Vt(S)&&S.textStyle&&(v=new De(S.textStyle,l,l.ecModel))}var A=new pe({silent:Qr.isLabelSilent(e),style:Fe(v,{x:_[0],y:_[1],fill:v.getTextColor()||e.get(["axisLine","lineStyle","color"]),text:h.formattedLabel,align:w,verticalAlign:x})});if(r.add(A),c){var T=Qr.makeAxisEventDataBase(e);T.targetType="axisLabel",T.value=h.rawLabel,Ht(A).eventData=T}},this)},splitLine:function(r,e,t,n,a,i){var o=e.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var c=[],h=0;h<n.length;h++){var d=u++%l.length;c[d]=c[d]||[],c[d].push(new gr({shape:Ev(t,i,n[h].coord)}))}for(var h=0;h<c.length;h++)r.add(qn(c[h],{style:zt({stroke:l[h%l.length]},s.getLineStyle()),silent:!0,z:e.get("z")}))},minorSplitLine:function(r,e,t,n,a,i){if(a.length){for(var o=e.getModel("minorSplitLine"),s=o.getModel("lineStyle"),l=[],u=0;u<a.length;u++)for(var c=0;c<a[u].length;c++)l.push(new gr({shape:Ev(t,i,a[u][c].coord)}));r.add(qn(l,{style:s.getLineStyle(),silent:!0,z:e.get("z")}))}},splitArea:function(r,e,t,n,a,i){if(n.length){var o=e.getModel("splitArea"),s=o.getModel("areaStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var c=[],h=Math.PI/180,d=-n[0].coord*h,v=Math.min(i[0],i[1]),p=Math.max(i[0],i[1]),y=e.get("clockwise"),_=1,g=n.length;_<=g;_++){var f=_===g?n[0].coord:n[_].coord,w=u++%l.length;c[w]=c[w]||[],c[w].push(new en({shape:{cx:t.cx,cy:t.cy,r0:v,r:p,startAngle:d,endAngle:-f*h,clockwise:y},silent:!0})),d=-f*h}for(var _=0;_<c.length;_++)r.add(qn(c[_],{style:zt({fill:l[_%l.length]},s.getAreaStyle()),silent:!0}))}}},Iet=["axisLine","axisTickLabel","axisName"],Pet=["splitLine","splitArea","minorSplitLine"],ket=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="PolarAxisPointer",t}return e.prototype.render=function(t,n){if(this.group.removeAll(),!!t.get("show")){var a=this._axisGroup,i=this._axisGroup=new Wt;this.group.add(i);var o=t.axis,s=o.polar,l=s.getAngleAxis(),u=o.getTicksCoords(),c=o.getMinorTicksCoords(),h=l.getExtent()[0],d=o.getExtent(),v=Eet(s,t,h),p=new Qr(t,v);B(Iet,p.add,p),i.add(p.getGroup()),Ph(a,i,t),B(Pet,function(y){t.get([y,"show"])&&!o.scale.isBlank()&&Ret[y](this.group,t,s,h,d,u,c)},this)}},e.type="radiusAxis",e}(js),Ret={splitLine:function(r,e,t,n,a,i){var o=e.getModel("splitLine"),s=o.getModel("lineStyle"),l=s.get("color"),u=0,c=t.getAngleAxis(),h=Math.PI/180,d=c.getExtent(),v=Math.abs(d[1]-d[0])===360?"Circle":"Arc";l=l instanceof Array?l:[l];for(var p=[],y=0;y<i.length;y++){var _=u++%l.length;p[_]=p[_]||[],p[_].push(new Zs[v]({shape:{cx:t.cx,cy:t.cy,r:Math.max(i[y].coord,0),startAngle:-d[0]*h,endAngle:-d[1]*h,clockwise:c.inverse}}))}for(var y=0;y<p.length;y++)r.add(qn(p[y],{style:zt({stroke:l[y%l.length],fill:null},s.getLineStyle()),silent:!0}))},minorSplitLine:function(r,e,t,n,a,i,o){if(o.length){for(var s=e.getModel("minorSplitLine"),l=s.getModel("lineStyle"),u=[],c=0;c<o.length;c++)for(var h=0;h<o[c].length;h++)u.push(new ki({shape:{cx:t.cx,cy:t.cy,r:o[c][h].coord}}));r.add(qn(u,{style:zt({fill:null},l.getLineStyle()),silent:!0}))}},splitArea:function(r,e,t,n,a,i){if(i.length){var o=e.getModel("splitArea"),s=o.getModel("areaStyle"),l=s.get("color"),u=0;l=l instanceof Array?l:[l];for(var c=[],h=i[0].coord,d=1;d<i.length;d++){var v=u++%l.length;c[v]=c[v]||[],c[v].push(new en({shape:{cx:t.cx,cy:t.cy,r0:h,r:i[d].coord,startAngle:0,endAngle:Math.PI*2},silent:!0})),h=i[d].coord}for(var d=0;d<c.length;d++)r.add(qn(c[d],{style:zt({fill:l[d%l.length]},s.getAreaStyle()),silent:!0}))}}};function Eet(r,e,t){return{position:[r.cx,r.cy],rotation:t/180*Math.PI,labelDirection:-1,tickDirection:-1,nameDirection:1,labelRotate:e.getModel("axisLabel").get("rotate"),z2:1}}function kO(r){return r.get("stack")||"__ec_stack_"+r.seriesIndex}function RO(r,e){return e.dim+r.model.componentIndex}function Oet(r,e,t){var n={},a=Bet(Te(e.getSeriesByType(r),function(i){return!e.isSeriesFiltered(i)&&i.coordinateSystem&&i.coordinateSystem.type==="polar"}));e.eachSeriesByType(r,function(i){if(i.coordinateSystem.type==="polar"){var o=i.getData(),s=i.coordinateSystem,l=s.getBaseAxis(),u=RO(s,l),c=kO(i),h=a[u][c],d=h.offset,v=h.width,p=s.getOtherAxis(l),y=i.coordinateSystem.cx,_=i.coordinateSystem.cy,g=i.get("barMinHeight")||0,f=i.get("barMinAngle")||0;n[c]=n[c]||[];for(var w=o.mapDimension(p.dim),x=o.mapDimension(l.dim),S=So(o,w),A=l.dim!=="radius"||!i.get("roundCap",!0),T=p.model,L=T.get("startValue"),M=p.dataToCoord(L||0),I=0,R=o.count();I<R;I++){var P=o.get(w,I),E=o.get(x,I),D=P>=0?"p":"n",N=M;S&&(n[c][E]||(n[c][E]={p:M,n:M}),N=n[c][E][D]);var V=void 0,W=void 0,$=void 0,H=void 0;if(p.dim==="radius"){var K=p.dataToCoord(P)-M,U=l.dataToCoord(E);Math.abs(K)<g&&(K=(K<0?-1:1)*g),V=N,W=N+K,$=U-d,H=$-v,S&&(n[c][E][D]=W)}else{var j=p.dataToCoord(P,A)-M,ut=l.dataToCoord(E);Math.abs(j)<f&&(j=(j<0?-1:1)*f),V=ut+d,W=V+v,$=N,H=N+j,S&&(n[c][E][D]=H)}o.setItemLayout(I,{cx:y,cy:_,r0:V,r:W,startAngle:-$*Math.PI/180,endAngle:-H*Math.PI/180,clockwise:$>=H})}}})}function Bet(r){var e={};B(r,function(n,a){var i=n.getData(),o=n.coordinateSystem,s=o.getBaseAxis(),l=RO(o,s),u=s.getExtent(),c=s.type==="category"?s.getBandWidth():Math.abs(u[1]-u[0])/i.count(),h=e[l]||{bandWidth:c,remainedWidth:c,autoWidthCount:0,categoryGap:"20%",gap:"30%",stacks:{}},d=h.stacks;e[l]=h;var v=kO(n);d[v]||h.autoWidthCount++,d[v]=d[v]||{width:0,maxWidth:0};var p=At(n.get("barWidth"),c),y=At(n.get("barMaxWidth"),c),_=n.get("barGap"),g=n.get("barCategoryGap");p&&!d[v].width&&(p=Math.min(h.remainedWidth,p),d[v].width=p,h.remainedWidth-=p),y&&(d[v].maxWidth=y),_!=null&&(h.gap=_),g!=null&&(h.categoryGap=g)});var t={};return B(e,function(n,a){t[a]={};var i=n.stacks,o=n.bandWidth,s=At(n.categoryGap,o),l=At(n.gap,1),u=n.remainedWidth,c=n.autoWidthCount,h=(u-s)/(c+(c-1)*l);h=Math.max(h,0),B(i,function(y,_){var g=y.maxWidth;g&&g<h&&(g=Math.min(g,u),y.width&&(g=Math.min(g,y.width)),u-=g,y.width=g,c--)}),h=(u-s)/(c+(c-1)*l),h=Math.max(h,0);var d=0,v;B(i,function(y,_){y.width||(y.width=h),v=y,d+=y.width*(1+l)}),v&&(d-=v.width*l);var p=-d/2;B(i,function(y,_){t[a][_]=t[a][_]||{offset:p,width:y.width},p+=y.width*(1+l)})}),t}var Net={startAngle:90,clockwise:!0,splitNumber:12,axisLabel:{rotate:0}},zet={splitNumber:5},Fet=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="polar",e}(Ze);function Vet(r){ne(Zh),js.registerAxisPointerClass("PolarAxisPointer",pet),r.registerCoordinateSystem("polar",Cet),r.registerComponentModel(met),r.registerComponentView(Fet),au(r,"angle",_et,Net),au(r,"radius",wet,zet),r.registerComponentView(Met),r.registerComponentView(ket),r.registerLayout(Xt(Oet,"bar"))}function g1(r,e){e=e||{};var t=r.coordinateSystem,n=r.axis,a={},i=n.position,o=n.orient,s=t.getRect(),l=[s.x,s.x+s.width,s.y,s.y+s.height],u={horizontal:{top:l[2],bottom:l[3]},vertical:{left:l[0],right:l[1]}};a.position=[o==="vertical"?u.vertical[i]:l[0],o==="horizontal"?u.horizontal[i]:l[3]];var c={horizontal:0,vertical:1};a.rotation=Math.PI/2*c[o];var h={top:-1,bottom:1,right:1,left:-1};a.labelDirection=a.tickDirection=a.nameDirection=h[i],r.get(["axisTick","inside"])&&(a.tickDirection=-a.tickDirection),Ar(e.labelInside,r.get(["axisLabel","inside"]))&&(a.labelDirection=-a.labelDirection);var d=e.rotate;return d==null&&(d=r.get(["axisLabel","rotate"])),a.labelRotation=i==="top"?-d:d,a.z2=1,a}var Get=["axisLine","axisTickLabel","axisName"],Wet=["splitArea","splitLine"],Het=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.axisPointerClass="SingleAxisPointer",t}return e.prototype.render=function(t,n,a,i){var o=this.group;o.removeAll();var s=this._axisGroup;this._axisGroup=new Wt;var l=g1(t),u=new Qr(t,l);B(Get,u.add,u),o.add(this._axisGroup),o.add(u.getGroup()),B(Wet,function(c){t.get([c,"show"])&&Uet[c](this,this.group,this._axisGroup,t)},this),Ph(s,this._axisGroup,t),r.prototype.render.call(this,t,n,a,i)},e.prototype.remove=function(){e5(this)},e.type="singleAxis",e}(js),Uet={splitLine:function(r,e,t,n){var a=n.axis;if(!a.scale.isBlank()){var i=n.getModel("splitLine"),o=i.getModel("lineStyle"),s=o.get("color");s=s instanceof Array?s:[s];for(var l=o.get("width"),u=n.coordinateSystem.getRect(),c=a.isHorizontal(),h=[],d=0,v=a.getTicksCoords({tickModel:i}),p=[],y=[],_=0;_<v.length;++_){var g=a.toGlobalCoord(v[_].coord);c?(p[0]=g,p[1]=u.y,y[0]=g,y[1]=u.y+u.height):(p[0]=u.x,p[1]=g,y[0]=u.x+u.width,y[1]=g);var f=new gr({shape:{x1:p[0],y1:p[1],x2:y[0],y2:y[1]},silent:!0});Jl(f.shape,l);var w=d++%s.length;h[w]=h[w]||[],h[w].push(f)}for(var x=o.getLineStyle(["color"]),_=0;_<h.length;++_)e.add(qn(h[_],{style:zt({stroke:s[_%s.length]},x),silent:!0}))}},splitArea:function(r,e,t,n){t5(r,t,n,n)}},ld=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.getCoordSysModel=function(){return this},e.type="singleAxis",e.layoutMode="box",e.defaultOption={left:"5%",top:"5%",right:"5%",bottom:"5%",type:"value",position:"bottom",orient:"horizontal",axisLine:{show:!0,lineStyle:{width:1,type:"solid"}},tooltip:{show:!0},axisTick:{show:!0,length:6,lineStyle:{width:1}},axisLabel:{show:!0,interval:"auto"},splitLine:{show:!0,lineStyle:{type:"dashed",opacity:.2}}},e}(le);sr(ld,Bh.prototype);var Zet=function(r){rt(e,r);function e(t,n,a,i,o){var s=r.call(this,t,n,a)||this;return s.type=i||"value",s.position=o||"bottom",s}return e.prototype.isHorizontal=function(){var t=this.position;return t==="top"||t==="bottom"},e.prototype.pointToData=function(t,n){return this.coordinateSystem.pointToData(t)[0]},e}(Sa),EO=["single"],Yet=function(){function r(e,t,n){this.type="single",this.dimension="single",this.dimensions=EO,this.axisPointerEnabled=!0,this.model=e,this._init(e,t,n)}return r.prototype._init=function(e,t,n){var a=this.dimension,i=new Zet(a,Wp(e),[0,0],e.get("type"),e.get("position")),o=i.type==="category";i.onBand=o&&e.get("boundaryGap"),i.inverse=e.get("inverse"),i.orient=e.get("orient"),e.axis=i,i.model=e,i.coordinateSystem=this,this._axis=i},r.prototype.update=function(e,t){e.eachSeries(function(n){if(n.coordinateSystem===this){var a=n.getData();B(a.mapDimensionsAll(this.dimension),function(i){this._axis.scale.unionExtentFromData(a,i)},this),ru(this._axis.scale,this._axis.model)}},this)},r.prototype.resize=function(e,t){this._rect=cr({left:e.get("left"),top:e.get("top"),right:e.get("right"),bottom:e.get("bottom"),width:e.get("width"),height:e.get("height")},{width:t.getWidth(),height:t.getHeight()}),this._adjustAxis()},r.prototype.getRect=function(){return this._rect},r.prototype._adjustAxis=function(){var e=this._rect,t=this._axis,n=t.isHorizontal(),a=n?[0,e.width]:[0,e.height],i=t.inverse?1:0;t.setExtent(a[i],a[1-i]),this._updateAxisTransform(t,n?e.x:e.y)},r.prototype._updateAxisTransform=function(e,t){var n=e.getExtent(),a=n[0]+n[1],i=e.isHorizontal();e.toGlobalCoord=i?function(o){return o+t}:function(o){return a-o+t},e.toLocalCoord=i?function(o){return o-t}:function(o){return a-o+t}},r.prototype.getAxis=function(){return this._axis},r.prototype.getBaseAxis=function(){return this._axis},r.prototype.getAxes=function(){return[this._axis]},r.prototype.getTooltipAxes=function(){return{baseAxes:[this.getAxis()],otherAxes:[]}},r.prototype.containPoint=function(e){var t=this.getRect(),n=this.getAxis(),a=n.orient;return a==="horizontal"?n.contain(n.toLocalCoord(e[0]))&&e[1]>=t.y&&e[1]<=t.y+t.height:n.contain(n.toLocalCoord(e[1]))&&e[0]>=t.y&&e[0]<=t.y+t.height},r.prototype.pointToData=function(e){var t=this.getAxis();return[t.coordToData(t.toLocalCoord(e[t.orient==="horizontal"?0:1]))]},r.prototype.dataToPoint=function(e){var t=this.getAxis(),n=this.getRect(),a=[],i=t.orient==="horizontal"?0:1;return e instanceof Array&&(e=e[0]),a[i]=t.toGlobalCoord(t.dataToCoord(+e)),a[1-i]=i===0?n.y+n.height/2:n.x+n.width/2,a},r.prototype.convertToPixel=function(e,t,n){var a=YM(t);return a===this?this.dataToPoint(n):null},r.prototype.convertFromPixel=function(e,t,n){var a=YM(t);return a===this?this.pointToData(n):null},r}();function YM(r){var e=r.seriesModel,t=r.singleAxisModel;return t&&t.coordinateSystem||e&&e.coordinateSystem}function Xet(r,e){var t=[];return r.eachComponent("singleAxis",function(n,a){var i=new Yet(n,r,e);i.name="single_"+a,i.resize(n,e),n.coordinateSystem=i,t.push(i)}),r.eachSeries(function(n){if(n.get("coordinateSystem")==="singleAxis"){var a=n.getReferringComponents("singleAxis",ir).models[0];n.coordinateSystem=a&&a.coordinateSystem}}),t}var $et={create:Xet,dimensions:EO},XM=["x","y"],jet=["width","height"],qet=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.makeElOption=function(t,n,a,i,o){var s=a.axis,l=s.coordinateSystem,u=g0(l,1-Qd(s)),c=l.dataToPoint(n)[0],h=i.get("type");if(h&&h!=="none"){var d=Tx(i),v=Ket[h](s,c,u);v.style=d,t.graphicKey=v.type,t.pointer=v}var p=g1(a);LO(n,t,p,a,i,o)},e.prototype.getHandleTransform=function(t,n,a){var i=g1(n,{labelInside:!1});i.labelMargin=a.get(["handle","margin"]);var o=Cx(n.axis,t,i);return{x:o[0],y:o[1],rotation:i.rotation+(i.labelDirection<0?Math.PI:0)}},e.prototype.updateHandleTransform=function(t,n,a,i){var o=a.axis,s=o.coordinateSystem,l=Qd(o),u=g0(s,l),c=[t.x,t.y];c[l]+=n[l],c[l]=Math.min(u[1],c[l]),c[l]=Math.max(u[0],c[l]);var h=g0(s,1-l),d=(h[1]+h[0])/2,v=[d,d];return v[l]=c[l],{x:c[0],y:c[1],rotation:t.rotation,cursorPoint:v,tooltipOption:{verticalAlign:"middle"}}},e}(Ax),Ket={line:function(r,e,t){var n=Lx([e,t[0]],[e,t[1]],Qd(r));return{type:"Line",subPixelOptimize:!0,shape:n}},shadow:function(r,e,t){var n=r.getBandWidth(),a=t[1]-t[0];return{type:"Rect",shape:MO([e-n/2,t[0]],[n,a],Qd(r))}}};function Qd(r){return r.isHorizontal()?0:1}function g0(r,e){var t=r.getRect();return[t[XM[e]],t[XM[e]]+t[jet[e]]]}var Qet=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="single",e}(Ze);function Jet(r){ne(Zh),js.registerAxisPointerClass("SingleAxisPointer",qet),r.registerComponentView(Qet),r.registerComponentView(Het),r.registerComponentModel(ld),au(r,"single",ld,ld.defaultOption),r.registerCoordinateSystem("single",$et)}var trt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n,a){var i=yu(t);r.prototype.init.apply(this,arguments),$M(t,i)},e.prototype.mergeOption=function(t){r.prototype.mergeOption.apply(this,arguments),$M(this.option,t)},e.prototype.getCellSize=function(){return this.option.cellSize},e.type="calendar",e.defaultOption={z:2,left:80,top:60,cellSize:20,orient:"horizontal",splitLine:{show:!0,lineStyle:{color:"#000",width:1,type:"solid"}},itemStyle:{color:"#fff",borderWidth:1,borderColor:"#ccc"},dayLabel:{show:!0,firstDay:0,position:"start",margin:"50%",color:"#000"},monthLabel:{show:!0,position:"start",margin:5,align:"center",formatter:null,color:"#000"},yearLabel:{show:!0,position:null,margin:30,formatter:null,color:"#ccc",fontFamily:"sans-serif",fontWeight:"bolder",fontSize:20}},e}(le);function $M(r,e){var t=r.cellSize,n;ht(t)?n=t:n=r.cellSize=[t,t],n.length===1&&(n[1]=n[0]);var a=ft([0,1],function(i){return _U(e,i)&&(n[i]="auto"),n[i]!=null&&n[i]!=="auto"});bo(r,e,{type:"box",ignoreSize:a})}var ert=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){var i=this.group;i.removeAll();var o=t.coordinateSystem,s=o.getRangeInfo(),l=o.getOrient(),u=n.getLocaleModel();this._renderDayRect(t,s,i),this._renderLines(t,s,l,i),this._renderYearText(t,s,l,i),this._renderMonthText(t,u,l,i),this._renderWeekText(t,u,s,l,i)},e.prototype._renderDayRect=function(t,n,a){for(var i=t.coordinateSystem,o=t.getModel("itemStyle").getItemStyle(),s=i.getCellWidth(),l=i.getCellHeight(),u=n.start.time;u<=n.end.time;u=i.getNextNDay(u,1).time){var c=i.dataToRect([u],!1).tl,h=new fe({shape:{x:c[0],y:c[1],width:s,height:l},cursor:"default",style:o});a.add(h)}},e.prototype._renderLines=function(t,n,a,i){var o=this,s=t.coordinateSystem,l=t.getModel(["splitLine","lineStyle"]).getLineStyle(),u=t.get(["splitLine","show"]),c=l.lineWidth;this._tlpoints=[],this._blpoints=[],this._firstDayOfMonth=[],this._firstDayPoints=[];for(var h=n.start,d=0;h.time<=n.end.time;d++){p(h.formatedDate),d===0&&(h=s.getDateInfo(n.start.y+"-"+n.start.m));var v=h.date;v.setMonth(v.getMonth()+1),h=s.getDateInfo(v)}p(s.getNextNDay(n.end.time,1).formatedDate);function p(y){o._firstDayOfMonth.push(s.getDateInfo(y)),o._firstDayPoints.push(s.dataToRect([y],!1).tl);var _=o._getLinePointsOfOneWeek(t,y,a);o._tlpoints.push(_[0]),o._blpoints.push(_[_.length-1]),u&&o._drawSplitline(_,l,i)}u&&this._drawSplitline(o._getEdgesPoints(o._tlpoints,c,a),l,i),u&&this._drawSplitline(o._getEdgesPoints(o._blpoints,c,a),l,i)},e.prototype._getEdgesPoints=function(t,n,a){var i=[t[0].slice(),t[t.length-1].slice()],o=a==="horizontal"?0:1;return i[0][o]=i[0][o]-n/2,i[1][o]=i[1][o]+n/2,i},e.prototype._drawSplitline=function(t,n,a){var i=new nn({z2:20,shape:{points:t},style:n});a.add(i)},e.prototype._getLinePointsOfOneWeek=function(t,n,a){for(var i=t.coordinateSystem,o=i.getDateInfo(n),s=[],l=0;l<7;l++){var u=i.getNextNDay(o.time,l),c=i.dataToRect([u.time],!1);s[2*u.day]=c.tl,s[2*u.day+1]=c[a==="horizontal"?"bl":"tr"]}return s},e.prototype._formatterLabel=function(t,n){return Lt(t)&&t?gU(t,n):Nt(t)?t(n):n.nameMap},e.prototype._yearTextPositionControl=function(t,n,a,i,o){var s=n[0],l=n[1],u=["center","bottom"];i==="bottom"?(l+=o,u=["center","top"]):i==="left"?s-=o:i==="right"?(s+=o,u=["center","top"]):l-=o;var c=0;return(i==="left"||i==="right")&&(c=Math.PI/2),{rotation:c,x:s,y:l,style:{align:u[0],verticalAlign:u[1]}}},e.prototype._renderYearText=function(t,n,a,i){var o=t.getModel("yearLabel");if(o.get("show")){var s=o.get("margin"),l=o.get("position");l||(l=a!=="horizontal"?"top":"left");var u=[this._tlpoints[this._tlpoints.length-1],this._blpoints[0]],c=(u[0][0]+u[1][0])/2,h=(u[0][1]+u[1][1])/2,d=a==="horizontal"?0:1,v={top:[c,u[d][1]],bottom:[c,u[1-d][1]],left:[u[1-d][0],h],right:[u[d][0],h]},p=n.start.y;+n.end.y>+n.start.y&&(p=p+"-"+n.end.y);var y=o.get("formatter"),_={start:n.start.y,end:n.end.y,nameMap:p},g=this._formatterLabel(y,_),f=new pe({z2:30,style:Fe(o,{text:g}),silent:o.get("silent")});f.attr(this._yearTextPositionControl(f,v[l],a,l,s)),i.add(f)}},e.prototype._monthTextPositionControl=function(t,n,a,i,o){var s="left",l="top",u=t[0],c=t[1];return a==="horizontal"?(c=c+o,n&&(s="center"),i==="start"&&(l="bottom")):(u=u+o,n&&(l="middle"),i==="start"&&(s="right")),{x:u,y:c,align:s,verticalAlign:l}},e.prototype._renderMonthText=function(t,n,a,i){var o=t.getModel("monthLabel");if(o.get("show")){var s=o.get("nameMap"),l=o.get("margin"),u=o.get("position"),c=o.get("align"),h=[this._tlpoints,this._blpoints];(!s||Lt(s))&&(s&&(n=A_(s)||n),s=n.get(["time","monthAbbr"])||[]);var d=u==="start"?0:1,v=a==="horizontal"?0:1;l=u==="start"?-l:l;for(var p=c==="center",y=o.get("silent"),_=0;_<h[d].length-1;_++){var g=h[d][_].slice(),f=this._firstDayOfMonth[_];if(p){var w=this._firstDayPoints[_];g[v]=(w[v]+h[0][_+1][v])/2}var x=o.get("formatter"),S=s[+f.m-1],A={yyyy:f.y,yy:(f.y+"").slice(2),MM:f.m,M:+f.m,nameMap:S},T=this._formatterLabel(x,A),L=new pe({z2:30,style:lt(Fe(o,{text:T}),this._monthTextPositionControl(g,p,a,u,l)),silent:y});i.add(L)}}},e.prototype._weekTextPositionControl=function(t,n,a,i,o){var s="center",l="middle",u=t[0],c=t[1],h=a==="start";return n==="horizontal"?(u=u+i+(h?1:-1)*o[0]/2,s=h?"right":"left"):(c=c+i+(h?1:-1)*o[1]/2,l=h?"bottom":"top"),{x:u,y:c,align:s,verticalAlign:l}},e.prototype._renderWeekText=function(t,n,a,i,o){var s=t.getModel("dayLabel");if(s.get("show")){var l=t.coordinateSystem,u=s.get("position"),c=s.get("nameMap"),h=s.get("margin"),d=l.getFirstDayOfWeek();if(!c||Lt(c)){c&&(n=A_(c)||n);var v=n.get(["time","dayOfWeekShort"]);c=v||ft(n.get(["time","dayOfWeekAbbr"]),function(A){return A[0]})}var p=l.getNextNDay(a.end.time,7-a.lweek).time,y=[l.getCellWidth(),l.getCellHeight()];h=At(h,Math.min(y[1],y[0])),u==="start"&&(p=l.getNextNDay(a.start.time,-(7+a.fweek)).time,h=-h);for(var _=s.get("silent"),g=0;g<7;g++){var f=l.getNextNDay(p,g),w=l.dataToRect([f.time],!1).center,x=g;x=Math.abs((g+d)%7);var S=new pe({z2:30,style:lt(Fe(s,{text:c[x]}),this._weekTextPositionControl(w,i,u,h,y)),silent:_});o.add(S)}}},e.type="calendar",e}(Ze),y0=864e5,rrt=function(){function r(e,t,n){this.type="calendar",this.dimensions=r.dimensions,this.getDimensionsInfo=r.getDimensionsInfo,this._model=e}return r.getDimensionsInfo=function(){return[{name:"time",type:"time"},"value"]},r.prototype.getRangeInfo=function(){return this._rangeInfo},r.prototype.getModel=function(){return this._model},r.prototype.getRect=function(){return this._rect},r.prototype.getCellWidth=function(){return this._sw},r.prototype.getCellHeight=function(){return this._sh},r.prototype.getOrient=function(){return this._orient},r.prototype.getFirstDayOfWeek=function(){return this._firstDayOfWeek},r.prototype.getDateInfo=function(e){e=$a(e);var t=e.getFullYear(),n=e.getMonth()+1,a=n<10?"0"+n:""+n,i=e.getDate(),o=i<10?"0"+i:""+i,s=e.getDay();return s=Math.abs((s+7-this.getFirstDayOfWeek())%7),{y:t+"",m:a,d:o,day:s,time:e.getTime(),formatedDate:t+"-"+a+"-"+o,date:e}},r.prototype.getNextNDay=function(e,t){return t=t||0,t===0?this.getDateInfo(e):(e=new Date(this.getDateInfo(e).time),e.setDate(e.getDate()+t),this.getDateInfo(e))},r.prototype.update=function(e,t){this._firstDayOfWeek=+this._model.getModel("dayLabel").get("firstDay"),this._orient=this._model.get("orient"),this._lineWidth=this._model.getModel("itemStyle").getItemStyle().lineWidth||0,this._rangeInfo=this._getRangeInfo(this._initRangeOption());var n=this._rangeInfo.weeks||1,a=["width","height"],i=this._model.getCellSize().slice(),o=this._model.getBoxLayoutParams(),s=this._orient==="horizontal"?[n,7]:[7,n];B([0,1],function(h){c(i,h)&&(o[a[h]]=i[h]*s[h])});var l={width:t.getWidth(),height:t.getHeight()},u=this._rect=cr(o,l);B([0,1],function(h){c(i,h)||(i[h]=u[a[h]]/s[h])});function c(h,d){return h[d]!=null&&h[d]!=="auto"}this._sw=i[0],this._sh=i[1]},r.prototype.dataToPoint=function(e,t){ht(e)&&(e=e[0]),t==null&&(t=!0);var n=this.getDateInfo(e),a=this._rangeInfo,i=n.formatedDate;if(t&&!(n.time>=a.start.time&&n.time<a.end.time+y0))return[NaN,NaN];var o=n.day,s=this._getRangeInfo([a.start.time,i]).nthWeek;return this._orient==="vertical"?[this._rect.x+o*this._sw+this._sw/2,this._rect.y+s*this._sh+this._sh/2]:[this._rect.x+s*this._sw+this._sw/2,this._rect.y+o*this._sh+this._sh/2]},r.prototype.pointToData=function(e){var t=this.pointToDate(e);return t&&t.time},r.prototype.dataToRect=function(e,t){var n=this.dataToPoint(e,t);return{contentShape:{x:n[0]-(this._sw-this._lineWidth)/2,y:n[1]-(this._sh-this._lineWidth)/2,width:this._sw-this._lineWidth,height:this._sh-this._lineWidth},center:n,tl:[n[0]-this._sw/2,n[1]-this._sh/2],tr:[n[0]+this._sw/2,n[1]-this._sh/2],br:[n[0]+this._sw/2,n[1]+this._sh/2],bl:[n[0]-this._sw/2,n[1]+this._sh/2]}},r.prototype.pointToDate=function(e){var t=Math.floor((e[0]-this._rect.x)/this._sw)+1,n=Math.floor((e[1]-this._rect.y)/this._sh)+1,a=this._rangeInfo.range;return this._orient==="vertical"?this._getDateByWeeksAndDay(n,t-1,a):this._getDateByWeeksAndDay(t,n-1,a)},r.prototype.convertToPixel=function(e,t,n){var a=jM(t);return a===this?a.dataToPoint(n):null},r.prototype.convertFromPixel=function(e,t,n){var a=jM(t);return a===this?a.pointToData(n):null},r.prototype.containPoint=function(e){return console.warn("Not implemented."),!1},r.prototype._initRangeOption=function(){var e=this._model.get("range"),t;if(ht(e)&&e.length===1&&(e=e[0]),ht(e))t=e;else{var n=e.toString();if(/^\d{4}$/.test(n)&&(t=[n+"-01-01",n+"-12-31"]),/^\d{4}[\/|-]\d{1,2}$/.test(n)){var a=this.getDateInfo(n),i=a.date;i.setMonth(i.getMonth()+1);var o=this.getNextNDay(i,-1);t=[a.formatedDate,o.formatedDate]}/^\d{4}[\/|-]\d{1,2}[\/|-]\d{1,2}$/.test(n)&&(t=[n,n])}if(!t)return e;var s=this._getRangeInfo(t);return s.start.time>s.end.time&&t.reverse(),t},r.prototype._getRangeInfo=function(e){var t=[this.getDateInfo(e[0]),this.getDateInfo(e[1])],n;t[0].time>t[1].time&&(n=!0,t.reverse());var a=Math.floor(t[1].time/y0)-Math.floor(t[0].time/y0)+1,i=new Date(t[0].time),o=i.getDate(),s=t[1].date.getDate();i.setDate(o+a-1);var l=i.getDate();if(l!==s)for(var u=i.getTime()-t[1].time>0?1:-1;(l=i.getDate())!==s&&(i.getTime()-t[1].time)*u>0;)a-=u,i.setDate(l-u);var c=Math.floor((a+t[0].day+6)/7),h=n?-c+1:c-1;return n&&t.reverse(),{range:[t[0].formatedDate,t[1].formatedDate],start:t[0],end:t[1],allDay:a,weeks:c,nthWeek:h,fweek:t[0].day,lweek:t[1].day}},r.prototype._getDateByWeeksAndDay=function(e,t,n){var a=this._getRangeInfo(n);if(e>a.weeks||e===0&&t<a.fweek||e===a.weeks&&t>a.lweek)return null;var i=(e-1)*7-a.fweek+t,o=new Date(a.start.time);return o.setDate(+a.start.d+i),this.getDateInfo(o)},r.create=function(e,t){var n=[];return e.eachComponent("calendar",function(a){var i=new r(a);n.push(i),a.coordinateSystem=i}),e.eachSeries(function(a){a.get("coordinateSystem")==="calendar"&&(a.coordinateSystem=n[a.get("calendarIndex")||0])}),n},r.dimensions=["time","value"],r}();function jM(r){var e=r.calendarModel,t=r.seriesModel,n=e?e.coordinateSystem:t?t.coordinateSystem:null;return n}function nrt(r){r.registerComponentModel(trt),r.registerComponentView(ert),r.registerCoordinateSystem("calendar",rrt)}function art(r,e){var t=r.existing;if(e.id=r.keyInfo.id,!e.type&&t&&(e.type=t.type),e.parentId==null){var n=e.parentOption;n?e.parentId=n.id:t&&(e.parentId=t.parentId)}e.parentOption=null}function qM(r,e){var t;return B(e,function(n){r[n]!=null&&r[n]!=="auto"&&(t=!0)}),t}function irt(r,e,t){var n=lt({},t),a=r[e],i=t.$action||"merge";i==="merge"?a?(qt(a,n,!0),bo(a,n,{ignoreSize:!0}),Ck(t,a),Bv(t,a),Bv(t,a,"shape"),Bv(t,a,"style"),Bv(t,a,"extra"),t.clipPath=a.clipPath):r[e]=n:i==="replace"?r[e]=n:i==="remove"&&a&&(r[e]=null)}var OO=["transition","enterFrom","leaveTo"],ort=OO.concat(["enterAnimation","updateAnimation","leaveAnimation"]);function Bv(r,e,t){if(t&&(!r[t]&&e[t]&&(r[t]={}),r=r[t],e=e[t]),!(!r||!e))for(var n=t?OO:ort,a=0;a<n.length;a++){var i=n[a];r[i]==null&&e[i]!=null&&(r[i]=e[i])}}function srt(r,e){if(r&&(r.hv=e.hv=[qM(e,["left","right"]),qM(e,["top","bottom"])],r.type==="group")){var t=r,n=e;t.width==null&&(t.width=n.width=0),t.height==null&&(t.height=n.height=0)}}var lrt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.preventAutoZ=!0,t}return e.prototype.mergeOption=function(t,n){var a=this.option.elements;this.option.elements=null,r.prototype.mergeOption.call(this,t,n),this.option.elements=a},e.prototype.optionUpdated=function(t,n){var a=this.option,i=(n?a:t).elements,o=a.elements=n?[]:a.elements,s=[];this._flatten(i,s,null);var l=bP(o,s,"normalMerge"),u=this._elOptionsToUpdate=[];B(l,function(c,h){var d=c.newOption;d&&(u.push(d),art(c,d),irt(o,h,d),srt(o[h],d))},this),a.elements=Te(o,function(c){return c&&delete c.$action,c!=null})},e.prototype._flatten=function(t,n,a){B(t,function(i){if(i){a&&(i.parentOption=a),n.push(i);var o=i.children;o&&o.length&&this._flatten(o,n,i),delete i.children}},this)},e.prototype.useElOptionsToUpdate=function(){var t=this._elOptionsToUpdate;return this._elOptionsToUpdate=null,t},e.type="graphic",e.defaultOption={elements:[]},e}(le),KM={path:null,compoundPath:null,group:Wt,image:Tr,text:pe},Xn=ve(),urt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){this._elMap=Pt()},e.prototype.render=function(t,n,a){t!==this._lastGraphicModel&&this._clear(),this._lastGraphicModel=t,this._updateElements(t),this._relocate(t,a)},e.prototype._updateElements=function(t){var n=t.useElOptionsToUpdate();if(n){var a=this._elMap,i=this.group,o=t.get("z"),s=t.get("zlevel");B(n,function(l){var u=ur(l.id,null),c=u!=null?a.get(u):null,h=ur(l.parentId,null),d=h!=null?a.get(h):i,v=l.type,p=l.style;v==="text"&&p&&l.hv&&l.hv[1]&&(p.textVerticalAlign=p.textBaseline=p.verticalAlign=p.align=null);var y=l.textContent,_=l.textConfig;if(p&&pO(p,v,!!_,!!y)){var g=gO(p,v,!0);!_&&g.textConfig&&(_=l.textConfig=g.textConfig),!y&&g.textContent&&(y=g.textContent)}var f=crt(l),w=l.$action||"merge",x=w==="merge",S=w==="replace";if(x){var A=!c,T=c;A?T=QM(u,d,l.type,a):(T&&(Xn(T).isNew=!1),wO(T)),T&&(od(T,f,t,{isInit:A}),JM(T,l,o,s))}else if(S){ud(c,l,a,t);var L=QM(u,d,l.type,a);L&&(od(L,f,t,{isInit:!0}),JM(L,l,o,s))}else w==="remove"&&(mO(c,l),ud(c,l,a,t));var M=a.get(u);if(M&&y)if(x){var I=M.getTextContent();I?I.attr(y):M.setTextContent(new pe(y))}else S&&M.setTextContent(new pe(y));if(M){var R=l.clipPath;if(R){var P=R.type,E=void 0,A=!1;if(x){var D=M.getClipPath();A=!D||Xn(D).type!==P,E=A?y1(P):D}else S&&(A=!0,E=y1(P));M.setClipPath(E),od(E,R,t,{isInit:A}),qd(E,R.keyframeAnimation,t)}var N=Xn(M);M.setTextConfig(_),N.option=l,hrt(M,t,l),Us({el:M,componentModel:t,itemName:M.name,itemTooltipOption:l.tooltip}),qd(M,l.keyframeAnimation,t)}})}},e.prototype._relocate=function(t,n){for(var a=t.option.elements,i=this.group,o=this._elMap,s=n.getWidth(),l=n.getHeight(),u=["x","y"],c=0;c<a.length;c++){var h=a[c],d=ur(h.id,null),v=d!=null?o.get(d):null;if(!(!v||!v.isGroup)){var p=v.parent,y=p===i,_=Xn(v),g=Xn(p);_.width=At(_.option.width,y?s:g.width)||0,_.height=At(_.option.height,y?l:g.height)||0}}for(var c=a.length-1;c>=0;c--){var h=a[c],d=ur(h.id,null),v=d!=null?o.get(d):null;if(v){var p=v.parent,g=Xn(p),f=p===i?{width:s,height:l}:{width:g.width,height:g.height},w={},x=Rp(v,h,f,null,{hv:h.hv,boundingMode:h.bounding},w);if(!Xn(v).isNew&&x){for(var S=h.transition,A={},T=0;T<u.length;T++){var L=u[T],M=w[L];S&&(Es(S)||te(S,L)>=0)?A[L]=M:v[L]=M}_e(v,A,t,0)}else v.attr(w)}}},e.prototype._clear=function(){var t=this,n=this._elMap;n.each(function(a){ud(a,Xn(a).option,n,t._lastGraphicModel)}),this._elMap=Pt()},e.prototype.dispose=function(){this._clear()},e.type="graphic",e}(Ze);function y1(r){var e=It(KM,r)?KM[r]:sw(r),t=new e({});return Xn(t).type=r,t}function QM(r,e,t,n){var a=y1(t);return e.add(a),n.set(r,a),Xn(a).id=r,Xn(a).isNew=!0,a}function ud(r,e,t,n){var a=r&&r.parent;a&&(r.type==="group"&&r.traverse(function(i){ud(i,e,t,n)}),jp(r,e,n),t.removeKey(Xn(r).id))}function JM(r,e,t,n){r.isGroup||B([["cursor",ta.prototype.cursor],["zlevel",n||0],["z",t||0],["z2",0]],function(a){var i=a[0];It(e,i)?r[i]=Zt(e[i],a[1]):r[i]==null&&(r[i]=a[1])}),B(ue(e),function(a){if(a.indexOf("on")===0){var i=e[a];r[a]=Nt(i)?i:null}}),It(e,"draggable")&&(r.draggable=e.draggable),e.name!=null&&(r.name=e.name),e.id!=null&&(r.id=e.id)}function crt(r){return r=lt({},r),B(["id","parentId","$action","hv","bounding","textContent","clipPath"].concat(Tk),function(e){delete r[e]}),r}function hrt(r,e,t){var n=Ht(r).eventData;!r.silent&&!r.ignore&&!n&&(n=Ht(r).eventData={componentType:"graphic",componentIndex:e.componentIndex,name:r.name}),n&&(n.info=t.info)}function frt(r){r.registerComponentModel(lrt),r.registerComponentView(urt),r.registerPreprocessor(function(e){var t=e.graphic;ht(t)?!t[0]||!t[0].elements?e.graphic=[{elements:t}]:e.graphic=[e.graphic[0]]:t&&!t.elements&&(e.graphic=[{elements:[t]}])})}var tD=["x","y","radius","angle","single"],vrt=["cartesian2d","polar","singleAxis"];function drt(r){var e=r.get("coordinateSystem");return te(vrt,e)>=0}function fo(r){return r+"Axis"}function prt(r,e){var t=Pt(),n=[],a=Pt();r.eachComponent({mainType:"dataZoom",query:e},function(c){a.get(c.uid)||s(c)});var i;do i=!1,r.eachComponent("dataZoom",o);while(i);function o(c){!a.get(c.uid)&&l(c)&&(s(c),i=!0)}function s(c){a.set(c.uid,!0),n.push(c),u(c)}function l(c){var h=!1;return c.eachTargetAxis(function(d,v){var p=t.get(d);p&&p[v]&&(h=!0)}),h}function u(c){c.eachTargetAxis(function(h,d){(t.get(h)||t.set(h,[]))[d]=!0})}return n}function BO(r){var e=r.ecModel,t={infoList:[],infoMap:Pt()};return r.eachTargetAxis(function(n,a){var i=e.getComponent(fo(n),a);if(i){var o=i.getCoordSysModel();if(o){var s=o.uid,l=t.infoMap.get(s);l||(l={model:o,axisModels:[]},t.infoList.push(l),t.infoMap.set(s,l)),l.axisModels.push(i)}}}),t}var m0=function(){function r(){this.indexList=[],this.indexMap=[]}return r.prototype.add=function(e){this.indexMap[e]||(this.indexList.push(e),this.indexMap[e]=!0)},r}(),_h=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._autoThrottle=!0,t._noTarget=!0,t._rangePropMode=["percent","percent"],t}return e.prototype.init=function(t,n,a){var i=eD(t);this.settledOption=i,this.mergeDefaultAndTheme(t,a),this._doInit(i)},e.prototype.mergeOption=function(t){var n=eD(t);qt(this.option,t,!0),qt(this.settledOption,n,!0),this._doInit(n)},e.prototype._doInit=function(t){var n=this.option;this._setDefaultThrottle(t),this._updateRangeUse(t);var a=this.settledOption;B([["start","startValue"],["end","endValue"]],function(i,o){this._rangePropMode[o]==="value"&&(n[i[0]]=a[i[0]]=null)},this),this._resetTarget()},e.prototype._resetTarget=function(){var t=this.get("orient",!0),n=this._targetAxisInfoMap=Pt(),a=this._fillSpecifiedTargetAxis(n);a?this._orient=t||this._makeAutoOrientByTargetAxis():(this._orient=t||"horizontal",this._fillAutoTargetAxisByOrient(n,this._orient)),this._noTarget=!0,n.each(function(i){i.indexList.length&&(this._noTarget=!1)},this)},e.prototype._fillSpecifiedTargetAxis=function(t){var n=!1;return B(tD,function(a){var i=this.getReferringComponents(fo(a),iW);if(i.specified){n=!0;var o=new m0;B(i.models,function(s){o.add(s.componentIndex)}),t.set(a,o)}},this),n},e.prototype._fillAutoTargetAxisByOrient=function(t,n){var a=this.ecModel,i=!0;if(i){var o=n==="vertical"?"y":"x",s=a.findComponents({mainType:o+"Axis"});l(s,o)}if(i){var s=a.findComponents({mainType:"singleAxis",filter:function(c){return c.get("orient",!0)===n}});l(s,"single")}function l(u,c){var h=u[0];if(h){var d=new m0;if(d.add(h.componentIndex),t.set(c,d),i=!1,c==="x"||c==="y"){var v=h.getReferringComponents("grid",ir).models[0];v&&B(u,function(p){h.componentIndex!==p.componentIndex&&v===p.getReferringComponents("grid",ir).models[0]&&d.add(p.componentIndex)})}}}i&&B(tD,function(u){if(i){var c=a.findComponents({mainType:fo(u),filter:function(d){return d.get("type",!0)==="category"}});if(c[0]){var h=new m0;h.add(c[0].componentIndex),t.set(u,h),i=!1}}},this)},e.prototype._makeAutoOrientByTargetAxis=function(){var t;return this.eachTargetAxis(function(n){!t&&(t=n)},this),t==="y"?"vertical":"horizontal"},e.prototype._setDefaultThrottle=function(t){if(t.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var n=this.ecModel.option;this.option.throttle=n.animation&&n.animationDurationUpdate>0?100:20}},e.prototype._updateRangeUse=function(t){var n=this._rangePropMode,a=this.get("rangeMode");B([["start","startValue"],["end","endValue"]],function(i,o){var s=t[i[0]]!=null,l=t[i[1]]!=null;s&&!l?n[o]="percent":!s&&l?n[o]="value":a?n[o]=a[o]:s&&(n[o]="percent")})},e.prototype.noTarget=function(){return this._noTarget},e.prototype.getFirstTargetAxisModel=function(){var t;return this.eachTargetAxis(function(n,a){t==null&&(t=this.ecModel.getComponent(fo(n),a))},this),t},e.prototype.eachTargetAxis=function(t,n){this._targetAxisInfoMap.each(function(a,i){B(a.indexList,function(o){t.call(n,i,o)})})},e.prototype.getAxisProxy=function(t,n){var a=this.getAxisModel(t,n);if(a)return a.__dzAxisProxy},e.prototype.getAxisModel=function(t,n){var a=this._targetAxisInfoMap.get(t);if(a&&a.indexMap[n])return this.ecModel.getComponent(fo(t),n)},e.prototype.setRawRange=function(t){var n=this.option,a=this.settledOption;B([["start","startValue"],["end","endValue"]],function(i){(t[i[0]]!=null||t[i[1]]!=null)&&(n[i[0]]=a[i[0]]=t[i[0]],n[i[1]]=a[i[1]]=t[i[1]])},this),this._updateRangeUse(t)},e.prototype.setCalculatedRange=function(t){var n=this.option;B(["start","startValue","end","endValue"],function(a){n[a]=t[a]})},e.prototype.getPercentRange=function(){var t=this.findRepresentativeAxisProxy();if(t)return t.getDataPercentWindow()},e.prototype.getValueRange=function(t,n){if(t==null&&n==null){var a=this.findRepresentativeAxisProxy();if(a)return a.getDataValueWindow()}else return this.getAxisProxy(t,n).getDataValueWindow()},e.prototype.findRepresentativeAxisProxy=function(t){if(t)return t.__dzAxisProxy;for(var n,a=this._targetAxisInfoMap.keys(),i=0;i<a.length;i++)for(var o=a[i],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;n||(n=u)}return n},e.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},e.prototype.getOrient=function(){return this._orient},e.type="dataZoom",e.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],e.defaultOption={z:4,filterMode:"filter",start:0,end:100},e}(le);function eD(r){var e={};return B(["start","end","startValue","endValue","throttle"],function(t){r.hasOwnProperty(t)&&(e[t]=r[t])}),e}var grt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.select",e}(_h),Px=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a,i){this.dataZoomModel=t,this.ecModel=n,this.api=a},e.type="dataZoom",e}(Ze),yrt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.select",e}(Px),Nl=B,rD=Qn,mrt=function(){function r(e,t,n,a){this._dimName=e,this._axisIndex=t,this.ecModel=a,this._dataZoomModel=n}return r.prototype.hostedBy=function(e){return this._dataZoomModel===e},r.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},r.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},r.prototype.getTargetSeriesModels=function(){var e=[];return this.ecModel.eachSeries(function(t){if(drt(t)){var n=fo(this._dimName),a=t.getReferringComponents(n,ir).models[0];a&&this._axisIndex===a.componentIndex&&e.push(t)}},this),e},r.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},r.prototype.getMinMaxSpan=function(){return Gt(this._minMaxSpan)},r.prototype.calculateDataWindow=function(e){var t=this._dataExtent,n=this.getAxisModel(),a=n.axis.scale,i=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;Nl(["start","end"],function(d,v){var p=e[d],y=e[d+"Value"];i[v]==="percent"?(p==null&&(p=o[v]),y=a.parse(Me(p,o,t))):(u=!0,y=y==null?t[v]:a.parse(y),p=Me(y,t,o)),l[v]=y==null||isNaN(y)?t[v]:y,s[v]=p==null||isNaN(p)?o[v]:p}),rD(l),rD(s);var c=this._minMaxSpan;u?h(l,s,t,o,!1):h(s,l,o,t,!0);function h(d,v,p,y,_){var g=_?"Span":"ValueSpan";qs(0,d,p,"all",c["min"+g],c["max"+g]);for(var f=0;f<2;f++)v[f]=Me(d[f],p,y,!0),_&&(v[f]=a.parse(v[f]))}return{valueWindow:l,percentWindow:s}},r.prototype.reset=function(e){if(e===this._dataZoomModel){var t=this.getTargetSeriesModels();this._dataExtent=_rt(this,this._dimName,t),this._updateMinMaxSpan();var n=this.calculateDataWindow(e.settledOption);this._valueWindow=n.valueWindow,this._percentWindow=n.percentWindow,this._setAxisModel()}},r.prototype.filterData=function(e,t){if(e!==this._dataZoomModel)return;var n=this._dimName,a=this.getTargetSeriesModels(),i=e.get("filterMode"),o=this._valueWindow;if(i==="none")return;Nl(a,function(l){var u=l.getData(),c=u.mapDimensionsAll(n);if(c.length){if(i==="weakFilter"){var h=u.getStore(),d=ft(c,function(v){return u.getDimensionIndex(v)},u);u.filterSelf(function(v){for(var p,y,_,g=0;g<c.length;g++){var f=h.get(d[g],v),w=!isNaN(f),x=f<o[0],S=f>o[1];if(w&&!x&&!S)return!0;w&&(_=!0),x&&(p=!0),S&&(y=!0)}return _&&p&&y})}else Nl(c,function(v){if(i==="empty")l.setData(u=u.map(v,function(y){return s(y)?y:NaN}));else{var p={};p[v]=o,u.selectRange(p)}});Nl(c,function(v){u.setApproximateExtent(o,v)})}});function s(l){return l>=o[0]&&l<=o[1]}},r.prototype._updateMinMaxSpan=function(){var e=this._minMaxSpan={},t=this._dataZoomModel,n=this._dataExtent;Nl(["min","max"],function(a){var i=t.get(a+"Span"),o=t.get(a+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?i=Me(n[0]+o,n,[0,100],!0):i!=null&&(o=Me(i,[0,100],n,!0)-n[0]),e[a+"Span"]=i,e[a+"ValueSpan"]=o},this)},r.prototype._setAxisModel=function(){var e=this.getAxisModel(),t=this._percentWindow,n=this._valueWindow;if(t){var a=dP(n,[0,500]);a=Math.min(a,20);var i=e.axis.scale.rawExtentInfo;t[0]!==0&&i.setDeterminedMinMax("min",+n[0].toFixed(a)),t[1]!==100&&i.setDeterminedMinMax("max",+n[1].toFixed(a)),i.freeze()}},r}();function _rt(r,e,t){var n=[1/0,-1/0];Nl(t,function(o){KZ(n,o.getData(),e)});var a=r.getAxisModel(),i=tE(a.axis.scale,a,n).calculate();return[i.min,i.max]}var wrt={getTargetSeries:function(r){function e(a){r.eachComponent("dataZoom",function(i){i.eachTargetAxis(function(o,s){var l=r.getComponent(fo(o),s);a(o,s,l,i)})})}e(function(a,i,o,s){o.__dzAxisProxy=null});var t=[];e(function(a,i,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new mrt(a,i,s,r),t.push(o.__dzAxisProxy))});var n=Pt();return B(t,function(a){B(a.getTargetSeriesModels(),function(i){n.set(i.uid,i)})}),n},overallReset:function(r,e){r.eachComponent("dataZoom",function(t){t.eachTargetAxis(function(n,a){t.getAxisProxy(n,a).reset(t)}),t.eachTargetAxis(function(n,a){t.getAxisProxy(n,a).filterData(t,e)})}),r.eachComponent("dataZoom",function(t){var n=t.findRepresentativeAxisProxy();if(n){var a=n.getDataPercentWindow(),i=n.getDataValueWindow();t.setCalculatedRange({start:a[0],end:a[1],startValue:i[0],endValue:i[1]})}})}};function xrt(r){r.registerAction("dataZoom",function(e,t){var n=prt(t,e);B(n,function(a){a.setRawRange({start:e.start,end:e.end,startValue:e.startValue,endValue:e.endValue})})})}var nD=!1;function kx(r){nD||(nD=!0,r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,wrt),xrt(r),r.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}function brt(r){r.registerComponentModel(grt),r.registerComponentView(yrt),kx(r)}var jn=function(){function r(){}return r}(),NO={};function zl(r,e){NO[r]=e}function zO(r){return NO[r]}var Srt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(){r.prototype.optionUpdated.apply(this,arguments);var t=this.ecModel;B(this.option.feature,function(n,a){var i=zO(a);i&&(i.getDefaultOption&&(i.defaultOption=i.getDefaultOption(t)),qt(n,i.defaultOption))})},e.type="toolbox",e.layoutMode={type:"box",ignoreSize:!0},e.defaultOption={show:!0,z:6,orient:"horizontal",left:"right",top:"top",backgroundColor:"transparent",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemSize:15,itemGap:8,showTitle:!0,iconStyle:{borderColor:"#666",color:"none"},emphasis:{iconStyle:{borderColor:"#3E98C5"}},tooltip:{show:!1,position:"bottom"}},e}(le);function Art(r,e,t){var n=e.getBoxLayoutParams(),a=e.get("padding"),i={width:t.getWidth(),height:t.getHeight()},o=cr(n,i,a);ks(e.get("orient"),r,e.get("itemGap"),o.width,o.height),Rp(r,n,i,a)}function FO(r,e){var t=gu(e.get("padding")),n=e.getItemStyle(["color","opacity"]);return n.fill=e.get("backgroundColor"),r=new fe({shape:{x:r.x-t[3],y:r.y-t[0],width:r.width+t[1]+t[3],height:r.height+t[0]+t[2],r:e.get("borderRadius")},style:n,silent:!0,z2:-1}),r}var Trt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.render=function(t,n,a,i){var o=this.group;if(o.removeAll(),!t.get("show"))return;var s=+t.get("itemSize"),l=t.get("orient")==="vertical",u=t.get("feature")||{},c=this._features||(this._features={}),h=[];B(u,function(p,y){h.push(y)}),new Li(this._featureNames||[],h).add(d).update(d).remove(Xt(d,null)).execute(),this._featureNames=h;function d(p,y){var _=h[p],g=h[y],f=u[_],w=new De(f,t,t.ecModel),x;if(i&&i.newTitle!=null&&i.featureName===_&&(f.title=i.newTitle),_&&!g){if(Crt(_))x={onclick:w.option.onclick,featureName:_};else{var S=zO(_);if(!S)return;x=new S}c[_]=x}else if(x=c[g],!x)return;x.uid=pu("toolbox-feature"),x.model=w,x.ecModel=n,x.api=a;var A=x instanceof jn;if(!_&&g){A&&x.dispose&&x.dispose(n,a);return}if(!w.get("show")||A&&x.unusable){A&&x.remove&&x.remove(n,a);return}v(w,x,_),w.setIconStatus=function(T,L){var M=this.option,I=this.iconPaths;M.iconStatus=M.iconStatus||{},M.iconStatus[T]=L,I[T]&&(L==="emphasis"?Ti:Ci)(I[T])},x instanceof jn&&x.render&&x.render(w,n,a,i)}function v(p,y,_){var g=p.getModel("iconStyle"),f=p.getModel(["emphasis","iconStyle"]),w=y instanceof jn&&y.getIcons?y.getIcons():p.get("icon"),x=p.get("title")||{},S,A;Lt(w)?(S={},S[_]=w):S=w,Lt(x)?(A={},A[_]=x):A=x;var T=p.iconPaths={};B(S,function(L,M){var I=kh(L,{},{x:-s/2,y:-s/2,width:s,height:s});I.setStyle(g.getItemStyle());var R=I.ensureState("emphasis");R.style=f.getItemStyle();var P=new pe({style:{text:A[M],align:f.get("textAlign"),borderRadius:f.get("textBorderRadius"),padding:f.get("textPadding"),fill:null,font:lw({fontStyle:f.get("textFontStyle"),fontFamily:f.get("textFontFamily"),fontSize:f.get("textFontSize"),fontWeight:f.get("textFontWeight")},n)},ignore:!0});I.setTextContent(P),Us({el:I,componentModel:t,itemName:M,formatterParamsExtra:{title:A[M]}}),I.__title=A[M],I.on("mouseover",function(){var E=f.getItemStyle(),D=l?t.get("right")==null&&t.get("left")!=="right"?"right":"left":t.get("bottom")==null&&t.get("top")!=="bottom"?"bottom":"top";P.setStyle({fill:f.get("textFill")||E.fill||E.stroke||"#000",backgroundColor:f.get("textBackgroundColor")}),I.setTextConfig({position:f.get("textPosition")||D}),P.ignore=!t.get("showTitle"),a.enterEmphasis(this)}).on("mouseout",function(){p.get(["iconStatus",M])!=="emphasis"&&a.leaveEmphasis(this),P.hide()}),(p.get(["iconStatus",M])==="emphasis"?Ti:Ci)(I),o.add(I),I.on("click",Mt(y.onclick,y,n,a,M)),T[M]=I})}Art(o,t,a),o.add(FO(o.getBoundingRect(),t)),l||o.eachChild(function(p){var y=p.__title,_=p.ensureState("emphasis"),g=_.textConfig||(_.textConfig={}),f=p.getTextContent(),w=f&&f.ensureState("emphasis");if(w&&!Nt(w)&&y){var x=w.style||(w.style={}),S=Th(y,pe.makeFont(x)),A=p.x+o.x,T=p.y+o.y+s,L=!1;T+S.height>a.getHeight()&&(g.position="top",L=!0);var M=L?-5-S.height:s+10;A+S.width/2>a.getWidth()?(g.position=["100%",M],x.align="right"):A-S.width/2<0&&(g.position=[0,M],x.align="left")}})},e.prototype.updateView=function(t,n,a,i){B(this._features,function(o){o instanceof jn&&o.updateView&&o.updateView(o.model,n,a,i)})},e.prototype.remove=function(t,n){B(this._features,function(a){a instanceof jn&&a.remove&&a.remove(t,n)}),this.group.removeAll()},e.prototype.dispose=function(t,n){B(this._features,function(a){a instanceof jn&&a.dispose&&a.dispose(t,n)})},e.type="toolbox",e}(Ze);function Crt(r){return r.indexOf("my")===0}var Lrt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.onclick=function(t,n){var a=this.model,i=a.get("name")||t.get("title.0.text")||"echarts",o=n.getZr().painter.getType()==="svg",s=o?"svg":a.get("type",!0)||"png",l=n.getConnectedDataURL({type:s,backgroundColor:a.get("backgroundColor",!0)||t.get("backgroundColor")||"#fff",connectedBackgroundColor:a.get("connectedBackgroundColor"),excludeComponents:a.get("excludeComponents"),pixelRatio:a.get("pixelRatio")}),u=oe.browser;if(typeof MouseEvent=="function"&&(u.newEdge||!u.ie&&!u.edge)){var c=document.createElement("a");c.download=i+"."+s,c.target="_blank",c.href=l;var h=new MouseEvent("click",{view:document.defaultView,bubbles:!0,cancelable:!1});c.dispatchEvent(h)}else if(window.navigator.msSaveOrOpenBlob||o){var d=l.split(","),v=d[0].indexOf("base64")>-1,p=o?decodeURIComponent(d[1]):d[1];v&&(p=window.atob(p));var y=i+"."+s;if(window.navigator.msSaveOrOpenBlob){for(var _=p.length,g=new Uint8Array(_);_--;)g[_]=p.charCodeAt(_);var f=new Blob([g]);window.navigator.msSaveOrOpenBlob(f,y)}else{var w=document.createElement("iframe");document.body.appendChild(w);var x=w.contentWindow,S=x.document;S.open("image/svg+xml","replace"),S.write(p),S.close(),x.focus(),S.execCommand("SaveAs",!0,y),document.body.removeChild(w)}}else{var A=a.get("lang"),T='<body style="margin:0;"><img src="'+l+'" style="max-width:100%;" title="'+(A&&A[0]||"")+'" /></body>',L=window.open();L.document.write(T),L.document.title=i}},e.getDefaultOption=function(t){var n={show:!0,icon:"M4.7,22.9L29.3,45.5L54.7,23.4M4.6,43.6L4.6,58L53.8,58L53.8,43.6M29.2,45.1L29.2,0",title:t.getLocaleModel().get(["toolbox","saveAsImage","title"]),type:"png",connectedBackgroundColor:"#fff",name:"",excludeComponents:["toolbox"],lang:t.getLocaleModel().get(["toolbox","saveAsImage","lang"])};return n},e}(jn),aD="__ec_magicType_stack__",Mrt=[["line","bar"],["stack"]],Drt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.getIcons=function(){var t=this.model,n=t.get("icon"),a={};return B(t.get("type"),function(i){n[i]&&(a[i]=n[i])}),a},e.getDefaultOption=function(t){var n={show:!0,type:[],icon:{line:"M4.1,28.9h7.1l9.3-22l7.4,38l9.7-19.7l3,12.8h14.9M4.1,58h51.4",bar:"M6.7,22.9h10V48h-10V22.9zM24.9,13h10v35h-10V13zM43.2,2h10v46h-10V2zM3.1,58h53.7",stack:"M8.2,38.4l-8.4,4.1l30.6,15.3L60,42.5l-8.1-4.1l-21.5,11L8.2,38.4z M51.9,30l-8.1,4.2l-13.4,6.9l-13.9-6.9L8.2,30l-8.4,4.2l8.4,4.2l22.2,11l21.5-11l8.1-4.2L51.9,30z M51.9,21.7l-8.1,4.2L35.7,30l-5.3,2.8L24.9,30l-8.4-4.1l-8.3-4.2l-8.4,4.2L8.2,30l8.3,4.2l13.9,6.9l13.4-6.9l8.1-4.2l8.1-4.1L51.9,21.7zM30.4,2.2L-0.2,17.5l8.4,4.1l8.3,4.2l8.4,4.2l5.5,2.7l5.3-2.7l8.1-4.2l8.1-4.2l8.1-4.1L30.4,2.2z"},title:t.getLocaleModel().get(["toolbox","magicType","title"]),option:{},seriesIndex:{}};return n},e.prototype.onclick=function(t,n,a){var i=this.model,o=i.get(["seriesIndex",a]);if(iD[a]){var s={series:[]},l=function(h){var d=h.subType,v=h.id,p=iD[a](d,v,h,i);p&&(zt(p,h.option),s.series.push(p));var y=h.coordinateSystem;if(y&&y.type==="cartesian2d"&&(a==="line"||a==="bar")){var _=y.getAxesByScale("ordinal")[0];if(_){var g=_.dim,f=g+"Axis",w=h.getReferringComponents(f,ir).models[0],x=w.componentIndex;s[f]=s[f]||[];for(var S=0;S<=x;S++)s[f][x]=s[f][x]||{};s[f][x].boundaryGap=a==="bar"}}};B(Mrt,function(h){te(h,a)>=0&&B(h,function(d){i.setIconStatus(d,"normal")})}),i.setIconStatus(a,"emphasis"),t.eachComponent({mainType:"series",query:o==null?null:{seriesIndex:o}},l);var u,c=a;a==="stack"&&(u=qt({stack:i.option.title.tiled,tiled:i.option.title.stack},i.option.title),i.get(["iconStatus",a])!=="emphasis"&&(c="tiled")),n.dispatchAction({type:"changeMagicType",currentType:c,newOption:s,newTitle:u,featureName:"magicType"})}},e}(jn),iD={line:function(r,e,t,n){if(r==="bar")return qt({id:e,type:"line",data:t.get("data"),stack:t.get("stack"),markPoint:t.get("markPoint"),markLine:t.get("markLine")},n.get(["option","line"])||{},!0)},bar:function(r,e,t,n){if(r==="line")return qt({id:e,type:"bar",data:t.get("data"),stack:t.get("stack"),markPoint:t.get("markPoint"),markLine:t.get("markLine")},n.get(["option","bar"])||{},!0)},stack:function(r,e,t,n){var a=t.get("stack")===aD;if(r==="line"||r==="bar")return n.setIconStatus("stack",a?"normal":"emphasis"),qt({id:e,stack:a?"":aD},n.get(["option","stack"])||{},!0)}};Qa({type:"changeMagicType",event:"magicTypeChanged",update:"prepareAndUpdate"},function(r,e){e.mergeOption(r.newOption)});var qp=new Array(60).join("-"),su="	";function Irt(r){var e={},t=[],n=[];return r.eachRawSeries(function(a){var i=a.coordinateSystem;if(i&&(i.type==="cartesian2d"||i.type==="polar")){var o=i.getBaseAxis();if(o.type==="category"){var s=o.dim+"_"+o.index;e[s]||(e[s]={categoryAxis:o,valueAxis:i.getOtherAxis(o),series:[]},n.push({axisDim:o.dim,axisIndex:o.index})),e[s].series.push(a)}else t.push(a)}else t.push(a)}),{seriesGroupByCategoryAxis:e,other:t,meta:n}}function Prt(r){var e=[];return B(r,function(t,n){var a=t.categoryAxis,i=t.valueAxis,o=i.dim,s=[" "].concat(ft(t.series,function(v){return v.name})),l=[a.model.getCategories()];B(t.series,function(v){var p=v.getRawData();l.push(v.getRawData().mapArray(p.mapDimension(o),function(y){return y}))});for(var u=[s.join(su)],c=0;c<l[0].length;c++){for(var h=[],d=0;d<l.length;d++)h.push(l[d][c]);u.push(h.join(su))}e.push(u.join(`
`))}),e.join(`

`+qp+`

`)}function krt(r){return ft(r,function(e){var t=e.getRawData(),n=[e.name],a=[];return t.each(t.dimensions,function(){for(var i=arguments.length,o=arguments[i-1],s=t.getName(o),l=0;l<i-1;l++)a[l]=arguments[l];n.push((s?s+su:"")+a.join(su))}),n.join(`
`)}).join(`

`+qp+`

`)}function Rrt(r){var e=Irt(r);return{value:Te([Prt(e.seriesGroupByCategoryAxis),krt(e.other)],function(t){return!!t.replace(/[\n\t\s]/g,"")}).join(`

`+qp+`

`),meta:e.meta}}function Jd(r){return r.replace(/^\s\s*/,"").replace(/\s\s*$/,"")}function Ert(r){var e=r.slice(0,r.indexOf(`
`));if(e.indexOf(su)>=0)return!0}var m1=new RegExp("["+su+"]+","g");function Ort(r){for(var e=r.split(/\n+/g),t=Jd(e.shift()).split(m1),n=[],a=ft(t,function(l){return{name:l,data:[]}}),i=0;i<e.length;i++){var o=Jd(e[i]).split(m1);n.push(o.shift());for(var s=0;s<o.length;s++)a[s]&&(a[s].data[i]=o[s])}return{series:a,categories:n}}function Brt(r){for(var e=r.split(/\n+/g),t=Jd(e.shift()),n=[],a=0;a<e.length;a++){var i=Jd(e[a]);if(i){var o=i.split(m1),s="",l=void 0,u=!1;isNaN(o[0])?(u=!0,s=o[0],o=o.slice(1),n[a]={name:s,value:[]},l=n[a].value):l=n[a]=[];for(var c=0;c<o.length;c++)l.push(+o[c]);l.length===1&&(u?n[a].value=l[0]:n[a]=l[0])}}return{name:t,data:n}}function Nrt(r,e){var t=r.split(new RegExp(`
*`+qp+`
*`,"g")),n={series:[]};return B(t,function(a,i){if(Ert(a)){var o=Ort(a),s=e[i],l=s.axisDim+"Axis";s&&(n[l]=n[l]||[],n[l][s.axisIndex]={data:o.categories},n.series=n.series.concat(o.series))}else{var o=Brt(a);n.series.push(o)}}),n}var zrt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.onclick=function(t,n){setTimeout(function(){n.dispatchAction({type:"hideTip"})});var a=n.getDom(),i=this.model;this._dom&&a.removeChild(this._dom);var o=document.createElement("div");o.style.cssText="position:absolute;top:0;bottom:0;left:0;right:0;padding:5px",o.style.backgroundColor=i.get("backgroundColor")||"#fff";var s=document.createElement("h4"),l=i.get("lang")||[];s.innerHTML=l[0]||i.get("title"),s.style.cssText="margin:10px 20px",s.style.color=i.get("textColor");var u=document.createElement("div"),c=document.createElement("textarea");u.style.cssText="overflow:auto";var h=i.get("optionToContent"),d=i.get("contentToOption"),v=Rrt(t);if(Nt(h)){var p=h(n.getOption());Lt(p)?u.innerHTML=p:Kl(p)&&u.appendChild(p)}else{c.readOnly=i.get("readOnly");var y=c.style;y.cssText="display:block;width:100%;height:100%;font-family:monospace;font-size:14px;line-height:1.6rem;resize:none;box-sizing:border-box;outline:none",y.color=i.get("textColor"),y.borderColor=i.get("textareaBorderColor"),y.backgroundColor=i.get("textareaColor"),c.value=v.value,u.appendChild(c)}var _=v.meta,g=document.createElement("div");g.style.cssText="position:absolute;bottom:5px;left:0;right:0";var f="float:right;margin-right:20px;border:none;cursor:pointer;padding:2px 5px;font-size:12px;border-radius:3px",w=document.createElement("div"),x=document.createElement("div");f+=";background-color:"+i.get("buttonColor"),f+=";color:"+i.get("buttonTextColor");var S=this;function A(){a.removeChild(o),S._dom=null}q0(w,"click",A),q0(x,"click",function(){if(d==null&&h!=null||d!=null&&h==null){A();return}var T;try{Nt(d)?T=d(u,n.getOption()):T=Nrt(c.value,_)}catch(L){throw A(),new Error("Data view format error "+L)}T&&n.dispatchAction({type:"changeDataView",newOption:T}),A()}),w.innerHTML=l[1],x.innerHTML=l[2],x.style.cssText=w.style.cssText=f,!i.get("readOnly")&&g.appendChild(x),g.appendChild(w),o.appendChild(s),o.appendChild(u),o.appendChild(g),u.style.height=a.clientHeight-80+"px",a.appendChild(o),this._dom=o},e.prototype.remove=function(t,n){this._dom&&n.getDom().removeChild(this._dom)},e.prototype.dispose=function(t,n){this.remove(t,n)},e.getDefaultOption=function(t){var n={show:!0,readOnly:!1,optionToContent:null,contentToOption:null,icon:"M17.5,17.3H33 M17.5,17.3H33 M45.4,29.5h-28 M11.5,2v56H51V14.8L38.4,2H11.5z M38.4,2.2v12.7H51 M45.4,41.7h-28",title:t.getLocaleModel().get(["toolbox","dataView","title"]),lang:t.getLocaleModel().get(["toolbox","dataView","lang"]),backgroundColor:"#fff",textColor:"#000",textareaColor:"#fff",textareaBorderColor:"#333",buttonColor:"#c23531",buttonTextColor:"#fff"};return n},e}(jn);function Frt(r,e){return ft(r,function(t,n){var a=e&&e[n];if(Vt(a)&&!ht(a)){var i=Vt(t)&&!ht(t);i||(t={value:t});var o=a.name!=null&&t.name==null;return t=zt(t,a),o&&delete t.name,t}else return t})}Qa({type:"changeDataView",event:"dataViewChanged",update:"prepareAndUpdate"},function(r,e){var t=[];B(r.newOption.series,function(n){var a=e.getSeriesByName(n.name)[0];if(!a)t.push(lt({type:"scatter"},n));else{var i=a.get("data");t.push({name:n.name,data:Frt(n.data,i)})}}),e.mergeOption(zt({series:t},r.newOption))});var VO=B,GO=ve();function Vrt(r,e){var t=Rx(r);VO(e,function(n,a){for(var i=t.length-1;i>=0;i--){var o=t[i];if(o[a])break}if(i<0){var s=r.queryComponents({mainType:"dataZoom",subType:"select",id:a})[0];if(s){var l=s.getPercentRange();t[0][a]={dataZoomId:a,start:l[0],end:l[1]}}}}),t.push(e)}function Grt(r){var e=Rx(r),t=e[e.length-1];e.length>1&&e.pop();var n={};return VO(t,function(a,i){for(var o=e.length-1;o>=0;o--)if(a=e[o][i],a){n[i]=a;break}}),n}function Wrt(r){GO(r).snapshots=null}function Hrt(r){return Rx(r).length}function Rx(r){var e=GO(r);return e.snapshots||(e.snapshots=[{}]),e.snapshots}var Urt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.onclick=function(t,n){Wrt(t),n.dispatchAction({type:"restore",from:this.uid})},e.getDefaultOption=function(t){var n={show:!0,icon:"M3.8,33.4 M47,18.9h9.8V8.7 M56.3,20.1 C52.1,9,40.5,0.6,26.8,2.1C12.6,3.7,1.6,16.2,2.1,30.6 M13,41.1H3.1v10.2 M3.7,39.9c4.2,11.1,15.8,19.5,29.5,18 c14.2-1.6,25.2-14.1,24.7-28.5",title:t.getLocaleModel().get(["toolbox","restore","title"])};return n},e}(jn);Qa({type:"restore",event:"restore",update:"prepareAndUpdate"},function(r,e){e.resetOption("recreate")});var Zrt=["grid","xAxis","yAxis","geo","graph","polar","radiusAxis","angleAxis","bmap"],Ex=function(){function r(e,t,n){var a=this;this._targetInfoList=[];var i=oD(t,e);B(Yrt,function(o,s){(!n||!n.include||te(n.include,s)>=0)&&o(i,a._targetInfoList)})}return r.prototype.setOutputRanges=function(e,t){return this.matchOutputRanges(e,t,function(n,a,i){if((n.coordRanges||(n.coordRanges=[])).push(a),!n.coordRange){n.coordRange=a;var o=_0[n.brushType](0,i,a);n.__rangeOffset={offset:cD[n.brushType](o.values,n.range,[1,1]),xyMinMax:o.xyMinMax}}}),e},r.prototype.matchOutputRanges=function(e,t,n){B(e,function(a){var i=this.findTargetInfo(a,t);i&&i!==!0&&B(i.coordSyses,function(o){var s=_0[a.brushType](1,o,a.range,!0);n(a,s.values,o,t)})},this)},r.prototype.setInputRanges=function(e,t){B(e,function(n){var a=this.findTargetInfo(n,t);if(n.range=n.range||[],a&&a!==!0){n.panelId=a.panelId;var i=_0[n.brushType](0,a.coordSys,n.coordRange),o=n.__rangeOffset;n.range=o?cD[n.brushType](i.values,o.offset,Xrt(i.xyMinMax,o.xyMinMax)):i.values}},this)},r.prototype.makePanelOpts=function(e,t){return ft(this._targetInfoList,function(n){var a=n.getPanelRect();return{panelId:n.panelId,defaultBrushType:t?t(n):null,clipPath:j5(a),isTargetByCursor:K5(a,e,n.coordSysModel),getLinearBrushOtherExtent:q5(a)}})},r.prototype.controlSeries=function(e,t,n){var a=this.findTargetInfo(e,n);return a===!0||a&&te(a.coordSyses,t.coordinateSystem)>=0},r.prototype.findTargetInfo=function(e,t){for(var n=this._targetInfoList,a=oD(t,e),i=0;i<n.length;i++){var o=n[i],s=e.panelId;if(s){if(o.panelId===s)return o}else for(var l=0;l<sD.length;l++)if(sD[l](a,o))return o}return!0},r}();function _1(r){return r[0]>r[1]&&r.reverse(),r}function oD(r,e){return Bc(r,e,{includeMainTypes:Zrt})}var Yrt={grid:function(r,e){var t=r.xAxisModels,n=r.yAxisModels,a=r.gridModels,i=Pt(),o={},s={};!t&&!n&&!a||(B(t,function(l){var u=l.axis.grid.model;i.set(u.id,u),o[u.id]=!0}),B(n,function(l){var u=l.axis.grid.model;i.set(u.id,u),s[u.id]=!0}),B(a,function(l){i.set(l.id,l),o[l.id]=!0,s[l.id]=!0}),i.each(function(l){var u=l.coordinateSystem,c=[];B(u.getCartesians(),function(h,d){(te(t,h.getAxis("x").model)>=0||te(n,h.getAxis("y").model)>=0)&&c.push(h)}),e.push({panelId:"grid--"+l.id,gridModel:l,coordSysModel:l,coordSys:c[0],coordSyses:c,getPanelRect:lD.grid,xAxisDeclared:o[l.id],yAxisDeclared:s[l.id]})}))},geo:function(r,e){B(r.geoModels,function(t){var n=t.coordinateSystem;e.push({panelId:"geo--"+t.id,geoModel:t,coordSysModel:t,coordSys:n,coordSyses:[n],getPanelRect:lD.geo})})}},sD=[function(r,e){var t=r.xAxisModel,n=r.yAxisModel,a=r.gridModel;return!a&&t&&(a=t.axis.grid.model),!a&&n&&(a=n.axis.grid.model),a&&a===e.gridModel},function(r,e){var t=r.geoModel;return t&&t===e.geoModel}],lD={grid:function(){return this.coordSys.master.getRect().clone()},geo:function(){var r=this.coordSys,e=r.getBoundingRect().clone();return e.applyTransform(Ps(r)),e}},_0={lineX:Xt(uD,0),lineY:Xt(uD,1),rect:function(r,e,t,n){var a=r?e.pointToData([t[0][0],t[1][0]],n):e.dataToPoint([t[0][0],t[1][0]],n),i=r?e.pointToData([t[0][1],t[1][1]],n):e.dataToPoint([t[0][1],t[1][1]],n),o=[_1([a[0],i[0]]),_1([a[1],i[1]])];return{values:o,xyMinMax:o}},polygon:function(r,e,t,n){var a=[[1/0,-1/0],[1/0,-1/0]],i=ft(t,function(o){var s=r?e.pointToData(o,n):e.dataToPoint(o,n);return a[0][0]=Math.min(a[0][0],s[0]),a[1][0]=Math.min(a[1][0],s[1]),a[0][1]=Math.max(a[0][1],s[0]),a[1][1]=Math.max(a[1][1],s[1]),s});return{values:i,xyMinMax:a}}};function uD(r,e,t,n){var a=t.getAxis(["x","y"][r]),i=_1(ft([0,1],function(s){return e?a.coordToData(a.toLocalCoord(n[s]),!0):a.toGlobalCoord(a.dataToCoord(n[s]))})),o=[];return o[r]=i,o[1-r]=[NaN,NaN],{values:i,xyMinMax:o}}var cD={lineX:Xt(hD,0),lineY:Xt(hD,1),rect:function(r,e,t){return[[r[0][0]-t[0]*e[0][0],r[0][1]-t[0]*e[0][1]],[r[1][0]-t[1]*e[1][0],r[1][1]-t[1]*e[1][1]]]},polygon:function(r,e,t){return ft(r,function(n,a){return[n[0]-t[0]*e[a][0],n[1]-t[1]*e[a][1]]})}};function hD(r,e,t,n){return[e[0]-n[r]*t[0],e[1]-n[r]*t[1]]}function Xrt(r,e){var t=fD(r),n=fD(e),a=[t[0]/n[0],t[1]/n[1]];return isNaN(a[0])&&(a[0]=1),isNaN(a[1])&&(a[1]=1),a}function fD(r){return r?[r[0][1]-r[0][0],r[1][1]-r[1][0]]:[NaN,NaN]}var w1=B,$rt=tW("toolbox-dataZoom_"),jrt=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.render=function(t,n,a,i){this._brushController||(this._brushController=new ox(a.getZr()),this._brushController.on("brush",Mt(this._onBrush,this)).mount()),Qrt(t,n,this,i,a),Krt(t,n)},e.prototype.onclick=function(t,n,a){qrt[a].call(this)},e.prototype.remove=function(t,n){this._brushController&&this._brushController.unmount()},e.prototype.dispose=function(t,n){this._brushController&&this._brushController.dispose()},e.prototype._onBrush=function(t){var n=t.areas;if(!t.isEnd||!n.length)return;var a={},i=this.ecModel;this._brushController.updateCovers([]);var o=new Ex(Ox(this.model),i,{include:["grid"]});o.matchOutputRanges(n,i,function(u,c,h){if(h.type==="cartesian2d"){var d=u.brushType;d==="rect"?(s("x",h,c[0]),s("y",h,c[1])):s({lineX:"x",lineY:"y"}[d],h,c)}}),Vrt(i,a),this._dispatchZoomAction(a);function s(u,c,h){var d=c.getAxis(u),v=d.model,p=l(u,v,i),y=p.findRepresentativeAxisProxy(v).getMinMaxSpan();(y.minValueSpan!=null||y.maxValueSpan!=null)&&(h=qs(0,h.slice(),d.scale.getExtent(),0,y.minValueSpan,y.maxValueSpan)),p&&(a[p.id]={dataZoomId:p.id,startValue:h[0],endValue:h[1]})}function l(u,c,h){var d;return h.eachComponent({mainType:"dataZoom",subType:"select"},function(v){var p=v.getAxisModel(u,c.componentIndex);p&&(d=v)}),d}},e.prototype._dispatchZoomAction=function(t){var n=[];w1(t,function(a,i){n.push(Gt(a))}),n.length&&this.api.dispatchAction({type:"dataZoom",from:this.uid,batch:n})},e.getDefaultOption=function(t){var n={show:!0,filterMode:"filter",icon:{zoom:"M0,13.5h26.9 M13.5,26.9V0 M32.1,13.5H58V58H13.5 V32.1",back:"M22,1.4L9.9,13.5l12.3,12.3 M10.3,13.5H54.9v44.6 H10.3v-26"},title:t.getLocaleModel().get(["toolbox","dataZoom","title"]),brushStyle:{borderWidth:0,color:"rgba(210,219,238,0.2)"}};return n},e}(jn),qrt={zoom:function(){var r=!this._isZoomActive;this.api.dispatchAction({type:"takeGlobalCursor",key:"dataZoomSelect",dataZoomSelectActive:r})},back:function(){this._dispatchZoomAction(Grt(this.ecModel))}};function Ox(r){var e={xAxisIndex:r.get("xAxisIndex",!0),yAxisIndex:r.get("yAxisIndex",!0),xAxisId:r.get("xAxisId",!0),yAxisId:r.get("yAxisId",!0)};return e.xAxisIndex==null&&e.xAxisId==null&&(e.xAxisIndex="all"),e.yAxisIndex==null&&e.yAxisId==null&&(e.yAxisIndex="all"),e}function Krt(r,e){r.setIconStatus("back",Hrt(e)>1?"emphasis":"normal")}function Qrt(r,e,t,n,a){var i=t._isZoomActive;n&&n.type==="takeGlobalCursor"&&(i=n.key==="dataZoomSelect"?n.dataZoomSelectActive:!1),t._isZoomActive=i,r.setIconStatus("zoom",i?"emphasis":"normal");var o=new Ex(Ox(r),e,{include:["grid"]}),s=o.makePanelOpts(a,function(l){return l.xAxisDeclared&&!l.yAxisDeclared?"lineX":!l.xAxisDeclared&&l.yAxisDeclared?"lineY":"rect"});t._brushController.setPanels(s).enableBrush(i&&s.length?{brushType:"auto",brushStyle:r.getModel("brushStyle").getItemStyle()}:!1)}TU("dataZoom",function(r){var e=r.getComponent("toolbox",0),t=["feature","dataZoom"];if(!e||e.get(t)==null)return;var n=e.getModel(t),a=[],i=Ox(n),o=Bc(r,i);w1(o.xAxisModels,function(l){return s(l,"xAxis","xAxisIndex")}),w1(o.yAxisModels,function(l){return s(l,"yAxis","yAxisIndex")});function s(l,u,c){var h=l.componentIndex,d={type:"select",$fromToolbox:!0,filterMode:n.get("filterMode",!0)||"filter",id:$rt+u+h};d[c]=h,a.push(d)}return a});function Jrt(r){r.registerComponentModel(Srt),r.registerComponentView(Trt),zl("saveAsImage",Lrt),zl("magicType",Drt),zl("dataView",zrt),zl("dataZoom",jrt),zl("restore",Urt),ne(brt)}var tnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="tooltip",e.dependencies=["axisPointer"],e.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,displayMode:"single",renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,enterable:!1,backgroundColor:"#fff",shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:"#999",width:1,type:"dashed",textStyle:{}}},textStyle:{color:"#666",fontSize:14}},e}(le);function WO(r){var e=r.get("confine");return e!=null?!!e:r.get("renderMode")==="richText"}function HO(r){if(oe.domSupported){for(var e=document.documentElement.style,t=0,n=r.length;t<n;t++)if(r[t]in e)return r[t]}}var UO=HO(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),ent=HO(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function ZO(r,e){if(!r)return e;e=Sk(e,!0);var t=r.indexOf(e);return r=t===-1?e:"-"+r.slice(0,t)+"-"+e,r.toLowerCase()}function rnt(r,e){var t=r.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(r);return t?t[e]:null}var nnt=ZO(ent,"transition"),Bx=ZO(UO,"transform"),ant="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(oe.transform3dSupported?"will-change:transform;":"");function int(r){return r=r==="left"?"right":r==="right"?"left":r==="top"?"bottom":"top",r}function ont(r,e,t){if(!Lt(t)||t==="inside")return"";var n=r.get("backgroundColor"),a=r.get("borderWidth");e=Fs(e);var i=int(t),o=Math.max(Math.round(a)*1.5,6),s="",l=Bx+":",u;te(["left","right"],i)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=i==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=i==="top"?225:45)+"deg)");var c=u*Math.PI/180,h=o+a,d=h*Math.abs(Math.cos(c))+h*Math.abs(Math.sin(c)),v=Math.round(((d-Math.SQRT2*a)/2+Math.SQRT2*a-(d-h)/2)*100)/100;s+=";"+i+":-"+v+"px";var p=e+" solid "+a+"px;",y=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+p,"border-right:"+p,"background-color:"+n+";"];return'<div style="'+y.join("")+'"></div>'}function snt(r,e){var t="cubic-bezier(0.23,1,0.32,1)",n=" "+r/2+"s "+t,a="opacity"+n+",visibility"+n;return e||(n=" "+r+"s "+t,a+=oe.transformSupported?","+Bx+n:",left"+n+",top"+n),nnt+":"+a}function vD(r,e,t){var n=r.toFixed(0)+"px",a=e.toFixed(0)+"px";if(!oe.transformSupported)return t?"top:"+a+";left:"+n+";":[["top",a],["left",n]];var i=oe.transform3dSupported,o="translate"+(i?"3d":"")+"("+n+","+a+(i?",0":"")+")";return t?"top:0;left:0;"+Bx+":"+o+";":[["top",0],["left",0],[UO,o]]}function lnt(r){var e=[],t=r.get("fontSize"),n=r.getTextColor();n&&e.push("color:"+n),e.push("font:"+r.getFont());var a=Zt(r.get("lineHeight"),Math.round(t*3/2));t&&e.push("line-height:"+a+"px");var i=r.get("textShadowColor"),o=r.get("textShadowBlur")||0,s=r.get("textShadowOffsetX")||0,l=r.get("textShadowOffsetY")||0;return i&&o&&e.push("text-shadow:"+s+"px "+l+"px "+o+"px "+i),B(["decoration","align"],function(u){var c=r.get(u);c&&e.push("text-"+u+":"+c)}),e.join(";")}function unt(r,e,t){var n=[],a=r.get("transitionDuration"),i=r.get("backgroundColor"),o=r.get("shadowBlur"),s=r.get("shadowColor"),l=r.get("shadowOffsetX"),u=r.get("shadowOffsetY"),c=r.getModel("textStyle"),h=nR(r,"html"),d=l+"px "+u+"px "+o+"px "+s;return n.push("box-shadow:"+d),e&&a&&n.push(snt(a,t)),i&&n.push("background-color:"+i),B(["width","color","radius"],function(v){var p="border-"+v,y=Sk(p),_=r.get(y);_!=null&&n.push(p+":"+_+(v==="color"?"":"px"))}),n.push(lnt(c)),h!=null&&n.push("padding:"+gu(h).join("px ")+"px"),n.join(";")+";"}function dD(r,e,t,n,a){var i=e&&e.painter;if(t){var o=i&&i.getViewportRoot();o&&k6(r,o,t,n,a)}else{r[0]=n,r[1]=a;var s=i&&i.getViewportRootOffset();s&&(r[0]+=s.offsetLeft,r[1]+=s.offsetTop)}r[2]=r[0]/e.getWidth(),r[3]=r[1]/e.getHeight()}var cnt=function(){function r(e,t){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,oe.wxa)return null;var n=document.createElement("div");n.domBelongToZr=!0,this.el=n;var a=this._zr=e.getZr(),i=t.appendTo,o=i&&(Lt(i)?document.querySelector(i):Kl(i)?i:Nt(i)&&i(e.getDom()));dD(this._styleCoord,a,o,e.getWidth()/2,e.getHeight()/2),(o||e.getDom()).appendChild(n),this._api=e,this._container=o;var s=this;n.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},n.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=a.handler,c=a.painter.getViewportRoot();Un(c,l,!0),u.dispatch("mousemove",l)}},n.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return r.prototype.update=function(e){if(!this._container){var t=this._api.getDom(),n=rnt(t,"position"),a=t.style;a.position!=="absolute"&&n!=="absolute"&&(a.position="relative")}var i=e.get("alwaysShowContent");i&&this._moveIfResized(),this._alwaysShowContent=i,this.el.className=e.get("className")||""},r.prototype.show=function(e,t){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var n=this.el,a=n.style,i=this._styleCoord;n.innerHTML?a.cssText=ant+unt(e,!this._firstShow,this._longHide)+vD(i[0],i[1],!0)+("border-color:"+Fs(t)+";")+(e.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):a.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},r.prototype.setContent=function(e,t,n,a,i){var o=this.el;if(e==null){o.innerHTML="";return}var s="";if(Lt(i)&&n.get("trigger")==="item"&&!WO(n)&&(s=ont(n,a,i)),Lt(e))o.innerHTML=e+s;else if(e){o.innerHTML="",ht(e)||(e=[e]);for(var l=0;l<e.length;l++)Kl(e[l])&&e[l].parentNode!==o&&o.appendChild(e[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},r.prototype.setEnterable=function(e){this._enterable=e},r.prototype.getSize=function(){var e=this.el;return e?[e.offsetWidth,e.offsetHeight]:[0,0]},r.prototype.moveTo=function(e,t){if(this.el){var n=this._styleCoord;if(dD(n,this._zr,this._container,e,t),n[0]!=null&&n[1]!=null){var a=this.el.style,i=vD(n[0],n[1]);B(i,function(o){a[o[0]]=o[1]})}}},r.prototype._moveIfResized=function(){var e=this._styleCoord[2],t=this._styleCoord[3];this.moveTo(e*this._zr.getWidth(),t*this._zr.getHeight())},r.prototype.hide=function(){var e=this,t=this.el.style;t.visibility="hidden",t.opacity="0",oe.transform3dSupported&&(t.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return e._longHide=!0},500)},r.prototype.hideLater=function(e){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(e?(this._hideDelay=e,this._show=!1,this._hideTimeout=setTimeout(Mt(this.hide,this),e)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var e=this.el.parentNode;e&&e.removeChild(this.el),this.el=this._container=null},r}(),hnt=function(){function r(e){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=e.getZr(),gD(this._styleCoord,this._zr,e.getWidth()/2,e.getHeight()/2)}return r.prototype.update=function(e){var t=e.get("alwaysShowContent");t&&this._moveIfResized(),this._alwaysShowContent=t},r.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},r.prototype.setContent=function(e,t,n,a,i){var o=this;Vt(e)&&Ae(""),this.el&&this._zr.remove(this.el);var s=n.getModel("textStyle");this.el=new pe({style:{rich:t.richTextStyles,text:e,lineHeight:22,borderWidth:1,borderColor:a,textShadowColor:s.get("textShadowColor"),fill:n.get(["textStyle","color"]),padding:nR(n,"richText"),verticalAlign:"top",align:"left"},z:n.get("z")}),B(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=n.get(u)}),B(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},r.prototype.setEnterable=function(e){this._enterable=e},r.prototype.getSize=function(){var e=this.el,t=this.el.getBoundingRect(),n=pD(e.style);return[t.width+n.left+n.right,t.height+n.top+n.bottom]},r.prototype.moveTo=function(e,t){var n=this.el;if(n){var a=this._styleCoord;gD(a,this._zr,e,t),e=a[0],t=a[1];var i=n.style,o=to(i.borderWidth||0),s=pD(i);n.x=e+o+s.left,n.y=t+o+s.top,n.markRedraw()}},r.prototype._moveIfResized=function(){var e=this._styleCoord[2],t=this._styleCoord[3];this.moveTo(e*this._zr.getWidth(),t*this._zr.getHeight())},r.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},r.prototype.hideLater=function(e){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(e?(this._hideDelay=e,this._show=!1,this._hideTimeout=setTimeout(Mt(this.hide,this),e)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){this._zr.remove(this.el)},r}();function to(r){return Math.max(0,r)}function pD(r){var e=to(r.shadowBlur||0),t=to(r.shadowOffsetX||0),n=to(r.shadowOffsetY||0);return{left:to(e-t),right:to(e+t),top:to(e-n),bottom:to(e+n)}}function gD(r,e,t,n){r[0]=t,r[1]=n,r[2]=r[0]/e.getWidth(),r[3]=r[1]/e.getHeight()}var fnt=new fe({shape:{x:-1,y:-1,width:2,height:2}}),vnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n){if(!(oe.node||!n.getDom())){var a=t.getComponent("tooltip"),i=this._renderMode=sW(a.get("renderMode"));this._tooltipContent=i==="richText"?new hnt(n):new cnt(n,{appendTo:a.get("appendToBody",!0)?"body":a.get("appendTo",!0)})}},e.prototype.render=function(t,n,a){if(!(oe.node||!a.getDom())){this.group.removeAll(),this._tooltipModel=t,this._ecModel=n,this._api=a;var i=this._tooltipContent;i.update(t),i.setEnterable(t.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&t.get("transitionDuration")?wu(this,"_updatePosition",50,"fixRate"):oh(this,"_updatePosition")}},e.prototype._initGlobalListener=function(){var t=this._tooltipModel,n=t.get("triggerOn");DO("itemTooltip",this._api,Mt(function(a,i,o){n!=="none"&&(n.indexOf(a)>=0?this._tryShow(i,o):a==="leave"&&this._hide(o))},this))},e.prototype._keepShow=function(){var t=this._tooltipModel,n=this._ecModel,a=this._api,i=t.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&i!=="none"&&i!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!a.isDisposed()&&o.manuallyShowTip(t,n,a,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},e.prototype.manuallyShowTip=function(t,n,a,i){if(!(i.from===this.uid||oe.node||!a.getDom())){var o=yD(i,a);this._ticket="";var s=i.dataByCoordSys,l=ynt(i,n,a);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:i.position,positionDefault:"bottom"},o)}else if(i.tooltip&&i.x!=null&&i.y!=null){var c=fnt;c.x=i.x,c.y=i.y,c.update(),Ht(c).tooltipConfig={name:null,option:i.tooltip},this._tryShow({offsetX:i.x,offsetY:i.y,target:c},o)}else if(s)this._tryShow({offsetX:i.x,offsetY:i.y,position:i.position,dataByCoordSys:s,tooltipOption:i.tooltipOption},o);else if(i.seriesIndex!=null){if(this._manuallyAxisShowTip(t,n,a,i))return;var h=IO(i,n),d=h.point[0],v=h.point[1];d!=null&&v!=null&&this._tryShow({offsetX:d,offsetY:v,target:h.el,position:i.position,positionDefault:"bottom"},o)}else i.x!=null&&i.y!=null&&(a.dispatchAction({type:"updateAxisPointer",x:i.x,y:i.y}),this._tryShow({offsetX:i.x,offsetY:i.y,position:i.position,target:a.getZr().findHover(i.x,i.y).target},o))}},e.prototype.manuallyHideTip=function(t,n,a,i){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,i.from!==this.uid&&this._hide(yD(i,a))},e.prototype._manuallyAxisShowTip=function(t,n,a,i){var o=i.seriesIndex,s=i.dataIndex,l=n.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=n.getSeriesByIndex(o);if(u){var c=u.getData(),h=cc([c.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(h.get("trigger")==="axis")return a.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:i.position}),!0}}},e.prototype._tryShow=function(t,n){var a=t.target,i=this._tooltipModel;if(i){this._lastX=t.offsetX,this._lastY=t.offsetY;var o=t.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,t);else if(a){var s=Ht(a);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;bs(a,function(c){if(Ht(c).dataIndex!=null)return l=c,!0;if(Ht(c).tooltipConfig!=null)return u=c,!0},!0),l?this._showSeriesItemTooltip(t,l,n):u?this._showComponentItemTooltip(t,u,n):this._hide(n)}else this._lastDataByCoordSys=null,this._hide(n)}},e.prototype._showOrMove=function(t,n){var a=t.get("showDelay");n=Mt(n,this),clearTimeout(this._showTimout),a>0?this._showTimout=setTimeout(n,a):n()},e.prototype._showAxisTooltip=function(t,n){var a=this._ecModel,i=this._tooltipModel,o=[n.offsetX,n.offsetY],s=cc([n.tooltipOption],i),l=this._renderMode,u=[],c=wr("section",{blocks:[],noHeader:!0}),h=[],d=new am;B(t,function(f){B(f.dataByAxis,function(w){var x=a.getComponent(w.axisDim+"Axis",w.axisIndex),S=w.value;if(!(!x||S==null)){var A=CO(S,x.axis,a,w.seriesDataIndices,w.valueLabelOpt),T=wr("section",{header:A,noHeader:!ga(A),sortBlocks:!0,blocks:[]});c.blocks.push(T),B(w.seriesDataIndices,function(L){var M=a.getSeriesByIndex(L.seriesIndex),I=L.dataIndexInside,R=M.getDataParams(I);if(!(R.dataIndex<0)){R.axisDim=w.axisDim,R.axisIndex=w.axisIndex,R.axisType=w.axisType,R.axisId=w.axisId,R.axisValue=Ew(x.axis,{value:S}),R.axisValueLabel=A,R.marker=d.makeTooltipMarker("item",Fs(R.color),l);var P=nT(M.formatTooltip(I,!0,null)),E=P.frag;if(E){var D=cc([M],i).get("valueFormatter");T.blocks.push(D?lt({valueFormatter:D},E):E)}P.text&&h.push(P.text),u.push(R)}})}})}),c.blocks.reverse(),h.reverse();var v=n.position,p=s.get("order"),y=uT(c,d,l,p,a.get("useUTC"),s.get("textStyle"));y&&h.unshift(y);var _=l==="richText"?`

`:"<br/>",g=h.join(_);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(t,u)?this._updatePosition(s,v,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,g,u,Math.random()+"",o[0],o[1],v,null,d)})},e.prototype._showSeriesItemTooltip=function(t,n,a){var i=this._ecModel,o=Ht(n),s=o.seriesIndex,l=i.getSeriesByIndex(s),u=o.dataModel||l,c=o.dataIndex,h=o.dataType,d=u.getData(h),v=this._renderMode,p=t.positionDefault,y=cc([d.getItemModel(c),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,p?{position:p}:null),_=y.get("trigger");if(!(_!=null&&_!=="item")){var g=u.getDataParams(c,h),f=new am;g.marker=f.makeTooltipMarker("item",Fs(g.color),v);var w=nT(u.formatTooltip(c,!1,h)),x=y.get("order"),S=y.get("valueFormatter"),A=w.frag,T=A?uT(S?lt({valueFormatter:S},A):A,f,v,x,i.get("useUTC"),y.get("textStyle")):w.text,L="item_"+u.name+"_"+c;this._showOrMove(y,function(){this._showTooltipContent(y,T,g,L,t.offsetX,t.offsetY,t.position,t.target,f)}),a({type:"showTip",dataIndexInside:c,dataIndex:d.getRawIndex(c),seriesIndex:s,from:this.uid})}},e.prototype._showComponentItemTooltip=function(t,n,a){var i=this._renderMode==="html",o=Ht(n),s=o.tooltipConfig,l=s.option||{},u=l.encodeHTMLContent;if(Lt(l)){var c=l;l={content:c,formatter:c},u=!0}u&&i&&l.content&&(l=Gt(l),l.content=qr(l.content));var h=[l],d=this._ecModel.getComponent(o.componentMainType,o.componentIndex);d&&h.push(d),h.push({formatter:l.content});var v=t.positionDefault,p=cc(h,this._tooltipModel,v?{position:v}:null),y=p.get("content"),_=Math.random()+"",g=new am;this._showOrMove(p,function(){var f=Gt(p.get("formatterParams")||{});this._showTooltipContent(p,y,f,_,t.offsetX,t.offsetY,t.position,n,g)}),a({type:"showTip",from:this.uid})},e.prototype._showTooltipContent=function(t,n,a,i,o,s,l,u,c){if(this._ticket="",!(!t.get("showContent")||!t.get("show"))){var h=this._tooltipContent;h.setEnterable(t.get("enterable"));var d=t.get("formatter");l=l||t.get("position");var v=n,p=this._getNearestPoint([o,s],a,t.get("trigger"),t.get("borderColor")),y=p.color;if(d)if(Lt(d)){var _=t.ecModel.get("useUTC"),g=ht(a)?a[0]:a,f=g&&g.axisType&&g.axisType.indexOf("time")>=0;v=d,f&&(v=Mp(g.axisValue,v,_)),v=Ak(v,a,!0)}else if(Nt(d)){var w=Mt(function(x,S){x===this._ticket&&(h.setContent(S,c,t,y,l),this._updatePosition(t,l,o,s,h,a,u))},this);this._ticket=i,v=d(a,i,w)}else v=d;h.setContent(v,c,t,y,l),h.show(t,y),this._updatePosition(t,l,o,s,h,a,u)}},e.prototype._getNearestPoint=function(t,n,a,i){if(a==="axis"||ht(n))return{color:i||(this._renderMode==="html"?"#fff":"none")};if(!ht(n))return{color:i||n.color||n.borderColor}},e.prototype._updatePosition=function(t,n,a,i,o,s,l){var u=this._api.getWidth(),c=this._api.getHeight();n=n||t.get("position");var h=o.getSize(),d=t.get("align"),v=t.get("verticalAlign"),p=l&&l.getBoundingRect().clone();if(l&&p.applyTransform(l.transform),Nt(n)&&(n=n([a,i],s,o.el,p,{viewSize:[u,c],contentSize:h.slice()})),ht(n))a=At(n[0],u),i=At(n[1],c);else if(Vt(n)){var y=n;y.width=h[0],y.height=h[1];var _=cr(y,{width:u,height:c});a=_.x,i=_.y,d=null,v=null}else if(Lt(n)&&l){var g=gnt(n,p,h,t.get("borderWidth"));a=g[0],i=g[1]}else{var g=dnt(a,i,o,u,c,d?null:20,v?null:20);a=g[0],i=g[1]}if(d&&(a-=mD(d)?h[0]/2:d==="right"?h[0]:0),v&&(i-=mD(v)?h[1]/2:v==="bottom"?h[1]:0),WO(t)){var g=pnt(a,i,o,u,c);a=g[0],i=g[1]}o.moveTo(a,i)},e.prototype._updateContentNotChangedOnAxis=function(t,n){var a=this._lastDataByCoordSys,i=this._cbParamsList,o=!!a&&a.length===t.length;return o&&B(a,function(s,l){var u=s.dataByAxis||[],c=t[l]||{},h=c.dataByAxis||[];o=o&&u.length===h.length,o&&B(u,function(d,v){var p=h[v]||{},y=d.seriesDataIndices||[],_=p.seriesDataIndices||[];o=o&&d.value===p.value&&d.axisType===p.axisType&&d.axisId===p.axisId&&y.length===_.length,o&&B(y,function(g,f){var w=_[f];o=o&&g.seriesIndex===w.seriesIndex&&g.dataIndex===w.dataIndex}),i&&B(d.seriesDataIndices,function(g){var f=g.seriesIndex,w=n[f],x=i[f];w&&x&&x.data!==w.data&&(o=!1)})})}),this._lastDataByCoordSys=t,this._cbParamsList=n,!!o},e.prototype._hide=function(t){this._lastDataByCoordSys=null,t({type:"hideTip",from:this.uid})},e.prototype.dispose=function(t,n){oe.node||!n.getDom()||(oh(this,"_updatePosition"),this._tooltipContent.dispose(),p1("itemTooltip",n))},e.type="tooltip",e}(Ze);function cc(r,e,t){var n=e.ecModel,a;t?(a=new De(t,n,n),a=new De(e.option,a,n)):a=e;for(var i=r.length-1;i>=0;i--){var o=r[i];o&&(o instanceof De&&(o=o.get("tooltip",!0)),Lt(o)&&(o={formatter:o}),o&&(a=new De(o,a,n)))}return a}function yD(r,e){return r.dispatchAction||Mt(e.dispatchAction,e)}function dnt(r,e,t,n,a,i,o){var s=t.getSize(),l=s[0],u=s[1];return i!=null&&(r+l+i+2>n?r-=l+i:r+=i),o!=null&&(e+u+o>a?e-=u+o:e+=o),[r,e]}function pnt(r,e,t,n,a){var i=t.getSize(),o=i[0],s=i[1];return r=Math.min(r+o,n)-o,e=Math.min(e+s,a)-s,r=Math.max(r,0),e=Math.max(e,0),[r,e]}function gnt(r,e,t,n){var a=t[0],i=t[1],o=Math.ceil(Math.SQRT2*n)+8,s=0,l=0,u=e.width,c=e.height;switch(r){case"inside":s=e.x+u/2-a/2,l=e.y+c/2-i/2;break;case"top":s=e.x+u/2-a/2,l=e.y-i-o;break;case"bottom":s=e.x+u/2-a/2,l=e.y+c+o;break;case"left":s=e.x-a-o,l=e.y+c/2-i/2;break;case"right":s=e.x+u+o,l=e.y+c/2-i/2}return[s,l]}function mD(r){return r==="center"||r==="middle"}function ynt(r,e,t){var n=j1(r).queryOptionMap,a=n.keys()[0];if(!(!a||a==="series")){var i=Ch(e,a,n.get(a),{useDefault:!1,enableAll:!1,enableNone:!1}),o=i.models[0];if(o){var s=t.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var c=Ht(u).tooltipConfig;if(c&&c.name===r.name)return l=u,!0}),l)return{componentMainType:a,componentIndex:o.componentIndex,el:l}}}}function mnt(r){ne(Zh),r.registerComponentModel(tnt),r.registerComponentView(vnt),r.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},tr),r.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},tr)}var _nt=["rect","polygon","keep","clear"];function wnt(r,e){var t=Ie(r?r.brush:[]);if(t.length){var n=[];B(t,function(l){var u=l.hasOwnProperty("toolbox")?l.toolbox:[];u instanceof Array&&(n=n.concat(u))});var a=r&&r.toolbox;ht(a)&&(a=a[0]),a||(a={feature:{}},r.toolbox=[a]);var i=a.feature||(a.feature={}),o=i.brush||(i.brush={}),s=o.type||(o.type=[]);s.push.apply(s,n),xnt(s),e&&!s.length&&s.push.apply(s,_nt)}}function xnt(r){var e={};B(r,function(t){e[t]=1}),r.length=0,B(e,function(t,n){r.push(n)})}var _D=B;function wD(r){if(r){for(var e in r)if(r.hasOwnProperty(e))return!0}}function x1(r,e,t){var n={};return _D(e,function(i){var o=n[i]=a();_D(r[i],function(s,l){if(mr.isValidType(l)){var u={type:l,visual:s};t&&t(u,i),o[l]=new mr(u),l==="opacity"&&(u=Gt(u),u.type="colorAlpha",o.__hidden.__alphaForOpacity=new mr(u))}})}),n;function a(){var i=function(){};i.prototype.__hidden=i.prototype;var o=new i;return o}}function YO(r,e,t){var n;B(t,function(a){e.hasOwnProperty(a)&&wD(e[a])&&(n=!0)}),n&&B(t,function(a){e.hasOwnProperty(a)&&wD(e[a])?r[a]=Gt(e[a]):delete r[a]})}function bnt(r,e,t,n,a,i){var o={};B(r,function(h){var d=mr.prepareVisualTypes(e[h]);o[h]=d});var s;function l(h){return Aw(t,s,h)}function u(h,d){vR(t,s,h,d)}t.each(c);function c(h,d){s=h;var v=t.getRawDataItem(s);if(!(v&&v.visualMap===!1))for(var p=n.call(a,h),y=e[p],_=o[p],g=0,f=_.length;g<f;g++){var w=_[g];y[w]&&y[w].applyVisual(h,l,u)}}}function Snt(r,e,t,n){var a={};return B(r,function(i){var o=mr.prepareVisualTypes(e[i]);a[i]=o}),{progress:function(o,s){var l;n!=null&&(l=s.getDimensionIndex(n));function u(S){return Aw(s,h,S)}function c(S,A){vR(s,h,S,A)}for(var h,d=s.getStore();(h=o.next())!=null;){var v=s.getRawDataItem(h);if(!(v&&v.visualMap===!1))for(var p=n!=null?d.get(l,h):h,y=t(p),_=e[y],g=a[y],f=0,w=g.length;f<w;f++){var x=g[f];_[x]&&_[x].applyVisual(p,u,c)}}}}}function Ant(r){var e=r.brushType,t={point:function(n){return xD[e].point(n,t,r)},rect:function(n){return xD[e].rect(n,t,r)}};return t}var xD={lineX:bD(0),lineY:bD(1),rect:{point:function(r,e,t){return r&&t.boundingRect.contain(r[0],r[1])},rect:function(r,e,t){return r&&t.boundingRect.intersect(r)}},polygon:{point:function(r,e,t){return r&&t.boundingRect.contain(r[0],r[1])&&ds(t.range,r[0],r[1])},rect:function(r,e,t){var n=t.range;if(!r||n.length<=1)return!1;var a=r.x,i=r.y,o=r.width,s=r.height,l=n[0];if(ds(n,a,i)||ds(n,a+o,i)||ds(n,a,i+s)||ds(n,a+o,i+s)||Qt.create(r).contain(l[0],l[1])||bc(a,i,a+o,i,n)||bc(a,i,a,i+s,n)||bc(a+o,i,a+o,i+s,n)||bc(a,i+s,a+o,i+s,n))return!0}}};function bD(r){var e=["x","y"],t=["width","height"];return{point:function(n,a,i){if(n){var o=i.range,s=n[r];return hc(s,o)}},rect:function(n,a,i){if(n){var o=i.range,s=[n[e[r]],n[e[r]]+n[t[r]]];return s[1]<s[0]&&s.reverse(),hc(s[0],o)||hc(s[1],o)||hc(o[0],s)||hc(o[1],s)}}}}function hc(r,e){return e[0]<=r&&r<=e[1]}var SD=["inBrush","outOfBrush"],w0="__ecBrushSelect",b1="__ecInBrushSelectEvent";function XO(r){r.eachComponent({mainType:"brush"},function(e){var t=e.brushTargetManager=new Ex(e.option,r);t.setInputRanges(e.areas,r)})}function Tnt(r,e,t){var n=[],a,i;r.eachComponent({mainType:"brush"},function(o){t&&t.type==="takeGlobalCursor"&&o.setBrushOption(t.key==="brush"?t.brushOption:{brushType:!1})}),XO(r),r.eachComponent({mainType:"brush"},function(o,s){var l={brushId:o.id,brushIndex:s,brushName:o.name,areas:Gt(o.areas),selected:[]};n.push(l);var u=o.option,c=u.brushLink,h=[],d=[],v=[],p=!1;s||(a=u.throttleType,i=u.throttleDelay);var y=ft(o.areas,function(S){var A=Dnt[S.brushType],T=zt({boundingRect:A?A(S):void 0},S);return T.selectors=Ant(T),T}),_=x1(o.option,SD,function(S){S.mappingMethod="fixed"});ht(c)&&B(c,function(S){h[S]=1});function g(S){return c==="all"||!!h[S]}function f(S){return!!S.length}r.eachSeries(function(S,A){var T=v[A]=[];S.subType==="parallel"?w(S,A):x(S,A,T)});function w(S,A){var T=S.coordinateSystem;p=p||T.hasAxisBrushed(),g(A)&&T.eachActiveState(S.getData(),function(L,M){L==="active"&&(d[M]=1)})}function x(S,A,T){if(!(!S.brushSelector||Mnt(o,A))&&(B(y,function(M){o.brushTargetManager.controlSeries(M,S,r)&&T.push(M),p=p||f(T)}),g(A)&&f(T))){var L=S.getData();L.each(function(M){AD(S,T,L,M)&&(d[M]=1)})}}r.eachSeries(function(S,A){var T={seriesId:S.id,seriesIndex:A,seriesName:S.name,dataIndex:[]};l.selected.push(T);var L=v[A],M=S.getData(),I=g(A)?function(R){return d[R]?(T.dataIndex.push(M.getRawIndex(R)),"inBrush"):"outOfBrush"}:function(R){return AD(S,L,M,R)?(T.dataIndex.push(M.getRawIndex(R)),"inBrush"):"outOfBrush"};(g(A)?p:f(L))&&bnt(SD,_,M,I)})}),Cnt(e,a,i,n,t)}function Cnt(r,e,t,n,a){if(a){var i=r.getZr();if(!i[b1]){i[w0]||(i[w0]=Lnt);var o=wu(i,w0,t,e);o(r,n)}}}function Lnt(r,e){if(!r.isDisposed()){var t=r.getZr();t[b1]=!0,r.dispatchAction({type:"brushSelect",batch:e}),t[b1]=!1}}function AD(r,e,t,n){for(var a=0,i=e.length;a<i;a++){var o=e[a];if(r.brushSelector(n,t,o.selectors,o))return!0}}function Mnt(r,e){var t=r.option.seriesIndex;return t!=null&&t!=="all"&&(ht(t)?te(t,e)<0:e!==t)}var Dnt={rect:function(r){return TD(r.range)},polygon:function(r){for(var e,t=r.range,n=0,a=t.length;n<a;n++){e=e||[[1/0,-1/0],[1/0,-1/0]];var i=t[n];i[0]<e[0][0]&&(e[0][0]=i[0]),i[0]>e[0][1]&&(e[0][1]=i[0]),i[1]<e[1][0]&&(e[1][0]=i[1]),i[1]>e[1][1]&&(e[1][1]=i[1])}return e&&TD(e)}};function TD(r){return new Qt(r[0][0],r[1][0],r[0][1]-r[0][0],r[1][1]-r[1][0])}var Int=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n){this.ecModel=t,this.api=n,this.model,(this._brushController=new ox(n.getZr())).on("brush",Mt(this._onBrush,this)).mount()},e.prototype.render=function(t,n,a,i){this.model=t,this._updateController(t,n,a,i)},e.prototype.updateTransform=function(t,n,a,i){XO(n),this._updateController(t,n,a,i)},e.prototype.updateVisual=function(t,n,a,i){this.updateTransform(t,n,a,i)},e.prototype.updateView=function(t,n,a,i){this._updateController(t,n,a,i)},e.prototype._updateController=function(t,n,a,i){(!i||i.$from!==t.id)&&this._brushController.setPanels(t.brushTargetManager.makePanelOpts(a)).enableBrush(t.brushOption).updateCovers(t.areas.slice())},e.prototype.dispose=function(){this._brushController.dispose()},e.prototype._onBrush=function(t){var n=this.model.id,a=this.model.brushTargetManager.setOutputRanges(t.areas,this.ecModel);(!t.isEnd||t.removeOnClick)&&this.api.dispatchAction({type:"brush",brushId:n,areas:Gt(a),$from:n}),t.isEnd&&this.api.dispatchAction({type:"brushEnd",brushId:n,areas:Gt(a),$from:n})},e.type="brush",e}(Ze),Pnt="#ddd",knt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.areas=[],t.brushOption={},t}return e.prototype.optionUpdated=function(t,n){var a=this.option;!n&&YO(a,t,["inBrush","outOfBrush"]);var i=a.inBrush=a.inBrush||{};a.outOfBrush=a.outOfBrush||{color:Pnt},i.hasOwnProperty("liftZ")||(i.liftZ=5)},e.prototype.setAreas=function(t){t&&(this.areas=ft(t,function(n){return CD(this.option,n)},this))},e.prototype.setBrushOption=function(t){this.brushOption=CD(this.option,t),this.brushType=this.brushOption.brushType},e.type="brush",e.dependencies=["geo","grid","xAxis","yAxis","parallel","series"],e.defaultOption={seriesIndex:"all",brushType:"rect",brushMode:"single",transformable:!0,brushStyle:{borderWidth:1,color:"rgba(210,219,238,0.3)",borderColor:"#D2DBEE"},throttleType:"fixRate",throttleDelay:0,removeOnClick:!0,z:1e4},e}(le);function CD(r,e){return qt({brushType:r.brushType,brushMode:r.brushMode,transformable:r.transformable,brushStyle:new De(r.brushStyle).getItemStyle(),removeOnClick:r.removeOnClick,z:r.z},e,!0)}var Rnt=["rect","polygon","lineX","lineY","keep","clear"],Ent=function(r){rt(e,r);function e(){return r!==null&&r.apply(this,arguments)||this}return e.prototype.render=function(t,n,a){var i,o,s;n.eachComponent({mainType:"brush"},function(l){i=l.brushType,o=l.brushOption.brushMode||"single",s=s||!!l.areas.length}),this._brushType=i,this._brushMode=o,B(t.get("type",!0),function(l){t.setIconStatus(l,(l==="keep"?o==="multiple":l==="clear"?s:l===i)?"emphasis":"normal")})},e.prototype.updateView=function(t,n,a){this.render(t,n,a)},e.prototype.getIcons=function(){var t=this.model,n=t.get("icon",!0),a={};return B(t.get("type",!0),function(i){n[i]&&(a[i]=n[i])}),a},e.prototype.onclick=function(t,n,a){var i=this._brushType,o=this._brushMode;a==="clear"?(n.dispatchAction({type:"axisAreaSelect",intervals:[]}),n.dispatchAction({type:"brush",command:"clear",areas:[]})):n.dispatchAction({type:"takeGlobalCursor",key:"brush",brushOption:{brushType:a==="keep"?i:i===a?!1:a,brushMode:a==="keep"?o==="multiple"?"single":"multiple":o}})},e.getDefaultOption=function(t){var n={show:!0,type:Rnt.slice(),icon:{rect:"M7.3,34.7 M0.4,10V-0.2h9.8 M89.6,10V-0.2h-9.8 M0.4,60v10.2h9.8 M89.6,60v10.2h-9.8 M12.3,22.4V10.5h13.1 M33.6,10.5h7.8 M49.1,10.5h7.8 M77.5,22.4V10.5h-13 M12.3,31.1v8.2 M77.7,31.1v8.2 M12.3,47.6v11.9h13.1 M33.6,59.5h7.6 M49.1,59.5 h7.7 M77.5,47.6v11.9h-13",polygon:"M55.2,34.9c1.7,0,3.1,1.4,3.1,3.1s-1.4,3.1-3.1,3.1 s-3.1-1.4-3.1-3.1S53.5,34.9,55.2,34.9z M50.4,51c1.7,0,3.1,1.4,3.1,3.1c0,1.7-1.4,3.1-3.1,3.1c-1.7,0-3.1-1.4-3.1-3.1 C47.3,52.4,48.7,51,50.4,51z M55.6,37.1l1.5-7.8 M60.1,13.5l1.6-8.7l-7.8,4 M59,19l-1,5.3 M24,16.1l6.4,4.9l6.4-3.3 M48.5,11.6 l-5.9,3.1 M19.1,12.8L9.7,5.1l1.1,7.7 M13.4,29.8l1,7.3l6.6,1.6 M11.6,18.4l1,6.1 M32.8,41.9 M26.6,40.4 M27.3,40.2l6.1,1.6 M49.9,52.1l-5.6-7.6l-4.9-1.2",lineX:"M15.2,30 M19.7,15.6V1.9H29 M34.8,1.9H40.4 M55.3,15.6V1.9H45.9 M19.7,44.4V58.1H29 M34.8,58.1H40.4 M55.3,44.4 V58.1H45.9 M12.5,20.3l-9.4,9.6l9.6,9.8 M3.1,29.9h16.5 M62.5,20.3l9.4,9.6L62.3,39.7 M71.9,29.9H55.4",lineY:"M38.8,7.7 M52.7,12h13.2v9 M65.9,26.6V32 M52.7,46.3h13.2v-9 M24.9,12H11.8v9 M11.8,26.6V32 M24.9,46.3H11.8v-9 M48.2,5.1l-9.3-9l-9.4,9.2 M38.9-3.9V12 M48.2,53.3l-9.3,9l-9.4-9.2 M38.9,62.3V46.4",keep:"M4,10.5V1h10.3 M20.7,1h6.1 M33,1h6.1 M55.4,10.5V1H45.2 M4,17.3v6.6 M55.6,17.3v6.6 M4,30.5V40h10.3 M20.7,40 h6.1 M33,40h6.1 M55.4,30.5V40H45.2 M21,18.9h62.9v48.6H21V18.9z",clear:"M22,14.7l30.9,31 M52.9,14.7L22,45.7 M4.7,16.8V4.2h13.1 M26,4.2h7.8 M41.6,4.2h7.8 M70.3,16.8V4.2H57.2 M4.7,25.9v8.6 M70.3,25.9v8.6 M4.7,43.2v12.6h13.1 M26,55.8h7.8 M41.6,55.8h7.8 M70.3,43.2v12.6H57.2"},title:t.getLocaleModel().get(["toolbox","brush","title"])};return n},e}(jn);function Ont(r){r.registerComponentView(Int),r.registerComponentModel(knt),r.registerPreprocessor(wnt),r.registerVisual(r.PRIORITY.VISUAL.BRUSH,Tnt),r.registerAction({type:"brush",event:"brush",update:"updateVisual"},function(e,t){t.eachComponent({mainType:"brush",query:e},function(n){n.setAreas(e.areas)})}),r.registerAction({type:"brushSelect",event:"brushSelected",update:"none"},tr),r.registerAction({type:"brushEnd",event:"brushEnd",update:"none"},tr),zl("brush",Ent)}var Bnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.layoutMode={type:"box",ignoreSize:!0},t}return e.type="title",e.defaultOption={z:6,show:!0,text:"",target:"blank",subtext:"",subtarget:"blank",left:0,top:0,backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderWidth:0,padding:5,itemGap:10,textStyle:{fontSize:18,fontWeight:"bold",color:"#464646"},subtextStyle:{fontSize:12,color:"#6E7079"}},e}(le),Nnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.render=function(t,n,a){if(this.group.removeAll(),!!t.get("show")){var i=this.group,o=t.getModel("textStyle"),s=t.getModel("subtextStyle"),l=t.get("textAlign"),u=Zt(t.get("textBaseline"),t.get("textVerticalAlign")),c=new pe({style:Fe(o,{text:t.get("text"),fill:o.getTextColor()},{disableBox:!0}),z2:10}),h=c.getBoundingRect(),d=t.get("subtext"),v=new pe({style:Fe(s,{text:d,fill:s.getTextColor(),y:h.height+t.get("itemGap"),verticalAlign:"top"},{disableBox:!0}),z2:10}),p=t.get("link"),y=t.get("sublink"),_=t.get("triggerEvent",!0);c.silent=!p&&!_,v.silent=!y&&!_,p&&c.on("click",function(){Dd(p,"_"+t.get("target"))}),y&&v.on("click",function(){Dd(y,"_"+t.get("subtarget"))}),Ht(c).eventData=Ht(v).eventData=_?{componentType:"title",componentIndex:t.componentIndex}:null,i.add(c),d&&i.add(v);var g=i.getBoundingRect(),f=t.getBoxLayoutParams();f.width=g.width,f.height=g.height;var w=cr(f,{width:a.getWidth(),height:a.getHeight()},t.get("padding"));l||(l=t.get("left")||t.get("right"),l==="middle"&&(l="center"),l==="right"?w.x+=w.width:l==="center"&&(w.x+=w.width/2)),u||(u=t.get("top")||t.get("bottom"),u==="center"&&(u="middle"),u==="bottom"?w.y+=w.height:u==="middle"&&(w.y+=w.height/2),u=u||"top"),i.x=w.x,i.y=w.y,i.markRedraw();var x={align:l,verticalAlign:u};c.setStyle(x),v.setStyle(x),g=i.getBoundingRect();var S=w.margin,A=t.getItemStyle(["color","opacity"]);A.fill=t.get("backgroundColor");var T=new fe({shape:{x:g.x-S[3],y:g.y-S[0],width:g.width+S[1]+S[3],height:g.height+S[0]+S[2],r:t.get("borderRadius")},style:A,subPixelOptimize:!0,silent:!0});i.add(T)}},e.type="title",e}(Ze);function znt(r){r.registerComponentModel(Bnt),r.registerComponentView(Nnt)}var LD=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.layoutMode="box",t}return e.prototype.init=function(t,n,a){this.mergeDefaultAndTheme(t,a),this._initData()},e.prototype.mergeOption=function(t){r.prototype.mergeOption.apply(this,arguments),this._initData()},e.prototype.setCurrentIndex=function(t){t==null&&(t=this.option.currentIndex);var n=this._data.count();this.option.loop?t=(t%n+n)%n:(t>=n&&(t=n-1),t<0&&(t=0)),this.option.currentIndex=t},e.prototype.getCurrentIndex=function(){return this.option.currentIndex},e.prototype.isIndexMax=function(){return this.getCurrentIndex()>=this._data.count()-1},e.prototype.setPlayState=function(t){this.option.autoPlay=!!t},e.prototype.getPlayState=function(){return!!this.option.autoPlay},e.prototype._initData=function(){var t=this.option,n=t.data||[],a=t.axisType,i=this._names=[],o;a==="category"?(o=[],B(n,function(u,c){var h=ur(hu(u),""),d;Vt(u)?(d=Gt(u),d.value=c):d=c,o.push(d),i.push(h)})):o=n;var s={category:"ordinal",time:"time",value:"number"}[a]||"number",l=this._data=new Kr([{name:"value",type:s}],this);l.initData(o,i)},e.prototype.getData=function(){return this._data},e.prototype.getCategories=function(){if(this.get("axisType")==="category")return this._names.slice()},e.type="timeline",e.defaultOption={z:4,show:!0,axisType:"time",realtime:!0,left:"20%",top:null,right:"20%",bottom:0,width:null,height:40,padding:5,controlPosition:"left",autoPlay:!1,rewind:!1,loop:!0,playInterval:2e3,currentIndex:0,itemStyle:{},label:{color:"#000"},data:[]},e}(le),$O=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="timeline.slider",e.defaultOption=Lo(LD.defaultOption,{backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderWidth:0,orient:"horizontal",inverse:!1,tooltip:{trigger:"item"},symbol:"circle",symbolSize:12,lineStyle:{show:!0,width:2,color:"#DAE1F5"},label:{position:"auto",show:!0,interval:"auto",rotate:0,color:"#A4B1D7"},itemStyle:{color:"#A4B1D7",borderWidth:1},checkpointStyle:{symbol:"circle",symbolSize:15,color:"#316bf3",borderColor:"#fff",borderWidth:2,shadowBlur:2,shadowOffsetX:1,shadowOffsetY:1,shadowColor:"rgba(0, 0, 0, 0.3)",animation:!0,animationDuration:300,animationEasing:"quinticInOut"},controlStyle:{show:!0,showPlayBtn:!0,showPrevBtn:!0,showNextBtn:!0,itemSize:24,itemGap:12,position:"left",playIcon:"path://M31.6,53C17.5,53,6,41.5,6,27.4S17.5,1.8,31.6,1.8C45.7,1.8,57.2,13.3,57.2,27.4S45.7,53,31.6,53z M31.6,3.3 C18.4,3.3,7.5,14.1,7.5,27.4c0,13.3,10.8,24.1,24.1,24.1C44.9,51.5,55.7,40.7,55.7,27.4C55.7,14.1,44.9,3.3,31.6,3.3z M24.9,21.3 c0-2.2,1.6-3.1,3.5-2l10.5,6.1c1.899,1.1,1.899,2.9,0,4l-10.5,6.1c-1.9,1.1-3.5,0.2-3.5-2V21.3z",stopIcon:"path://M30.9,53.2C16.8,53.2,5.3,41.7,5.3,27.6S16.8,2,30.9,2C45,2,56.4,13.5,56.4,27.6S45,53.2,30.9,53.2z M30.9,3.5C17.6,3.5,6.8,14.4,6.8,27.6c0,13.3,10.8,24.1,24.101,24.1C44.2,51.7,55,40.9,55,27.6C54.9,14.4,44.1,3.5,30.9,3.5z M36.9,35.8c0,0.601-0.4,1-0.9,1h-1.3c-0.5,0-0.9-0.399-0.9-1V19.5c0-0.6,0.4-1,0.9-1H36c0.5,0,0.9,0.4,0.9,1V35.8z M27.8,35.8 c0,0.601-0.4,1-0.9,1h-1.3c-0.5,0-0.9-0.399-0.9-1V19.5c0-0.6,0.4-1,0.9-1H27c0.5,0,0.9,0.4,0.9,1L27.8,35.8L27.8,35.8z",nextIcon:"M2,18.5A1.52,1.52,0,0,1,.92,18a1.49,1.49,0,0,1,0-2.12L7.81,9.36,1,3.11A1.5,1.5,0,1,1,3,.89l8,7.34a1.48,1.48,0,0,1,.49,1.09,1.51,1.51,0,0,1-.46,1.1L3,18.08A1.5,1.5,0,0,1,2,18.5Z",prevIcon:"M10,.5A1.52,1.52,0,0,1,11.08,1a1.49,1.49,0,0,1,0,2.12L4.19,9.64,11,15.89a1.5,1.5,0,1,1-2,2.22L1,10.77A1.48,1.48,0,0,1,.5,9.68,1.51,1.51,0,0,1,1,8.58L9,.92A1.5,1.5,0,0,1,10,.5Z",prevBtnSize:18,nextBtnSize:18,color:"#A4B1D7",borderColor:"#A4B1D7",borderWidth:1},emphasis:{label:{show:!0,color:"#6f778d"},itemStyle:{color:"#316BF3"},controlStyle:{color:"#316BF3",borderColor:"#316BF3",borderWidth:2}},progress:{lineStyle:{color:"#316BF3"},itemStyle:{color:"#316BF3"},label:{color:"#6f778d"}},data:[]}),e}(LD);sr($O,Op.prototype);var Fnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="timeline",e}(Ze),Vnt=function(r){rt(e,r);function e(t,n,a,i){var o=r.call(this,t,n,a)||this;return o.type=i||"value",o}return e.prototype.getLabelModel=function(){return this.model.getModel("label")},e.prototype.isHorizontal=function(){return this.model.get("orient")==="horizontal"},e}(Sa),x0=Math.PI,MD=ve(),Gnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(t,n){this.api=n},e.prototype.render=function(t,n,a){if(this.model=t,this.api=a,this.ecModel=n,this.group.removeAll(),t.get("show",!0)){var i=this._layout(t,a),o=this._createGroup("_mainGroup"),s=this._createGroup("_labelGroup"),l=this._axis=this._createAxis(i,t);t.formatTooltip=function(u){var c=l.scale.getLabel({value:u});return wr("nameValue",{noName:!0,value:c})},B(["AxisLine","AxisTick","Control","CurrentPointer"],function(u){this["_render"+u](i,o,l,t)},this),this._renderAxisLabel(i,s,l,t),this._position(i,t)}this._doPlayStop(),this._updateTicksStatus()},e.prototype.remove=function(){this._clearTimer(),this.group.removeAll()},e.prototype.dispose=function(){this._clearTimer()},e.prototype._layout=function(t,n){var a=t.get(["label","position"]),i=t.get("orient"),o=Hnt(t,n),s;a==null||a==="auto"?s=i==="horizontal"?o.y+o.height/2<n.getHeight()/2?"-":"+":o.x+o.width/2<n.getWidth()/2?"+":"-":Lt(a)?s={horizontal:{top:"-",bottom:"+"},vertical:{left:"-",right:"+"}}[i][a]:s=a;var l={horizontal:"center",vertical:s>=0||s==="+"?"left":"right"},u={horizontal:s>=0||s==="+"?"top":"bottom",vertical:"middle"},c={horizontal:0,vertical:x0/2},h=i==="vertical"?o.height:o.width,d=t.getModel("controlStyle"),v=d.get("show",!0),p=v?d.get("itemSize"):0,y=v?d.get("itemGap"):0,_=p+y,g=t.get(["label","rotate"])||0;g=g*x0/180;var f,w,x,S=d.get("position",!0),A=v&&d.get("showPlayBtn",!0),T=v&&d.get("showPrevBtn",!0),L=v&&d.get("showNextBtn",!0),M=0,I=h;S==="left"||S==="bottom"?(A&&(f=[0,0],M+=_),T&&(w=[M,0],M+=_),L&&(x=[I-p,0],I-=_)):(A&&(f=[I-p,0],I-=_),T&&(w=[0,0],M+=_),L&&(x=[I-p,0],I-=_));var R=[M,I];return t.get("inverse")&&R.reverse(),{viewRect:o,mainLength:h,orient:i,rotation:c[i],labelRotation:g,labelPosOpt:s,labelAlign:t.get(["label","align"])||l[i],labelBaseline:t.get(["label","verticalAlign"])||t.get(["label","baseline"])||u[i],playPosition:f,prevBtnPosition:w,nextBtnPosition:x,axisExtent:R,controlSize:p,controlGap:y}},e.prototype._position=function(t,n){var a=this._mainGroup,i=this._labelGroup,o=t.viewRect;if(t.orient==="vertical"){var s=Ln(),l=o.x,u=o.y+o.height;Ya(s,s,[-l,-u]),Hs(s,s,-x0/2),Ya(s,s,[l,u]),o=o.clone(),o.applyTransform(s)}var c=f(o),h=f(a.getBoundingRect()),d=f(i.getBoundingRect()),v=[a.x,a.y],p=[i.x,i.y];p[0]=v[0]=c[0][0];var y=t.labelPosOpt;if(y==null||Lt(y)){var _=y==="+"?0:1;w(v,h,c,1,_),w(p,d,c,1,1-_)}else{var _=y>=0?0:1;w(v,h,c,1,_),p[1]=v[1]+y}a.setPosition(v),i.setPosition(p),a.rotation=i.rotation=t.rotation,g(a),g(i);function g(x){x.originX=c[0][0]-x.x,x.originY=c[1][0]-x.y}function f(x){return[[x.x,x.x+x.width],[x.y,x.y+x.height]]}function w(x,S,A,T,L){x[T]+=A[T][L]-S[T][L]}},e.prototype._createAxis=function(t,n){var a=n.getData(),i=n.get("axisType"),o=Wnt(n,i);o.getTicks=function(){return a.mapArray(["value"],function(u){return{value:u}})};var s=a.getDataExtent("value");o.setExtent(s[0],s[1]),o.calcNiceTicks();var l=new Vnt("value",o,t.axisExtent,i);return l.model=n,l},e.prototype._createGroup=function(t){var n=this[t]=new Wt;return this.group.add(n),n},e.prototype._renderAxisLine=function(t,n,a,i){var o=a.getExtent();if(i.get(["lineStyle","show"])){var s=new gr({shape:{x1:o[0],y1:0,x2:o[1],y2:0},style:lt({lineCap:"round"},i.getModel("lineStyle").getLineStyle()),silent:!0,z2:1});n.add(s);var l=this._progressLine=new gr({shape:{x1:o[0],x2:this._currentPointer?this._currentPointer.x:o[0],y1:0,y2:0},style:zt({lineCap:"round",lineWidth:s.style.lineWidth},i.getModel(["progress","lineStyle"]).getLineStyle()),silent:!0,z2:1});n.add(l)}},e.prototype._renderAxisTick=function(t,n,a,i){var o=this,s=i.getData(),l=a.scale.getTicks();this._tickSymbols=[],B(l,function(u){var c=a.dataToCoord(u.value),h=s.getItemModel(u.value),d=h.getModel("itemStyle"),v=h.getModel(["emphasis","itemStyle"]),p=h.getModel(["progress","itemStyle"]),y={x:c,y:0,onclick:Mt(o._changeTimeline,o,u.value)},_=DD(h,d,n,y);_.ensureState("emphasis").style=v.getItemStyle(),_.ensureState("progress").style=p.getItemStyle(),Is(_);var g=Ht(_);h.get("tooltip")?(g.dataIndex=u.value,g.dataModel=i):g.dataIndex=g.dataModel=null,o._tickSymbols.push(_)})},e.prototype._renderAxisLabel=function(t,n,a,i){var o=this,s=a.getLabelModel();if(s.get("show")){var l=i.getData(),u=a.getViewLabels();this._tickLabels=[],B(u,function(c){var h=c.tickValue,d=l.getItemModel(h),v=d.getModel("label"),p=d.getModel(["emphasis","label"]),y=d.getModel(["progress","label"]),_=a.dataToCoord(c.tickValue),g=new pe({x:_,y:0,rotation:t.labelRotation-t.rotation,onclick:Mt(o._changeTimeline,o,h),silent:!1,style:Fe(v,{text:c.formattedLabel,align:t.labelAlign,verticalAlign:t.labelBaseline})});g.ensureState("emphasis").style=Fe(p),g.ensureState("progress").style=Fe(y),n.add(g),Is(g),MD(g).dataIndex=h,o._tickLabels.push(g)})}},e.prototype._renderControl=function(t,n,a,i){var o=t.controlSize,s=t.rotation,l=i.getModel("controlStyle").getItemStyle(),u=i.getModel(["emphasis","controlStyle"]).getItemStyle(),c=i.getPlayState(),h=i.get("inverse",!0);d(t.nextBtnPosition,"next",Mt(this._changeTimeline,this,h?"-":"+")),d(t.prevBtnPosition,"prev",Mt(this._changeTimeline,this,h?"+":"-")),d(t.playPosition,c?"stop":"play",Mt(this._handlePlayClick,this,!c),!0);function d(v,p,y,_){if(v){var g=wa(Zt(i.get(["controlStyle",p+"BtnSize"]),o),o),f=[0,-g/2,g,g],w=Unt(i,p+"Icon",f,{x:v[0],y:v[1],originX:o/2,originY:0,rotation:_?-s:0,rectHover:!0,style:l,onclick:y});w.ensureState("emphasis").style=u,n.add(w),Is(w)}}},e.prototype._renderCurrentPointer=function(t,n,a,i){var o=i.getData(),s=i.getCurrentIndex(),l=o.getItemModel(s).getModel("checkpointStyle"),u=this,c={onCreate:function(h){h.draggable=!0,h.drift=Mt(u._handlePointerDrag,u),h.ondragend=Mt(u._handlePointerDragend,u),ID(h,u._progressLine,s,a,i,!0)},onUpdate:function(h){ID(h,u._progressLine,s,a,i)}};this._currentPointer=DD(l,l,this._mainGroup,{},this._currentPointer,c)},e.prototype._handlePlayClick=function(t){this._clearTimer(),this.api.dispatchAction({type:"timelinePlayChange",playState:t,from:this.uid})},e.prototype._handlePointerDrag=function(t,n,a){this._clearTimer(),this._pointerChangeTimeline([a.offsetX,a.offsetY])},e.prototype._handlePointerDragend=function(t){this._pointerChangeTimeline([t.offsetX,t.offsetY],!0)},e.prototype._pointerChangeTimeline=function(t,n){var a=this._toAxisCoord(t)[0],i=this._axis,o=Qn(i.getExtent().slice());a>o[1]&&(a=o[1]),a<o[0]&&(a=o[0]),this._currentPointer.x=a,this._currentPointer.markRedraw();var s=this._progressLine;s&&(s.shape.x2=a,s.dirty());var l=this._findNearestTick(a),u=this.model;(n||l!==u.getCurrentIndex()&&u.get("realtime"))&&this._changeTimeline(l)},e.prototype._doPlayStop=function(){var t=this;this._clearTimer(),this.model.getPlayState()&&(this._timer=setTimeout(function(){var n=t.model;t._changeTimeline(n.getCurrentIndex()+(n.get("rewind",!0)?-1:1))},this.model.get("playInterval")))},e.prototype._toAxisCoord=function(t){var n=this._mainGroup.getLocalTransform();return _a(t,n,!0)},e.prototype._findNearestTick=function(t){var n=this.model.getData(),a=1/0,i,o=this._axis;return n.each(["value"],function(s,l){var u=o.dataToCoord(s),c=Math.abs(u-t);c<a&&(a=c,i=l)}),i},e.prototype._clearTimer=function(){this._timer&&(clearTimeout(this._timer),this._timer=null)},e.prototype._changeTimeline=function(t){var n=this.model.getCurrentIndex();t==="+"?t=n+1:t==="-"&&(t=n-1),this.api.dispatchAction({type:"timelineChange",currentIndex:t,from:this.uid})},e.prototype._updateTicksStatus=function(){var t=this.model.getCurrentIndex(),n=this._tickSymbols,a=this._tickLabels;if(n)for(var i=0;i<n.length;i++)n&&n[i]&&n[i].toggleState("progress",i<t);if(a)for(var i=0;i<a.length;i++)a&&a[i]&&a[i].toggleState("progress",MD(a[i]).dataIndex<=t)},e.type="timeline.slider",e}(Fnt);function Wnt(r,e){if(e=e||r.get("type"),e)switch(e){case"category":return new Gp({ordinalMeta:r.getCategories(),extent:[1/0,-1/0]});case"time":return new kw({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new Mi}}function Hnt(r,e){return cr(r.getBoxLayoutParams(),{width:e.getWidth(),height:e.getHeight()},r.get("padding"))}function Unt(r,e,t,n){var a=n.style,i=kh(r.get(["controlStyle",e]),n||{},new Qt(t[0],t[1],t[2],t[3]));return a&&i.setStyle(a),i}function DD(r,e,t,n,a,i){var o=e.get("color");if(a)a.setColor(o),t.add(a),i&&i.onUpdate(a);else{var s=r.get("symbol");a=or(s,-1,-1,2,2,o),a.setStyle("strokeNoScale",!0),t.add(a),i&&i.onCreate(a)}var l=e.getItemStyle(["color"]);a.setStyle(l),n=qt({rectHover:!0,z2:100},n,!0);var u=xu(r.get("symbolSize"));n.scaleX=u[0]/2,n.scaleY=u[1]/2;var c=Ys(r.get("symbolOffset"),u);c&&(n.x=(n.x||0)+c[0],n.y=(n.y||0)+c[1]);var h=r.get("symbolRotate");return n.rotation=(h||0)*Math.PI/180||0,a.attr(n),a.updateTransform(),a}function ID(r,e,t,n,a,i){if(!r.dragging){var o=a.getModel("checkpointStyle"),s=n.dataToCoord(a.getData().get("value",t));if(i||!o.get("animation",!0))r.attr({x:s,y:0}),e&&e.attr({shape:{x2:s}});else{var l={duration:o.get("animationDuration",!0),easing:o.get("animationEasing",!0)};r.stopAnimation(null,!0),r.animateTo({x:s,y:0},l),e&&e.animateTo({shape:{x2:s}},l)}}}function Znt(r){r.registerAction({type:"timelineChange",event:"timelineChanged",update:"prepareAndUpdate"},function(e,t,n){var a=t.getComponent("timeline");return a&&e.currentIndex!=null&&(a.setCurrentIndex(e.currentIndex),!a.get("loop",!0)&&a.isIndexMax()&&a.getPlayState()&&(a.setPlayState(!1),n.dispatchAction({type:"timelinePlayChange",playState:!1,from:e.from}))),t.resetOption("timeline",{replaceMerge:a.get("replaceMerge",!0)}),zt({currentIndex:a.option.currentIndex},e)}),r.registerAction({type:"timelinePlayChange",event:"timelinePlayChanged",update:"update"},function(e,t){var n=t.getComponent("timeline");n&&e.playState!=null&&n.setPlayState(e.playState)})}function Ynt(r){var e=r&&r.timeline;ht(e)||(e=e?[e]:[]),B(e,function(t){t&&Xnt(t)})}function Xnt(r){var e=r.type,t={number:"value",time:"time"};if(t[e]&&(r.axisType=t[e],delete r.type),PD(r),ys(r,"controlPosition")){var n=r.controlStyle||(r.controlStyle={});ys(n,"position")||(n.position=r.controlPosition),n.position==="none"&&!ys(n,"show")&&(n.show=!1,delete n.position),delete r.controlPosition}B(r.data||[],function(a){Vt(a)&&!ht(a)&&(!ys(a,"value")&&ys(a,"name")&&(a.value=a.name),PD(a))})}function PD(r){var e=r.itemStyle||(r.itemStyle={}),t=e.emphasis||(e.emphasis={}),n=r.label||r.label||{},a=n.normal||(n.normal={}),i={normal:1,emphasis:1};B(n,function(o,s){!i[s]&&!ys(a,s)&&(a[s]=o)}),t.label&&!ys(n,"emphasis")&&(n.emphasis=t.label,delete t.label)}function ys(r,e){return r.hasOwnProperty(e)}function $nt(r){r.registerComponentModel($O),r.registerComponentView(Gnt),r.registerSubTypeDefaulter("timeline",function(){return"slider"}),Znt(r),r.registerPreprocessor(Ynt)}function Nx(r,e){if(!r)return!1;for(var t=ht(r)?r:[r],n=0;n<t.length;n++)if(t[n]&&t[n][e])return!0;return!1}function Nv(r){Os(r,"label",["show"])}var zv=ve(),Ii=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.createdBySelf=!1,t}return e.prototype.init=function(t,n,a){this.mergeDefaultAndTheme(t,a),this._mergeOption(t,a,!1,!0)},e.prototype.isAnimationEnabled=function(){if(oe.node)return!1;var t=this.__hostSeries;return this.getShallow("animation")&&t&&t.isAnimationEnabled()},e.prototype.mergeOption=function(t,n){this._mergeOption(t,n,!1,!1)},e.prototype._mergeOption=function(t,n,a,i){var o=this.mainType;a||n.eachSeries(function(s){var l=s.get(this.mainType,!0),u=zv(s)[o];if(!l||!l.data){zv(s)[o]=null;return}u?u._mergeOption(l,n,!0):(i&&Nv(l),B(l.data,function(c){c instanceof Array?(Nv(c[0]),Nv(c[1])):Nv(c)}),u=this.createMarkerModelFromSeries(l,this,n),lt(u,{mainType:this.mainType,seriesIndex:s.seriesIndex,name:s.name,createdBySelf:!0}),u.__hostSeries=s),zv(s)[o]=u},this)},e.prototype.formatTooltip=function(t,n,a){var i=this.getData(),o=this.getRawValue(t),s=i.getName(t);return wr("section",{header:this.name,blocks:[wr("nameValue",{name:s,value:o,noName:!s,noValue:o==null})]})},e.prototype.getData=function(){return this._data},e.prototype.setData=function(t){this._data=t},e.prototype.getDataParams=function(t,n){var a=Op.prototype.getDataParams.call(this,t,n),i=this.__hostSeries;return i&&(a.seriesId=i.id,a.seriesName=i.name,a.seriesType=i.subType),a},e.getMarkerModelFromSeries=function(t,n){return zv(t)[n]},e.type="marker",e.dependencies=["series","grid","polar","geo"],e}(le);sr(Ii,Op.prototype);var jnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.createMarkerModelFromSeries=function(t,n,a){return new e(t,n,a)},e.type="markPoint",e.defaultOption={z:5,symbol:"pin",symbolSize:50,tooltip:{trigger:"item"},label:{show:!0,position:"inside"},itemStyle:{borderWidth:2},emphasis:{label:{show:!0}}},e}(Ii);function S1(r){return!(isNaN(parseFloat(r.x))&&isNaN(parseFloat(r.y)))}function qnt(r){return!isNaN(parseFloat(r.x))&&!isNaN(parseFloat(r.y))}function Fv(r,e,t,n,a,i){var o=[],s=So(e,n),l=s?e.getCalculationInfo("stackResultDimension"):n,u=zx(e,l,r),c=e.indicesOfNearest(l,u)[0];o[a]=e.get(t,c),o[i]=e.get(l,c);var h=e.get(n,c),d=Fa(e.get(n,c));return d=Math.min(d,20),d>=0&&(o[i]=+o[i].toFixed(d)),[o,h]}var b0={min:Xt(Fv,"min"),max:Xt(Fv,"max"),average:Xt(Fv,"average"),median:Xt(Fv,"median")};function wh(r,e){if(e){var t=r.getData(),n=r.coordinateSystem,a=n&&n.dimensions;if(!qnt(e)&&!ht(e.coord)&&ht(a)){var i=jO(e,t,n,r);if(e=Gt(e),e.type&&b0[e.type]&&i.baseAxis&&i.valueAxis){var o=te(a,i.baseAxis.dim),s=te(a,i.valueAxis.dim),l=b0[e.type](t,i.baseDataDim,i.valueDataDim,o,s);e.coord=l[0],e.value=l[1]}else e.coord=[e.xAxis!=null?e.xAxis:e.radiusAxis,e.yAxis!=null?e.yAxis:e.angleAxis]}if(e.coord==null||!ht(a))e.coord=[];else for(var u=e.coord,c=0;c<2;c++)b0[u[c]]&&(u[c]=zx(t,t.mapDimension(a[c]),u[c]));return e}}function jO(r,e,t,n){var a={};return r.valueIndex!=null||r.valueDim!=null?(a.valueDataDim=r.valueIndex!=null?e.getDimension(r.valueIndex):r.valueDim,a.valueAxis=t.getAxis(Knt(n,a.valueDataDim)),a.baseAxis=t.getOtherAxis(a.valueAxis),a.baseDataDim=e.mapDimension(a.baseAxis.dim)):(a.baseAxis=n.getBaseAxis(),a.valueAxis=t.getOtherAxis(a.baseAxis),a.baseDataDim=e.mapDimension(a.baseAxis.dim),a.valueDataDim=e.mapDimension(a.valueAxis.dim)),a}function Knt(r,e){var t=r.getData().getDimensionInfo(e);return t&&t.coordDim}function xh(r,e){return r&&r.containData&&e.coord&&!S1(e)?r.containData(e.coord):!0}function Qnt(r,e,t){return r&&r.containZone&&e.coord&&t.coord&&!S1(e)&&!S1(t)?r.containZone(e.coord,t.coord):!0}function qO(r,e){return r?function(t,n,a,i){var o=i<2?t.coord&&t.coord[i]:t.value;return go(o,e[i])}:function(t,n,a,i){return go(t.value,e[i])}}function zx(r,e,t){if(t==="average"){var n=0,a=0;return r.each(e,function(i,o){isNaN(i)||(n+=i,a++)}),n/a}else return t==="median"?r.getMedian(e):r.getDataExtent(e)[t==="max"?1:0]}var S0=ve(),Fx=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.init=function(){this.markerGroupMap=Pt()},e.prototype.render=function(t,n,a){var i=this,o=this.markerGroupMap;o.each(function(s){S0(s).keep=!1}),n.eachSeries(function(s){var l=Ii.getMarkerModelFromSeries(s,i.type);l&&i.renderSeries(s,l,n,a)}),o.each(function(s){!S0(s).keep&&i.group.remove(s.group)})},e.prototype.markKeep=function(t){S0(t).keep=!0},e.prototype.toggleBlurSeries=function(t,n){var a=this;B(t,function(i){var o=Ii.getMarkerModelFromSeries(i,a.type);if(o){var s=o.getData();s.eachItemGraphicEl(function(l){l&&(n?GP(l):rw(l))})}})},e.type="marker",e}(Ze);function kD(r,e,t){var n=e.coordinateSystem;r.each(function(a){var i=r.getItemModel(a),o,s=At(i.get("x"),t.getWidth()),l=At(i.get("y"),t.getHeight());if(!isNaN(s)&&!isNaN(l))o=[s,l];else if(e.getMarkerPosition)o=e.getMarkerPosition(r.getValues(r.dimensions,a));else if(n){var u=r.get(n.dimensions[0],a),c=r.get(n.dimensions[1],a);o=n.dataToPoint([u,c])}isNaN(s)||(o[0]=s),isNaN(l)||(o[1]=l),r.setItemLayout(a,o)})}var Jnt=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.updateTransform=function(t,n,a){n.eachSeries(function(i){var o=Ii.getMarkerModelFromSeries(i,"markPoint");o&&(kD(o.getData(),i,a),this.markerGroupMap.get(i.id).updateLayout())},this)},e.prototype.renderSeries=function(t,n,a,i){var o=t.coordinateSystem,s=t.id,l=t.getData(),u=this.markerGroupMap,c=u.get(s)||u.set(s,new zh),h=tat(o,t,n);n.setData(h),kD(n.getData(),t,i),h.each(function(d){var v=h.getItemModel(d),p=v.getShallow("symbol"),y=v.getShallow("symbolSize"),_=v.getShallow("symbolRotate"),g=v.getShallow("symbolOffset"),f=v.getShallow("symbolKeepAspect");if(Nt(p)||Nt(y)||Nt(_)||Nt(g)){var w=n.getRawValue(d),x=n.getDataParams(d);Nt(p)&&(p=p(w,x)),Nt(y)&&(y=y(w,x)),Nt(_)&&(_=_(w,x)),Nt(g)&&(g=g(w,x))}var S=v.getModel("itemStyle").getItemStyle(),A=Eh(l,"color");S.fill||(S.fill=A),h.setItemVisual(d,{symbol:p,symbolSize:y,symbolRotate:_,symbolOffset:g,symbolKeepAspect:f,style:S})}),c.updateData(h),this.group.add(c.group),h.eachItemGraphicEl(function(d){d.traverse(function(v){Ht(v).dataModel=n})}),this.markKeep(c),c.group.silent=n.get("silent")||t.get("silent")},e.type="markPoint",e}(Fx);function tat(r,e,t){var n;r?n=ft(r&&r.dimensions,function(s){var l=e.getData().getDimensionInfo(e.getData().mapDimension(s))||{};return lt(lt({},l),{name:s,ordinalMeta:null})}):n=[{name:"value",type:"float"}];var a=new Kr(n,t),i=ft(t.get("data"),Xt(wh,e));r&&(i=Te(i,Xt(xh,r)));var o=qO(!!r,n);return a.initData(i,null,o),a}function eat(r){r.registerComponentModel(jnt),r.registerComponentView(Jnt),r.registerPreprocessor(function(e){Nx(e.series,"markPoint")&&(e.markPoint=e.markPoint||{})})}var rat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.createMarkerModelFromSeries=function(t,n,a){return new e(t,n,a)},e.type="markLine",e.defaultOption={z:5,symbol:["circle","arrow"],symbolSize:[8,16],symbolOffset:0,precision:2,tooltip:{trigger:"item"},label:{show:!0,position:"end",distance:5},lineStyle:{type:"dashed"},emphasis:{label:{show:!0},lineStyle:{width:3}},animationEasing:"linear"},e}(Ii),Vv=ve(),nat=function(r,e,t,n){var a=r.getData(),i;if(ht(n))i=n;else{var o=n.type;if(o==="min"||o==="max"||o==="average"||o==="median"||n.xAxis!=null||n.yAxis!=null){var s=void 0,l=void 0;if(n.yAxis!=null||n.xAxis!=null)s=e.getAxis(n.yAxis!=null?"y":"x"),l=Ar(n.yAxis,n.xAxis);else{var u=jO(n,a,e,r);s=u.valueAxis;var c=WR(a,u.valueDataDim);l=zx(a,c,o)}var h=s.dim==="x"?0:1,d=1-h,v=Gt(n),p={coord:[]};v.type=null,v.coord=[],v.coord[d]=-1/0,p.coord[d]=1/0;var y=t.get("precision");y>=0&&ye(l)&&(l=+l.toFixed(Math.min(y,20))),v.coord[h]=p.coord[h]=l,i=[v,p,{type:o,valueIndex:n.valueIndex,value:l}]}else i=[]}var _=[wh(r,i[0]),wh(r,i[1]),lt({},i[2])];return _[2].type=_[2].type||null,qt(_[2],_[0]),qt(_[2],_[1]),_};function tp(r){return!isNaN(r)&&!isFinite(r)}function RD(r,e,t,n){var a=1-r,i=n.dimensions[r];return tp(e[a])&&tp(t[a])&&e[r]===t[r]&&n.getAxis(i).containData(e[r])}function aat(r,e){if(r.type==="cartesian2d"){var t=e[0].coord,n=e[1].coord;if(t&&n&&(RD(1,t,n,r)||RD(0,t,n,r)))return!0}return xh(r,e[0])&&xh(r,e[1])}function A0(r,e,t,n,a){var i=n.coordinateSystem,o=r.getItemModel(e),s,l=At(o.get("x"),a.getWidth()),u=At(o.get("y"),a.getHeight());if(!isNaN(l)&&!isNaN(u))s=[l,u];else{if(n.getMarkerPosition)s=n.getMarkerPosition(r.getValues(r.dimensions,e));else{var c=i.dimensions,h=r.get(c[0],e),d=r.get(c[1],e);s=i.dataToPoint([h,d])}if($s(i,"cartesian2d")){var v=i.getAxis("x"),p=i.getAxis("y"),c=i.dimensions;tp(r.get(c[0],e))?s[0]=v.toGlobalCoord(v.getExtent()[t?0:1]):tp(r.get(c[1],e))&&(s[1]=p.toGlobalCoord(p.getExtent()[t?0:1]))}isNaN(l)||(s[0]=l),isNaN(u)||(s[1]=u)}r.setItemLayout(e,s)}var iat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.updateTransform=function(t,n,a){n.eachSeries(function(i){var o=Ii.getMarkerModelFromSeries(i,"markLine");if(o){var s=o.getData(),l=Vv(o).from,u=Vv(o).to;l.each(function(c){A0(l,c,!0,i,a),A0(u,c,!1,i,a)}),s.each(function(c){s.setItemLayout(c,[l.getItemLayout(c),u.getItemLayout(c)])}),this.markerGroupMap.get(i.id).updateLayout()}},this)},e.prototype.renderSeries=function(t,n,a,i){var o=t.coordinateSystem,s=t.id,l=t.getData(),u=this.markerGroupMap,c=u.get(s)||u.set(s,new ix);this.group.add(c.group);var h=oat(o,t,n),d=h.from,v=h.to,p=h.line;Vv(n).from=d,Vv(n).to=v,n.setData(p);var y=n.get("symbol"),_=n.get("symbolSize"),g=n.get("symbolRotate"),f=n.get("symbolOffset");ht(y)||(y=[y,y]),ht(_)||(_=[_,_]),ht(g)||(g=[g,g]),ht(f)||(f=[f,f]),h.from.each(function(x){w(d,x,!0),w(v,x,!1)}),p.each(function(x){var S=p.getItemModel(x).getModel("lineStyle").getLineStyle();p.setItemLayout(x,[d.getItemLayout(x),v.getItemLayout(x)]),S.stroke==null&&(S.stroke=d.getItemVisual(x,"style").fill),p.setItemVisual(x,{fromSymbolKeepAspect:d.getItemVisual(x,"symbolKeepAspect"),fromSymbolOffset:d.getItemVisual(x,"symbolOffset"),fromSymbolRotate:d.getItemVisual(x,"symbolRotate"),fromSymbolSize:d.getItemVisual(x,"symbolSize"),fromSymbol:d.getItemVisual(x,"symbol"),toSymbolKeepAspect:v.getItemVisual(x,"symbolKeepAspect"),toSymbolOffset:v.getItemVisual(x,"symbolOffset"),toSymbolRotate:v.getItemVisual(x,"symbolRotate"),toSymbolSize:v.getItemVisual(x,"symbolSize"),toSymbol:v.getItemVisual(x,"symbol"),style:S})}),c.updateData(p),h.line.eachItemGraphicEl(function(x){Ht(x).dataModel=n,x.traverse(function(S){Ht(S).dataModel=n})});function w(x,S,A){var T=x.getItemModel(S);A0(x,S,A,t,i);var L=T.getModel("itemStyle").getItemStyle();L.fill==null&&(L.fill=Eh(l,"color")),x.setItemVisual(S,{symbolKeepAspect:T.get("symbolKeepAspect"),symbolOffset:Zt(T.get("symbolOffset",!0),f[A?0:1]),symbolRotate:Zt(T.get("symbolRotate",!0),g[A?0:1]),symbolSize:Zt(T.get("symbolSize"),_[A?0:1]),symbol:Zt(T.get("symbol",!0),y[A?0:1]),style:L})}this.markKeep(c),c.group.silent=n.get("silent")||t.get("silent")},e.type="markLine",e}(Fx);function oat(r,e,t){var n;r?n=ft(r&&r.dimensions,function(u){var c=e.getData().getDimensionInfo(e.getData().mapDimension(u))||{};return lt(lt({},c),{name:u,ordinalMeta:null})}):n=[{name:"value",type:"float"}];var a=new Kr(n,t),i=new Kr(n,t),o=new Kr([],t),s=ft(t.get("data"),Xt(nat,e,r,t));r&&(s=Te(s,Xt(aat,r)));var l=qO(!!r,n);return a.initData(ft(s,function(u){return u[0]}),null,l),i.initData(ft(s,function(u){return u[1]}),null,l),o.initData(ft(s,function(u){return u[2]})),o.hasItemOption=!0,{from:a,to:i,line:o}}function sat(r){r.registerComponentModel(rat),r.registerComponentView(iat),r.registerPreprocessor(function(e){Nx(e.series,"markLine")&&(e.markLine=e.markLine||{})})}var lat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.createMarkerModelFromSeries=function(t,n,a){return new e(t,n,a)},e.type="markArea",e.defaultOption={z:1,tooltip:{trigger:"item"},animation:!1,label:{show:!0,position:"top"},itemStyle:{borderWidth:0},emphasis:{label:{show:!0,position:"top"}}},e}(Ii),Gv=ve(),uat=function(r,e,t,n){var a=n[0],i=n[1];if(!(!a||!i)){var o=wh(r,a),s=wh(r,i),l=o.coord,u=s.coord;l[0]=Ar(l[0],-1/0),l[1]=Ar(l[1],-1/0),u[0]=Ar(u[0],1/0),u[1]=Ar(u[1],1/0);var c=z1([{},o,s]);return c.coord=[o.coord,s.coord],c.x0=o.x,c.y0=o.y,c.x1=s.x,c.y1=s.y,c}};function ep(r){return!isNaN(r)&&!isFinite(r)}function ED(r,e,t,n){var a=1-r;return ep(e[a])&&ep(t[a])}function cat(r,e){var t=e.coord[0],n=e.coord[1],a={coord:t,x:e.x0,y:e.y0},i={coord:n,x:e.x1,y:e.y1};return $s(r,"cartesian2d")?t&&n&&(ED(1,t,n)||ED(0,t,n))?!0:Qnt(r,a,i):xh(r,a)||xh(r,i)}function OD(r,e,t,n,a){var i=n.coordinateSystem,o=r.getItemModel(e),s,l=At(o.get(t[0]),a.getWidth()),u=At(o.get(t[1]),a.getHeight());if(!isNaN(l)&&!isNaN(u))s=[l,u];else{if(n.getMarkerPosition){var c=r.getValues(["x0","y0"],e),h=r.getValues(["x1","y1"],e),d=i.clampData(c),v=i.clampData(h),p=[];t[0]==="x0"?p[0]=d[0]>v[0]?h[0]:c[0]:p[0]=d[0]>v[0]?c[0]:h[0],t[1]==="y0"?p[1]=d[1]>v[1]?h[1]:c[1]:p[1]=d[1]>v[1]?c[1]:h[1],s=n.getMarkerPosition(p,t,!0)}else{var y=r.get(t[0],e),_=r.get(t[1],e),g=[y,_];i.clampData&&i.clampData(g,g),s=i.dataToPoint(g,!0)}if($s(i,"cartesian2d")){var f=i.getAxis("x"),w=i.getAxis("y"),y=r.get(t[0],e),_=r.get(t[1],e);ep(y)?s[0]=f.toGlobalCoord(f.getExtent()[t[0]==="x0"?0:1]):ep(_)&&(s[1]=w.toGlobalCoord(w.getExtent()[t[1]==="y0"?0:1]))}isNaN(l)||(s[0]=l),isNaN(u)||(s[1]=u)}return s}var BD=[["x0","y0"],["x1","y0"],["x1","y1"],["x0","y1"]],hat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.updateTransform=function(t,n,a){n.eachSeries(function(i){var o=Ii.getMarkerModelFromSeries(i,"markArea");if(o){var s=o.getData();s.each(function(l){var u=ft(BD,function(h){return OD(s,l,h,i,a)});s.setItemLayout(l,u);var c=s.getItemGraphicEl(l);c.setShape("points",u)})}},this)},e.prototype.renderSeries=function(t,n,a,i){var o=t.coordinateSystem,s=t.id,l=t.getData(),u=this.markerGroupMap,c=u.get(s)||u.set(s,{group:new Wt});this.group.add(c.group),this.markKeep(c);var h=fat(o,t,n);n.setData(h),h.each(function(d){var v=ft(BD,function(L){return OD(h,d,L,t,i)}),p=o.getAxis("x").scale,y=o.getAxis("y").scale,_=p.getExtent(),g=y.getExtent(),f=[p.parse(h.get("x0",d)),p.parse(h.get("x1",d))],w=[y.parse(h.get("y0",d)),y.parse(h.get("y1",d))];Qn(f),Qn(w);var x=!(_[0]>f[1]||_[1]<f[0]||g[0]>w[1]||g[1]<w[0]),S=!x;h.setItemLayout(d,{points:v,allClipped:S});var A=h.getItemModel(d).getModel("itemStyle").getItemStyle(),T=Eh(l,"color");A.fill||(A.fill=T,Lt(A.fill)&&(A.fill=yd(A.fill,.4))),A.stroke||(A.stroke=T),h.setItemVisual(d,"style",A)}),h.diff(Gv(c).data).add(function(d){var v=h.getItemLayout(d);if(!v.allClipped){var p=new rn({shape:{points:v.points}});h.setItemGraphicEl(d,p),c.group.add(p)}}).update(function(d,v){var p=Gv(c).data.getItemGraphicEl(v),y=h.getItemLayout(d);y.allClipped?p&&c.group.remove(p):(p?_e(p,{shape:{points:y.points}},n,d):p=new rn({shape:{points:y.points}}),h.setItemGraphicEl(d,p),c.group.add(p))}).remove(function(d){var v=Gv(c).data.getItemGraphicEl(d);c.group.remove(v)}).execute(),h.eachItemGraphicEl(function(d,v){var p=h.getItemModel(v),y=h.getItemVisual(v,"style");d.useStyle(h.getItemVisual(v,"style")),Rr(d,_r(p),{labelFetcher:n,labelDataIndex:v,defaultText:h.getName(v)||"",inheritColor:Lt(y.fill)?yd(y.fill,1):"#000"}),kr(d,p),Xe(d,null,null,p.get(["emphasis","disabled"])),Ht(d).dataModel=n}),Gv(c).data=h,c.group.silent=n.get("silent")||t.get("silent")},e.type="markArea",e}(Fx);function fat(r,e,t){var n,a,i=["x0","y0","x1","y1"];if(r){var o=ft(r&&r.dimensions,function(u){var c=e.getData(),h=c.getDimensionInfo(c.mapDimension(u))||{};return lt(lt({},h),{name:u,ordinalMeta:null})});a=ft(i,function(u,c){return{name:u,type:o[c%2].type}}),n=new Kr(a,t)}else a=[{name:"value",type:"float"}],n=new Kr(a,t);var s=ft(t.get("data"),Xt(uat,e,r,t));r&&(s=Te(s,Xt(cat,r)));var l=r?function(u,c,h,d){var v=u.coord[Math.floor(d/2)][d%2];return go(v,a[d])}:function(u,c,h,d){return go(u.value,a[d])};return n.initData(s,null,l),n.hasItemOption=!0,n}function vat(r){r.registerComponentModel(lat),r.registerComponentView(hat),r.registerPreprocessor(function(e){Nx(e.series,"markArea")&&(e.markArea=e.markArea||{})})}var dat=function(r,e){if(e==="all")return{type:"all",title:r.getLocaleModel().get(["legend","selector","all"])};if(e==="inverse")return{type:"inverse",title:r.getLocaleModel().get(["legend","selector","inverse"])}},A1=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.layoutMode={type:"box",ignoreSize:!0},t}return e.prototype.init=function(t,n,a){this.mergeDefaultAndTheme(t,a),t.selected=t.selected||{},this._updateSelector(t)},e.prototype.mergeOption=function(t,n){r.prototype.mergeOption.call(this,t,n),this._updateSelector(t)},e.prototype._updateSelector=function(t){var n=t.selector,a=this.ecModel;n===!0&&(n=t.selector=["all","inverse"]),ht(n)&&B(n,function(i,o){Lt(i)&&(i={type:i}),n[o]=qt(i,dat(a,i.type))})},e.prototype.optionUpdated=function(){this._updateData(this.ecModel);var t=this._data;if(t[0]&&this.get("selectedMode")==="single"){for(var n=!1,a=0;a<t.length;a++){var i=t[a].get("name");if(this.isSelected(i)){this.select(i),n=!0;break}}!n&&this.select(t[0].get("name"))}},e.prototype._updateData=function(t){var n=[],a=[];t.eachRawSeries(function(l){var u=l.name;a.push(u);var c;if(l.legendVisualProvider){var h=l.legendVisualProvider,d=h.getAllNames();t.isSeriesFiltered(l)||(a=a.concat(d)),d.length?n=n.concat(d):c=!0}else c=!0;c&&$1(l)&&n.push(l.name)}),this._availableNames=a;var i=this.get("data")||n,o=Pt(),s=ft(i,function(l){return(Lt(l)||ye(l))&&(l={name:l}),o.get(l.name)?null:(o.set(l.name,!0),new De(l,this,this.ecModel))},this);this._data=Te(s,function(l){return!!l})},e.prototype.getData=function(){return this._data},e.prototype.select=function(t){var n=this.option.selected,a=this.get("selectedMode");if(a==="single"){var i=this._data;B(i,function(o){n[o.get("name")]=!1})}n[t]=!0},e.prototype.unSelect=function(t){this.get("selectedMode")!=="single"&&(this.option.selected[t]=!1)},e.prototype.toggleSelected=function(t){var n=this.option.selected;n.hasOwnProperty(t)||(n[t]=!0),this[n[t]?"unSelect":"select"](t)},e.prototype.allSelect=function(){var t=this._data,n=this.option.selected;B(t,function(a){n[a.get("name",!0)]=!0})},e.prototype.inverseSelect=function(){var t=this._data,n=this.option.selected;B(t,function(a){var i=a.get("name",!0);n.hasOwnProperty(i)||(n[i]=!0),n[i]=!n[i]})},e.prototype.isSelected=function(t){var n=this.option.selected;return!(n.hasOwnProperty(t)&&!n[t])&&te(this._availableNames,t)>=0},e.prototype.getOrient=function(){return this.get("orient")==="vertical"?{index:1,name:"vertical"}:{index:0,name:"horizontal"}},e.type="legend.plain",e.dependencies=["series"],e.defaultOption={z:4,show:!0,orient:"horizontal",left:"center",top:0,align:"auto",backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemGap:10,itemWidth:25,itemHeight:14,symbolRotate:"inherit",symbolKeepAspect:!0,inactiveColor:"#ccc",inactiveBorderColor:"#ccc",inactiveBorderWidth:"auto",itemStyle:{color:"inherit",opacity:"inherit",borderColor:"inherit",borderWidth:"auto",borderCap:"inherit",borderJoin:"inherit",borderDashOffset:"inherit",borderMiterLimit:"inherit"},lineStyle:{width:"auto",color:"inherit",inactiveColor:"#ccc",inactiveWidth:2,opacity:"inherit",type:"inherit",cap:"inherit",join:"inherit",dashOffset:"inherit",miterLimit:"inherit"},textStyle:{color:"#333"},selectedMode:!0,selector:!1,selectorLabel:{show:!0,borderRadius:10,padding:[3,5,3,5],fontSize:12,fontFamily:"sans-serif",color:"#666",borderWidth:1,borderColor:"#666"},emphasis:{selectorLabel:{show:!0,color:"#eee",backgroundColor:"#666"}},selectorPosition:"auto",selectorItemGap:7,selectorButtonGap:10,tooltip:{show:!1}},e}(le),Il=Xt,T1=B,Wv=Wt,KO=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.newlineDisabled=!1,t}return e.prototype.init=function(){this.group.add(this._contentGroup=new Wv),this.group.add(this._selectorGroup=new Wv),this._isFirstRender=!0},e.prototype.getContentGroup=function(){return this._contentGroup},e.prototype.getSelectorGroup=function(){return this._selectorGroup},e.prototype.render=function(t,n,a){var i=this._isFirstRender;if(this._isFirstRender=!1,this.resetInner(),!!t.get("show",!0)){var o=t.get("align"),s=t.get("orient");(!o||o==="auto")&&(o=t.get("left")==="right"&&s==="vertical"?"right":"left");var l=t.get("selector",!0),u=t.get("selectorPosition",!0);l&&(!u||u==="auto")&&(u=s==="horizontal"?"end":"start"),this.renderInner(o,t,n,a,l,s,u);var c=t.getBoxLayoutParams(),h={width:a.getWidth(),height:a.getHeight()},d=t.get("padding"),v=cr(c,h,d),p=this.layoutInner(t,o,v,i,l,u),y=cr(zt({width:p.width,height:p.height},c),h,d);this.group.x=y.x-p.x,this.group.y=y.y-p.y,this.group.markRedraw(),this.group.add(this._backgroundEl=FO(p,t))}},e.prototype.resetInner=function(){this.getContentGroup().removeAll(),this._backgroundEl&&this.group.remove(this._backgroundEl),this.getSelectorGroup().removeAll()},e.prototype.renderInner=function(t,n,a,i,o,s,l){var u=this.getContentGroup(),c=Pt(),h=n.get("selectedMode"),d=[];a.eachRawSeries(function(v){!v.get("legendHoverLink")&&d.push(v.id)}),T1(n.getData(),function(v,p){var y=v.get("name");if(!this.newlineDisabled&&(y===""||y===`
`)){var _=new Wv;_.newline=!0,u.add(_);return}var g=a.getSeriesByName(y)[0];if(!c.get(y))if(g){var f=g.getData(),w=f.getVisual("legendLineStyle")||{},x=f.getVisual("legendIcon"),S=f.getVisual("style"),A=this._createItem(g,y,p,v,n,t,w,S,x,h,i);A.on("click",Il(ND,y,null,i,d)).on("mouseover",Il(C1,g.name,null,i,d)).on("mouseout",Il(L1,g.name,null,i,d)),a.ssr&&A.eachChild(function(T){var L=Ht(T);L.seriesIndex=g.seriesIndex,L.dataIndex=p,L.ssrType="legend"}),c.set(y,!0)}else a.eachRawSeries(function(T){if(!c.get(y)&&T.legendVisualProvider){var L=T.legendVisualProvider;if(!L.containName(y))return;var M=L.indexOfName(y),I=L.getItemVisual(M,"style"),R=L.getItemVisual(M,"legendIcon"),P=Mn(I.fill);P&&P[3]===0&&(P[3]=.2,I=lt(lt({},I),{fill:wi(P,"rgba")}));var E=this._createItem(T,y,p,v,n,t,{},I,R,h,i);E.on("click",Il(ND,null,y,i,d)).on("mouseover",Il(C1,null,y,i,d)).on("mouseout",Il(L1,null,y,i,d)),a.ssr&&E.eachChild(function(D){var N=Ht(D);N.seriesIndex=T.seriesIndex,N.dataIndex=p,N.ssrType="legend"}),c.set(y,!0)}},this)},this),o&&this._createSelector(o,n,i,s,l)},e.prototype._createSelector=function(t,n,a,i,o){var s=this.getSelectorGroup();T1(t,function(u){var c=u.type,h=new pe({style:{x:0,y:0,align:"center",verticalAlign:"middle"},onclick:function(){a.dispatchAction({type:c==="all"?"legendAllSelect":"legendInverseSelect",legendId:n.id})}});s.add(h);var d=n.getModel("selectorLabel"),v=n.getModel(["emphasis","selectorLabel"]);Rr(h,{normal:d,emphasis:v},{defaultText:u.title}),Is(h)})},e.prototype._createItem=function(t,n,a,i,o,s,l,u,c,h,d){var v=t.visualDrawType,p=o.get("itemWidth"),y=o.get("itemHeight"),_=o.isSelected(n),g=i.get("symbolRotate"),f=i.get("symbolKeepAspect"),w=i.get("icon");c=w||c||"roundRect";var x=pat(c,i,l,u,v,_,d),S=new Wv,A=i.getModel("textStyle");if(Nt(t.getLegendIcon)&&(!w||w==="inherit"))S.add(t.getLegendIcon({itemWidth:p,itemHeight:y,icon:c,iconRotate:g,itemStyle:x.itemStyle,lineStyle:x.lineStyle,symbolKeepAspect:f}));else{var T=w==="inherit"&&t.getData().getVisual("symbol")?g==="inherit"?t.getData().getVisual("symbolRotate"):g:0;S.add(gat({itemWidth:p,itemHeight:y,icon:c,iconRotate:T,itemStyle:x.itemStyle,symbolKeepAspect:f}))}var L=s==="left"?p+5:-5,M=s,I=o.get("formatter"),R=n;Lt(I)&&I?R=I.replace("{name}",n??""):Nt(I)&&(R=I(n));var P=_?A.getTextColor():i.get("inactiveColor");S.add(new pe({style:Fe(A,{text:R,x:L,y:y/2,fill:P,align:M,verticalAlign:"middle"},{inheritColor:P})}));var E=new fe({shape:S.getBoundingRect(),style:{fill:"transparent"}}),D=i.getModel("tooltip");return D.get("show")&&Us({el:E,componentModel:o,itemName:n,itemTooltipOption:D.option}),S.add(E),S.eachChild(function(N){N.silent=!0}),E.silent=!h,this.getContentGroup().add(S),Is(S),S.__legendDataIndex=a,S},e.prototype.layoutInner=function(t,n,a,i,o,s){var l=this.getContentGroup(),u=this.getSelectorGroup();ks(t.get("orient"),l,t.get("itemGap"),a.width,a.height);var c=l.getBoundingRect(),h=[-c.x,-c.y];if(u.markRedraw(),l.markRedraw(),o){ks("horizontal",u,t.get("selectorItemGap",!0));var d=u.getBoundingRect(),v=[-d.x,-d.y],p=t.get("selectorButtonGap",!0),y=t.getOrient().index,_=y===0?"width":"height",g=y===0?"height":"width",f=y===0?"y":"x";s==="end"?v[y]+=c[_]+p:h[y]+=d[_]+p,v[1-y]+=c[g]/2-d[g]/2,u.x=v[0],u.y=v[1],l.x=h[0],l.y=h[1];var w={x:0,y:0};return w[_]=c[_]+p+d[_],w[g]=Math.max(c[g],d[g]),w[f]=Math.min(0,d[f]+v[1-y]),w}else return l.x=h[0],l.y=h[1],this.group.getBoundingRect()},e.prototype.remove=function(){this.getContentGroup().removeAll(),this._isFirstRender=!0},e.type="legend.plain",e}(Ze);function pat(r,e,t,n,a,i,o){function s(_,g){_.lineWidth==="auto"&&(_.lineWidth=g.lineWidth>0?2:0),T1(_,function(f,w){_[w]==="inherit"&&(_[w]=g[w])})}var l=e.getModel("itemStyle"),u=l.getItemStyle(),c=r.lastIndexOf("empty",0)===0?"fill":"stroke",h=l.getShallow("decal");u.decal=!h||h==="inherit"?n.decal:eu(h,o),u.fill==="inherit"&&(u.fill=n[a]),u.stroke==="inherit"&&(u.stroke=n[c]),u.opacity==="inherit"&&(u.opacity=(a==="fill"?n:t).opacity),s(u,n);var d=e.getModel("lineStyle"),v=d.getLineStyle();if(s(v,t),u.fill==="auto"&&(u.fill=n.fill),u.stroke==="auto"&&(u.stroke=n.fill),v.stroke==="auto"&&(v.stroke=n.fill),!i){var p=e.get("inactiveBorderWidth"),y=u[c];u.lineWidth=p==="auto"?n.lineWidth>0&&y?2:0:u.lineWidth,u.fill=e.get("inactiveColor"),u.stroke=e.get("inactiveBorderColor"),v.stroke=d.get("inactiveColor"),v.lineWidth=d.get("inactiveWidth")}return{itemStyle:u,lineStyle:v}}function gat(r){var e=r.icon||"roundRect",t=or(e,0,0,r.itemWidth,r.itemHeight,r.itemStyle.fill,r.symbolKeepAspect);return t.setStyle(r.itemStyle),t.rotation=(r.iconRotate||0)*Math.PI/180,t.setOrigin([r.itemWidth/2,r.itemHeight/2]),e.indexOf("empty")>-1&&(t.style.stroke=t.style.fill,t.style.fill="#fff",t.style.lineWidth=2),t}function ND(r,e,t,n){L1(r,e,t,n),t.dispatchAction({type:"legendToggleSelect",name:r??e}),C1(r,e,t,n)}function QO(r){for(var e=r.getZr().storage.getDisplayList(),t,n=0,a=e.length;n<a&&!(t=e[n].states.emphasis);)n++;return t&&t.hoverLayer}function C1(r,e,t,n){QO(t)||t.dispatchAction({type:"highlight",seriesName:r,name:e,excludeSeriesId:n})}function L1(r,e,t,n){QO(t)||t.dispatchAction({type:"downplay",seriesName:r,name:e,excludeSeriesId:n})}function yat(r){var e=r.findComponents({mainType:"legend"});e&&e.length&&r.filterSeries(function(t){for(var n=0;n<e.length;n++)if(!e[n].isSelected(t.name))return!1;return!0})}function fc(r,e,t){var n=r==="allSelect"||r==="inverseSelect",a={},i=[];t.eachComponent({mainType:"legend",query:e},function(s){n?s[r]():s[r](e.name),zD(s,a),i.push(s.componentIndex)});var o={};return t.eachComponent("legend",function(s){B(a,function(l,u){s[l?"select":"unSelect"](u)}),zD(s,o)}),n?{selected:o,legendIndex:i}:{name:e.name,selected:o}}function zD(r,e){var t=e||{};return B(r.getData(),function(n){var a=n.get("name");if(!(a===`
`||a==="")){var i=r.isSelected(a);It(t,a)?t[a]=t[a]&&i:t[a]=i}}),t}function mat(r){r.registerAction("legendToggleSelect","legendselectchanged",Xt(fc,"toggleSelected")),r.registerAction("legendAllSelect","legendselectall",Xt(fc,"allSelect")),r.registerAction("legendInverseSelect","legendinverseselect",Xt(fc,"inverseSelect")),r.registerAction("legendSelect","legendselected",Xt(fc,"select")),r.registerAction("legendUnSelect","legendunselected",Xt(fc,"unSelect"))}function JO(r){r.registerComponentModel(A1),r.registerComponentView(KO),r.registerProcessor(r.PRIORITY.PROCESSOR.SERIES_FILTER,yat),r.registerSubTypeDefaulter("legend",function(){return"plain"}),mat(r)}var _at=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.setScrollDataIndex=function(t){this.option.scrollDataIndex=t},e.prototype.init=function(t,n,a){var i=yu(t);r.prototype.init.call(this,t,n,a),FD(this,t,i)},e.prototype.mergeOption=function(t,n){r.prototype.mergeOption.call(this,t,n),FD(this,this.option,t)},e.type="legend.scroll",e.defaultOption=Lo(A1.defaultOption,{scrollDataIndex:0,pageButtonItemGap:5,pageButtonGap:null,pageButtonPosition:"end",pageFormatter:"{current}/{total}",pageIcons:{horizontal:["M0,0L12,-10L12,10z","M0,0L-12,-10L-12,10z"],vertical:["M0,0L20,0L10,-20z","M0,0L20,0L10,20z"]},pageIconColor:"#2f4554",pageIconInactiveColor:"#aaa",pageIconSize:15,pageTextStyle:{color:"#333"},animationDurationUpdate:800}),e}(A1);function FD(r,e,t){var n=r.getOrient(),a=[1,1];a[n.index]=0,bo(e,t,{type:"box",ignoreSize:!!a})}var VD=Wt,T0=["width","height"],C0=["x","y"],wat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.newlineDisabled=!0,t._currentIndex=0,t}return e.prototype.init=function(){r.prototype.init.call(this),this.group.add(this._containerGroup=new VD),this._containerGroup.add(this.getContentGroup()),this.group.add(this._controllerGroup=new VD)},e.prototype.resetInner=function(){r.prototype.resetInner.call(this),this._controllerGroup.removeAll(),this._containerGroup.removeClipPath(),this._containerGroup.__rectSize=null},e.prototype.renderInner=function(t,n,a,i,o,s,l){var u=this;r.prototype.renderInner.call(this,t,n,a,i,o,s,l);var c=this._controllerGroup,h=n.get("pageIconSize",!0),d=ht(h)?h:[h,h];p("pagePrev",0);var v=n.getModel("pageTextStyle");c.add(new pe({name:"pageText",style:{text:"xx/xx",fill:v.getTextColor(),font:v.getFont(),verticalAlign:"middle",align:"center"},silent:!0})),p("pageNext",1);function p(y,_){var g=y+"DataIndex",f=kh(n.get("pageIcons",!0)[n.getOrient().name][_],{onclick:Mt(u._pageGo,u,g,n,i)},{x:-d[0]/2,y:-d[1]/2,width:d[0],height:d[1]});f.name=y,c.add(f)}},e.prototype.layoutInner=function(t,n,a,i,o,s){var l=this.getSelectorGroup(),u=t.getOrient().index,c=T0[u],h=C0[u],d=T0[1-u],v=C0[1-u];o&&ks("horizontal",l,t.get("selectorItemGap",!0));var p=t.get("selectorButtonGap",!0),y=l.getBoundingRect(),_=[-y.x,-y.y],g=Gt(a);o&&(g[c]=a[c]-y[c]-p);var f=this._layoutContentAndController(t,i,g,u,c,d,v,h);if(o){if(s==="end")_[u]+=f[c]+p;else{var w=y[c]+p;_[u]-=w,f[h]-=w}f[c]+=y[c]+p,_[1-u]+=f[v]+f[d]/2-y[d]/2,f[d]=Math.max(f[d],y[d]),f[v]=Math.min(f[v],y[v]+_[1-u]),l.x=_[0],l.y=_[1],l.markRedraw()}return f},e.prototype._layoutContentAndController=function(t,n,a,i,o,s,l,u){var c=this.getContentGroup(),h=this._containerGroup,d=this._controllerGroup;ks(t.get("orient"),c,t.get("itemGap"),i?a.width:null,i?null:a.height),ks("horizontal",d,t.get("pageButtonItemGap",!0));var v=c.getBoundingRect(),p=d.getBoundingRect(),y=this._showController=v[o]>a[o],_=[-v.x,-v.y];n||(_[i]=c[u]);var g=[0,0],f=[-p.x,-p.y],w=Zt(t.get("pageButtonGap",!0),t.get("itemGap",!0));if(y){var x=t.get("pageButtonPosition",!0);x==="end"?f[i]+=a[o]-p[o]:g[i]+=p[o]+w}f[1-i]+=v[s]/2-p[s]/2,c.setPosition(_),h.setPosition(g),d.setPosition(f);var S={x:0,y:0};if(S[o]=y?a[o]:v[o],S[s]=Math.max(v[s],p[s]),S[l]=Math.min(0,p[l]+f[1-i]),h.__rectSize=a[o],y){var A={x:0,y:0};A[o]=Math.max(a[o]-p[o]-w,0),A[s]=S[s],h.setClipPath(new fe({shape:A})),h.__rectSize=A[o]}else d.eachChild(function(L){L.attr({invisible:!0,silent:!0})});var T=this._getPageInfo(t);return T.pageIndex!=null&&_e(c,{x:T.contentPosition[0],y:T.contentPosition[1]},y?t:null),this._updatePageInfoView(t,T),S},e.prototype._pageGo=function(t,n,a){var i=this._getPageInfo(n)[t];i!=null&&a.dispatchAction({type:"legendScroll",scrollDataIndex:i,legendId:n.id})},e.prototype._updatePageInfoView=function(t,n){var a=this._controllerGroup;B(["pagePrev","pageNext"],function(c){var h=c+"DataIndex",d=n[h]!=null,v=a.childOfName(c);v&&(v.setStyle("fill",d?t.get("pageIconColor",!0):t.get("pageIconInactiveColor",!0)),v.cursor=d?"pointer":"default")});var i=a.childOfName("pageText"),o=t.get("pageFormatter"),s=n.pageIndex,l=s!=null?s+1:0,u=n.pageCount;i&&o&&i.setStyle("text",Lt(o)?o.replace("{current}",l==null?"":l+"").replace("{total}",u==null?"":u+""):o({current:l,total:u}))},e.prototype._getPageInfo=function(t){var n=t.get("scrollDataIndex",!0),a=this.getContentGroup(),i=this._containerGroup.__rectSize,o=t.getOrient().index,s=T0[o],l=C0[o],u=this._findTargetItemIndex(n),c=a.children(),h=c[u],d=c.length,v=d?1:0,p={contentPosition:[a.x,a.y],pageCount:v,pageIndex:v-1,pagePrevDataIndex:null,pageNextDataIndex:null};if(!h)return p;var y=x(h);p.contentPosition[o]=-y.s;for(var _=u+1,g=y,f=y,w=null;_<=d;++_)w=x(c[_]),(!w&&f.e>g.s+i||w&&!S(w,g.s))&&(f.i>g.i?g=f:g=w,g&&(p.pageNextDataIndex==null&&(p.pageNextDataIndex=g.i),++p.pageCount)),f=w;for(var _=u-1,g=y,f=y,w=null;_>=-1;--_)w=x(c[_]),(!w||!S(f,w.s))&&g.i<f.i&&(f=g,p.pagePrevDataIndex==null&&(p.pagePrevDataIndex=g.i),++p.pageCount,++p.pageIndex),g=w;return p;function x(A){if(A){var T=A.getBoundingRect(),L=T[l]+A[l];return{s:L,e:L+T[s],i:A.__legendDataIndex}}}function S(A,T){return A.e>=T&&A.s<=T+i}},e.prototype._findTargetItemIndex=function(t){if(!this._showController)return 0;var n,a=this.getContentGroup(),i;return a.eachChild(function(o,s){var l=o.__legendDataIndex;i==null&&l!=null&&(i=s),l===t&&(n=s)}),n??i},e.type="legend.scroll",e}(KO);function xat(r){r.registerAction("legendScroll","legendscroll",function(e,t){var n=e.scrollDataIndex;n!=null&&t.eachComponent({mainType:"legend",subType:"scroll",query:e},function(a){a.setScrollDataIndex(n)})})}function bat(r){ne(JO),r.registerComponentModel(_at),r.registerComponentView(wat),xat(r)}function Sat(r){ne(JO),ne(bat)}var Aat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.inside",e.defaultOption=Lo(_h.defaultOption,{disabled:!1,zoomLock:!1,zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),e}(_h),Vx=ve();function Tat(r,e,t){Vx(r).coordSysRecordMap.each(function(n){var a=n.dataZoomInfoMap.get(e.uid);a&&(a.getRange=t)})}function Cat(r,e){for(var t=Vx(r).coordSysRecordMap,n=t.keys(),a=0;a<n.length;a++){var i=n[a],o=t.get(i),s=o.dataZoomInfoMap;if(s){var l=e.uid,u=s.get(l);u&&(s.removeKey(l),s.keys().length||tB(t,o))}}}function tB(r,e){if(e){r.removeKey(e.model.uid);var t=e.controller;t&&t.dispose()}}function Lat(r,e){var t={model:e,containsPoint:Xt(Dat,e),dispatchAction:Xt(Mat,r),dataZoomInfoMap:null,controller:null},n=t.controller=new Hh(r.getZr());return B(["pan","zoom","scrollMove"],function(a){n.on(a,function(i){var o=[];t.dataZoomInfoMap.each(function(s){if(i.isAvailableBehavior(s.model.option)){var l=(s.getRange||{})[a],u=l&&l(s.dzReferCoordSysInfo,t.model.mainType,t.controller,i);!s.model.get("disabled",!0)&&u&&o.push({dataZoomId:s.model.id,start:u[0],end:u[1]})}}),o.length&&t.dispatchAction(o)})}),t}function Mat(r,e){r.isDisposed()||r.dispatchAction({type:"dataZoom",animation:{easing:"cubicOut",duration:100},batch:e})}function Dat(r,e,t,n){return r.coordinateSystem.containPoint([t,n])}function Iat(r){var e,t="type_",n={type_true:2,type_move:1,type_false:0,type_undefined:-1},a=!0;return r.each(function(i){var o=i.model,s=o.get("disabled",!0)?!1:o.get("zoomLock",!0)?"move":!0;n[t+s]>n[t+e]&&(e=s),a=a&&o.get("preventDefaultMouseMove",!0)}),{controlType:e,opt:{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!0,preventDefaultMouseMove:!!a}}}function Pat(r){r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,function(e,t){var n=Vx(t),a=n.coordSysRecordMap||(n.coordSysRecordMap=Pt());a.each(function(i){i.dataZoomInfoMap=null}),e.eachComponent({mainType:"dataZoom",subType:"inside"},function(i){var o=BO(i);B(o.infoList,function(s){var l=s.model.uid,u=a.get(l)||a.set(l,Lat(t,s.model)),c=u.dataZoomInfoMap||(u.dataZoomInfoMap=Pt());c.set(i.uid,{dzReferCoordSysInfo:s,model:i,getRange:null})})}),a.each(function(i){var o=i.controller,s,l=i.dataZoomInfoMap;if(l){var u=l.keys()[0];u!=null&&(s=l.get(u))}if(!s){tB(a,i);return}var c=Iat(l);o.enable(c.controlType,c.opt),o.setPointerChecker(i.containsPoint),wu(i,"dispatchAction",s.model.get("throttle",!0),"fixRate")})})}var kat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="dataZoom.inside",t}return e.prototype.render=function(t,n,a){if(r.prototype.render.apply(this,arguments),t.noTarget()){this._clear();return}this.range=t.getPercentRange(),Tat(a,t,{pan:Mt(L0.pan,this),zoom:Mt(L0.zoom,this),scrollMove:Mt(L0.scrollMove,this)})},e.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},e.prototype._clear=function(){Cat(this.api,this.dataZoomModel),this.range=null},e.type="dataZoom.inside",e}(Px),L0={zoom:function(r,e,t,n){var a=this.range,i=a.slice(),o=r.axisModels[0];if(o){var s=M0[e](null,[n.originX,n.originY],o,t,r),l=(s.signal>0?s.pixelStart+s.pixelLength-s.pixel:s.pixel-s.pixelStart)/s.pixelLength*(i[1]-i[0])+i[0],u=Math.max(1/n.scale,0);i[0]=(i[0]-l)*u+l,i[1]=(i[1]-l)*u+l;var c=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();if(qs(0,i,[0,100],0,c.minSpan,c.maxSpan),this.range=i,a[0]!==i[0]||a[1]!==i[1])return i}},pan:GD(function(r,e,t,n,a,i){var o=M0[n]([i.oldX,i.oldY],[i.newX,i.newY],e,a,t);return o.signal*(r[1]-r[0])*o.pixel/o.pixelLength}),scrollMove:GD(function(r,e,t,n,a,i){var o=M0[n]([0,0],[i.scrollDelta,i.scrollDelta],e,a,t);return o.signal*(r[1]-r[0])*i.scrollDelta})};function GD(r){return function(e,t,n,a){var i=this.range,o=i.slice(),s=e.axisModels[0];if(s){var l=r(o,s,e,t,n,a);if(qs(l,o,[0,100],"all"),this.range=o,i[0]!==o[0]||i[1]!==o[1])return o}}}var M0={grid:function(r,e,t,n,a){var i=t.axis,o={},s=a.model.coordinateSystem.getRect();return r=r||[0,0],i.dim==="x"?(o.pixel=e[0]-r[0],o.pixelLength=s.width,o.pixelStart=s.x,o.signal=i.inverse?1:-1):(o.pixel=e[1]-r[1],o.pixelLength=s.height,o.pixelStart=s.y,o.signal=i.inverse?-1:1),o},polar:function(r,e,t,n,a){var i=t.axis,o={},s=a.model.coordinateSystem,l=s.getRadiusAxis().getExtent(),u=s.getAngleAxis().getExtent();return r=r?s.pointToCoord(r):[0,0],e=s.pointToCoord(e),t.mainType==="radiusAxis"?(o.pixel=e[0]-r[0],o.pixelLength=l[1]-l[0],o.pixelStart=l[0],o.signal=i.inverse?1:-1):(o.pixel=e[1]-r[1],o.pixelLength=u[1]-u[0],o.pixelStart=u[0],o.signal=i.inverse?-1:1),o},singleAxis:function(r,e,t,n,a){var i=t.axis,o=a.model.coordinateSystem.getRect(),s={};return r=r||[0,0],i.orient==="horizontal"?(s.pixel=e[0]-r[0],s.pixelLength=o.width,s.pixelStart=o.x,s.signal=i.inverse?1:-1):(s.pixel=e[1]-r[1],s.pixelLength=o.height,s.pixelStart=o.y,s.signal=i.inverse?-1:1),s}};function eB(r){kx(r),r.registerComponentModel(Aat),r.registerComponentView(kat),Pat(r)}var Rat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.type="dataZoom.slider",e.layoutMode="box",e.defaultOption=Lo(_h.defaultOption,{show:!0,right:"ph",top:"ph",width:"ph",height:"ph",left:null,bottom:null,borderColor:"#d2dbee",borderRadius:3,backgroundColor:"rgba(47,69,84,0)",dataBackground:{lineStyle:{color:"#d2dbee",width:.5},areaStyle:{color:"#d2dbee",opacity:.2}},selectedDataBackground:{lineStyle:{color:"#8fb0f7",width:.5},areaStyle:{color:"#8fb0f7",opacity:.2}},fillerColor:"rgba(135,175,274,0.2)",handleIcon:"path://M-9.35,34.56V42m0-40V9.5m-2,0h4a2,2,0,0,1,2,2v21a2,2,0,0,1-2,2h-4a2,2,0,0,1-2-2v-21A2,2,0,0,1-11.35,9.5Z",handleSize:"100%",handleStyle:{color:"#fff",borderColor:"#ACB8D1"},moveHandleSize:7,moveHandleIcon:"path://M-320.9-50L-320.9-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-348-41-339-50-320.9-50z M-212.3-50L-212.3-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-239.4-41-230.4-50-212.3-50z M-103.7-50L-103.7-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-130.9-41-121.8-50-103.7-50z",moveHandleStyle:{color:"#D2DBEE",opacity:.7},showDetail:!0,showDataShadow:"auto",realtime:!0,zoomLock:!1,textStyle:{color:"#6E7079"},brushSelect:!0,brushStyle:{color:"rgba(135,175,274,0.15)"},emphasis:{handleLabel:{show:!0},handleStyle:{borderColor:"#8FB0F7"},moveHandleStyle:{color:"#8FB0F7"}}}),e}(_h),vc=fe,WD=7,Eat=1,D0=30,Oat=7,dc="horizontal",HD="vertical",Bat=5,Nat=["line","bar","candlestick","scatter"],zat={easing:"cubicOut",duration:100,delay:0},Fat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._displayables={},t}return e.prototype.init=function(t,n){this.api=n,this._onBrush=Mt(this._onBrush,this),this._onBrushEnd=Mt(this._onBrushEnd,this)},e.prototype.render=function(t,n,a,i){if(r.prototype.render.apply(this,arguments),wu(this,"_dispatchZoomAction",t.get("throttle"),"fixRate"),this._orient=t.getOrient(),t.get("show")===!1){this.group.removeAll();return}if(t.noTarget()){this._clear(),this.group.removeAll();return}(!i||i.type!=="dataZoom"||i.from!==this.uid)&&this._buildView(),this._updateView()},e.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},e.prototype._clear=function(){oh(this,"_dispatchZoomAction");var t=this.api.getZr();t.off("mousemove",this._onBrush),t.off("mouseup",this._onBrushEnd)},e.prototype._buildView=function(){var t=this.group;t.removeAll(),this._brushing=!1,this._displayables.brushRect=null,this._resetLocation(),this._resetInterval();var n=this._displayables.sliderGroup=new Wt;this._renderBackground(),this._renderHandle(),this._renderDataShadow(),t.add(n),this._positionGroup()},e.prototype._resetLocation=function(){var t=this.dataZoomModel,n=this.api,a=t.get("brushSelect"),i=a?Oat:0,o=this._findCoordRect(),s={width:n.getWidth(),height:n.getHeight()},l=this._orient===dc?{right:s.width-o.x-o.width,top:s.height-D0-WD-i,width:o.width,height:D0}:{right:WD,top:o.y,width:D0,height:o.height},u=yu(t.option);B(["right","top","width","height"],function(h){u[h]==="ph"&&(u[h]=l[h])});var c=cr(u,s);this._location={x:c.x,y:c.y},this._size=[c.width,c.height],this._orient===HD&&this._size.reverse()},e.prototype._positionGroup=function(){var t=this.group,n=this._location,a=this._orient,i=this.dataZoomModel.getFirstTargetAxisModel(),o=i&&i.get("inverse"),s=this._displayables.sliderGroup,l=(this._dataShadowInfo||{}).otherAxisInverse;s.attr(a===dc&&!o?{scaleY:l?1:-1,scaleX:1}:a===dc&&o?{scaleY:l?1:-1,scaleX:-1}:a===HD&&!o?{scaleY:l?-1:1,scaleX:1,rotation:Math.PI/2}:{scaleY:l?-1:1,scaleX:-1,rotation:Math.PI/2});var u=t.getBoundingRect([s]);t.x=n.x-u.x,t.y=n.y-u.y,t.markRedraw()},e.prototype._getViewExtent=function(){return[0,this._size[0]]},e.prototype._renderBackground=function(){var t=this.dataZoomModel,n=this._size,a=this._displayables.sliderGroup,i=t.get("brushSelect");a.add(new vc({silent:!0,shape:{x:0,y:0,width:n[0],height:n[1]},style:{fill:t.get("backgroundColor")},z2:-40}));var o=new vc({shape:{x:0,y:0,width:n[0],height:n[1]},style:{fill:"transparent"},z2:0,onclick:Mt(this._onClickPanel,this)}),s=this.api.getZr();i?(o.on("mousedown",this._onBrushStart,this),o.cursor="crosshair",s.on("mousemove",this._onBrush),s.on("mouseup",this._onBrushEnd)):(s.off("mousemove",this._onBrush),s.off("mouseup",this._onBrushEnd)),a.add(o)},e.prototype._renderDataShadow=function(){var t=this._dataShadowInfo=this._prepareDataShadowInfo();if(this._displayables.dataShadowSegs=[],!t)return;var n=this._size,a=this._shadowSize||[],i=t.series,o=i.getRawData(),s=i.getShadowDim&&i.getShadowDim(),l=s&&o.getDimensionInfo(s)?i.getShadowDim():t.otherDim;if(l==null)return;var u=this._shadowPolygonPts,c=this._shadowPolylinePts;if(o!==this._shadowData||l!==this._shadowDim||n[0]!==a[0]||n[1]!==a[1]){var h=o.getDataExtent(l),d=(h[1]-h[0])*.3;h=[h[0]-d,h[1]+d];var v=[0,n[1]],p=[0,n[0]],y=[[n[0],0],[0,0]],_=[],g=p[1]/(o.count()-1),f=0,w=Math.round(o.count()/n[0]),x;o.each([l],function(M,I){if(w>0&&I%w){f+=g;return}var R=M==null||isNaN(M)||M==="",P=R?0:Me(M,h,v,!0);R&&!x&&I?(y.push([y[y.length-1][0],0]),_.push([_[_.length-1][0],0])):!R&&x&&(y.push([f,0]),_.push([f,0])),y.push([f,P]),_.push([f,P]),f+=g,x=R}),u=this._shadowPolygonPts=y,c=this._shadowPolylinePts=_}this._shadowData=o,this._shadowDim=l,this._shadowSize=[n[0],n[1]];var S=this.dataZoomModel;function A(M){var I=S.getModel(M?"selectedDataBackground":"dataBackground"),R=new Wt,P=new rn({shape:{points:u},segmentIgnoreThreshold:1,style:I.getModel("areaStyle").getAreaStyle(),silent:!0,z2:-20}),E=new nn({shape:{points:c},segmentIgnoreThreshold:1,style:I.getModel("lineStyle").getLineStyle(),silent:!0,z2:-19});return R.add(P),R.add(E),R}for(var T=0;T<3;T++){var L=A(T===1);this._displayables.sliderGroup.add(L),this._displayables.dataShadowSegs.push(L)}},e.prototype._prepareDataShadowInfo=function(){var t=this.dataZoomModel,n=t.get("showDataShadow");if(n!==!1){var a,i=this.ecModel;return t.eachTargetAxis(function(o,s){var l=t.getAxisProxy(o,s).getTargetSeriesModels();B(l,function(u){if(!a&&!(n!==!0&&te(Nat,u.get("type"))<0)){var c=i.getComponent(fo(o),s).axis,h=Vat(o),d,v=u.coordinateSystem;h!=null&&v.getOtherAxis&&(d=v.getOtherAxis(c).inverse),h=u.getData().mapDimension(h),a={thisAxis:c,series:u,thisDim:o,otherDim:h,otherAxisInverse:d}}},this)},this),a}},e.prototype._renderHandle=function(){var t=this.group,n=this._displayables,a=n.handles=[null,null],i=n.handleLabels=[null,null],o=this._displayables.sliderGroup,s=this._size,l=this.dataZoomModel,u=this.api,c=l.get("borderRadius")||0,h=l.get("brushSelect"),d=n.filler=new vc({silent:h,style:{fill:l.get("fillerColor")},textConfig:{position:"inside"}});o.add(d),o.add(new vc({silent:!0,subPixelOptimize:!0,shape:{x:0,y:0,width:s[0],height:s[1],r:c},style:{stroke:l.get("dataBackgroundColor")||l.get("borderColor"),lineWidth:Eat,fill:"rgba(0,0,0,0)"}})),B([0,1],function(w){var x=l.get("handleIcon");!kd[x]&&x.indexOf("path://")<0&&x.indexOf("image://")<0&&(x="path://"+x);var S=or(x,-1,0,2,2,null,!0);S.attr({cursor:UD(this._orient),draggable:!0,drift:Mt(this._onDragMove,this,w),ondragend:Mt(this._onDragEnd,this),onmouseover:Mt(this._showDataInfo,this,!0),onmouseout:Mt(this._showDataInfo,this,!1),z2:5});var A=S.getBoundingRect(),T=l.get("handleSize");this._handleHeight=At(T,this._size[1]),this._handleWidth=A.width/A.height*this._handleHeight,S.setStyle(l.getModel("handleStyle").getItemStyle()),S.style.strokeNoScale=!0,S.rectHover=!0,S.ensureState("emphasis").style=l.getModel(["emphasis","handleStyle"]).getItemStyle(),Is(S);var L=l.get("handleColor");L!=null&&(S.style.fill=L),o.add(a[w]=S);var M=l.getModel("textStyle"),I=l.get("handleLabel")||{},R=I.show||!1;t.add(i[w]=new pe({silent:!0,invisible:!R,style:Fe(M,{x:0,y:0,text:"",verticalAlign:"middle",align:"center",fill:M.getTextColor(),font:M.getFont()}),z2:10}))},this);var v=d;if(h){var p=At(l.get("moveHandleSize"),s[1]),y=n.moveHandle=new fe({style:l.getModel("moveHandleStyle").getItemStyle(),silent:!0,shape:{r:[0,0,2,2],y:s[1]-.5,height:p}}),_=p*.8,g=n.moveHandleIcon=or(l.get("moveHandleIcon"),-_/2,-_/2,_,_,"#fff",!0);g.silent=!0,g.y=s[1]+p/2-.5,y.ensureState("emphasis").style=l.getModel(["emphasis","moveHandleStyle"]).getItemStyle();var f=Math.min(s[1]/2,Math.max(p,10));v=n.moveZone=new fe({invisible:!0,shape:{y:s[1]-f,height:p+f}}),v.on("mouseover",function(){u.enterEmphasis(y)}).on("mouseout",function(){u.leaveEmphasis(y)}),o.add(y),o.add(g),o.add(v)}v.attr({draggable:!0,cursor:UD(this._orient),drift:Mt(this._onDragMove,this,"all"),ondragstart:Mt(this._showDataInfo,this,!0),ondragend:Mt(this._onDragEnd,this),onmouseover:Mt(this._showDataInfo,this,!0),onmouseout:Mt(this._showDataInfo,this,!1)})},e.prototype._resetInterval=function(){var t=this._range=this.dataZoomModel.getPercentRange(),n=this._getViewExtent();this._handleEnds=[Me(t[0],[0,100],n,!0),Me(t[1],[0,100],n,!0)]},e.prototype._updateInterval=function(t,n){var a=this.dataZoomModel,i=this._handleEnds,o=this._getViewExtent(),s=a.findRepresentativeAxisProxy().getMinMaxSpan(),l=[0,100];qs(n,i,o,a.get("zoomLock")?"all":t,s.minSpan!=null?Me(s.minSpan,l,o,!0):null,s.maxSpan!=null?Me(s.maxSpan,l,o,!0):null);var u=this._range,c=this._range=Qn([Me(i[0],o,l,!0),Me(i[1],o,l,!0)]);return!u||u[0]!==c[0]||u[1]!==c[1]},e.prototype._updateView=function(t){var n=this._displayables,a=this._handleEnds,i=Qn(a.slice()),o=this._size;B([0,1],function(v){var p=n.handles[v],y=this._handleHeight;p.attr({scaleX:y/2,scaleY:y/2,x:a[v]+(v?-1:1),y:o[1]/2-y/2})},this),n.filler.setShape({x:i[0],y:0,width:i[1]-i[0],height:o[1]});var s={x:i[0],width:i[1]-i[0]};n.moveHandle&&(n.moveHandle.setShape(s),n.moveZone.setShape(s),n.moveZone.getBoundingRect(),n.moveHandleIcon&&n.moveHandleIcon.attr("x",s.x+s.width/2));for(var l=n.dataShadowSegs,u=[0,i[0],i[1],o[0]],c=0;c<l.length;c++){var h=l[c],d=h.getClipPath();d||(d=new fe,h.setClipPath(d)),d.setShape({x:u[c],y:0,width:u[c+1]-u[c],height:o[1]})}this._updateDataInfo(t)},e.prototype._updateDataInfo=function(t){var n=this.dataZoomModel,a=this._displayables,i=a.handleLabels,o=this._orient,s=["",""];if(n.get("showDetail")){var l=n.findRepresentativeAxisProxy();if(l){var u=l.getAxisModel().axis,c=this._range,h=t?l.calculateDataWindow({start:c[0],end:c[1]}).valueWindow:l.getDataValueWindow();s=[this._formatLabel(h[0],u),this._formatLabel(h[1],u)]}}var d=Qn(this._handleEnds.slice());v.call(this,0),v.call(this,1);function v(p){var y=Ps(a.handles[p].parent,this.group),_=Cp(p===0?"right":"left",y),g=this._handleWidth/2+Bat,f=_a([d[p]+(p===0?-g:g),this._size[1]/2],y);i[p].setStyle({x:f[0],y:f[1],verticalAlign:o===dc?"middle":_,align:o===dc?_:"center",text:s[p]})}},e.prototype._formatLabel=function(t,n){var a=this.dataZoomModel,i=a.get("labelFormatter"),o=a.get("labelPrecision");(o==null||o==="auto")&&(o=n.getPixelPrecision());var s=t==null||isNaN(t)?"":n.type==="category"||n.type==="time"?n.scale.getLabel({value:Math.round(t)}):t.toFixed(Math.min(o,20));return Nt(i)?i(t,s):Lt(i)?i.replace("{value}",s):s},e.prototype._showDataInfo=function(t){var n=this.dataZoomModel.get("handleLabel")||{},a=n.show||!1,i=this.dataZoomModel.getModel(["emphasis","handleLabel"]),o=i.get("show")||!1,s=t||this._dragging?o:a,l=this._displayables,u=l.handleLabels;u[0].attr("invisible",!s),u[1].attr("invisible",!s),l.moveHandle&&this.api[s?"enterEmphasis":"leaveEmphasis"](l.moveHandle,1)},e.prototype._onDragMove=function(t,n,a,i){this._dragging=!0,Si(i.event);var o=this._displayables.sliderGroup.getLocalTransform(),s=_a([n,a],o,!0),l=this._updateInterval(t,s[0]),u=this.dataZoomModel.get("realtime");this._updateView(!u),l&&u&&this._dispatchZoomAction(!0)},e.prototype._onDragEnd=function(){this._dragging=!1,this._showDataInfo(!1);var t=this.dataZoomModel.get("realtime");!t&&this._dispatchZoomAction(!1)},e.prototype._onClickPanel=function(t){var n=this._size,a=this._displayables.sliderGroup.transformCoordToLocal(t.offsetX,t.offsetY);if(!(a[0]<0||a[0]>n[0]||a[1]<0||a[1]>n[1])){var i=this._handleEnds,o=(i[0]+i[1])/2,s=this._updateInterval("all",a[0]-o);this._updateView(),s&&this._dispatchZoomAction(!1)}},e.prototype._onBrushStart=function(t){var n=t.offsetX,a=t.offsetY;this._brushStart=new Kt(n,a),this._brushing=!0,this._brushStartTime=+new Date},e.prototype._onBrushEnd=function(t){if(this._brushing){var n=this._displayables.brushRect;if(this._brushing=!1,!!n){n.attr("ignore",!0);var a=n.shape,i=+new Date;if(!(i-this._brushStartTime<200&&Math.abs(a.width)<5)){var o=this._getViewExtent(),s=[0,100];this._range=Qn([Me(a.x,o,s,!0),Me(a.x+a.width,o,s,!0)]),this._handleEnds=[a.x,a.x+a.width],this._updateView(),this._dispatchZoomAction(!1)}}}},e.prototype._onBrush=function(t){this._brushing&&(Si(t.event),this._updateBrushRect(t.offsetX,t.offsetY))},e.prototype._updateBrushRect=function(t,n){var a=this._displayables,i=this.dataZoomModel,o=a.brushRect;o||(o=a.brushRect=new vc({silent:!0,style:i.getModel("brushStyle").getItemStyle()}),a.sliderGroup.add(o)),o.attr("ignore",!1);var s=this._brushStart,l=this._displayables.sliderGroup,u=l.transformCoordToLocal(t,n),c=l.transformCoordToLocal(s.x,s.y),h=this._size;u[0]=Math.max(Math.min(h[0],u[0]),0),o.setShape({x:c[0],y:0,width:u[0]-c[0],height:h[1]})},e.prototype._dispatchZoomAction=function(t){var n=this._range;this.api.dispatchAction({type:"dataZoom",from:this.uid,dataZoomId:this.dataZoomModel.id,animation:t?zat:null,start:n[0],end:n[1]})},e.prototype._findCoordRect=function(){var t,n=BO(this.dataZoomModel).infoList;if(!t&&n.length){var a=n[0].model.coordinateSystem;t=a.getRect&&a.getRect()}if(!t){var i=this.api.getWidth(),o=this.api.getHeight();t={x:i*.2,y:o*.2,width:i*.6,height:o*.6}}return t},e.type="dataZoom.slider",e}(Px);function Vat(r){var e={x:"y",y:"x",radius:"angle",angle:"radius"};return e[r]}function UD(r){return r==="vertical"?"ns-resize":"ew-resize"}function rB(r){r.registerComponentModel(Rat),r.registerComponentView(Fat),kx(r)}function Gat(r){ne(eB),ne(rB)}var nB={get:function(r,e,t){var n=Gt((Wat[r]||{})[e]);return t&&ht(n)?n[n.length-1]:n}},Wat={color:{active:["#006edd","#e0ffff"],inactive:["rgba(0,0,0,0)"]},colorHue:{active:[0,360],inactive:[0,0]},colorSaturation:{active:[.3,1],inactive:[0,0]},colorLightness:{active:[.9,.5],inactive:[0,0]},colorAlpha:{active:[.3,1],inactive:[0,0]},opacity:{active:[.3,1],inactive:[0,0]},symbol:{active:["circle","roundRect","diamond"],inactive:["none"]},symbolSize:{active:[10,50],inactive:[0,0]}},ZD=mr.mapVisual,Hat=mr.eachVisual,Uat=ht,YD=B,Zat=Qn,Yat=Me,rp=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.stateList=["inRange","outOfRange"],t.replacableOptionKeys=["inRange","outOfRange","target","controller","color"],t.layoutMode={type:"box",ignoreSize:!0},t.dataBound=[-1/0,1/0],t.targetVisuals={},t.controllerVisuals={},t}return e.prototype.init=function(t,n,a){this.mergeDefaultAndTheme(t,a)},e.prototype.optionUpdated=function(t,n){var a=this.option;!n&&YO(a,t,this.replacableOptionKeys),this.textStyleModel=this.getModel("textStyle"),this.resetItemSize(),this.completeVisualOption()},e.prototype.resetVisual=function(t){var n=this.stateList;t=Mt(t,this),this.controllerVisuals=x1(this.option.controller,n,t),this.targetVisuals=x1(this.option.target,n,t)},e.prototype.getItemSymbol=function(){return null},e.prototype.getTargetSeriesIndices=function(){var t=this.option.seriesIndex,n=[];return t==null||t==="all"?this.ecModel.eachSeries(function(a,i){n.push(i)}):n=Ie(t),n},e.prototype.eachTargetSeries=function(t,n){B(this.getTargetSeriesIndices(),function(a){var i=this.ecModel.getSeriesByIndex(a);i&&t.call(n,i)},this)},e.prototype.isTargetSeries=function(t){var n=!1;return this.eachTargetSeries(function(a){a===t&&(n=!0)}),n},e.prototype.formatValueText=function(t,n,a){var i=this.option,o=i.precision,s=this.dataBound,l=i.formatter,u;a=a||["<",">"],ht(t)&&(t=t.slice(),u=!0);var c=n?t:u?[h(t[0]),h(t[1])]:h(t);if(Lt(l))return l.replace("{value}",u?c[0]:c).replace("{value2}",u?c[1]:c);if(Nt(l))return u?l(t[0],t[1]):l(t);if(u)return t[0]===s[0]?a[0]+" "+c[1]:t[1]===s[1]?a[1]+" "+c[0]:c[0]+" - "+c[1];return c;function h(d){return d===s[0]?"min":d===s[1]?"max":(+d).toFixed(Math.min(o,20))}},e.prototype.resetExtent=function(){var t=this.option,n=Zat([t.min,t.max]);this._dataExtent=n},e.prototype.getDataDimensionIndex=function(t){var n=this.option.dimension;if(n!=null)return t.getDimensionIndex(n);for(var a=t.dimensions,i=a.length-1;i>=0;i--){var o=a[i],s=t.getDimensionInfo(o);if(!s.isCalculationCoord)return s.storeDimIndex}},e.prototype.getExtent=function(){return this._dataExtent.slice()},e.prototype.completeVisualOption=function(){var t=this.ecModel,n=this.option,a={inRange:n.inRange,outOfRange:n.outOfRange},i=n.target||(n.target={}),o=n.controller||(n.controller={});qt(i,a),qt(o,a);var s=this.isCategory();l.call(this,i),l.call(this,o),u.call(this,i,"inRange","outOfRange"),c.call(this,o);function l(h){Uat(n.color)&&!h.inRange&&(h.inRange={color:n.color.slice().reverse()}),h.inRange=h.inRange||{color:t.get("gradientColor")}}function u(h,d,v){var p=h[d],y=h[v];p&&!y&&(y=h[v]={},YD(p,function(_,g){if(mr.isValidType(g)){var f=nB.get(g,"inactive",s);f!=null&&(y[g]=f,g==="color"&&!y.hasOwnProperty("opacity")&&!y.hasOwnProperty("colorAlpha")&&(y.opacity=[0,0]))}}))}function c(h){var d=(h.inRange||{}).symbol||(h.outOfRange||{}).symbol,v=(h.inRange||{}).symbolSize||(h.outOfRange||{}).symbolSize,p=this.get("inactiveColor"),y=this.getItemSymbol(),_=y||"roundRect";YD(this.stateList,function(g){var f=this.itemSize,w=h[g];w||(w=h[g]={color:s?p:[p]}),w.symbol==null&&(w.symbol=d&&Gt(d)||(s?_:[_])),w.symbolSize==null&&(w.symbolSize=v&&Gt(v)||(s?f[0]:[f[0],f[0]])),w.symbol=ZD(w.symbol,function(A){return A==="none"?_:A});var x=w.symbolSize;if(x!=null){var S=-1/0;Hat(x,function(A){A>S&&(S=A)}),w.symbolSize=ZD(x,function(A){return Yat(A,[0,S],[0,f[0]],!0)})}},this)}},e.prototype.resetItemSize=function(){this.itemSize=[parseFloat(this.get("itemWidth")),parseFloat(this.get("itemHeight"))]},e.prototype.isCategory=function(){return!!this.option.categories},e.prototype.setSelected=function(t){},e.prototype.getSelected=function(){return null},e.prototype.getValueState=function(t){return null},e.prototype.getVisualMeta=function(t){return null},e.type="visualMap",e.dependencies=["series"],e.defaultOption={show:!0,z:4,seriesIndex:"all",min:0,max:200,left:0,right:null,top:null,bottom:0,itemWidth:null,itemHeight:null,inverse:!1,orient:"vertical",backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",contentColor:"#5793f3",inactiveColor:"#aaa",borderWidth:0,padding:5,textGap:10,precision:0,textStyle:{color:"#333"}},e}(le),XD=[20,140],Xat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.optionUpdated=function(t,n){r.prototype.optionUpdated.apply(this,arguments),this.resetExtent(),this.resetVisual(function(a){a.mappingMethod="linear",a.dataExtent=this.getExtent()}),this._resetRange()},e.prototype.resetItemSize=function(){r.prototype.resetItemSize.apply(this,arguments);var t=this.itemSize;(t[0]==null||isNaN(t[0]))&&(t[0]=XD[0]),(t[1]==null||isNaN(t[1]))&&(t[1]=XD[1])},e.prototype._resetRange=function(){var t=this.getExtent(),n=this.option.range;!n||n.auto?(t.auto=1,this.option.range=t):ht(n)&&(n[0]>n[1]&&n.reverse(),n[0]=Math.max(n[0],t[0]),n[1]=Math.min(n[1],t[1]))},e.prototype.completeVisualOption=function(){r.prototype.completeVisualOption.apply(this,arguments),B(this.stateList,function(t){var n=this.option.controller[t].symbolSize;n&&n[0]!==n[1]&&(n[0]=n[1]/3)},this)},e.prototype.setSelected=function(t){this.option.range=t.slice(),this._resetRange()},e.prototype.getSelected=function(){var t=this.getExtent(),n=Qn((this.get("range")||[]).slice());return n[0]>t[1]&&(n[0]=t[1]),n[1]>t[1]&&(n[1]=t[1]),n[0]<t[0]&&(n[0]=t[0]),n[1]<t[0]&&(n[1]=t[0]),n},e.prototype.getValueState=function(t){var n=this.option.range,a=this.getExtent();return(n[0]<=a[0]||n[0]<=t)&&(n[1]>=a[1]||t<=n[1])?"inRange":"outOfRange"},e.prototype.findTargetDataIndices=function(t){var n=[];return this.eachTargetSeries(function(a){var i=[],o=a.getData();o.each(this.getDataDimensionIndex(o),function(s,l){t[0]<=s&&s<=t[1]&&i.push(l)},this),n.push({seriesId:a.id,dataIndex:i})},this),n},e.prototype.getVisualMeta=function(t){var n=$D(this,"outOfRange",this.getExtent()),a=$D(this,"inRange",this.option.range.slice()),i=[];function o(v,p){i.push({value:v,color:t(v,p)})}for(var s=0,l=0,u=a.length,c=n.length;l<c&&(!a.length||n[l]<=a[0]);l++)n[l]<a[s]&&o(n[l],"outOfRange");for(var h=1;s<u;s++,h=0)h&&i.length&&o(a[s],"outOfRange"),o(a[s],"inRange");for(var h=1;l<c;l++)(!a.length||a[a.length-1]<n[l])&&(h&&(i.length&&o(i[i.length-1].value,"outOfRange"),h=0),o(n[l],"outOfRange"));var d=i.length;return{stops:i,outerColors:[d?i[0].color:"transparent",d?i[d-1].color:"transparent"]}},e.type="visualMap.continuous",e.defaultOption=Lo(rp.defaultOption,{align:"auto",calculable:!1,hoverLink:!0,realtime:!0,handleIcon:"path://M-11.39,9.77h0a3.5,3.5,0,0,1-3.5,3.5h-22a3.5,3.5,0,0,1-3.5-3.5h0a3.5,3.5,0,0,1,3.5-3.5h22A3.5,3.5,0,0,1-11.39,9.77Z",handleSize:"120%",handleStyle:{borderColor:"#fff",borderWidth:1},indicatorIcon:"circle",indicatorSize:"50%",indicatorStyle:{borderColor:"#fff",borderWidth:2,shadowBlur:2,shadowOffsetX:1,shadowOffsetY:1,shadowColor:"rgba(0,0,0,0.2)"}}),e}(rp);function $D(r,e,t){if(t[0]===t[1])return t.slice();for(var n=200,a=(t[1]-t[0])/n,i=t[0],o=[],s=0;s<=n&&i<t[1];s++)o.push(i),i+=a;return o.push(t[1]),o}var aB=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t.autoPositionValues={left:1,right:1,top:1,bottom:1},t}return e.prototype.init=function(t,n){this.ecModel=t,this.api=n},e.prototype.render=function(t,n,a,i){if(this.visualMapModel=t,t.get("show")===!1){this.group.removeAll();return}this.doRender(t,n,a,i)},e.prototype.renderBackground=function(t){var n=this.visualMapModel,a=gu(n.get("padding")||0),i=t.getBoundingRect();t.add(new fe({z2:-1,silent:!0,shape:{x:i.x-a[3],y:i.y-a[0],width:i.width+a[3]+a[1],height:i.height+a[0]+a[2]},style:{fill:n.get("backgroundColor"),stroke:n.get("borderColor"),lineWidth:n.get("borderWidth")}}))},e.prototype.getControllerVisual=function(t,n,a){a=a||{};var i=a.forceState,o=this.visualMapModel,s={};if(n==="color"){var l=o.get("contentColor");s.color=l}function u(v){return s[v]}function c(v,p){s[v]=p}var h=o.controllerVisuals[i||o.getValueState(t)],d=mr.prepareVisualTypes(h);return B(d,function(v){var p=h[v];a.convertOpacityToAlpha&&v==="opacity"&&(v="colorAlpha",p=h.__alphaForOpacity),mr.dependsOn(v,n)&&p&&p.applyVisual(t,u,c)}),s[n]},e.prototype.positionGroup=function(t){var n=this.visualMapModel,a=this.api;Rp(t,n.getBoxLayoutParams(),{width:a.getWidth(),height:a.getHeight()})},e.prototype.doRender=function(t,n,a,i){},e.type="visualMap",e}(Ze),jD=[["left","right","width"],["top","bottom","height"]];function iB(r,e,t){var n=r.option,a=n.align;if(a!=null&&a!=="auto")return a;for(var i={width:e.getWidth(),height:e.getHeight()},o=n.orient==="horizontal"?1:0,s=jD[o],l=[0,null,10],u={},c=0;c<3;c++)u[jD[1-o][c]]=l[c],u[s[c]]=c===2?t[0]:n[s[c]];var h=[["x","width",3],["y","height",0]][o],d=cr(u,i,n.padding);return s[(d.margin[h[2]]||0)+d[h[0]]+d[h[1]]*.5<i[h[1]]*.5?0:1]}function cd(r,e){return B(r||[],function(t){t.dataIndex!=null&&(t.dataIndexInside=t.dataIndex,t.dataIndex=null),t.highlightKey="visualMap"+(e?e.componentIndex:"")}),r}var Ea=Me,$at=B,qD=Math.min,I0=Math.max,jat=12,qat=6,Kat=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._shapes={},t._dataInterval=[],t._handleEnds=[],t._hoverLinkDataIndices=[],t}return e.prototype.init=function(t,n){r.prototype.init.call(this,t,n),this._hoverLinkFromSeriesMouseOver=Mt(this._hoverLinkFromSeriesMouseOver,this),this._hideIndicator=Mt(this._hideIndicator,this)},e.prototype.doRender=function(t,n,a,i){(!i||i.type!=="selectDataRange"||i.from!==this.uid)&&this._buildView()},e.prototype._buildView=function(){this.group.removeAll();var t=this.visualMapModel,n=this.group;this._orient=t.get("orient"),this._useHandle=t.get("calculable"),this._resetInterval(),this._renderBar(n);var a=t.get("text");this._renderEndsText(n,a,0),this._renderEndsText(n,a,1),this._updateView(!0),this.renderBackground(n),this._updateView(),this._enableHoverLinkToSeries(),this._enableHoverLinkFromSeries(),this.positionGroup(n)},e.prototype._renderEndsText=function(t,n,a){if(n){var i=n[1-a];i=i!=null?i+"":"";var o=this.visualMapModel,s=o.get("textGap"),l=o.itemSize,u=this._shapes.mainGroup,c=this._applyTransform([l[0]/2,a===0?-s:l[1]+s],u),h=this._applyTransform(a===0?"bottom":"top",u),d=this._orient,v=this.visualMapModel.textStyleModel;this.group.add(new pe({style:Fe(v,{x:c[0],y:c[1],verticalAlign:d==="horizontal"?"middle":h,align:d==="horizontal"?h:"center",text:i})}))}},e.prototype._renderBar=function(t){var n=this.visualMapModel,a=this._shapes,i=n.itemSize,o=this._orient,s=this._useHandle,l=iB(n,this.api,i),u=a.mainGroup=this._createBarGroup(l),c=new Wt;u.add(c),c.add(a.outOfRange=KD()),c.add(a.inRange=KD(null,s?JD(this._orient):null,Mt(this._dragHandle,this,"all",!1),Mt(this._dragHandle,this,"all",!0))),c.setClipPath(new fe({shape:{x:0,y:0,width:i[0],height:i[1],r:3}}));var h=n.textStyleModel.getTextRect("国"),d=I0(h.width,h.height);s&&(a.handleThumbs=[],a.handleLabels=[],a.handleLabelPoints=[],this._createHandle(n,u,0,i,d,o),this._createHandle(n,u,1,i,d,o)),this._createIndicator(n,u,i,d,o),t.add(u)},e.prototype._createHandle=function(t,n,a,i,o,s){var l=Mt(this._dragHandle,this,a,!1),u=Mt(this._dragHandle,this,a,!0),c=wa(t.get("handleSize"),i[0]),h=or(t.get("handleIcon"),-c/2,-c/2,c,c,null,!0),d=JD(this._orient);h.attr({cursor:d,draggable:!0,drift:l,ondragend:u,onmousemove:function(g){Si(g.event)}}),h.x=i[0]/2,h.useStyle(t.getModel("handleStyle").getItemStyle()),h.setStyle({strokeNoScale:!0,strokeFirst:!0}),h.style.lineWidth*=2,h.ensureState("emphasis").style=t.getModel(["emphasis","handleStyle"]).getItemStyle(),ws(h,!0),n.add(h);var v=this.visualMapModel.textStyleModel,p=new pe({cursor:d,draggable:!0,drift:l,onmousemove:function(g){Si(g.event)},ondragend:u,style:Fe(v,{x:0,y:0,text:""})});p.ensureState("blur").style={opacity:.1},p.stateTransition={duration:200},this.group.add(p);var y=[c,0],_=this._shapes;_.handleThumbs[a]=h,_.handleLabelPoints[a]=y,_.handleLabels[a]=p},e.prototype._createIndicator=function(t,n,a,i,o){var s=wa(t.get("indicatorSize"),a[0]),l=or(t.get("indicatorIcon"),-s/2,-s/2,s,s,null,!0);l.attr({cursor:"move",invisible:!0,silent:!0,x:a[0]/2});var u=t.getModel("indicatorStyle").getItemStyle();if(l instanceof Tr){var c=l.style;l.useStyle(lt({image:c.image,x:c.x,y:c.y,width:c.width,height:c.height},u))}else l.useStyle(u);n.add(l);var h=this.visualMapModel.textStyleModel,d=new pe({silent:!0,invisible:!0,style:Fe(h,{x:0,y:0,text:""})});this.group.add(d);var v=[(o==="horizontal"?i/2:qat)+a[0]/2,0],p=this._shapes;p.indicator=l,p.indicatorLabel=d,p.indicatorLabelPoint=v,this._firstShowIndicator=!0},e.prototype._dragHandle=function(t,n,a,i){if(this._useHandle){if(this._dragging=!n,!n){var o=this._applyTransform([a,i],this._shapes.mainGroup,!0);this._updateInterval(t,o[1]),this._hideIndicator(),this._updateView()}n===!this.visualMapModel.get("realtime")&&this.api.dispatchAction({type:"selectDataRange",from:this.uid,visualMapId:this.visualMapModel.id,selected:this._dataInterval.slice()}),n?!this._hovering&&this._clearHoverLinkToSeries():QD(this.visualMapModel)&&this._doHoverLinkToSeries(this._handleEnds[t],!1)}},e.prototype._resetInterval=function(){var t=this.visualMapModel,n=this._dataInterval=t.getSelected(),a=t.getExtent(),i=[0,t.itemSize[1]];this._handleEnds=[Ea(n[0],a,i,!0),Ea(n[1],a,i,!0)]},e.prototype._updateInterval=function(t,n){n=n||0;var a=this.visualMapModel,i=this._handleEnds,o=[0,a.itemSize[1]];qs(n,i,o,t,0);var s=a.getExtent();this._dataInterval=[Ea(i[0],o,s,!0),Ea(i[1],o,s,!0)]},e.prototype._updateView=function(t){var n=this.visualMapModel,a=n.getExtent(),i=this._shapes,o=[0,n.itemSize[1]],s=t?o:this._handleEnds,l=this._createBarVisual(this._dataInterval,a,s,"inRange"),u=this._createBarVisual(a,a,o,"outOfRange");i.inRange.setStyle({fill:l.barColor}).setShape("points",l.barPoints),i.outOfRange.setStyle({fill:u.barColor}).setShape("points",u.barPoints),this._updateHandle(s,l)},e.prototype._createBarVisual=function(t,n,a,i){var o={forceState:i,convertOpacityToAlpha:!0},s=this._makeColorGradient(t,o),l=[this.getControllerVisual(t[0],"symbolSize",o),this.getControllerVisual(t[1],"symbolSize",o)],u=this._createBarPoints(a,l);return{barColor:new Ih(0,0,0,1,s),barPoints:u,handlesColor:[s[0].color,s[s.length-1].color]}},e.prototype._makeColorGradient=function(t,n){var a=100,i=[],o=(t[1]-t[0])/a;i.push({color:this.getControllerVisual(t[0],"color",n),offset:0});for(var s=1;s<a;s++){var l=t[0]+o*s;if(l>t[1])break;i.push({color:this.getControllerVisual(l,"color",n),offset:s/a})}return i.push({color:this.getControllerVisual(t[1],"color",n),offset:1}),i},e.prototype._createBarPoints=function(t,n){var a=this.visualMapModel.itemSize;return[[a[0]-n[0],t[0]],[a[0],t[0]],[a[0],t[1]],[a[0]-n[1],t[1]]]},e.prototype._createBarGroup=function(t){var n=this._orient,a=this.visualMapModel.get("inverse");return new Wt(n==="horizontal"&&!a?{scaleX:t==="bottom"?1:-1,rotation:Math.PI/2}:n==="horizontal"&&a?{scaleX:t==="bottom"?-1:1,rotation:-Math.PI/2}:n==="vertical"&&!a?{scaleX:t==="left"?1:-1,scaleY:-1}:{scaleX:t==="left"?1:-1})},e.prototype._updateHandle=function(t,n){if(this._useHandle){var a=this._shapes,i=this.visualMapModel,o=a.handleThumbs,s=a.handleLabels,l=i.itemSize,u=i.getExtent(),c=this._applyTransform("left",a.mainGroup);$at([0,1],function(h){var d=o[h];d.setStyle("fill",n.handlesColor[h]),d.y=t[h];var v=Ea(t[h],[0,l[1]],u,!0),p=this.getControllerVisual(v,"symbolSize");d.scaleX=d.scaleY=p/l[0],d.x=l[0]-p/2;var y=_a(a.handleLabelPoints[h],Ps(d,this.group));if(this._orient==="horizontal"){var _=c==="left"||c==="top"?(l[0]-p)/2:(l[0]-p)/-2;y[1]+=_}s[h].setStyle({x:y[0],y:y[1],text:i.formatValueText(this._dataInterval[h]),verticalAlign:"middle",align:this._orient==="vertical"?this._applyTransform("left",a.mainGroup):"center"})},this)}},e.prototype._showIndicator=function(t,n,a,i){var o=this.visualMapModel,s=o.getExtent(),l=o.itemSize,u=[0,l[1]],c=this._shapes,h=c.indicator;if(h){h.attr("invisible",!1);var d={convertOpacityToAlpha:!0},v=this.getControllerVisual(t,"color",d),p=this.getControllerVisual(t,"symbolSize"),y=Ea(t,s,u,!0),_=l[0]-p/2,g={x:h.x,y:h.y};h.y=y,h.x=_;var f=_a(c.indicatorLabelPoint,Ps(h,this.group)),w=c.indicatorLabel;w.attr("invisible",!1);var x=this._applyTransform("left",c.mainGroup),S=this._orient,A=S==="horizontal";w.setStyle({text:(a||"")+o.formatValueText(n),verticalAlign:A?x:"middle",align:A?"center":x});var T={x:_,y,style:{fill:v}},L={style:{x:f[0],y:f[1]}};if(o.ecModel.isAnimationEnabled()&&!this._firstShowIndicator){var M={duration:100,easing:"cubicInOut",additive:!0};h.x=g.x,h.y=g.y,h.animateTo(T,M),w.animateTo(L,M)}else h.attr(T),w.attr(L);this._firstShowIndicator=!1;var I=this._shapes.handleLabels;if(I)for(var R=0;R<I.length;R++)this.api.enterBlur(I[R])}},e.prototype._enableHoverLinkToSeries=function(){var t=this;this._shapes.mainGroup.on("mousemove",function(n){if(t._hovering=!0,!t._dragging){var a=t.visualMapModel.itemSize,i=t._applyTransform([n.offsetX,n.offsetY],t._shapes.mainGroup,!0,!0);i[1]=qD(I0(0,i[1]),a[1]),t._doHoverLinkToSeries(i[1],0<=i[0]&&i[0]<=a[0])}}).on("mouseout",function(){t._hovering=!1,!t._dragging&&t._clearHoverLinkToSeries()})},e.prototype._enableHoverLinkFromSeries=function(){var t=this.api.getZr();this.visualMapModel.option.hoverLink?(t.on("mouseover",this._hoverLinkFromSeriesMouseOver,this),t.on("mouseout",this._hideIndicator,this)):this._clearHoverLinkFromSeries()},e.prototype._doHoverLinkToSeries=function(t,n){var a=this.visualMapModel,i=a.itemSize;if(a.option.hoverLink){var o=[0,i[1]],s=a.getExtent();t=qD(I0(o[0],t),o[1]);var l=Qat(a,s,o),u=[t-l,t+l],c=Ea(t,o,s,!0),h=[Ea(u[0],o,s,!0),Ea(u[1],o,s,!0)];u[0]<o[0]&&(h[0]=-1/0),u[1]>o[1]&&(h[1]=1/0),n&&(h[0]===-1/0?this._showIndicator(c,h[1],"< ",l):h[1]===1/0?this._showIndicator(c,h[0],"> ",l):this._showIndicator(c,c,"≈ ",l));var d=this._hoverLinkDataIndices,v=[];(n||QD(a))&&(v=this._hoverLinkDataIndices=a.findTargetDataIndices(h));var p=nW(d,v);this._dispatchHighDown("downplay",cd(p[0],a)),this._dispatchHighDown("highlight",cd(p[1],a))}},e.prototype._hoverLinkFromSeriesMouseOver=function(t){var n;if(bs(t.target,function(l){var u=Ht(l);if(u.dataIndex!=null)return n=u,!0},!0),!!n){var a=this.ecModel.getSeriesByIndex(n.seriesIndex),i=this.visualMapModel;if(i.isTargetSeries(a)){var o=a.getData(n.dataType),s=o.getStore().get(i.getDataDimensionIndex(o),n.dataIndex);isNaN(s)||this._showIndicator(s,s)}}},e.prototype._hideIndicator=function(){var t=this._shapes;t.indicator&&t.indicator.attr("invisible",!0),t.indicatorLabel&&t.indicatorLabel.attr("invisible",!0);var n=this._shapes.handleLabels;if(n)for(var a=0;a<n.length;a++)this.api.leaveBlur(n[a])},e.prototype._clearHoverLinkToSeries=function(){this._hideIndicator();var t=this._hoverLinkDataIndices;this._dispatchHighDown("downplay",cd(t,this.visualMapModel)),t.length=0},e.prototype._clearHoverLinkFromSeries=function(){this._hideIndicator();var t=this.api.getZr();t.off("mouseover",this._hoverLinkFromSeriesMouseOver),t.off("mouseout",this._hideIndicator)},e.prototype._applyTransform=function(t,n,a,i){var o=Ps(n,i?null:this.group);return ht(t)?_a(t,o,a):Cp(t,o,a)},e.prototype._dispatchHighDown=function(t,n){n&&n.length&&this.api.dispatchAction({type:t,batch:n})},e.prototype.dispose=function(){this._clearHoverLinkFromSeries(),this._clearHoverLinkToSeries()},e.type="visualMap.continuous",e}(aB);function KD(r,e,t,n){return new rn({shape:{points:r},draggable:!!t,cursor:e,drift:t,onmousemove:function(a){Si(a.event)},ondragend:n})}function Qat(r,e,t){var n=jat/2,a=r.get("hoverLinkDataSize");return a&&(n=Ea(a,e,t,!0)/2),n}function QD(r){var e=r.get("hoverLinkOnHandle");return!!(e??r.get("realtime"))}function JD(r){return r==="vertical"?"ns-resize":"ew-resize"}var Jat={type:"selectDataRange",event:"dataRangeSelected",update:"update"},tit=function(r,e){e.eachComponent({mainType:"visualMap",query:r},function(t){t.setSelected(r.selected)})},eit=[{createOnAllSeries:!0,reset:function(r,e){var t=[];return e.eachComponent("visualMap",function(n){var a=r.pipelineContext;!n.isTargetSeries(r)||a&&a.large||t.push(Snt(n.stateList,n.targetVisuals,Mt(n.getValueState,n),n.getDataDimensionIndex(r.getData())))}),t}},{createOnAllSeries:!0,reset:function(r,e){var t=r.getData(),n=[];e.eachComponent("visualMap",function(a){if(a.isTargetSeries(r)){var i=a.getVisualMeta(Mt(rit,null,r,a))||{stops:[],outerColors:[]},o=a.getDataDimensionIndex(t);o>=0&&(i.dimension=o,n.push(i))}}),r.getData().setVisual("visualMeta",n)}}];function rit(r,e,t,n){for(var a=e.targetVisuals[n],i=mr.prepareVisualTypes(a),o={color:Eh(r.getData(),"color")},s=0,l=i.length;s<l;s++){var u=i[s],c=a[u==="opacity"?"__alphaForOpacity":u];c&&c.applyVisual(t,h,d)}return o.color;function h(v){return o[v]}function d(v,p){o[v]=p}}var tI=B;function nit(r){var e=r&&r.visualMap;ht(e)||(e=e?[e]:[]),tI(e,function(t){if(t){Pl(t,"splitList")&&!Pl(t,"pieces")&&(t.pieces=t.splitList,delete t.splitList);var n=t.pieces;n&&ht(n)&&tI(n,function(a){Vt(a)&&(Pl(a,"start")&&!Pl(a,"min")&&(a.min=a.start),Pl(a,"end")&&!Pl(a,"max")&&(a.max=a.end))})}})}function Pl(r,e){return r&&r.hasOwnProperty&&r.hasOwnProperty(e)}var eI=!1;function oB(r){eI||(eI=!0,r.registerSubTypeDefaulter("visualMap",function(e){return!e.categories&&(!(e.pieces?e.pieces.length>0:e.splitNumber>0)||e.calculable)?"continuous":"piecewise"}),r.registerAction(Jat,tit),B(eit,function(e){r.registerVisual(r.PRIORITY.VISUAL.COMPONENT,e)}),r.registerPreprocessor(nit))}function sB(r){r.registerComponentModel(Xat),r.registerComponentView(Kat),oB(r)}var ait=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t._pieceList=[],t}return e.prototype.optionUpdated=function(t,n){r.prototype.optionUpdated.apply(this,arguments),this.resetExtent();var a=this._mode=this._determineMode();this._pieceList=[],iit[this._mode].call(this,this._pieceList),this._resetSelected(t,n);var i=this.option.categories;this.resetVisual(function(o,s){a==="categories"?(o.mappingMethod="category",o.categories=Gt(i)):(o.dataExtent=this.getExtent(),o.mappingMethod="piecewise",o.pieceList=ft(this._pieceList,function(l){return l=Gt(l),s!=="inRange"&&(l.visual=null),l}))})},e.prototype.completeVisualOption=function(){var t=this.option,n={},a=mr.listVisualTypes(),i=this.isCategory();B(t.pieces,function(s){B(a,function(l){s.hasOwnProperty(l)&&(n[l]=1)})}),B(n,function(s,l){var u=!1;B(this.stateList,function(c){u=u||o(t,c,l)||o(t.target,c,l)},this),!u&&B(this.stateList,function(c){(t[c]||(t[c]={}))[l]=nB.get(l,c==="inRange"?"active":"inactive",i)})},this);function o(s,l,u){return s&&s[l]&&s[l].hasOwnProperty(u)}r.prototype.completeVisualOption.apply(this,arguments)},e.prototype._resetSelected=function(t,n){var a=this.option,i=this._pieceList,o=(n?a:t).selected||{};if(a.selected=o,B(i,function(l,u){var c=this.getSelectedMapKey(l);o.hasOwnProperty(c)||(o[c]=!0)},this),a.selectedMode==="single"){var s=!1;B(i,function(l,u){var c=this.getSelectedMapKey(l);o[c]&&(s?o[c]=!1:s=!0)},this)}},e.prototype.getItemSymbol=function(){return this.get("itemSymbol")},e.prototype.getSelectedMapKey=function(t){return this._mode==="categories"?t.value+"":t.index+""},e.prototype.getPieceList=function(){return this._pieceList},e.prototype._determineMode=function(){var t=this.option;return t.pieces&&t.pieces.length>0?"pieces":this.option.categories?"categories":"splitNumber"},e.prototype.setSelected=function(t){this.option.selected=Gt(t)},e.prototype.getValueState=function(t){var n=mr.findPieceIndex(t,this._pieceList);return n!=null&&this.option.selected[this.getSelectedMapKey(this._pieceList[n])]?"inRange":"outOfRange"},e.prototype.findTargetDataIndices=function(t){var n=[],a=this._pieceList;return this.eachTargetSeries(function(i){var o=[],s=i.getData();s.each(this.getDataDimensionIndex(s),function(l,u){var c=mr.findPieceIndex(l,a);c===t&&o.push(u)},this),n.push({seriesId:i.id,dataIndex:o})},this),n},e.prototype.getRepresentValue=function(t){var n;if(this.isCategory())n=t.value;else if(t.value!=null)n=t.value;else{var a=t.interval||[];n=a[0]===-1/0&&a[1]===1/0?0:(a[0]+a[1])/2}return n},e.prototype.getVisualMeta=function(t){if(this.isCategory())return;var n=[],a=["",""],i=this;function o(c,h){var d=i.getRepresentValue({interval:c});h||(h=i.getValueState(d));var v=t(d,h);c[0]===-1/0?a[0]=v:c[1]===1/0?a[1]=v:n.push({value:c[0],color:v},{value:c[1],color:v})}var s=this._pieceList.slice();if(!s.length)s.push({interval:[-1/0,1/0]});else{var l=s[0].interval[0];l!==-1/0&&s.unshift({interval:[-1/0,l]}),l=s[s.length-1].interval[1],l!==1/0&&s.push({interval:[l,1/0]})}var u=-1/0;return B(s,function(c){var h=c.interval;h&&(h[0]>u&&o([u,h[0]],"outOfRange"),o(h.slice()),u=h[1])},this),{stops:n,outerColors:a}},e.type="visualMap.piecewise",e.defaultOption=Lo(rp.defaultOption,{selected:null,minOpen:!1,maxOpen:!1,align:"auto",itemWidth:20,itemHeight:14,itemSymbol:"roundRect",pieces:null,categories:null,splitNumber:5,selectedMode:"multiple",itemGap:10,hoverLink:!0}),e}(rp),iit={splitNumber:function(r){var e=this.option,t=Math.min(e.precision,20),n=this.getExtent(),a=e.splitNumber;a=Math.max(parseInt(a,10),1),e.splitNumber=a;for(var i=(n[1]-n[0])/a;+i.toFixed(t)!==i&&t<5;)t++;e.precision=t,i=+i.toFixed(t),e.minOpen&&r.push({interval:[-1/0,n[0]],close:[0,0]});for(var o=0,s=n[0];o<a;s+=i,o++){var l=o===a-1?n[1]:s+i;r.push({interval:[s,l],close:[1,1]})}e.maxOpen&&r.push({interval:[n[1],1/0],close:[0,0]}),j2(r),B(r,function(u,c){u.index=c,u.text=this.formatValueText(u.interval)},this)},categories:function(r){var e=this.option;B(e.categories,function(t){r.push({text:this.formatValueText(t,!0),value:t})},this),rI(e,r)},pieces:function(r){var e=this.option;B(e.pieces,function(t,n){Vt(t)||(t={value:t});var a={text:"",index:n};if(t.label!=null&&(a.text=t.label),t.hasOwnProperty("value")){var i=a.value=t.value;a.interval=[i,i],a.close=[1,1]}else{for(var o=a.interval=[],s=a.close=[0,0],l=[1,0,1],u=[-1/0,1/0],c=[],h=0;h<2;h++){for(var d=[["gte","gt","min"],["lte","lt","max"]][h],v=0;v<3&&o[h]==null;v++)o[h]=t[d[v]],s[h]=l[v],c[h]=v===2;o[h]==null&&(o[h]=u[h])}c[0]&&o[1]===1/0&&(s[0]=0),c[1]&&o[0]===-1/0&&(s[1]=0),o[0]===o[1]&&s[0]&&s[1]&&(a.value=o[0])}a.visual=mr.retrieveVisuals(t),r.push(a)},this),rI(e,r),j2(r),B(r,function(t){var n=t.close,a=[["<","≤"][n[1]],[">","≥"][n[0]]];t.text=t.text||this.formatValueText(t.value!=null?t.value:t.interval,!1,a)},this)}};function rI(r,e){var t=r.inverse;(r.orient==="vertical"?!t:t)&&e.reverse()}var oit=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type=e.type,t}return e.prototype.doRender=function(){var t=this.group;t.removeAll();var n=this.visualMapModel,a=n.get("textGap"),i=n.textStyleModel,o=i.getFont(),s=i.getTextColor(),l=this._getItemAlign(),u=n.itemSize,c=this._getViewData(),h=c.endsText,d=Ar(n.get("showLabel",!0),!h),v=!n.get("selectedMode");h&&this._renderEndsText(t,h[0],u,d,l),B(c.viewPieceList,function(p){var y=p.piece,_=new Wt;_.onclick=Mt(this._onItemClick,this,y),this._enableHoverLink(_,p.indexInModelPieceList);var g=n.getRepresentValue(y);if(this._createItemSymbol(_,g,[0,0,u[0],u[1]],v),d){var f=this.visualMapModel.getValueState(g);_.add(new pe({style:{x:l==="right"?-a:u[0]+a,y:u[1]/2,text:y.text,verticalAlign:"middle",align:l,font:o,fill:s,opacity:f==="outOfRange"?.5:1},silent:v}))}t.add(_)},this),h&&this._renderEndsText(t,h[1],u,d,l),ks(n.get("orient"),t,n.get("itemGap")),this.renderBackground(t),this.positionGroup(t)},e.prototype._enableHoverLink=function(t,n){var a=this;t.on("mouseover",function(){return i("highlight")}).on("mouseout",function(){return i("downplay")});var i=function(o){var s=a.visualMapModel;s.option.hoverLink&&a.api.dispatchAction({type:o,batch:cd(s.findTargetDataIndices(n),s)})}},e.prototype._getItemAlign=function(){var t=this.visualMapModel,n=t.option;if(n.orient==="vertical")return iB(t,this.api,t.itemSize);var a=n.align;return(!a||a==="auto")&&(a="left"),a},e.prototype._renderEndsText=function(t,n,a,i,o){if(n){var s=new Wt,l=this.visualMapModel.textStyleModel;s.add(new pe({style:Fe(l,{x:i?o==="right"?a[0]:0:a[0]/2,y:a[1]/2,verticalAlign:"middle",align:i?o:"center",text:n})})),t.add(s)}},e.prototype._getViewData=function(){var t=this.visualMapModel,n=ft(t.getPieceList(),function(s,l){return{piece:s,indexInModelPieceList:l}}),a=t.get("text"),i=t.get("orient"),o=t.get("inverse");return(i==="horizontal"?o:!o)?n.reverse():a&&(a=a.slice().reverse()),{viewPieceList:n,endsText:a}},e.prototype._createItemSymbol=function(t,n,a,i){var o=or(this.getControllerVisual(n,"symbol"),a[0],a[1],a[2],a[3],this.getControllerVisual(n,"color"));o.silent=i,t.add(o)},e.prototype._onItemClick=function(t){var n=this.visualMapModel,a=n.option,i=a.selectedMode;if(i){var o=Gt(a.selected),s=n.getSelectedMapKey(t);i==="single"||i===!0?(o[s]=!0,B(o,function(l,u){o[u]=u===s})):o[s]=!o[s],this.api.dispatchAction({type:"selectDataRange",from:this.uid,visualMapId:this.visualMapModel.id,selected:o})}},e.type="visualMap.piecewise",e}(aB);function lB(r){r.registerComponentModel(ait),r.registerComponentView(oit),oB(r)}function sit(r){ne(sB),ne(lB)}var lit={label:{enabled:!0},decal:{show:!1}},nI=ve(),uit={};function cit(r,e){var t=r.getModel("aria");if(!t.get("enabled"))return;var n=Gt(lit);qt(n.label,r.getLocaleModel().get("aria"),!1),qt(t.option,n,!1),a(),i();function a(){var u=t.getModel("decal"),c=u.get("show");if(c){var h=Pt();r.eachSeries(function(d){if(!d.isColorBySeries()){var v=h.get(d.type);v||(v={},h.set(d.type,v)),nI(d).scope=v}}),r.eachRawSeries(function(d){if(r.isSeriesFiltered(d))return;if(Nt(d.enableAriaDecal)){d.enableAriaDecal();return}var v=d.getData();if(d.isColorBySeries()){var f=L_(d.ecModel,d.name,uit,r.getSeriesCount()),w=v.getVisual("decal");v.setVisual("decal",x(w,f))}else{var p=d.getRawData(),y={},_=nI(d).scope;v.each(function(S){var A=v.getRawIndex(S);y[A]=S});var g=p.count();p.each(function(S){var A=y[S],T=p.getName(S)||S+"",L=L_(d.ecModel,T,_,g),M=v.getItemVisual(A,"decal");v.setItemVisual(A,"decal",x(M,L))})}function x(S,A){var T=S?lt(lt({},A),S):A;return T.dirty=!0,T}})}}function i(){var u=e.getZr().dom;if(u){var c=r.getLocaleModel().get("aria"),h=t.getModel("label");if(h.option=zt(h.option,c),!!h.get("enabled")){if(u.setAttribute("role","img"),h.get("description")){u.setAttribute("aria-label",h.get("description"));return}var d=r.getSeriesCount(),v=h.get(["data","maxCount"])||10,p=h.get(["series","maxCount"])||10,y=Math.min(d,p),_;if(!(d<1)){var g=s();if(g){var f=h.get(["general","withTitle"]);_=o(f,{title:g})}else _=h.get(["general","withoutTitle"]);var w=[],x=d>1?h.get(["series","multiple","prefix"]):h.get(["series","single","prefix"]);_+=o(x,{seriesCount:d}),r.eachSeries(function(L,M){if(M<y){var I=void 0,R=L.get("name"),P=R?"withName":"withoutName";I=d>1?h.get(["series","multiple",P]):h.get(["series","single",P]),I=o(I,{seriesId:L.seriesIndex,seriesName:L.get("name"),seriesType:l(L.subType)});var E=L.getData();if(E.count()>v){var D=h.get(["data","partialData"]);I+=o(D,{displayCnt:v})}else I+=h.get(["data","allData"]);for(var N=h.get(["data","separator","middle"]),V=h.get(["data","separator","end"]),W=h.get(["data","excludeDimensionId"]),$=[],H=0;H<E.count();H++)if(H<v){var K=E.getName(H),U=W?Te(E.getValues(H),function(ut,ot){return te(W,ot)===-1}):E.getValues(H),j=h.get(["data",K?"withName":"withoutName"]);$.push(o(j,{name:K,value:U.join(N)}))}I+=$.join(N)+V,w.push(I)}});var S=h.getModel(["series","multiple","separator"]),A=S.get("middle"),T=S.get("end");_+=w.join(A)+T,u.setAttribute("aria-label",_)}}}}function o(u,c){if(!Lt(u))return u;var h=u;return B(c,function(d,v){h=h.replace(new RegExp("\\{\\s*"+v+"\\s*\\}","g"),d)}),h}function s(){var u=r.get("title");return u&&u.length&&(u=u[0]),u&&u.text}function l(u){var c=r.getLocaleModel().get(["series","typeNames"]);return c[u]||c.chart}}function hit(r){if(!(!r||!r.aria)){var e=r.aria;e.show!=null&&(e.enabled=e.show),e.label=e.label||{},B(["description","general","series","data"],function(t){e[t]!=null&&(e.label[t]=e[t])})}}function fit(r){r.registerPreprocessor(hit),r.registerVisual(r.PRIORITY.VISUAL.ARIA,cit)}var aI={value:"eq","<":"lt","<=":"lte",">":"gt",">=":"gte","=":"eq","!=":"ne","<>":"ne"},vit=function(){function r(e){var t=this._condVal=Lt(e)?new RegExp(e):S6(e)?e:null;if(t==null){var n="";Ae(n)}}return r.prototype.evaluate=function(e){var t=typeof e;return Lt(t)?this._condVal.test(e):ye(t)?this._condVal.test(e+""):!1},r}(),dit=function(){function r(){}return r.prototype.evaluate=function(){return this.value},r}(),pit=function(){function r(){}return r.prototype.evaluate=function(){for(var e=this.children,t=0;t<e.length;t++)if(!e[t].evaluate())return!1;return!0},r}(),git=function(){function r(){}return r.prototype.evaluate=function(){for(var e=this.children,t=0;t<e.length;t++)if(e[t].evaluate())return!0;return!1},r}(),yit=function(){function r(){}return r.prototype.evaluate=function(){return!this.child.evaluate()},r}(),mit=function(){function r(){}return r.prototype.evaluate=function(){for(var e=!!this.valueParser,t=this.getValue,n=t(this.valueGetterParam),a=e?this.valueParser(n):null,i=0;i<this.subCondList.length;i++)if(!this.subCondList[i].evaluate(e?a:n))return!1;return!0},r}();function Gx(r,e){if(r===!0||r===!1){var t=new dit;return t.value=r,t}var n="";return uB(r)||Ae(n),r.and?iI("and",r,e):r.or?iI("or",r,e):r.not?_it(r,e):wit(r,e)}function iI(r,e,t){var n=e[r],a="";ht(n)||Ae(a),n.length||Ae(a);var i=r==="and"?new pit:new git;return i.children=ft(n,function(o){return Gx(o,t)}),i.children.length||Ae(a),i}function _it(r,e){var t=r.not,n="";uB(t)||Ae(n);var a=new yit;return a.child=Gx(t,e),a.child||Ae(n),a}function wit(r,e){for(var t="",n=e.prepareGetValue(r),a=[],i=ue(r),o=r.parser,s=o?Uk(o):null,l=0;l<i.length;l++){var u=i[l];if(!(u==="parser"||e.valueGetterAttrMap.get(u))){var c=It(aI,u)?aI[u]:u,h=r[u],d=s?s(h):h,v=o7(c,d)||c==="reg"&&new vit(d);v||Ae(t),a.push(v)}}a.length||Ae(t);var p=new mit;return p.valueGetterParam=n,p.valueParser=s,p.getValue=e.getValue,p.subCondList=a,p}function uB(r){return Vt(r)&&!Gr(r)}var xit=function(){function r(e,t){this._cond=Gx(e,t)}return r.prototype.evaluate=function(){return this._cond.evaluate()},r}();function bit(r,e){return new xit(r,e)}var Sit={type:"echarts:filter",transform:function(r){for(var e=r.upstream,t,n=bit(r.config,{valueGetterAttrMap:Pt({dimension:!0}),prepareGetValue:function(s){var l="",u=s.dimension;It(s,"dimension")||Ae(l);var c=e.getDimensionInfo(u);return c||Ae(l),{dimIdx:c.index}},getValue:function(s){return e.retrieveValueFromItem(t,s.dimIdx)}}),a=[],i=0,o=e.count();i<o;i++)t=e.getRawDataItem(i),n.evaluate()&&a.push(t);return{data:a}}},Ait={type:"echarts:sort",transform:function(r){var e=r.upstream,t=r.config,n="",a=Ie(t);a.length||Ae(n);var i=[];B(a,function(c){var h=c.dimension,d=c.order,v=c.parser,p=c.incomparable;if(h==null&&Ae(n),d!=="asc"&&d!=="desc"&&Ae(n),p&&p!=="min"&&p!=="max"){var y="";Ae(y)}if(d!=="asc"&&d!=="desc"){var _="";Ae(_)}var g=e.getDimensionInfo(h);g||Ae(n);var f=v?Uk(v):null;v&&!f&&Ae(n),i.push({dimIdx:g.index,parser:f,comparator:new Yk(d,p)})});var o=e.sourceFormat;o!==Wr&&o!==na&&Ae(n);for(var s=[],l=0,u=e.count();l<u;l++)s.push(e.getRawDataItem(l));return s.sort(function(c,h){for(var d=0;d<i.length;d++){var v=i[d],p=e.retrieveValueFromItem(c,v.dimIdx),y=e.retrieveValueFromItem(h,v.dimIdx);v.parser&&(p=v.parser(p),y=v.parser(y));var _=v.comparator.evaluate(p,y);if(_!==0)return _}return 0}),{data:s}}};function Tit(r){r.registerTransform(Sit),r.registerTransform(Ait)}var Cit=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="dataset",t}return e.prototype.init=function(t,n,a){r.prototype.init.call(this,t,n,a),this._sourceManager=new qk(this),sT(this)},e.prototype.mergeOption=function(t,n){r.prototype.mergeOption.call(this,t,n),sT(this)},e.prototype.optionUpdated=function(){this._sourceManager.dirty()},e.prototype.getSourceManager=function(){return this._sourceManager},e.type="dataset",e.defaultOption={seriesLayoutBy:Ua},e}(le),Lit=function(r){rt(e,r);function e(){var t=r!==null&&r.apply(this,arguments)||this;return t.type="dataset",t}return e.type="dataset",e}(Ze);function Mit(r){r.registerComponentModel(Cit),r.registerComponentView(Lit)}var ka=ja.CMD;function Wl(r,e){return Math.abs(r-e)<1e-5}function M1(r){var e=r.data,t=r.len(),n=[],a,i=0,o=0,s=0,l=0;function u(E,D){a&&a.length>2&&n.push(a),a=[E,D]}function c(E,D,N,V){Wl(E,N)&&Wl(D,V)||a.push(E,D,N,V,N,V)}function h(E,D,N,V,W,$){var H=Math.abs(D-E),K=Math.tan(H/4)*4/3,U=D<E?-1:1,j=Math.cos(E),ut=Math.sin(E),ot=Math.cos(D),it=Math.sin(D),Et=j*W+N,jt=ut*$+V,bt=ot*W+N,wt=it*$+V,Ot=W*K*U,xt=$*K*U;a.push(Et-Ot*ut,jt+xt*j,bt+Ot*it,wt-xt*ot,bt,wt)}for(var d,v,p,y,_=0;_<t;){var g=e[_++],f=_===1;switch(f&&(i=e[_],o=e[_+1],s=i,l=o,(g===ka.L||g===ka.C||g===ka.Q)&&(a=[s,l])),g){case ka.M:i=s=e[_++],o=l=e[_++],u(s,l);break;case ka.L:d=e[_++],v=e[_++],c(i,o,d,v),i=d,o=v;break;case ka.C:a.push(e[_++],e[_++],e[_++],e[_++],i=e[_++],o=e[_++]);break;case ka.Q:d=e[_++],v=e[_++],p=e[_++],y=e[_++],a.push(i+2/3*(d-i),o+2/3*(v-o),p+2/3*(d-p),y+2/3*(v-y),p,y),i=p,o=y;break;case ka.A:var w=e[_++],x=e[_++],S=e[_++],A=e[_++],T=e[_++],L=e[_++]+T;_+=1;var M=!e[_++];d=Math.cos(T)*S+w,v=Math.sin(T)*A+x,f?(s=d,l=v,u(s,l)):c(i,o,d,v),i=Math.cos(L)*S+w,o=Math.sin(L)*A+x;for(var I=(M?-1:1)*Math.PI/2,R=T;M?R>L:R<L;R+=I){var P=M?Math.max(R+I,L):Math.min(R+I,L);h(R,P,w,x,S,A)}break;case ka.R:s=i=e[_++],l=o=e[_++],d=s+e[_++],v=l+e[_++],u(d,l),c(d,l,d,v),c(d,v,s,v),c(s,v,s,l),c(s,l,d,l);break;case ka.Z:a&&c(i,o,s,l),i=s,o=l;break}}return a&&a.length>2&&n.push(a),n}function D1(r,e,t,n,a,i,o,s,l,u){if(Wl(r,t)&&Wl(e,n)&&Wl(a,o)&&Wl(i,s)){l.push(o,s);return}var c=2/u,h=c*c,d=o-r,v=s-e,p=Math.sqrt(d*d+v*v);d/=p,v/=p;var y=t-r,_=n-e,g=a-o,f=i-s,w=y*y+_*_,x=g*g+f*f;if(w<h&&x<h){l.push(o,s);return}var S=d*y+v*_,A=-d*g-v*f,T=w-S*S,L=x-A*A;if(T<h&&S>=0&&L<h&&A>=0){l.push(o,s);return}var M=[],I=[];wo(r,t,a,o,.5,M),wo(e,n,i,s,.5,I),D1(M[0],I[0],M[1],I[1],M[2],I[2],M[3],I[3],l,u),D1(M[4],I[4],M[5],I[5],M[6],I[6],M[7],I[7],l,u)}function Dit(r,e){var t=M1(r),n=[];e=e||1;for(var a=0;a<t.length;a++){var i=t[a],o=[],s=i[0],l=i[1];o.push(s,l);for(var u=2;u<i.length;){var c=i[u++],h=i[u++],d=i[u++],v=i[u++],p=i[u++],y=i[u++];D1(s,l,c,h,d,v,p,y,o,e),s=p,l=y}n.push(o)}return n}function cB(r,e,t){var n=r[e],a=r[1-e],i=Math.abs(n/a),o=Math.ceil(Math.sqrt(i*t)),s=Math.floor(t/o);s===0&&(s=1,o=t);for(var l=[],u=0;u<o;u++)l.push(s);var c=o*s,h=t-c;if(h>0)for(var u=0;u<h;u++)l[u%o]+=1;return l}function oI(r,e,t){for(var n=r.r0,a=r.r,i=r.startAngle,o=r.endAngle,s=Math.abs(o-i),l=s*a,u=a-n,c=l>Math.abs(u),h=cB([l,u],c?0:1,e),d=(c?s:u)/h.length,v=0;v<h.length;v++)for(var p=(c?u:s)/h[v],y=0;y<h[v];y++){var _={};c?(_.startAngle=i+d*v,_.endAngle=i+d*(v+1),_.r0=n+p*y,_.r=n+p*(y+1)):(_.startAngle=i+p*y,_.endAngle=i+p*(y+1),_.r0=n+d*v,_.r=n+d*(v+1)),_.clockwise=r.clockwise,_.cx=r.cx,_.cy=r.cy,t.push(_)}}function Iit(r,e,t){for(var n=r.width,a=r.height,i=n>a,o=cB([n,a],i?0:1,e),s=i?"width":"height",l=i?"height":"width",u=i?"x":"y",c=i?"y":"x",h=r[s]/o.length,d=0;d<o.length;d++)for(var v=r[l]/o[d],p=0;p<o[d];p++){var y={};y[u]=d*h,y[c]=p*v,y[s]=h,y[l]=v,y.x+=r.x,y.y+=r.y,t.push(y)}}function sI(r,e,t,n){return r*n-t*e}function Pit(r,e,t,n,a,i,o,s){var l=t-r,u=n-e,c=o-a,h=s-i,d=sI(c,h,l,u);if(Math.abs(d)<1e-6)return null;var v=r-a,p=e-i,y=sI(v,p,c,h)/d;return y<0||y>1?null:new Kt(y*l+r,y*u+e)}function kit(r,e,t){var n=new Kt;Kt.sub(n,t,e),n.normalize();var a=new Kt;Kt.sub(a,r,e);var i=a.dot(n);return i}function kl(r,e){var t=r[r.length-1];t&&t[0]===e[0]&&t[1]===e[1]||r.push(e)}function Rit(r,e,t){for(var n=r.length,a=[],i=0;i<n;i++){var o=r[i],s=r[(i+1)%n],l=Pit(o[0],o[1],s[0],s[1],e.x,e.y,t.x,t.y);l&&a.push({projPt:kit(l,e,t),pt:l,idx:i})}if(a.length<2)return[{points:r},{points:r}];a.sort(function(_,g){return _.projPt-g.projPt});var u=a[0],c=a[a.length-1];if(c.idx<u.idx){var h=u;u=c,c=h}for(var d=[u.pt.x,u.pt.y],v=[c.pt.x,c.pt.y],p=[d],y=[v],i=u.idx+1;i<=c.idx;i++)kl(p,r[i].slice());kl(p,v),kl(p,d);for(var i=c.idx+1;i<=u.idx+n;i++)kl(y,r[i%n].slice());return kl(y,d),kl(y,v),[{points:p},{points:y}]}function lI(r){var e=r.points,t=[],n=[];wp(e,t,n);var a=new Qt(t[0],t[1],n[0]-t[0],n[1]-t[1]),i=a.width,o=a.height,s=a.x,l=a.y,u=new Kt,c=new Kt;return i>o?(u.x=c.x=s+i/2,u.y=l,c.y=l+o):(u.y=c.y=l+o/2,u.x=s,c.x=s+i),Rit(e,u,c)}function np(r,e,t,n){if(t===1)n.push(e);else{var a=Math.floor(t/2),i=r(e);np(r,i[0],a,n),np(r,i[1],t-a,n)}return n}function Eit(r,e){for(var t=[],n=0;n<e;n++)t.push(aw(r));return t}function Oit(r,e){e.setStyle(r.style),e.z=r.z,e.z2=r.z2,e.zlevel=r.zlevel}function Bit(r){for(var e=[],t=0;t<r.length;)e.push([r[t++],r[t++]]);return e}function Nit(r,e){var t=[],n=r.shape,a;switch(r.type){case"rect":Iit(n,e,t),a=fe;break;case"sector":oI(n,e,t),a=en;break;case"circle":oI({r0:0,r:n.r,startAngle:0,endAngle:Math.PI*2,cx:n.cx,cy:n.cy},e,t),a=en;break;default:var i=r.getComputedTransform(),o=i?Math.sqrt(Math.max(i[0]*i[0]+i[1]*i[1],i[2]*i[2]+i[3]*i[3])):1,s=ft(Dit(r.getUpdatedPathProxy(),o),function(g){return Bit(g)}),l=s.length;if(l===0)np(lI,{points:s[0]},e,t);else if(l===e)for(var u=0;u<l;u++)t.push({points:s[u]});else{var c=0,h=ft(s,function(g){var f=[],w=[];wp(g,f,w);var x=(w[1]-f[1])*(w[0]-f[0]);return c+=x,{poly:g,area:x}});h.sort(function(g,f){return f.area-g.area});for(var d=e,u=0;u<l;u++){var v=h[u];if(d<=0)break;var p=u===l-1?d:Math.ceil(v.area/c*e);p<0||(np(lI,{points:v.poly},p,t),d-=p)}}a=rn;break}if(!a)return Eit(r,e);for(var y=[],u=0;u<t.length;u++){var _=new a;_.setShape(t[u]),Oit(r,_),y.push(_)}return y}function zit(r,e){var t=r.length,n=e.length;if(t===n)return[r,e];for(var a=[],i=[],o=t<n?r:e,s=Math.min(t,n),l=Math.abs(n-t)/6,u=(s-2)/6,c=Math.ceil(l/u)+1,h=[o[0],o[1]],d=l,v=2;v<s;){var p=o[v-2],y=o[v-1],_=o[v++],g=o[v++],f=o[v++],w=o[v++],x=o[v++],S=o[v++];if(d<=0){h.push(_,g,f,w,x,S);continue}for(var A=Math.min(d,c-1)+1,T=1;T<=A;T++){var L=T/A;wo(p,_,f,x,L,a),wo(y,g,w,S,L,i),p=a[3],y=i[3],h.push(a[1],i[1],a[2],i[2],p,y),_=a[5],g=i[5],f=a[6],w=i[6]}d-=A-1}return o===r?[h,e]:[r,h]}function uI(r,e){for(var t=r.length,n=r[t-2],a=r[t-1],i=[],o=0;o<e.length;)i[o++]=n,i[o++]=a;return i}function Fit(r,e){for(var t,n,a,i=[],o=[],s=0;s<Math.max(r.length,e.length);s++){var l=r[s],u=e[s],c=void 0,h=void 0;l?u?(t=zit(l,u),c=t[0],h=t[1],n=c,a=h):(h=uI(a||l,l),c=l):(c=uI(n||u,u),h=u),i.push(c),o.push(h)}return[i,o]}function cI(r){for(var e=0,t=0,n=0,a=r.length,i=0,o=a-2;i<a;o=i,i+=2){var s=r[o],l=r[o+1],u=r[i],c=r[i+1],h=s*c-u*l;e+=h,t+=(s+u)*h,n+=(l+c)*h}return e===0?[r[0]||0,r[1]||0]:[t/e/3,n/e/3,e]}function Vit(r,e,t,n){for(var a=(r.length-2)/6,i=1/0,o=0,s=r.length,l=s-2,u=0;u<a;u++){for(var c=u*6,h=0,d=0;d<s;d+=2){var v=d===0?c:(c+d-2)%l+2,p=r[v]-t[0],y=r[v+1]-t[1],_=e[d]-n[0],g=e[d+1]-n[1],f=_-p,w=g-y;h+=f*f+w*w}h<i&&(i=h,o=u)}return o}function Git(r){for(var e=[],t=r.length,n=0;n<t;n+=2)e[n]=r[t-n-2],e[n+1]=r[t-n-1];return e}function Wit(r,e,t,n){for(var a=[],i,o=0;o<r.length;o++){var s=r[o],l=e[o],u=cI(s),c=cI(l);i==null&&(i=u[2]<0!=c[2]<0);var h=[],d=[],v=0,p=1/0,y=[],_=s.length;i&&(s=Git(s));for(var g=Vit(s,l,u,c)*6,f=_-2,w=0;w<f;w+=2){var x=(g+w)%f+2;h[w+2]=s[x]-u[0],h[w+3]=s[x+1]-u[1]}h[0]=s[g]-u[0],h[1]=s[g+1]-u[1];for(var S=n/t,A=-n/2;A<=n/2;A+=S){for(var T=Math.sin(A),L=Math.cos(A),M=0,w=0;w<s.length;w+=2){var I=h[w],R=h[w+1],P=l[w]-c[0],E=l[w+1]-c[1],D=P*L-E*T,N=P*T+E*L;y[w]=D,y[w+1]=N;var V=D-I,W=N-R;M+=V*V+W*W}if(M<p){p=M,v=A;for(var $=0;$<y.length;$++)d[$]=y[$]}}a.push({from:h,to:d,fromCp:u,toCp:c,rotation:-v})}return a}function ap(r){return r.__isCombineMorphing}var hB="__mOriginal_";function ip(r,e,t){var n=hB+e,a=r[n]||r[e];r[n]||(r[n]=r[e]);var i=t.replace,o=t.after,s=t.before;r[e]=function(){var l=arguments,u;return s&&s.apply(this,l),i?u=i.apply(this,l):u=a.apply(this,l),o&&o.apply(this,l),u}}function Yc(r,e){var t=hB+e;r[t]&&(r[e]=r[t],r[t]=null)}function hI(r,e){for(var t=0;t<r.length;t++)for(var n=r[t],a=0;a<n.length;){var i=n[a],o=n[a+1];n[a++]=e[0]*i+e[2]*o+e[4],n[a++]=e[1]*i+e[3]*o+e[5]}}function fB(r,e){var t=r.getUpdatedPathProxy(),n=e.getUpdatedPathProxy(),a=Fit(M1(t),M1(n)),i=a[0],o=a[1],s=r.getComputedTransform(),l=e.getComputedTransform();function u(){this.transform=null}s&&hI(i,s),l&&hI(o,l),ip(e,"updateTransform",{replace:u}),e.transform=null;var c=Wit(i,o,10,Math.PI),h=[];ip(e,"buildPath",{replace:function(d){for(var v=e.__morphT,p=1-v,y=[],_=0;_<c.length;_++){var g=c[_],f=g.from,w=g.to,x=g.rotation*v,S=g.fromCp,A=g.toCp,T=Math.sin(x),L=Math.cos(x);Yv(y,S,A,v);for(var M=0;M<f.length;M+=2){var I=f[M],R=f[M+1],P=w[M],E=w[M+1],D=I*p+P*v,N=R*p+E*v;h[M]=D*L-N*T+y[0],h[M+1]=D*T+N*L+y[1]}var V=h[0],W=h[1];d.moveTo(V,W);for(var M=2;M<f.length;){var P=h[M++],E=h[M++],$=h[M++],H=h[M++],K=h[M++],U=h[M++];V===P&&W===E&&$===K&&H===U?d.lineTo(K,U):d.bezierCurveTo(P,E,$,H,K,U),V=K,W=U}}}})}function Wx(r,e,t){if(!r||!e)return e;var n=t.done,a=t.during;fB(r,e),e.__morphT=0;function i(){Yc(e,"buildPath"),Yc(e,"updateTransform"),e.__morphT=-1,e.createPathProxy(),e.dirtyShape()}return e.animateTo({__morphT:1},zt({during:function(o){e.dirtyShape(),a&&a(o)},done:function(){i(),n&&n()}},t)),e}function Hit(r,e,t,n,a,i){var o=16;r=a===t?0:Math.round(32767*(r-t)/(a-t)),e=i===n?0:Math.round(32767*(e-n)/(i-n));for(var s=0,l,u=(1<<o)/2;u>0;u/=2){var c=0,h=0;(r&u)>0&&(c=1),(e&u)>0&&(h=1),s+=u*u*(3*c^h),h===0&&(c===1&&(r=u-1-r,e=u-1-e),l=r,r=e,e=l)}return s}function op(r){var e=1/0,t=1/0,n=-1/0,a=-1/0,i=ft(r,function(s){var l=s.getBoundingRect(),u=s.getComputedTransform(),c=l.x+l.width/2+(u?u[4]:0),h=l.y+l.height/2+(u?u[5]:0);return e=Math.min(c,e),t=Math.min(h,t),n=Math.max(c,n),a=Math.max(h,a),[c,h]}),o=ft(i,function(s,l){return{cp:s,z:Hit(s[0],s[1],e,t,n,a),path:r[l]}});return o.sort(function(s,l){return s.z-l.z}).map(function(s){return s.path})}function vB(r){return Nit(r.path,r.count)}function I1(){return{fromIndividuals:[],toIndividuals:[],count:0}}function Uit(r,e,t){var n=[];function a(S){for(var A=0;A<S.length;A++){var T=S[A];ap(T)?a(T.childrenRef()):T instanceof ie&&n.push(T)}}a(r);var i=n.length;if(!i)return I1();var o=t.dividePath||vB,s=o({path:e,count:i});if(s.length!==i)return console.error("Invalid morphing: unmatched splitted path"),I1();n=op(n),s=op(s);for(var l=t.done,u=t.during,c=t.individualDelay,h=new gi,d=0;d<i;d++){var v=n[d],p=s[d];p.parent=e,p.copyTransform(h),c||fB(v,p)}e.__isCombineMorphing=!0,e.childrenRef=function(){return s};function y(S){for(var A=0;A<s.length;A++)s[A].addSelfToZr(S)}ip(e,"addSelfToZr",{after:function(S){y(S)}}),ip(e,"removeSelfFromZr",{after:function(S){for(var A=0;A<s.length;A++)s[A].removeSelfFromZr(S)}});function _(){e.__isCombineMorphing=!1,e.__morphT=-1,e.childrenRef=null,Yc(e,"addSelfToZr"),Yc(e,"removeSelfFromZr")}var g=s.length;if(c)for(var f=g,w=function(){f--,f===0&&(_(),l&&l())},d=0;d<g;d++){var x=c?zt({delay:(t.delay||0)+c(d,g,n[d],s[d]),done:w},t):t;Wx(n[d],s[d],x)}else e.__morphT=0,e.animateTo({__morphT:1},zt({during:function(S){for(var A=0;A<g;A++){var T=s[A];T.__morphT=e.__morphT,T.dirtyShape()}u&&u(S)},done:function(){_();for(var S=0;S<r.length;S++)Yc(r[S],"updateTransform");l&&l()}},t));return e.__zr&&y(e.__zr),{fromIndividuals:n,toIndividuals:s,count:g}}function Zit(r,e,t){var n=e.length,a=[],i=t.dividePath||vB;function o(v){for(var p=0;p<v.length;p++){var y=v[p];ap(y)?o(y.childrenRef()):y instanceof ie&&a.push(y)}}if(ap(r)){o(r.childrenRef());var s=a.length;if(s<n)for(var l=0,u=s;u<n;u++)a.push(aw(a[l++%s]));a.length=n}else{a=i({path:r,count:n});for(var c=r.getComputedTransform(),u=0;u<a.length;u++)a[u].setLocalTransform(c);if(a.length!==n)return console.error("Invalid morphing: unmatched splitted path"),I1()}a=op(a),e=op(e);for(var h=t.individualDelay,u=0;u<n;u++){var d=h?zt({delay:(t.delay||0)+h(u,n,a[u],e[u])},t):t;Wx(a[u],e[u],d)}return{fromIndividuals:a,toIndividuals:e,count:e.length}}function fI(r){return ht(r[0])}function vI(r,e){for(var t=[],n=r.length,a=0;a<n;a++)t.push({one:r[a],many:[]});for(var a=0;a<e.length;a++){var i=e[a].length,o=void 0;for(o=0;o<i;o++)t[o%n].many.push(e[a][o])}for(var s=0,a=n-1;a>=0;a--)if(!t[a].many.length){var l=t[s].many;if(l.length<=1)if(s)s=0;else return t;var i=l.length,u=Math.ceil(i/2);t[a].many=l.slice(u,i),t[s].many=l.slice(0,u),s++}return t}var Yit={clone:function(r){for(var e=[],t=1-Math.pow(1-r.path.style.opacity,1/r.count),n=0;n<r.count;n++){var a=aw(r.path);a.setStyle("opacity",t),e.push(a)}return e},split:null};function P0(r,e,t,n,a,i){if(!r.length||!e.length)return;var o=vu("update",n,a);if(!(o&&o.duration>0))return;var s=n.getModel("universalTransition").get("delay"),l=Object.assign({setToFinal:!0},o),u,c;fI(r)&&(u=r,c=e),fI(e)&&(u=e,c=r);function h(g,f,w,x,S){var A=g.many,T=g.one;if(A.length===1&&!S){var L=f?A[0]:T,M=f?T:A[0];if(ap(L))h({many:[L],one:M},!0,w,x,!0);else{var I=s?zt({delay:s(w,x)},l):l;Wx(L,M,I),i(L,M,L,M,I)}}else for(var R=zt({dividePath:Yit[t],individualDelay:s&&function(W,$,H,K){return s(W+w,x)}},l),P=f?Uit(A,T,R):Zit(T,A,R),E=P.fromIndividuals,D=P.toIndividuals,N=E.length,V=0;V<N;V++){var I=s?zt({delay:s(V,N)},l):l;i(E[V],D[V],f?A[V]:g.one,f?g.one:A[V],I)}}for(var d=u?u===r:r.length>e.length,v=u?vI(c,u):vI(d?e:r,[d?r:e]),p=0,y=0;y<v.length;y++)p+=v[y].many.length;for(var _=0,y=0;y<v.length;y++)h(v[y],d,_,p),_+=v[y].many.length}function vs(r){if(!r)return[];if(ht(r)){for(var e=[],t=0;t<r.length;t++)e.push(vs(r[t]));return e}var n=[];return r.traverse(function(a){a instanceof ie&&!a.disableMorphing&&!a.invisible&&!a.ignore&&n.push(a)}),n}var dB=1e4,Xit=0,dI=1,pI=2,$it=ve();function jit(r,e){for(var t=r.dimensions,n=0;n<t.length;n++){var a=r.getDimensionInfo(t[n]);if(a&&a.otherDims[e]===0)return t[n]}}function qit(r,e,t){var n=r.getDimensionInfo(t),a=n&&n.ordinalMeta;if(n){var i=r.get(n.name,e);return a&&a.categories[i]||i+""}}function gI(r,e,t,n){var a=n?"itemChildGroupId":"itemGroupId",i=jit(r,a);if(i){var o=qit(r,e,i);return o}var s=r.getRawDataItem(e),l=n?"childGroupId":"groupId";if(s&&s[l])return s[l]+"";if(!n)return t||r.getId(e)}function yI(r){var e=[];return B(r,function(t){var n=t.data,a=t.dataGroupId;if(!(n.count()>dB))for(var i=n.getIndices(),o=0;o<i.length;o++)e.push({data:n,groupId:gI(n,o,a,!1),childGroupId:gI(n,o,a,!0),divide:t.divide,dataIndex:o})}),e}function k0(r,e,t){r.traverse(function(n){n instanceof ie&&He(n,{style:{opacity:0}},e,{dataIndex:t,isFrom:!0})})}function R0(r){if(r.parent){var e=r.getComputedTransform();r.setLocalTransform(e),r.parent.remove(r)}}function Rl(r){r.stopAnimation(),r.isGroup&&r.traverse(function(e){e.stopAnimation()})}function Kit(r,e,t){var n=vu("update",t,e);n&&r.traverse(function(a){if(a instanceof ta){var i=HH(a);i&&a.animateFrom({style:i},n)}})}function Qit(r,e){var t=r.length;if(t!==e.length)return!1;for(var n=0;n<t;n++){var a=r[n],i=e[n];if(a.data.getId(a.dataIndex)!==i.data.getId(i.dataIndex))return!1}return!0}function pB(r,e,t){var n=yI(r),a=yI(e);function i(w,x,S,A,T){(S||w)&&x.animateFrom({style:S&&S!==w?lt(lt({},S.style),w.style):w.style},T)}var o=!1,s=Xit,l=Pt(),u=Pt();n.forEach(function(w){w.groupId&&l.set(w.groupId,!0),w.childGroupId&&u.set(w.childGroupId,!0)});for(var c=0;c<a.length;c++){var h=a[c].groupId;if(u.get(h)){s=dI;break}var d=a[c].childGroupId;if(d&&l.get(d)){s=pI;break}}function v(w,x){return function(S){var A=S.data,T=S.dataIndex;return x?A.getId(T):w?s===dI?S.childGroupId:S.groupId:s===pI?S.childGroupId:S.groupId}}var p=Qit(n,a),y={};if(!p)for(var c=0;c<a.length;c++){var _=a[c],g=_.data.getItemGraphicEl(_.dataIndex);g&&(y[g.id]=!0)}function f(w,x){var S=n[x],A=a[w],T=A.data.hostModel,L=S.data.getItemGraphicEl(S.dataIndex),M=A.data.getItemGraphicEl(A.dataIndex);if(L===M){M&&Kit(M,A.dataIndex,T);return}L&&y[L.id]||M&&(Rl(M),L?(Rl(L),R0(L),o=!0,P0(vs(L),vs(M),A.divide,T,w,i)):k0(M,T,w))}new Li(n,a,v(!0,p),v(!1,p),null,"multiple").update(f).updateManyToOne(function(w,x){var S=a[w],A=S.data,T=A.hostModel,L=A.getItemGraphicEl(S.dataIndex),M=Te(ft(x,function(I){return n[I].data.getItemGraphicEl(n[I].dataIndex)}),function(I){return I&&I!==L&&!y[I.id]});L&&(Rl(L),M.length?(B(M,function(I){Rl(I),R0(I)}),o=!0,P0(vs(M),vs(L),S.divide,T,w,i)):k0(L,T,S.dataIndex))}).updateOneToMany(function(w,x){var S=n[x],A=S.data.getItemGraphicEl(S.dataIndex);if(!(A&&y[A.id])){var T=Te(ft(w,function(M){return a[M].data.getItemGraphicEl(a[M].dataIndex)}),function(M){return M&&M!==A}),L=a[w[0]].data.hostModel;T.length&&(B(T,function(M){return Rl(M)}),A?(Rl(A),R0(A),o=!0,P0(vs(A),vs(T),S.divide,L,w[0],i)):B(T,function(M){return k0(M,L,w[0])}))}}).updateManyToMany(function(w,x){new Li(x,w,function(S){return n[S].data.getId(n[S].dataIndex)},function(S){return a[S].data.getId(a[S].dataIndex)}).update(function(S,A){f(w[S],x[A])}).execute()}).execute(),o&&B(e,function(w){var x=w.data,S=x.hostModel,A=S&&t.getViewOfSeriesModel(S),T=vu("update",S,0);A&&S.isAnimationEnabled()&&T&&T.duration>0&&A.group.traverse(function(L){L instanceof ie&&!L.animators.length&&L.animateFrom({style:{opacity:0}},T)})})}function mI(r){var e=r.getModel("universalTransition").get("seriesKey");return e||r.id}function _I(r){return ht(r)?r.sort().join(","):r}function ro(r){if(r.hostModel)return r.hostModel.getModel("universalTransition").get("divideShape")}function Jit(r,e){var t=Pt(),n=Pt(),a=Pt();return B(r.oldSeries,function(i,o){var s=r.oldDataGroupIds[o],l=r.oldData[o],u=mI(i),c=_I(u);n.set(c,{dataGroupId:s,data:l}),ht(u)&&B(u,function(h){a.set(h,{key:c,dataGroupId:s,data:l})})}),B(e.updatedSeries,function(i){if(i.isUniversalTransitionEnabled()&&i.isAnimationEnabled()){var o=i.get("dataGroupId"),s=i.getData(),l=mI(i),u=_I(l),c=n.get(u);if(c)t.set(u,{oldSeries:[{dataGroupId:c.dataGroupId,divide:ro(c.data),data:c.data}],newSeries:[{dataGroupId:o,divide:ro(s),data:s}]});else if(ht(l)){var h=[];B(l,function(p){var y=n.get(p);y.data&&h.push({dataGroupId:y.dataGroupId,divide:ro(y.data),data:y.data})}),h.length&&t.set(u,{oldSeries:h,newSeries:[{dataGroupId:o,data:s,divide:ro(s)}]})}else{var d=a.get(l);if(d){var v=t.get(d.key);v||(v={oldSeries:[{dataGroupId:d.dataGroupId,data:d.data,divide:ro(d.data)}],newSeries:[]},t.set(d.key,v)),v.newSeries.push({dataGroupId:o,data:s,divide:ro(s)})}}}}),t}function wI(r,e){for(var t=0;t<r.length;t++){var n=e.seriesIndex!=null&&e.seriesIndex===r[t].seriesIndex||e.seriesId!=null&&e.seriesId===r[t].id;if(n)return t}}function tot(r,e,t,n){var a=[],i=[];B(Ie(r.from),function(o){var s=wI(e.oldSeries,o);s>=0&&a.push({dataGroupId:e.oldDataGroupIds[s],data:e.oldData[s],divide:ro(e.oldData[s]),groupIdDim:o.dimension})}),B(Ie(r.to),function(o){var s=wI(t.updatedSeries,o);if(s>=0){var l=t.updatedSeries[s].getData();i.push({dataGroupId:e.oldDataGroupIds[s],data:l,divide:ro(l),groupIdDim:o.dimension})}}),a.length>0&&i.length>0&&pB(a,i,n)}function eot(r){r.registerUpdateLifecycle("series:beforeupdate",function(e,t,n){B(Ie(n.seriesTransition),function(a){B(Ie(a.to),function(i){for(var o=n.updatedSeries,s=0;s<o.length;s++)(i.seriesIndex!=null&&i.seriesIndex===o[s].seriesIndex||i.seriesId!=null&&i.seriesId===o[s].id)&&(o[s][nd]=!0)})})}),r.registerUpdateLifecycle("series:transition",function(e,t,n){var a=$it(t);if(a.oldSeries&&n.updatedSeries&&n.optionChanged){var i=n.seriesTransition;if(i)B(Ie(i),function(v){tot(v,a,n,t)});else{var o=Jit(a,n);B(o.keys(),function(v){var p=o.get(v);pB(p.oldSeries,p.newSeries,t)})}B(n.updatedSeries,function(v){v[nd]&&(v[nd]=!1)})}for(var s=e.getSeries(),l=a.oldSeries=[],u=a.oldDataGroupIds=[],c=a.oldData=[],h=0;h<s.length;h++){var d=s[h].getData();d.count()<dB&&(l.push(s[h]),u.push(s[h].get("dataGroupId")),c.push(d))}})}ne([cX]);ne([iX]);ne([IX,ZX,e$,E$,Z$,Pj,iq,Wq,cK,gK,TK,_Q,UQ,eJ,yJ,xJ,PJ,zJ,jJ,ett,htt,$tt]);ne(det);ne(Vet);ne(v5);ne(Jet);ne(Q5);ne(nrt);ne(frt);ne(Jrt);ne(mnt);ne(Zh);ne(Ont);ne(znt);ne($nt);ne(eat);ne(sat);ne(vat);ne(Sat);ne(Gat);ne(eB);ne(rB);ne(sit);ne(sB);ne(lB);ne(fit);ne(Tit);ne(Mit);ne(eot);ne(TY);var hd=1;function hn(r){var e=60,t=62,n=45,a=47,i=33,o=39,s=34,l=63,u=`\r
	>/= `,c=0;return hd=1,gB(function h(){for(var d=[];r[c];){if(r.charCodeAt(c)==e){if(r.charCodeAt(c+1)===a)return c=r.indexOf(">",c),d;if(r.charCodeAt(c+1)===i){if(r.charCodeAt(c+2)==n){for(;r.charCodeAt(c)!==t||r.charCodeAt(c-1)!=n||r.charCodeAt(c-2)!=n||c==-1;)c=r.indexOf(">",c+1);c===-1&&(c=r.length)}else for(c+=2;r.charCodeAt(c)!==t;c++);c++;continue}if(r.charCodeAt(c+1)===l){c=r.indexOf(">",c),c++;continue}for(var v=++c;u.indexOf(r[c])===-1;c++);for(var p=r.slice(v,c),y=!1,_={};r.charCodeAt(c)!==t;c++){var g=r.charCodeAt(c);if(g>64&&g<91||g>96&&g<123){for(v=c;u.indexOf(r[c])===-1;c++);for(var f=r.slice(v,c),w=r.charCodeAt(c);w!==o&&w!==s;)c++,w=r.charCodeAt(c);var x=r[c],S=++c;c=r.indexOf(x,S);var A=r.slice(S,c);y||(_={},y=!0),_[f]=A}}var T=[];r.charCodeAt(c-1)!==a&&(c++,T=h()),d.push({children:T,tagName:p,attrs:_})}else{var L=c;(c=r.indexOf("<",c)-1)===-2&&(c=r.length);var M=r.slice(L,c+1);M.length>0&&d.push(M)}c++}return d}())}function gB(r){var e={};if(r===void 0)return{};if(r.length===1&&typeof r[0]=="string")return r[0];for(var t in r.forEach(function(n){if(e[n.tagName]||(e[n.tagName]=[]),typeof n=="object"){var a=gB(n.children);typeof a=="object"&&(n.attrs&&(a.attrs=n.attrs),a.attrs===void 0?a.attrs={order:hd}:a.attrs.order=hd),hd++,e[n.tagName].push(a)}}),e)e[t].length==1&&(e[t]=e[t][0]);return e}function Hl(r){return Math.abs(r)>2e4?"emu":"point"}function ke(r){return r/12700}function Oa(r){return r/20}function sp(r){return r/100}function Kp(r){return r/6e4}function no(r){return r/1e5}function E0(r){var e=Math.ceil(r/26),t=(r%26||26)-1+65;return String.fromCharCode(t).repeat(e)}function Ke(r,e,t){var n={type:"solidFill"};if(r["a:srgbClr"])n.color="#"+r["a:srgbClr"].attrs.val;else if(r["a:schemeClr"]){var a=r["a:schemeClr"].attrs.val;t&&(a=t.getColorThemeName(a)),n.color=e.getColor(a)}else if(r["a:sysClr"])n.color="#"+r["a:sysClr"].attrs.lastClr;else if(r["a:prstClr"]){var i=Y.get(r["a:prstClr"],["attrs","val"]);n.color=function(d){var v,p=["white","AliceBlue","AntiqueWhite","Aqua","Aquamarine","Azure","Beige","Bisque","black","BlanchedAlmond","Blue","BlueViolet","Brown","BurlyWood","CadetBlue","Chartreuse","Chocolate","Coral","CornflowerBlue","Cornsilk","Crimson","Cyan","DarkBlue","DarkCyan","DarkGoldenRod","DarkGray","DarkGrey","DarkGreen","DarkKhaki","DarkMagenta","DarkOliveGreen","DarkOrange","DarkOrchid","DarkRed","DarkSalmon","DarkSeaGreen","DarkSlateBlue","DarkSlateGray","DarkSlateGrey","DarkTurquoise","DarkViolet","DeepPink","DeepSkyBlue","DimGray","DimGrey","DodgerBlue","FireBrick","FloralWhite","ForestGreen","Fuchsia","Gainsboro","GhostWhite","Gold","GoldenRod","Gray","Grey","Green","GreenYellow","HoneyDew","HotPink","IndianRed","Indigo","Ivory","Khaki","Lavender","LavenderBlush","LawnGreen","LemonChiffon","LightBlue","LightCoral","LightCyan","LightGoldenRodYellow","LightGray","LightGrey","LightGreen","LightPink","LightSalmon","LightSeaGreen","LightSkyBlue","LightSlateGray","LightSlateGrey","LightSteelBlue","LightYellow","Lime","LimeGreen","Linen","Magenta","Maroon","MediumAquaMarine","MediumBlue","MediumOrchid","MediumPurple","MediumSeaGreen","MediumSlateBlue","MediumSpringGreen","MediumTurquoise","MediumVioletRed","MidnightBlue","MintCream","MistyRose","Moccasin","NavajoWhite","Navy","OldLace","Olive","OliveDrab","Orange","OrangeRed","Orchid","PaleGoldenRod","PaleGreen","PaleTurquoise","PaleVioletRed","PapayaWhip","PeachPuff","Peru","Pink","Plum","PowderBlue","Purple","RebeccaPurple","Red","RosyBrown","RoyalBlue","SaddleBrown","Salmon","SandyBrown","SeaGreen","SeaShell","Sienna","Silver","SkyBlue","SlateBlue","SlateGray","SlateGrey","Snow","SpringGreen","SteelBlue","Tan","Teal","Thistle","Tomato","Turquoise","Violet","Wheat","White","WhiteSmoke","Yellow","YellowGreen"],y=["ffffff","f0f8ff","faebd7","00ffff","7fffd4","f0ffff","f5f5dc","ffe4c4","000000","ffebcd","0000ff","8a2be2","a52a2a","deb887","5f9ea0","7fff00","d2691e","ff7f50","6495ed","fff8dc","dc143c","00ffff","00008b","008b8b","b8860b","a9a9a9","a9a9a9","006400","bdb76b","8b008b","556b2f","ff8c00","9932cc","8b0000","e9967a","8fbc8f","483d8b","2f4f4f","2f4f4f","00ced1","9400d3","ff1493","00bfff","696969","696969","1e90ff","b22222","fffaf0","228b22","ff00ff","dcdcdc","f8f8ff","ffd700","daa520","808080","808080","008000","adff2f","f0fff0","ff69b4","cd5c5c","4b0082","fffff0","f0e68c","e6e6fa","fff0f5","7cfc00","fffacd","add8e6","f08080","e0ffff","fafad2","d3d3d3","d3d3d3","90ee90","ffb6c1","ffa07a","20b2aa","87cefa","778899","778899","b0c4de","ffffe0","00ff00","32cd32","faf0e6","ff00ff","800000","66cdaa","0000cd","ba55d3","9370db","3cb371","7b68ee","00fa9a","48d1cc","c71585","191970","f5fffa","ffe4e1","ffe4b5","ffdead","000080","fdf5e6","808000","6b8e23","ffa500","ff4500","da70d6","eee8aa","98fb98","afeeee","db7093","ffefd5","ffdab9","cd853f","ffc0cb","dda0dd","b0e0e6","800080","663399","ff0000","bc8f8f","4169e1","8b4513","fa8072","f4a460","2e8b57","fff5ee","a0522d","c0c0c0","87ceeb","6a5acd","708090","708090","fffafa","00ff7f","4682b4","d2b48c","008080","d8bfd8","ff6347","40e0d0","ee82ee","f5deb3","ffffff","f5f5f5","ffff00","9acd32"],_=p.indexOf(d);return _!=-1&&(v=y[_]),"#".concat(v||"000000")}(i)}var o=r["a:srgbClr"]||r["a:schemeClr"]||r["a:sysClr"],s=Y.get(o,["a:alpha","attrs","val"],1e5);n.alpha=s/1e5;var l=Y.get(o,["a:shade","attrs","val"]);l&&(n.shade=l/1e5);var u=Y.get(o,["a:lumMod","attrs","val"]);u&&(n.lumMod=u/1e5);var c=Y.get(o,["a:lumOff","attrs","val"]);c&&(n.lumOff=c/1e5);var h=Y.get(o,["a:tint","attrs","val"]);return h&&(n.tint=h/1e5),n}function Yh(r,e,t){var n,a={type:"blipFill"},i=Y.get(r,["a:blip","attrs","r:embed"]);if(i){var o=(n=t.rels[i])===null||n===void 0?void 0:n.target;o&&(a.base64=e.getMedia(o))}var s=Y.get(r,["a:blip","a:alphaModFix","attrs","amt"]);s&&(a.alpha=s/1e5);var l=Y.get(r,["a:stretch","a:fillRect","attrs"]);return l&&(a.fillRect={},l.b&&(a.fillRect.b=l.b/1e5),l.t&&(a.fillRect.t=l.t/1e5),l.r&&(a.fillRect.r=l.r/1e5),l.l&&(a.fillRect.l=l.l/1e5)),a}function Xh(r,e,t){var n={type:"gradFill",tileRect:{},lin:{},gsList:[]};n.flip=r.attrs.flip,n.path=Y.get(r,["a:path","attrs","path"])||"linear",n.rotWithShape=r.attrs.rotWithShape==="1",Y.get(r,["a:lin","attrs","ang"])&&(n.lin.ang=Kp(r["a:lin"].attrs.ang)),Y.get(r,["a:lin","attrs","scaled"])&&(n.lin.scaled=r["a:lin"].attrs.scaled==="1");var a=Y.get(r,["a:gsLst","a:gs"])||[];return n.gsList=a.map(function(i){return{color:Ke(i,e,t),pos:no(i.attrs.pos)}}),Y.get(r,["a:tileRect","attrs","l"])&&(n.tileRect.l=no(r["a:tileRect"].attrs.l)),Y.get(r,["a:tileRect","attrs","t"])&&(n.tileRect.t=no(r["a:tileRect"].attrs.t)),Y.get(r,["a:tileRect","attrs","r"])&&(n.tileRect.r=no(r["a:tileRect"].attrs.r)),Y.get(r,["a:tileRect","attrs","b"])&&(n.tileRect.b=no(r["a:tileRect"].attrs.b)),n}function O0(r){return r<=.04045?r/12.92:Math.pow((r+.055)/1.055,2.4)}function B0(r){return r<.0031308?12.92*r:1.055*Math.pow(r,1/2.4)-.055}function xI(r,e){var t=r[0],n=r[1],a=r[2],i=O0(t/255)*e,o=O0(n/255)*e,s=O0(a/255)*e;return[Math.round(255*B0(i)),Math.round(255*B0(o)),Math.round(255*B0(s))]}function N0(r,e,t){var n=r/255,a=e/255,i=t/255,o=Math.max(n,a,i),s=Math.min(n,a,i),l=o-s,u=0,c=(o+s)/2;return l===0?u=0:o===n?u=(a-i)/l%6:o===a?u=(i-n)/l+2:o===i&&(u=(n-a)/l+4),(u=Math.round(60*u))<0&&(u+=360),{h:u,s:l===0||c===0||c===1?0:l/(1-Math.abs(2*c-1)),l:c}}function z0(r,e,t){var n,a,i,o=(1-Math.abs(2*t-1))*e,s=o*(1-Math.abs(r/60%2-1)),l=t-o/2;return r<60?(n=o,a=s,i=0):r<120?(n=s,a=o,i=0):r<180?(n=0,a=o,i=s):r<240?(n=0,a=s,i=o):r<300?(n=s,a=0,i=o):(n=o,a=0,i=s),[n=Math.round(255*(n+l)),a=Math.round(255*(a+l)),i=Math.round(255*(i+l))]}function Le(r,e){if(!r||r.type==="none")return"";if(r.type==="solidFill"&&/^#[\da-fA-F]{3,6}$/.test(r.color)){var t=parseInt(r.color.substr(1,2),16),n=parseInt(r.color.substr(3,2),16),a=parseInt(r.color.substr(5,2),16);if(r.shade){var i=xI([t,n,a],r.shade);t=i[0],n=i[1],a=i[2]}if(r.lumMod){var o=function(c,h,d,v){var p=N0(c,h,d),y=p.h,_=p.l*v;return _>=1&&(_=1),z0(y,p.s,_)}(t,n,a,r.lumMod);t=o[0],n=o[1],a=o[2]}if(r.lumOff&&(o=function(c,h,d,v){var p=N0(c,h,d),y=p.h,_=v+p.l;return _>1&&(_=1),z0(y,p.s,_)}(t,n,a,r.lumOff),t=o[0],n=o[1],a=o[2]),r.tint||e?.light){var s=function(c,h,d,v){var p=N0(c,h,d),y=p.h,_=p.l;return v>=1&&(v=1),z0(y,p.s,_*v+(1-v))}(t,n,a,r.tint||e?.light);t=s[0],n=s[1],a=s[2]}if(e?.dark){var l=xI([t,n,a],e?.dark);t=l[0],n=l[1],a=l[2]}var u=r.alpha;return"rgba(".concat(t,",").concat(n,",").concat(a,",").concat(u,")")}}var $h=function(){function r(e,t,n){var a,i;this.uuid=o6(),this.offset={x:0,y:0},this.extend={w:0,h:0},this.rotate=0,this.order=0,this.flipV=!1,this.flipH=!1,this.source=e,this.ctx=t,this.group=n;var o=Y.get(e,["p:nvSpPr","p:nvPr"]);if(o){var s=Y.get(o,"p:ph");s&&s.attrs&&(this.idx=s.attrs.idx,this.type=s.attrs.type),Y.get(o,["attrs","userDrawn"])&&(this.userDrawn=Y.get(o,["attrs","userDrawn"])==="1")}if(this.order=Y.get(e,"attrs.order",0),this.source["p:spPr"]){if(u=this.getXfrm()){var l=this.group&&(!((a=this.ctx.pptx)===null||a===void 0)&&a.wps||Hl(parseInt(u["a:off"].attrs.x))==="point")?Oa:ke;this.offset={x:Math.round(l(parseInt(u["a:off"].attrs.x))),y:Math.round(l(parseInt(u["a:off"].attrs.y)))},this.extend={w:Math.round(l(parseInt(u["a:ext"].attrs.cx))),h:Math.round(l(parseInt(u["a:ext"].attrs.cy||"0")))},this.rotate=Kp(parseInt(Y.get(u,"attrs.rot",0))),this.flipV=Y.get(u,"attrs.flipV")==="1",this.flipH=Y.get(u,"attrs.flipH")==="1"}}else if(this.source["p:xfrm"]){var u=this.source["p:xfrm"];l=this.group&&(!((i=this.ctx.pptx)===null||i===void 0)&&i.wps||Hl(parseInt(u["a:off"].attrs.x))==="point")?Oa:ke,this.offset={x:Math.round(l(parseInt(u["a:off"].attrs.x))),y:Math.round(l(parseInt(u["a:off"].attrs.y)))},this.extend={w:Math.round(l(parseInt(u["a:ext"].attrs.cx))),h:Math.round(l(parseInt(u["a:ext"].attrs.cy)))}}if(n){var c=n.extend,h=n.chExtend,d=n.chOffset,v=h.w===0?0:c.w/h.w,p=h.h===0?0:c.h/h.h;this.extend.w=this.extend.w*v,this.extend.h=this.extend.h*p,this.offset.x=(this.offset.x-d.x)*v,this.offset.y=(this.offset.y-d.y)*p}}return Object.defineProperty(r.prototype,"theme",{get:function(){return(this.ctx.sliderMaster||this.ctx).theme},enumerable:!1,configurable:!0}),r.prototype.getColorThemeName=function(e){return this.ctx.getColorThemeName(e)},r.prototype.getXfrm=function(){var e=this.source["p:spPr"]["a:xfrm"];return e||(this.idx?e=this.ctx.getNodeInheritAttrsByIdx(this.idx,["p:spPr","a:xfrm"]):this.type&&(e=this.ctx.getNodeInheritAttrsByType(this.type,["p:spPr","a:xfrm"]))),e},r}(),rot=function(){function r(e,t){this.props={},this.inheritProps={},this.source=e,this.node=t,this._getInheritBodyProps(),this._parseBodyProps(),this._parseLstStyle(),this._parseText()}return r.prototype._getInheritBodyProps=function(){var e,t=this.node.ctx,n=this.node.type,a=this.node.idx;if(n||a)switch(t.slideType){case"slideMaster":break;case"slideLayout":(e=n?t.slideMaster.getNodeByType(n):t.slideMaster.getNodeByIdx(a))&&(this.inheritProps=Y.get(e,["textBody","props"])||{});break;case"slide":(e=n?t.slideLayout.slideMaster.getNodeByType(n):t.slideLayout.slideMaster.getNodeByIdx(a))&&Object.assign(this.inheritProps,Y.get(e,["textBody","props"])||{}),(e=n?t.slideLayout.getNodeByType(n):t.slideLayout.getNodeByIdx(a))&&Object.assign(this.inheritProps,Y.get(e,["textBody","props"])||{})}},r.prototype._parseBodyProps=function(){var e=this,t=Y.get(this.source,["a:bodyPr","attrs"])||{};Object.keys(t).forEach(function(o){switch(o){case"anchor":e.props.anchor=t[o];break;case"rtlCol":e.props.rtlCol=t[o]==="1";break;case"lIns":case"rIns":case"tIns":case"bIns":e.props[o]=ke(parseInt(t[o]));break;case"order":break;default:e.props[o]=t[o]}});var n=Y.get(this.source,["a:bodyPr","a:normAutofit","attrs"]);if(n){this.props.normAutofit={};var a=n.fontScale;a&&(this.props.normAutofit.fontScale=no(parseInt(a)));var i=n.lnSpcReduction;i&&(this.props.normAutofit.lnSpcReduction=no(parseInt(i)))}},r.prototype._parseLstStyle=function(){var e=this,t={},n=Y.get(this.source,"a:lstStyle")||{};Object.keys(n).forEach(function(a){if(a.startsWith("a:")&&a.endsWith("pPr")){var i=a.substr(2,a.length-5);t[i]={props:e._formatPPr(n[a])};var o=Y.get(n[a],["a:defRPr"]);t[i].defRPr=e._formatRPr(o)}}),this.lstStyle=t},r.prototype._parseText=function(){var e=this,t=Y.get(this.source,["a:p"])||[];Array.isArray(t)||(t=[t]),this.paragraphs=t.map(function(n){return e._parseParagraph(n)})},r.prototype._parseParagraph=function(e){var t=this,n={props:{},inheritProps:{},inheritRProps:{},endParaRProps:{},rows:[]},a=Y.get(e,["a:pPr"])||{};n.props=this._formatPPr(a);var i=Y.get(e,["a:endParaRPr"]);n.endParaRProps=this._formatRPr(i);var o=Y.get(e,["a:r"])||[];Array.isArray(o)||(o=[o]);var s=Y.get(e,["a:br"])||[];return Array.isArray(s)||(s=[s]),(o=o.concat(s.map(function(l){return Dt({isBr:!0},l)}))).sort(function(l,u){return Y.get(l,["attrs","order"])-Y.get(u,["attrs","order"])}),n.rows=o.map(function(l){return t._parseRow(l)}),n.inheritProps=this._getInheritPProps(n.props.level),n.inheritRProps=this._getInheritRProps(n.props.level),n},r.prototype._getInheritPProps=function(e){e===void 0&&(e="0");var t,n={},a=this.node.ctx,i=this.node.type,o=this.node.idx;switch(a.slideType){case"slideMaster":this.node.isTextBox?Object.assign(n,Y.get(a.defaultTextStyle,["lvl".concat(e?+e+1:1),"props"])||{}):Object.assign(n,Y.get(a,["textStyles","otherStyle","lvl".concat(e?+e+1:1),"props"])||{});break;case"slideLayout":this.node.isTextBox?Object.assign(n,Y.get(a.slideMaster.defaultTextStyle,["lvl".concat(e?+e+1:1),"props"])||{}):Object.assign(n,Y.get(a.slideMaster,["textStyles","otherStyle","lvl".concat(e?+e+1:1),"props"])||{}),(i||o)&&(t=i?a.slideMaster.getNodeByType(i):a.slideMaster.getNodeByIdx(o))&&Object.assign(n,Y.get(t,["textBody","lstStyle","lvl".concat(e?+e+1:1),"props"])||{});break;case"slide":this.node.isTextBox?Object.assign(n,Y.get(a.slideLayout.slideMaster.defaultTextStyle,["lvl".concat(e?+e+1:1),"props"])||{}):Object.assign(n,Y.get(a.slideLayout.slideMaster,["textStyles","otherStyle","lvl".concat(e?+e+1:1),"props"])||{}),(i||o)&&(["subTitle","ctrTitle","title"].includes(i)&&Object.assign(n,Y.get(a.slideLayout.slideMaster,["textStyles","titleStyle","lvl".concat(e?+e+1:1),"props"])||{}),(t=i?a.slideLayout.slideMaster.getNodeByType(i):a.slideLayout.slideMaster.getNodeByIdx(o))&&Object.assign(n,Y.get(t,["textBody","lstStyle","lvl".concat(e?+e+1:1),"props"])||{}),(t=i?a.slideLayout.getNodeByType(i):a.slideLayout.getNodeByIdx(o))&&Object.assign(n,Y.get(t,["textBody","lstStyle","lvl".concat(e?+e+1:1),"props"])||{}))}return n},r.prototype._getInheritRProps=function(e){e===void 0&&(e="0");var t,n={},a=this.node.ctx,i=this.node.type,o=this.node.idx;switch(a.slideType){case"slideMaster":this.node.isTextBox?Object.assign(n,Y.get(a.defaultTextStyle,["lvl".concat(e?+e+1:1),"defRPr"])||{}):Object.assign(n,Y.get(a,["textStyles","otherStyle","lvl".concat(e?+e+1:1),"defRPr"])||{});break;case"slideLayout":this.node.isTextBox?Object.assign(n,Y.get(a.slideMaster.defaultTextStyle,["lvl".concat(e?+e+1:1),"defRPr"])||{}):Object.assign(n,Y.get(a.slideMaster,["textStyles","otherStyle","lvl".concat(e?+e+1:1),"defRPr"])||{}),(i||o)&&(t=i?a.slideMaster.getNodeByType(i):a.slideMaster.getNodeByIdx(o))&&(n=Y.get(t,["textBody","lstStyle","lvl".concat(e?+e+1:1),"defRPr"])||{});break;case"slide":this.node.isTextBox?Object.assign(n,Y.get(a.slideLayout.slideMaster.defaultTextStyle,["lvl".concat(e?+e+1:1),"defRPr"])||{}):Object.assign(n,Y.get(a.slideLayout.slideMaster,["textStyles","otherStyle","lvl".concat(e?+e+1:1),"defRPr"])||{}),(i||o)&&(["subTitle","ctrTitle","title"].includes(i)&&Object.assign(n,Y.get(a.slideLayout.slideMaster,["textStyles","titleStyle","lvl".concat(e?+e+1:1),"defRPr"])||{}),(t=i?a.slideLayout.slideMaster.getNodeByType(i):a.slideLayout.slideMaster.getNodeByIdx(o))&&Object.assign(n,Y.get(t,["textBody","lstStyle","lvl".concat(e?+e+1:1),"defRPr"])||{}),(t=i?a.slideLayout.getNodeByType(i):a.slideLayout.getNodeByIdx(o))&&Object.assign(n,Y.get(t,["textBody","lstStyle","lvl".concat(e?+e+1:1),"defRPr"])||{}))}var s=Y.get(this.node.source,["p:style","a:fontRef"]);return Y.get(s,"a:schemeClr")&&(n.color=Ke(s,this.node.theme,this.node)),Y.get(this.lstStyle,["lvl".concat(e?+e+1:1),"defRPr"])&&Object.assign(n,Y.get(this.lstStyle,["lvl".concat(e?+e+1:1),"defRPr"])),n},r.prototype._formatPPr=function(e){var t={},n=Y.get(e,"attrs")||{};return Object.keys(n).forEach(function(a){switch(a){case"algn":t.align=n[a];break;case"marL":t.marginLeft=ke(parseInt(n[a]));break;case"indent":t.indent=ke(parseInt(n[a]));break;case"lvl":t.level=n[a]}}),Y.get(e,["a:lnSpc","a:spcPct","attrs","val"])&&(t.lineHeight=parseInt(e["a:lnSpc"]["a:spcPct"].attrs.val)/1e5),Y.get(e,["a:buAutoNum","attrs","type"])&&(t.buAutoNum=e["a:buAutoNum"].attrs.type),Y.get(e,["a:buChar","attrs","char"])&&(t.buChar=e["a:buChar"].attrs.char),Y.get(e,["a:spcBef","a:spcPts","attrs","val"])&&(t.spaceBefore=sp(parseInt(e["a:spcBef"]["a:spcPts"].attrs.val))),Y.get(e,["a:spcAft","a:spcPts","attrs","val"])&&(t.spaceAfter=sp(parseInt(e["a:spcAft"]["a:spcPts"].attrs.val))),Y.get(e,["a:defRPr"])&&(t.defRPr=this._formatRPr(Y.get(e,["a:defRPr"]))),t},r.prototype._parseRow=function(e){if(e.isBr)return{isBr:!0};var t={props:{},text:""},n=Y.get(e,["a:rPr"])||{};return t.props=this._formatRPr(n),t.text=Y.get(e,"a:t")||"",t},r.prototype._formatRPr=function(e){var t={},n=Y.get(e,"attrs")||{};Object.keys(n).forEach(function(o){switch(o){case"sz":t.size=parseInt(n[o])/100;break;case"b":t.bold=n[o]==="1";break;case"i":t.italic=n[o]==="1";break;case"u":t.underline=n[o];break;case"strike":t.strike=n[o];break;case"order":case"dirty":break;default:t[o]=n[o]}});var a=Y.get(e,"a:solidFill");a&&(t.color=Ke(a,this.node.theme,this.node));var i=Y.get(e,"a:highlight");return i&&(t.background=Ke(i,this.node.theme,this.node)),t.typeface=Y.get(e,["a:ea","attrs","typeface"]),t},r}();function Ul(r,e,t){var n={};if(!Y.get(r,"a:noFill")){Y.get(r,"attrs.w")&&(n.width=ke(parseInt(Y.get(r,"attrs.w"))));var a=Y.get(r,"a:solidFill");a&&(n.color=Ke(a,e,t));var i=Y.get(r,"a:prstDash");if(i&&(n.type=i.attrs.val),Y.get(r,["a:miter"])&&(n.lineJoin="miter"),Y.get(r,["a:bevel"])&&(n.lineJoin="bevel"),Y.get(r,["a:round"])&&(n.lineJoin="round"),Y.get(r,["a:miter","attrs","lim"])&&(n.miterLim=ke(parseInt(Y.get(r,["a:miter","attrs","lim"])))),Y.get(r,["a:headEnd"])){var o=Y.get(r,["a:headEnd","attrs"]);n.headEnd={type:o.type,len:o.len,w:o.w}}if(Y.get(r,["a:tailEnd"])){var s=Y.get(r,["a:tailEnd","attrs"]);n.tailEnd={type:s.type,len:s.len,w:s.w}}return n}}var bh=function(r){function e(t,n,a,i){var o=r.call(this,t,a,i)||this;return o.border={},o.prstGeom={},o.isTextBox=!1,o.pptx=n,o._parseShape(),o._parIsTextBox(),o._parsePrstGeom(),o._parseBackground(),o._parseBorder(),o._parseTxt(),o}return Sh(e,r),e.prototype._parseShape=function(){if(this.shape=Y.get(this.source,["p:spPr","a:prstGeom","attrs","prst"]),!this.shape&&Y.get(this.source,["p:spPr","a:custGeom"])){this.shape="customGeom";var t=Y.get(this.source,["p:spPr","a:custGeom","a:pathLst","a:path"]),n=[],a=[],i=function(s){switch(s){case"a:moveTo":case"a:cubicBezTo":case"a:lnTo":a=Array.isArray(t[s])?t[s]:[t[s]],n=n.concat(a.map(function(l){return{order:l.attrs.order,type:s.split(":")[1],points:(Array.isArray(l["a:pt"])?l["a:pt"]:[l["a:pt"]]).map(function(u){return[ke(parseInt(Y.get(u,["attrs","x"]))),ke(parseInt(Y.get(u,["attrs","y"])))]})}}));break;case"a:close":a=Array.isArray(t[s])?t[s]:[t[s]],n=n.concat(a.map(function(l){return{order:l.attrs.order,type:s.split(":")[1]}}))}};for(var o in t)i(o);n.sort(function(s,l){return s.order-l.order}),this.prstGeom.pathList=n,Y.get(t,["attrs","w"])&&(this.prstGeom.w=ke(parseInt(Y.get(t,["attrs","w"])))),Y.get(t,["attrs","h"])&&(this.prstGeom.h=ke(parseInt(Y.get(t,["attrs","h"]))))}},e.prototype._parIsTextBox=function(){this.isTextBox=Y.get(this.source,["p:nvSpPr","p:cNvSpPr","attrs","txBox"])==="1"},e.prototype._parsePrstGeom=function(){var t=this,n=Y.get(this.source,["p:spPr","a:prstGeom"]),a=Y.get(n,["a:avLst","a:gd"]);a&&(Array.isArray(a)||(a=[a]),this.prstGeom.gd=a.map(function(i){var o=["pie","chord","arc"].includes(t.shape)||["blockArc"].includes(t.shape)&&["adj1","adj2"].includes(i.attrs.name)?Kp(parseInt(i.attrs.fmla.split(" ")[1])):no(parseInt(i.attrs.fmla.split(" ")[1]));return{name:i.attrs.name,fmla:o}}))},e.prototype._parseBackground=function(){if(!Y.get(this.source,["p:spPr","a:noFill"]))if(Y.get(this.source,["p:spPr","a:grpFill"])&&this.group)this.background=this.group.getBackground();else{var t=Y.get(this.source,["p:spPr","a:solidFill"]);if(t)this.background=Ke(t,this.theme,this);else{var n=Y.get(this.source,["p:spPr","a:gradFill"]);if(n)this.background=Xh(n,this.theme,this);else{var a=Y.get(this.source,["p:spPr","a:blipFill"]);if(a)this.background=Yh(a,this.pptx,this.ctx);else{var i=Y.get(this.source,["p:style","a:fillRef"]);i&&(this.background=Ke(i,this.theme,this))}}}}},e.prototype._parseBorder=function(){var t=Y.get(this.source,["p:style","a:lnRef"]);if(t){var n=parseInt(t.attrs.idx),a=this.theme.getLineStyle(n);this.border=Dt(Dt({},a),this.border),this.border.color&&this.border.color.color||(this.border.color=Ke(t,this.theme,this))}var i=Y.get(this.source,["p:spPr","a:ln"]);i&&Object.assign(this.border,Ul(i,this.theme,this)),this.border.color&&this.border.color.color&&!this.border.width&&(this.border.width=e.defaultBorderWidth)},e.prototype._parseTxt=function(){this.textBody=new rot(Y.get(this.source,["p:txBody"]),this)},e.defaultBorderWidth=.75,e}($h),lp=function(r){function e(t,n,a,i,o){var s,l,u=r.call(this,n,i,o)||this;u.userDrawn=!0,u.pptx=a,u.path=t;var c=Y.get(u.source,["p:blipFill","a:srcRect"]);c&&(u.clip={},c.attrs.b&&(u.clip.b=parseInt(c.attrs.b)/1e5),c.attrs.t&&(u.clip.t=parseInt(c.attrs.t)/1e5),c.attrs.l&&(u.clip.l=parseInt(c.attrs.l)/1e5),c.attrs.r&&(u.clip.r=parseInt(c.attrs.r)/1e5));var h=Y.get(n,["p:nvPicPr","p:nvPr","a:audioFile","attrs","r:link"]);if(h){var d=(s=u.ctx.rels[h])===null||s===void 0?void 0:s.target;u.audioFile=u.pptx.getMedia(d)}var v=Y.get(n,["p:nvPicPr","p:nvPr","a:videoFile","attrs","r:link"]);if(v){var p=(l=u.ctx.rels[v])===null||l===void 0?void 0:l.target;u.videoFile=u.pptx.getMedia(p)}return u}return Sh(e,r),Object.defineProperty(e.prototype,"base64",{get:function(){return this.pptx.getMedia(this.path)},enumerable:!1,configurable:!0}),e}($h),yB=function(r){function e(t,n,a,i){var o=r.call(this,t,a,i)||this;return o.userDrawn=!0,o.props={tableStyleId:""},o.tableGrid={gridCol:[]},o.tr=[],o.tableStyles={},o.pptx=n,o._parseTableProps(),o._parseTableGrid(),o._parseTr(),o._parseInheritStyles(),o}return Sh(e,r),Object.defineProperty(e.prototype,"slideMaster",{get:function(){return this.ctx.slideMaster||this.ctx},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"theme",{get:function(){return this.slideMaster.theme},enumerable:!1,configurable:!0}),e.prototype._parseTableProps=function(){var t=Y.get(this.source,["a:graphic","a:graphicData","a:tbl","a:tblPr"]);this.props.tableStyleId=Y.get(t,"a:tableStyleId"),this.tableStyles=Y.get(this.slideMaster.tableStyles,this.props.tableStyleId)||{},Y.get(t,["attrs","bandCol"])==="1"&&(this.props.bandCol=!0),Y.get(t,["attrs","bandRow"])==="1"&&(this.props.bandRow=!0),Y.get(t,["attrs","firstCol"])==="1"&&(this.props.firstCol=!0),Y.get(t,["attrs","firstRow"])==="1"&&(this.props.firstRow=!0),Y.get(t,["attrs","lastCol"])==="1"&&(this.props.lastCol=!0),Y.get(t,["attrs","lastRow"])==="1"&&(this.props.lastRow=!0)},e.prototype._parseTableGrid=function(){var t=Y.get(this.source,["a:graphic","a:graphicData","a:tbl","a:tblGrid","a:gridCol"]);if(t)for(var n=0;n<t.length;n++){var a=Y.get(t[n],["attrs","w"]);this.tableGrid.gridCol.push({width:ke(parseInt(a))})}},e.prototype._parseTr=function(){var t=[],n=Y.get(this.source,["a:graphic","a:graphicData","a:tbl","a:tr"]);Array.isArray(n)||(n=[n]);for(var a=0;a<n.length;a++){var i={props:{},td:[]},o=n[a];i.props.height=ke(parseInt(Y.get(o,["attrs","h"])));var s=Y.get(o,["a:tc"]);Array.isArray(s)||(s=[s]);for(var l=0;l<s.length;l++)i.td.push(this._parseTd(s[l]));t.push(i)}this.tr=t},e.prototype._parseTd=function(t){var n,a,i,o,s=this,l={props:{border:{}},paragraphs:[]},u=Y.get(t,["a:tcPr","attrs"]);u?.marB&&(l.props.marB=ke(parseInt(u?.marB))),u?.marT&&(l.props.marT=ke(parseInt(u?.marT))),u?.marL&&(l.props.marL=ke(parseInt(u?.marL))),u?.marR&&(l.props.marR=ke(parseInt(u?.marR))),u?.anchor&&(l.props.anchor=u?.anchor);var c=Y.get(t,["a:tcPr"]);Y.get(c,["a:lnR"])&&(l.props.border.right=Ul(Y.get(c,["a:lnR"]),this.theme,this.ctx)),Y.get(c,["a:lnL"])&&(l.props.border.left=Ul(Y.get(c,["a:lnL"]),this.theme,this.ctx)),Y.get(c,["a:lnT"])&&(l.props.border.top=Ul(Y.get(c,["a:lnT"]),this.theme,this.ctx)),Y.get(c,["a:lnB"])&&(l.props.border.bottom=Ul(Y.get(c,["a:lnB"]),this.theme,this.ctx)),!((n=t?.attrs)===null||n===void 0)&&n.rowSpan&&(l.props.rowSpan=parseInt(t.attrs.rowSpan)),!((a=t?.attrs)===null||a===void 0)&&a.gridSpan&&(l.props.gridSpan=parseInt(t.attrs.gridSpan)),!((i=t?.attrs)===null||i===void 0)&&i.vMerge&&(l.props.vMerge=t.attrs.vMerge==="1"),!((o=t?.attrs)===null||o===void 0)&&o.hMerge&&(l.props.hMerge=t.attrs.hMerge==="1");var h=Y.get(t,["a:tcPr","a:solidFill"]);h&&(l.props.background=Ke(h,this.theme,this.ctx));var d=Y.get(t,["a:txBody"]),v=Y.get(d,["a:p"]);return Array.isArray(v)||(v=[v]),l.paragraphs=v.map(function(p){return s._parseParagraph(p)}),l},e.prototype._parseParagraph=function(t){var n=this,a={props:{},inheritProps:{},inheritRProps:{},endParaRProps:{},rows:[]},i=Y.get(t,["a:pPr"])||{};a.props=this._formatPPr(i);var o=Y.get(t,["a:endParaRPr"]);a.endParaRProps=this._formatRPr(o);var s=Y.get(t,["a:r"])||[];Array.isArray(s)||(s=[s]);var l=Y.get(t,["a:br"])||[];return Array.isArray(l)||(l=[l]),(s=s.concat(l.map(function(u){return Dt({isBr:!0},u)}))).sort(function(u,c){return Y.get(u,["attrs","order"])-Y.get(c,["attrs","order"])}),a.rows=s.map(function(u){return n._parseRow(u)}),a},e.prototype._parseRow=function(t){if(t.isBr)return{isBr:!0};var n={props:{},text:""},a=Y.get(t,["a:rPr"])||{};return n.props=this._formatRPr(a),n.text=Y.get(t,"a:t")||"",n},e.prototype._formatPPr=function(t){var n={},a=Y.get(t,"attrs")||{};return Object.keys(a).forEach(function(i){i==="algn"&&(n.align=a[i])}),Y.get(t,["a:lnSpc","a:spcPct","attrs","val"])&&(n.lineHeight=parseInt(t["a:lnSpc"]["a:spcPct"].attrs.val)/1e5),Y.get(t,["a:buAutoNum","attrs","type"])&&(n.buAutoNum=t["a:buAutoNum"].attrs.type),Y.get(t,["a:buChar","attrs","char"])&&(n.buChar=t["a:buChar"].attrs.char),Y.get(t,["a:spcBef","a:spcPts","attrs","val"])&&(n.spaceBefore=sp(parseInt(t["a:spcBef"]["a:spcPts"].attrs.val))),Y.get(t,["a:spcAft","a:spcPts","attrs","val"])&&(n.spaceAfter=sp(parseInt(t["a:spcAft"]["a:spcPts"].attrs.val))),n},e.prototype._formatRPr=function(t){var n={},a=Y.get(t,"attrs")||{};Object.keys(a).forEach(function(s){switch(s){case"sz":n.size=parseInt(a[s])/100;break;case"b":n.bold=a[s]==="1";break;case"i":n.italic=a[s]==="1";break;case"u":n.underline=a[s];break;case"strike":n.strike=a[s];break;case"order":case"dirty":break;default:n[s]=a[s]}});var i=Y.get(t,"a:solidFill");i&&(n.color=Ke(i,this.theme,this.ctx));var o=Y.get(t,"a:highlight");return o&&(n.background=Ke(o,this.theme,this.ctx)),n.typeface=Y.get(t,["a:ea","attrs","typeface"]),n},e.prototype._isLastCol=function(t,n){var a,i;if(n===t.length-1)return!0;for(var o=n+1;o<t.length;o++)if(!(!((a=t[o].props)===null||a===void 0)&&a.hMerge)&&!(!((i=t[o].props)===null||i===void 0)&&i.vMerge))return!1;return!0},e.prototype._isBandRow=function(t){var n;return!((n=this.props)===null||n===void 0)&&n.firstRow?t%2==1:t%2==0},e.prototype._isBandCol=function(t){var n;return!((n=this.props)===null||n===void 0)&&n.firstCol?t%2==1:t%2==0},e.prototype._parseInheritStyles=function(){var t,n,a,i,o,s,l,u,c=this,h=(n=(t=this.tableStyles)===null||t===void 0?void 0:t.wholeTbl)===null||n===void 0?void 0:n.tcStyle,d=(i=(a=this.tableStyles)===null||a===void 0?void 0:a.wholeTbl)===null||i===void 0?void 0:i.tcTxStyle,v=(s=(o=this.slideMaster.defaultTextStyle)===null||o===void 0?void 0:o.lvl1)===null||s===void 0?void 0:s.props,p=(u=(l=this.slideMaster.defaultTextStyle)===null||l===void 0?void 0:l.lvl1)===null||u===void 0?void 0:u.defRPr;this.tr.forEach(function(y,_){y.td.forEach(function(g,f){var w,x,S,A,T,L,M,I,R,P,E,D,N,V,W,$,H,K,U,j,ut,ot,it,Et,jt,bt,wt,Ot,xt,kt,ae,O,st,nt,X,Z,J,pt,vt,at,Tt,Bt,Ct,Yt,be,se,lr,gn,xr,yn,Be,In,aa,Cr,Aa,Mo,we=Dt(Dt({},v),h),er=Dt(Dt({},p),d);c.props.firstRow&&_===0?(we=Dt(Dt(Dt({},we),(x=(w=c.tableStyles)===null||w===void 0?void 0:w.firstRow)===null||x===void 0?void 0:x.tcStyle),{border:Dt(Dt({},we?.border),(T=(A=(S=c.tableStyles)===null||S===void 0?void 0:S.firstRow)===null||A===void 0?void 0:A.tcStyle)===null||T===void 0?void 0:T.border)}),er=Dt(Dt({},er),(M=(L=c.tableStyles)===null||L===void 0?void 0:L.firstRow)===null||M===void 0?void 0:M.tcTxStyle)):c.props.lastRow&&_===c.tr.length-1?(we=Dt(Dt(Dt({},we),(R=(I=c.tableStyles)===null||I===void 0?void 0:I.lastRow)===null||R===void 0?void 0:R.tcStyle),{border:Dt(Dt({},we?.border),(D=(E=(P=c.tableStyles)===null||P===void 0?void 0:P.lastRow)===null||E===void 0?void 0:E.tcStyle)===null||D===void 0?void 0:D.border)}),er=Dt(Dt({},er),(V=(N=c.tableStyles)===null||N===void 0?void 0:N.lastRow)===null||V===void 0?void 0:V.tcTxStyle)):c.props.firstCol&&f===0?(we=Dt(Dt(Dt({},we),($=(W=c.tableStyles)===null||W===void 0?void 0:W.firstCol)===null||$===void 0?void 0:$.tcStyle),{border:Dt(Dt({},we?.border),(U=(K=(H=c.tableStyles)===null||H===void 0?void 0:H.firstCol)===null||K===void 0?void 0:K.tcStyle)===null||U===void 0?void 0:U.border)}),er=Dt(Dt({},er),(ut=(j=c.tableStyles)===null||j===void 0?void 0:j.firstCol)===null||ut===void 0?void 0:ut.tcTxStyle)):c.props.lastCol&&c._isLastCol(y.td,f)?(we=Dt(Dt(Dt({},we),(it=(ot=c.tableStyles)===null||ot===void 0?void 0:ot.lastCol)===null||it===void 0?void 0:it.tcStyle),{border:Dt(Dt({},we?.border),(bt=(jt=(Et=c.tableStyles)===null||Et===void 0?void 0:Et.lastCol)===null||jt===void 0?void 0:jt.tcStyle)===null||bt===void 0?void 0:bt.border)}),er=Dt(Dt({},er),(Ot=(wt=c.tableStyles)===null||wt===void 0?void 0:wt.lastCol)===null||Ot===void 0?void 0:Ot.tcTxStyle)):(c.props.bandRow&&(c._isBandRow(_)?(we=Dt(Dt(Dt({},we),(kt=(xt=c.tableStyles)===null||xt===void 0?void 0:xt.band1H)===null||kt===void 0?void 0:kt.tcStyle),{border:Dt(Dt({},we?.border),(st=(O=(ae=c.tableStyles)===null||ae===void 0?void 0:ae.band1H)===null||O===void 0?void 0:O.tcStyle)===null||st===void 0?void 0:st.border)}),er=Dt(Dt({},er),(X=(nt=c.tableStyles)===null||nt===void 0?void 0:nt.band1H)===null||X===void 0?void 0:X.tcTxStyle)):(we=Dt(Dt(Dt({},we),(J=(Z=c.tableStyles)===null||Z===void 0?void 0:Z.band2V)===null||J===void 0?void 0:J.tcStyle),{border:Dt(Dt({},we?.border),(at=(vt=(pt=c.tableStyles)===null||pt===void 0?void 0:pt.band2V)===null||vt===void 0?void 0:vt.tcStyle)===null||at===void 0?void 0:at.border)}),er=Dt(Dt({},er),(Bt=(Tt=c.tableStyles)===null||Tt===void 0?void 0:Tt.band2V)===null||Bt===void 0?void 0:Bt.tcTxStyle))),c.props.bandCol&&(c._isBandCol(f)?(we=Dt(Dt(Dt({},we),(Yt=(Ct=c.tableStyles)===null||Ct===void 0?void 0:Ct.band1V)===null||Yt===void 0?void 0:Yt.tcStyle),{border:Dt(Dt({},we?.border),(lr=(se=(be=c.tableStyles)===null||be===void 0?void 0:be.band1V)===null||se===void 0?void 0:se.tcStyle)===null||lr===void 0?void 0:lr.border)}),er=Dt(Dt({},er),(xr=(gn=c.tableStyles)===null||gn===void 0?void 0:gn.band1V)===null||xr===void 0?void 0:xr.tcTxStyle)):(we=Dt(Dt(Dt({},we),(Be=(yn=c.tableStyles)===null||yn===void 0?void 0:yn.band2H)===null||Be===void 0?void 0:Be.tcStyle),{border:Dt(Dt({},we?.border),(Cr=(aa=(In=c.tableStyles)===null||In===void 0?void 0:In.band2H)===null||aa===void 0?void 0:aa.tcStyle)===null||Cr===void 0?void 0:Cr.border)}),er=Dt(Dt({},er),(Mo=(Aa=c.tableStyles)===null||Aa===void 0?void 0:Aa.band2H)===null||Mo===void 0?void 0:Mo.tcTxStyle)))),g.inheritTcStyle=we,g.inheritTcTxStyle=er})})},e}($h),Hx=function(){function r(e,t,n,a){if(this.offset={x:0,y:0},this.chOffset={x:0,y:0},this.extend={w:0,h:0},this.chExtend={w:0,h:0},this.rotate=0,this.nodes=[],this.flipV=!1,this.flipH=!1,this.userDrawn=!0,this.order=Y.get(e,["attrs","order"]),this.pptx=t,this.ctx=n,this.source=e,this.group=a,this.source["p:grpSpPr"]){var i=Y.get(this.source,["p:grpSpPr","a:xfrm"]);if(i&&(this.offset={x:Math.round(this.group&&this.pptx.wps?Oa(parseInt(i["a:off"].attrs.x)):ke(parseInt(i["a:off"].attrs.x))),y:Math.round(this.group&&this.pptx.wps?Oa(parseInt(i["a:off"].attrs.y)):ke(parseInt(i["a:off"].attrs.y)))},this.chOffset={x:Math.round(Hl(i["a:chOff"].attrs.x)==="point"||this.pptx.wps?Oa(parseInt(i["a:chOff"].attrs.x)):ke(parseInt(i["a:chOff"].attrs.x))),y:Math.round(Hl(i["a:chOff"].attrs.y)==="point"||this.pptx.wps?Oa(parseInt(i["a:chOff"].attrs.y)):ke(parseInt(i["a:chOff"].attrs.y)))},this.chExtend={w:Math.round(Hl(i["a:chExt"].attrs.cx)==="point"||this.pptx.wps?Oa(parseInt(i["a:chExt"].attrs.cx)):ke(parseInt(i["a:chExt"].attrs.cx))),h:Math.round(Hl(i["a:chExt"].attrs.cy)==="point"||this.pptx.wps?Oa(parseInt(i["a:chExt"].attrs.cy)):ke(parseInt(i["a:chExt"].attrs.cy)))},this.extend={w:Math.round(this.group&&this.pptx.wps?Oa(parseInt(i["a:ext"].attrs.cx)):ke(parseInt(i["a:ext"].attrs.cx))),h:Math.round(this.group&&this.pptx.wps?Oa(parseInt(i["a:ext"].attrs.cy)):ke(parseInt(i["a:ext"].attrs.cy)))},this.rotate=Kp(parseInt(Y.get(i,"attrs.rot",0))),this.flipV=Y.get(i,"attrs.flipV")==="1",this.flipH=Y.get(i,"attrs.flipH")==="1"),a){var o=a.extend,s=a.chExtend,l=a.chOffset,u=o.w/s.w,c=o.h/s.h;this.extend.w=this.extend.w*u,this.extend.h=this.extend.h*c,this.offset.x=(this.offset.x-l.x)*u,this.offset.y=(this.offset.y-l.y)*c}}this._parseBackground(),this._parseNodes()}return r.prototype.getBackground=function(){return this.background&&this.background.type!=="none"?this.background:this.group?this.group.getBackground():void 0},r.prototype._parseBackground=function(){var e=Y.get(this.source,["p:grpSpPr"]);e&&e["a:solidFill"]?this.background=Ke(e["a:solidFill"],this.ctx.theme,this.ctx):e&&e["a:gradFill"]?this.background=Xh(e["a:gradFill"],this.ctx.theme,this.ctx):e&&e["a:blipFill"]&&(this.background=Yh(e["a:blipFill"],this.pptx,this.ctx))},r.prototype._parseNodes=function(){var e=this.source;jh(this.nodes,e,this.pptx,this.ctx,this)},r}(),mB=function(r){function e(t,n,a,i){var o=r.call(this,t,a,i)||this;return o.nodes=[],o.pptx=n,o}return Sh(e,r),e.prototype.parseNode=function(){return dr(this,void 0,void 0,function(){var t,n,a,i,o,s,l,u,c;return pr(this,function(h){switch(h.label){case 0:return h.trys.push([0,3,,4]),(t=Y.get(this.source,["a:graphic","a:graphicData","dgm:relIds","attrs","r:dm"]))&&this.ctx.rels[t]?(n=this.ctx.rels[t].target,i=hn,[4,this.pptx.getXmlByPath(n)]):[2];case 1:return a=i.apply(void 0,[h.sent()]),(o=Y.get(a,["dgm:dataModel","dgm:extLst","a:ext","dsp:dataModelExt","attrs","relId"]))&&this.ctx.rels[o]?(s=this.ctx.rels[o].target,[4,this.pptx.getXmlByPath(s)]):[2];case 2:return l=(l=h.sent()).replace(/dsp:/g,"p:"),u=hn(l),c=Y.get(u,["p:drawing","p:spTree"]),jh(this.nodes,c,this.pptx,this.ctx),[3,4];case 3:return h.sent(),[3,4];case 4:return[2]}})})},e}($h),_B=function(r){function e(t,n,a,i){var o=r.call(this,t,a,i)||this;return o.options={title:{},tooltip:{},legend:{},series:[],color:[]},o.userDrawn=!0,o.pptx=n,o}return Sh(e,r),Object.defineProperty(e.prototype,"slideMaster",{get:function(){return this.ctx.slideMaster||this.ctx},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"theme",{get:function(){return this.slideMaster.theme},enumerable:!1,configurable:!0}),e.prototype.parseNode=function(){return dr(this,void 0,void 0,function(){var t,n,a,i,o,s;return pr(this,function(l){switch(l.label){case 0:return l.trys.push([0,2,,3]),(t=Y.get(this.source,["a:graphic","a:graphicData","c:chart","attrs","r:id"]))&&this.ctx.rels[t]?(n=this.ctx.rels[t].target,i=hn,[4,this.pptx.getXmlByPath(n)]):[2];case 1:return a=i.apply(void 0,[l.sent()]),o=Y.get(a,["c:chartSpace","c:chart"]),s=Y.get(o,["c:plotArea"]),Y.get(s,["c:lineChart"])?this.parseLine(Y.get(s,["c:lineChart"]),o):Y.get(s,["c:line3DChart"])?this.parseLine(Y.get(s,["c:line3DChart"]),o):Y.get(s,["c:areaChart"])?this.parseAreaLine(Y.get(s,["c:areaChart"]),o):Y.get(s,["c:area3DChart"])?this.parseAreaLine(Y.get(s,["c:area3DChart"]),o):Y.get(s,["c:barChart"])?this.parseBar(Y.get(s,["c:barChart"]),o):Y.get(s,["c:bar3DChart"])?this.parseBar(Y.get(s,["c:bar3DChart"]),o):Y.get(s,["c:pieChart"])?this.parsePie(Y.get(s,["c:pieChart"])):Y.get(s,["c:pie3DChart"])?this.parsePie(Y.get(s,["c:pie3DChart"])):Y.get(s,["c:doughnutChart"])&&this.parseDoughnutChart(Y.get(s,["c:doughnutChart"])),[3,3];case 2:return l.sent(),[3,3];case 3:return[2]}})})},e.prototype.parseAreaLine=function(t,n){this.parseLine(t,n),this.options.series=this.options.series.map(function(a){return a.areaStyle={},a})},e.prototype.parseLine=function(t,n){var a=Y.get(t,["c:ser"]);Array.isArray(a)||(a=[a]),this.options.title={top:"top",left:"center",text:this.parseChartTitle(Y.get(n,["c:title"]))},this.options.xAxis={type:"category",data:this.getCategory(a[0])},this.options.yAxis={type:"value"},this.options.series=this.parseLineSeries(a,t),this.options.color=this.parseLineColors(a),this.options.legend={bottom:"bottom",left:"center"},Y.get(t,["c:grouping","attrs","val"])==="percentStacked"&&(this.options.tooltip.valueFormatter=function(i){return(100*i).toFixed(2)+"%"})},e.prototype.parseBar=function(t,n){var a=Y.get(t,["c:ser"]);Array.isArray(a)||(a=[a]),this.options.title={top:"top",left:"center",text:this.parseChartTitle(Y.get(n,["c:title"]))},Y.get(t,["c:barDir","attrs","val"])==="bar"?(this.options.yAxis={type:"category",data:this.getCategory(a[0])},this.options.xAxis={type:"value"}):(this.options.xAxis={type:"category",data:this.getCategory(a[0])},this.options.yAxis={type:"value"}),this.options.series=this.parseBarSeries(a,t),this.options.color=this.parseBarColors(a),this.options.legend={bottom:"bottom",left:"center"},Y.get(t,["c:grouping","attrs","val"])==="percentStacked"&&(this.options.tooltip.valueFormatter=function(i){return(100*i).toFixed(2)+"%"})},e.prototype.parsePie=function(t){var n=Y.get(t,["c:ser"]);this.options.title={top:"top",left:"center",text:this.parsePieTitle(n)},this.options.color=this.parsePieColors(n),this.options.series=[this.parsePieSeries(n,t)],this.options.legend={bottom:"bottom",left:"center"}},e.prototype.parseDoughnutChart=function(t){var n=Y.get(t,["c:ser"]);this.options.title.text=this.parsePieTitle(n),this.options.color=this.parsePieColors(n),this.options.series=[this.parsePieSeries(n,t)],this.options.legend={bottom:"bottom",left:"center"}},e.prototype.parsePieTitle=function(t){return Y.get(t,["c:tx","c:strRef","c:strCache","c:pt","c:v"])},e.prototype.parseChartTitle=function(t){var n=Y.get(t,["c:tx","c:rich","a:p"]);return Array.isArray(n)||(n=[n]),n.map(function(a){var i=Y.get(a,["a:r"]);return Array.isArray(i)||(i=[i]),i.map(function(o){return Y.get(o,["a:t"])||""}).join("")}).join("")||"图表标题"},e.prototype.parseBarColors=function(t){var n=this;return t.map(function(a){return Le(Ke(Y.get(a,["c:spPr","a:solidFill"]),n.theme,n.ctx))})},e.prototype.parseLineColors=function(t){var n=this;return t.map(function(a){return Le(Ke(Y.get(a,["c:spPr","a:ln","a:solidFill"])||Y.get(a,["c:spPr","a:solidFill"]),n.theme,n.ctx))})},e.prototype.parsePieColors=function(t){var n=this,a=[],i=Y.get(t,["c:dPt"]);return Array.isArray(i)||(i=[i]),i.forEach(function(o){a.push(Le(Ke(Y.get(o,["c:spPr","a:solidFill"]),n.theme,n.ctx)))}),a},e.prototype.parsePieSeries=function(t,n){var a={type:"pie",radius:"80%",startAngle:90,data:[]};Y.get(n,["c:holeSize","attrs","val"])&&(a.radius=["".concat(.8*Y.get(n,["c:holeSize","attrs","val"]),"%"),"80%"]);var i=Y.get(n,["c:firstSliceAng","attrs","val"]);i&&(a.startAngle=90-i);for(var o=this.getCategory(t),s=this.getVal(t),l=0;l<o.length;l++)a.data.push({name:o[l],value:s[l]});return a},e.prototype.parseBarSeries=function(t,n){var a,i=this,o=Y.get(n,["c:grouping","attrs","val"]);o==="stacked"?a="Ad":o==="percentStacked"&&(a="total");var s=t.map(function(u){return{type:"bar",name:Y.get(u,["c:tx","c:strRef","c:strCache","c:pt","c:v"]),data:i.getVal(u),stack:a}});if(o==="percentStacked"){var l=[];s.forEach(function(u,c){l=c===0?Ic([],u.data,!0):l.map(function(h,d){return h+u.data[d]})}),s.forEach(function(u){u.data=u.data.map(function(c,h){return l[h]<=0?0:c/l[h]})})}return s},e.prototype.parseLineSeries=function(t,n){var a,i=this,o=Y.get(n,["c:grouping","attrs","val"]);o==="stacked"?a="Ad":o==="percentStacked"&&(a="total");var s=t.map(function(u){return{type:"line",name:Y.get(u,["c:tx","c:strRef","c:strCache","c:pt","c:v"]),data:i.getVal(u),stack:a}});if(a==="total"){var l=[];s.forEach(function(u,c){l=c===0?Ic([],u.data,!0):l.map(function(h,d){return h+u.data[d]})}),s.forEach(function(u){u.data=u.data.map(function(c,h){return l[h]<=0?0:c/l[h]})})}return s},e.prototype.getCategory=function(t){if(Y.get(t,["c:cat","c:strRef"])){var n=Y.get(t,["c:cat","c:strRef","c:strCache","c:pt"]);return Array.isArray(n)||(n=[n]),n.map(function(a){return Y.get(a,["c:v"])})}if(Y.get(t,["c:cat","c:numRef"]))return n=Y.get(t,["c:cat","c:numRef","c:numCache","c:pt"]),Array.isArray(n)||(n=[n]),n.map(function(a){return Y.get(a,["c:v"])})},e.prototype.getVal=function(t){var n=Y.get(t,["c:val","c:numRef","c:numCache","c:pt"]);return Array.isArray(n)||(n=[n]),n.map(function(a){return+Y.get(a,["c:v"])})},e}($h);function bI(r){var e={},t=Y.get(r,"attrs")||{};return Object.keys(t).forEach(function(n){switch(n){case"algn":e.align=t[n];break;case"marL":e.marginLeft=ke(parseInt(t[n]));break;case"indent":e.indent=ke(parseInt(t[n]));break;case"lvl":e.level=t[n]}}),Y.get(r,["a:lnSpc","a:spcPct","attrs","val"])&&(e.lineHeight=parseInt(r["a:lnSpc"]["a:spcPct"].attrs.val)/1e5),e}function SI(r,e,t){var n={},a=Y.get(r,"attrs")||{};Object.keys(a).forEach(function(o){switch(o){case"sz":n.size=parseInt(a[o])/100;break;case"b":n.bold=a[o]==="1";break;case"i":n.italic=a[o]==="1";break;case"u":n.underline=a[o];break;case"strike":n.strike=a[o];break;case"order":case"dirty":break;default:n[o]=a[o]}});var i=Y.get(r,"a:solidFill");return i&&(n.color=Ke(i,e,t)),n}function jh(r,e,t,n,a){return dr(this,void 0,void 0,function(){var i,o,s,l,u,c,h,d,v,p,y,_,g,f,w,x,S,A,T,L,M;return pr(this,function(I){switch(I.label){case 0:for(s in o=[],i=e)o.push(s);l=0,I.label=1;case 1:if(!(l<o.length))return[3,17];if(!((s=o[l])in i))return[3,16];switch(u=s){case"p:sp":return[3,2];case"p:pic":return[3,3];case"p:cxnSp":return[3,4];case"p:graphicFrame":return[3,5];case"p:grpSp":return[3,14]}return[3,15];case 2:for(c=Array.isArray(e[u])?e[u]:[e[u]],L=0;L<c.length;L++)g=c[L],r.push(new bh(g,t,n,a));return[3,16];case 3:for(h=Array.isArray(e[u])?e[u]:[e[u]],L=0;L<h.length;L++)d=h[L],v=d["p:blipFill"]["a:blip"].attrs["r:embed"],p=n.rels[v].target,y=new lp(p,d,t,n,a),r.push(y);return[3,16];case 4:for(_=Array.isArray(e[u])?e[u]:[e[u]],L=0;L<_.length;L++)g=_[L],r.push(new bh(g,t,n,a));return[3,16];case 5:f=Array.isArray(e[u])?e[u]:[e[u]],L=0,I.label=6;case 6:if(!(L<f.length))return[3,13];switch(w=f[L],x=Y.get(w,["a:graphic","a:graphicData","attrs","uri"]),x){case"http://schemas.openxmlformats.org/drawingml/2006/table":return[3,7];case"http://schemas.openxmlformats.org/drawingml/2006/diagram":return[3,8];case"http://schemas.openxmlformats.org/drawingml/2006/chart":return[3,10]}return[3,12];case 7:return r.push(new yB(w,t,n,a)),[3,12];case 8:return[4,(S=new mB(w,t,n,a)).parseNode()];case 9:return I.sent(),r.push(S),[3,12];case 10:return[4,(A=new _B(w,t,n,a)).parseNode()];case 11:return I.sent(),r.push(A),[3,12];case 12:return L++,[3,6];case 13:return[3,16];case 14:for(T=Array.isArray(e[u])?e[u]:[e[u]],L=0;L<T.length;L++)M=T[L],r.push(new Hx(M,t,n,a));return[3,16];case 15:return[3,16];case 16:return l++,[3,1];case 17:return[2]}})})}var not=function(){function r(e,t,n){this.slideType="slide",this.rels={},this.background={type:"none"},this.nodes=[],this.name=e,this.source=t,this.pptx=n}return Object.defineProperty(r.prototype,"index",{get:function(){if(!this.name)return 0;var e=this.name.match(/(\d+)/);return e?parseInt(e[0]):1},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"slideMaster",{get:function(){return this.slideLayout&&this.slideLayout.slideMaster},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"theme",{get:function(){return this.slideMaster.theme},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"_relsPath",{get:function(){return this.name.replace("slides/slide","slides/_rels/slide")+".rels"},enumerable:!1,configurable:!0}),r.prototype.load=function(){return dr(this,void 0,void 0,function(){return pr(this,function(e){switch(e.label){case 0:return[4,this._loadRels()];case 1:return e.sent(),this._loadBackground(),[4,this._loadNodes()];case 2:return e.sent(),[2]}})})},r.prototype._loadRels=function(){return dr(this,void 0,void 0,function(){var e,t,n,a=this;return pr(this,function(i){switch(i.label){case 0:return t=hn,[4,this.pptx.getXmlByPath(this._relsPath)];case 1:return e=t.apply(void 0,[i.sent()]),n=Y.get(e,["Relationships","Relationship"])||[],Array.isArray(n)||(n=[n]),n.forEach(function(o){switch(Y.get(o,["attrs","Type"])){case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/slideLayout":var s=o.attrs.Target.replace("../","ppt/");s.startsWith("/ppt")&&(s=s.substr(1)),a.slideLayout=a.pptx.getSlideLayout(s);break;case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/audio":case"http://schemas.microsoft.com/office/2007/relationships/media":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/video":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramLayout":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramData":case"http://schemas.microsoft.com/office/2007/relationships/diagramDrawing":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramColors":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart":var l=o.attrs.Target.replace("../","ppt/");l.startsWith("/ppt")&&(l=l.substr(1)),a.rels[o.attrs.Id]={type:o.attrs.Type.split("/").pop(),target:l}}}),[2]}})})},r.prototype._loadBackground=function(){var e=Y.get(this.source,["p:sld","p:cSld","p:bg","p:bgPr"]);e&&e["a:solidFill"]?this.background=Ke(e["a:solidFill"],this.theme,this):e&&e["a:gradFill"]?this.background=Xh(e["a:gradFill"],this.theme,this):e&&e["a:blipFill"]&&(this.background=Yh(e["a:blipFill"],this.pptx,this))},r.prototype._loadNodes=function(){return dr(this,void 0,void 0,function(){var e;return pr(this,function(t){switch(t.label){case 0:return e=Y.get(this.source,["p:sld","p:cSld","p:spTree"]),[4,jh(this.nodes,e,this.pptx,this)];case 1:return t.sent(),[2]}})})},r.prototype.getColorThemeName=function(e){return this.slideLayout.getColorThemeName(e)},r.prototype.getNodeInheritAttrsByType=function(e,t){var n=this.slideLayout.getNodeByType(e),a=Y.get(n.source,t);return a||this.slideLayout.getNodeInheritAttrsByType(e,t)},r.prototype.getNodeInheritAttrsByIdx=function(e,t){var n=this.slideLayout.getNodeByIdx(e),a=Y.get(n.source,t);return a||this.slideLayout.getNodeInheritAttrsByIdx(e,t)},r}(),aot=function(){function r(e,t,n){this.slideType="slideLayout",this.rels={},this.background={type:"none"},this.nodes=[],this.name=e,this.source=t,this.pptx=n}return Object.defineProperty(r.prototype,"_relsPath",{get:function(){return this.name.replace("slideLayouts/slideLayout","slideLayouts/_rels/slideLayout")+".rels"},enumerable:!1,configurable:!0}),Object.defineProperty(r.prototype,"theme",{get:function(){return this.slideMaster.theme},enumerable:!1,configurable:!0}),r.prototype.load=function(){return dr(this,void 0,void 0,function(){return pr(this,function(e){switch(e.label){case 0:return[4,this._loadRels()];case 1:return e.sent(),[4,this._loadBackground()];case 2:return e.sent(),[4,this._loadNodes()];case 3:return e.sent(),[2]}})})},r.prototype._loadRels=function(){return dr(this,void 0,void 0,function(){var e,t,n,a=this;return pr(this,function(i){switch(i.label){case 0:return t=hn,[4,this.pptx.getXmlByPath(this._relsPath)];case 1:return e=t.apply(void 0,[i.sent()]),n=Y.get(e,["Relationships","Relationship"])||[],Array.isArray(n)||(n=[n]),n.forEach(function(o){switch(Y.get(o,["attrs","Type"])){case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/slideMaster":var s=o.attrs.Target.replace("../","ppt/");s.startsWith("/ppt")&&(s=s.substr(1)),a.slideMaster=a.pptx.getSlideMaster(s);break;case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/audio":case"http://schemas.microsoft.com/office/2007/relationships/media":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/video":var l=o.attrs.Target.replace("../","ppt/");l.startsWith("/ppt")&&(l=l.substr(1)),a.rels[o.attrs.Id]={type:o.attrs.Type.split("/").pop(),target:l}}}),[2]}})})},r.prototype._loadBackground=function(){return dr(this,void 0,void 0,function(){var e;return pr(this,function(t){return(e=Y.get(this.source,["p:sldLayout","p:cSld","p:bg","p:bgPr"]))&&e["a:solidFill"]?this.background=Ke(e["a:solidFill"],this.theme):e&&e["a:gradFill"]?this.background=Xh(e["a:gradFill"],this.theme,this):e&&e["a:blipFill"]&&(this.background=Yh(e["a:blipFill"],this.pptx,this)),[2]})})},r.prototype._loadNodes=function(){return dr(this,void 0,void 0,function(){var e;return pr(this,function(t){return e=Y.get(this.source,["p:sldLayout","p:cSld","p:spTree"]),jh(this.nodes,e,this.pptx,this),[2]})})},r.prototype.getColorThemeName=function(e){return this.slideMaster.getColorThemeName(e)},r.prototype.getNodeByType=function(e){return this.nodes.find(function(t){return t.type===e})},r.prototype.getNodeByIdx=function(e){return this.nodes.find(function(t){return t.idx===e})},r.prototype.getNodeInheritAttrsByType=function(e,t){var n=this.slideMaster.getNodeByType(e);return n&&Y.get(n.source,t)},r.prototype.getNodeInheritAttrsByIdx=function(e,t){var n=this.slideMaster.getNodeByIdx(e);return n&&Y.get(n.source,t)},r}(),iot=function(){function r(e,t,n){this.slideType="slideMaster",this.rels={},this.background={type:"none"},this.textStyles={titleStyle:{},bodyStyle:{},otherStyle:{}},this.defaultTextStyle={},this.nodes=[],this.tableStyles={},this.name=e,this.source=t,this.pptx=n,this.load()}return Object.defineProperty(r.prototype,"_relsPath",{get:function(){return this.name.replace("slideMasters/slideMaster","slideMasters/_rels/slideMaster")+".rels"},enumerable:!1,configurable:!0}),r.prototype.load=function(){return dr(this,void 0,void 0,function(){return pr(this,function(e){switch(e.label){case 0:return[4,this._parseRels()];case 1:return e.sent(),this._parseColorMap(),this._parseBackground(),this._parseTextStyles(),this._parseTableStyles(),this._parseDefaultTextStyle(),this._loadNodes(),[2]}})})},r.prototype._parseRels=function(){return dr(this,void 0,void 0,function(){var e,t,n,a=this;return pr(this,function(i){switch(i.label){case 0:return t=hn,[4,this.pptx.getXmlByPath(this._relsPath)];case 1:return e=t.apply(void 0,[i.sent()]),n=Y.get(e,["Relationships","Relationship"])||[],Array.isArray(n)||(n=[n]),n.forEach(function(o){switch(Y.get(o,["attrs","Type"])){case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme":var s=o.attrs.Target.replace("../","ppt/");s.startsWith("/ppt")&&(s=s.substr(1)),a.theme=a.pptx.getTheme(s);break;case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/image":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/audio":case"http://schemas.microsoft.com/office/2007/relationships/media":case"http://schemas.openxmlformats.org/officeDocument/2006/relationships/video":var l=o.attrs.Target.replace("../","ppt/");l.startsWith("/ppt")&&(l=l.substr(1)),a.rels[o.attrs.Id]={type:o.attrs.Type.split("/").pop(),target:l}}}),[2]}})})},r.prototype._parseColorMap=function(){this.colorMap=Y.omit(Y.get(this.source,["p:sldMaster","p:clrMap","attrs"])||{},["order"])},r.prototype.getColorThemeName=function(e){return this.colorMap[e]||e},r.prototype._parseBackground=function(){var e=Y.get(this.source,["p:sldMaster","p:cSld","p:bg","p:bgPr"]),t=Y.get(this.source,["p:sldMaster","p:cSld","p:bg","p:bgRef"]);e&&e["a:solidFill"]?this.background=Ke(e["a:solidFill"],this.theme,this):e&&e["a:gradFill"]?this.background=Xh(e["a:gradFill"],this.theme,this):e&&e["a:blipFill"]?this.background=Yh(e["a:blipFill"],this.pptx,this):t&&(this.background=Ke(t,this.theme,this))},r.prototype._parseDefaultTextStyle=function(){var e=this,t=this.pptx.defaultTextStyleSource;Object.keys(t).forEach(function(n){if(n.startsWith("a:")&&n.endsWith("pPr")){var a=n.substr(2,n.length-5),i=Y.get(t[n],["a:defRPr"]);e.defaultTextStyle[a]={props:bI(t[n]),defRPr:SI(i,e.theme,e)}}})},r.prototype._parseTextStyles=function(){var e=this,t=Y.get(this.source,["p:sldMaster","p:txStyles"]);["titleStyle","bodyStyle","otherStyle"].forEach(function(n){var a=e.textStyles[n],i=Y.get(t,"p:".concat(n))||{};Object.keys(i).forEach(function(o){if(o.startsWith("a:")&&o.endsWith("pPr")){var s=o.substr(2,o.length-5);a[s]={},a[s].props=bI(i[o]);var l=Y.get(i[o],["a:defRPr"]);a[s].defRPr=SI(l,e.theme,e)}})})},r.prototype._parseTableStyles=function(){var e=this,t={},n=Y.get(this.pptx.tableStyles,["a:tblStyleLst","a:tblStyle"])||[];Array.isArray(n)||(n=[n]),n.forEach(function(a){var i=Y.get(a,["attrs","styleId"]);t[i]={},Object.keys(a).forEach(function(o){if(o.startsWith("a:")){var s=o.substr(2);t[i][s]={};var l=Y.get(a[o],["a:tcStyle"]);if(l){var u={};Y.get(l,["a:fill","a:solidFill"])&&(u.background=Ke(Y.get(l,["a:fill","a:solidFill"]),e.theme,e));var c=Y.get(l,"a:tcBdr");c&&(u.border={},Object.keys(c).forEach(function(v){if(v.startsWith("a:")){var p=v.substr(2),y=Y.get(c[v],["a:ln"]);u.border[p]=Ul(y,e.theme,e)}})),t[i][s].tcStyle=u}var h=Y.get(a[o],["a:tcTxStyle"]);if(h){var d={};d.color=Ke(h,e.theme,e),Y.get(h,["attrs","b"])==="on"&&(d.bold=!0),t[i][s].tcTxStyle=d}}})}),this.tableStyles=t},r.prototype._loadNodes=function(){return dr(this,void 0,void 0,function(){var e;return pr(this,function(t){return e=Y.get(this.source,["p:sldMaster","p:cSld","p:spTree"]),jh(this.nodes,e,this.pptx,this),[2]})})},r.prototype.getNodeByType=function(e){return this.nodes.find(function(t){return t.type===e})},r.prototype.getNodeByIdx=function(e){return this.nodes.find(function(t){return t.idx===e})},r.prototype.getNodeInheritAttrsByType=function(e,t){},r.prototype.getNodeInheritAttrsByIdx=function(e,t){},r}(),oot=function(){function r(e,t,n){this.clrScheme={},this.borderScheme=[],this.name=e,this.source=t,this.pptx=n,this._parseClrScheme(),this._parseLineStyleLst()}return r.prototype._parseClrScheme=function(){var e=Y.get(this.source,["a:theme","a:themeElements","a:clrScheme"]);for(var t in e)if(t.startsWith("a:")){var n=t.substring(2),a=Y.get(e[t],["a:sysClr","attrs","lastClr"])||Y.get(e[t],["a:srgbClr","attrs","val"]);this.clrScheme[n]="#"+a}},r.prototype._parseLineStyleLst=function(){var e=this,t=Y.get(this.source,["a:theme","a:themeElements","a:fmtScheme","a:lnStyleLst","a:ln"])||[];this.borderScheme=t.map(function(n){var a={color:{}};return Y.get(n,["attrs","w"])&&(a.width=ke(parseInt(Y.get(n,["attrs","w"])))),Y.get(n,["attrs","algn"])&&(a.algn=Y.get(n,["attrs","algn"])),Y.get(n,["attrs","cap"])&&(a.cap=Y.get(n,["attrs","cap"])),Y.get(n,["attrs","cmpd"])&&(a.cmpd=Y.get(n,["attrs","cmpd"])),Y.get(n,["a:miter","attrs","lim"])&&(a.miterLim=ke(parseInt(Y.get(n,["a:miter","attrs","lim"])))),Y.get(n,["a:prstDash","attrs","val"])&&(a.type=Y.get(n,["a:prstDash","attrs","val"])),Y.get(n,["a:solidFill"])&&(a.color=Ke(Y.get(n,["a:solidFill"]),e)),a})},r.prototype.getColor=function(e){if(e!=="phClr")return this.clrScheme[e]||this.defaultColor},r.prototype.getLineStyle=function(e){return this.borderScheme[e-1]},r}(),AI=function(){function r(){this.slides=[],this.slideLayouts=[],this.slideMaster=[],this.themes=[],this.medias={},this.wps=!1}return r.prototype.load=function(e){return dr(this,void 0,void 0,function(){var t,n;return pr(this,function(a){switch(a.label){case 0:return t=new e6,n=this,[4,t.loadAsync(e)];case 1:return n._zipContents=a.sent(),[4,this._loadThumbnail()];case 2:return a.sent(),[4,this._loadMedia()];case 3:return a.sent(),[4,this._loadPresentation()];case 4:return a.sent(),[4,this._loadContentTypes()];case 5:return a.sent(),[2]}})})},r.prototype._loadThumbnail=function(){return dr(this,void 0,void 0,function(){var e;return pr(this,function(t){switch(t.label){case 0:return t.trys.push([0,3,,4]),this._zipContents.files["docProps/thumbnail.jpeg"]?[4,this._zipContents.files["docProps/thumbnail.jpeg"].async("base64")]:[3,2];case 1:e=t.sent(),this.thumbnail="data:image/jpeg;base64,"+e,t.label=2;case 2:return[3,4];case 3:return t.sent(),[3,4];case 4:return[2]}})})},r.prototype._loadPresentation=function(){return dr(this,void 0,void 0,function(){var e,t,n,a,i,o;return pr(this,function(s){switch(s.label){case 0:return s.trys.push([0,4,,5]),[4,this._zipContents.files["ppt/presentation.xml"].async("text")];case 1:return e=s.sent(),t=hn(e),n=t["p:presentation"]["p:sldSz"].attrs,this.width=ke(parseInt(n.cx)),this.height=ke(parseInt(n.cy)),this.defaultTextStyleSource=Y.get(t,["p:presentation","p:defaultTextStyle"]),this._zipContents.files["docProps/app.xml"]?[4,this._zipContents.files["docProps/app.xml"].async("text")]:[3,3];case 2:a=s.sent(),i=hn(a),o=Y.get(i,["Properties","Application"]),this.wps=o?.includes("WPS")||!1,s.label=3;case 3:return[3,5];case 4:return s.sent(),[3,5];case 5:return[2]}})})},r.prototype._loadContentTypes=function(){return dr(this,void 0,void 0,function(){var e,t,n,a,i,o,s,l,u,c,h,d,v,p,y,_,g,f,w,x,S;return pr(this,function(A){switch(A.label){case 0:return A.trys.push([0,22,,23]),t=hn,[4,this._zipContents.files["[Content_Types].xml"].async("text")];case 1:if(e=t.apply(void 0,[A.sent()]),n=e.Types.Override,!(a=n.filter(function(T){return T.attrs.ContentType==="application/vnd.openxmlformats-officedocument.theme+xml"})))return[3,5];i=0,o=a,A.label=2;case 2:return i<o.length?(s=o[i],f=s.attrs.PartName.substr(1),l=hn,[4,this._zipContents.files[f].async("text")]):[3,5];case 3:w=l.apply(void 0,[A.sent()]),this.themes.push(new oot(f,w,this)),A.label=4;case 4:return i++,[3,2];case 5:return(u=n.find(function(T){return T.attrs.ContentType==="application/vnd.openxmlformats-officedocument.presentationml.tableStyles+xml"}))?(f=u.attrs.PartName.substr(1),c=hn,[4,this._zipContents.files[f].async("text")]):[3,7];case 6:w=c.apply(void 0,[A.sent()]),this.tableStyles=w,A.label=7;case 7:h=n.filter(function(T){return T.attrs.ContentType==="application/vnd.openxmlformats-officedocument.presentationml.slideMaster+xml"}),g=0,A.label=8;case 8:return g<h.length?(f=h[g].attrs.PartName.substr(1),d=hn,[4,this._zipContents.files[f].async("text")]):[3,11];case 9:w=d.apply(void 0,[A.sent()]),this.slideMaster.push(new iot(f,w,this)),A.label=10;case 10:return g++,[3,8];case 11:v=n.filter(function(T){return T.attrs.ContentType==="application/vnd.openxmlformats-officedocument.presentationml.slideLayout+xml"}),g=0,A.label=12;case 12:return g<v.length?(f=v[g].attrs.PartName.substr(1),p=hn,[4,this._zipContents.files[f].async("text")]):[3,16];case 13:return w=p.apply(void 0,[A.sent()]),[4,(y=new aot(f,w,this)).load()];case 14:A.sent(),this.slideLayouts.push(y),A.label=15;case 15:return g++,[3,12];case 16:_=n.filter(function(T){return T.attrs.ContentType==="application/vnd.openxmlformats-officedocument.presentationml.slide+xml"}),g=0,A.label=17;case 17:return g<_.length?(f=_[g].attrs.PartName.substr(1),x=hn,[4,this._zipContents.files[f].async("text")]):[3,21];case 18:return w=x.apply(void 0,[A.sent()]),[4,(S=new not(f,w,this)).load()];case 19:A.sent(),this.slides.push(S),A.label=20;case 20:return g++,[3,17];case 21:return this.slides.sort(function(T,L){return T.index-L.index}),[3,23];case 22:return A.sent(),[3,23];case 23:return[2]}})})},r.prototype._loadMedia=function(){return dr(this,void 0,void 0,function(){var e,t,n,a,i,o,s,l,u,c,h,d,v,p=this;return pr(this,function(y){switch(y.label){case 0:e=Object.keys(this._zipContents.files).filter(function(g){return g.startsWith("ppt/media/image")}).map(function(g){return p._zipContents.files[g]}),t=0,n=e,y.label=1;case 1:return t<n.length?(a=n[t],i=function(g){var f;switch(g){case"jpg":case"jpeg":f="image/jpeg";break;case"png":f="image/png";break;case"gif":f="image/gif";break;case"emf":f="image/x-emf";break;case"wmf":f="image/x-wmf";break;default:f="image/*"}return f}((_=a.name).substr(2+(~-_.lastIndexOf(".")>>>0))),[4,a.async("base64")]):[3,4];case 2:o=y.sent(),this.medias[a.name]="data:".concat(i,";base64,").concat(o),y.label=3;case 3:return t++,[3,1];case 4:s=Object.keys(this._zipContents.files).filter(function(g){return g.startsWith("ppt/media/media")&&["mp3","wav","ogg","mp4","webm"].includes(g.split(".").pop().toLowerCase())}).map(function(g){return p._zipContents.files[g]}),l=0,u=s,y.label=5;case 5:return l<u.length?(c=u[l],h=c.name.split(".").pop().toLowerCase(),[4,c.async("arraybuffer")]):[3,8];case 6:d=y.sent(),v=new Blob([d],{type:"".concat(["mp3","wav"].includes(h)?"audio":"video","/").concat(h)}),this.medias[c.name]=URL.createObjectURL(v),y.label=7;case 7:return l++,[3,5];case 8:return[2]}var _})})},r.prototype.getXmlByPath=function(e){return dr(this,void 0,void 0,function(){return pr(this,function(t){switch(t.label){case 0:if(!this._zipContents.files[e])throw new Error("文件不存在");return[4,this._zipContents.files[e].async("text")];case 1:return[2,t.sent()]}})})},r.prototype.getSlideLayout=function(e){return this.slideLayouts.find(function(t){return t.name===e})},r.prototype.getSlideMaster=function(e){return this.slideMaster.find(function(t){return t.name===e})},r.prototype.getTheme=function(e){return this.themes.find(function(t){return t.name===e})},r.prototype.getMedia=function(e){return this.medias[e]},r}();function P1(r){var e=r.extend,t=r.offset,n=r.clip,a=r.base64,i=r.audioFile,o=r.videoFile,s=document.createElement("div");s.style.setProperty("position","absolute"),s.style.setProperty("left",t.x+"px"),s.style.setProperty("top",t.y+"px");var l,u,c,h,d=document.createElement("div");d.style.setProperty("position","absolute"),d.style.setProperty("left","0"),d.style.setProperty("top","0"),d.style.setProperty("width",e.w+"px"),d.style.setProperty("height",e.h+"px"),d.style.setProperty("overflow","hidden"),n?(l=e.w/(1-(n.l===void 0?0:n.l)-(n.r===void 0?0:n.r)),u=e.h/(1-(n.t===void 0?0:n.t)-(n.b===void 0?0:n.b)),c=-1*l*(n.l===void 0?0:n.l),h=-1*u*(n.t===void 0?0:n.t)):(l=e.w,u=e.h,c=0);var v=document.createElement("img");if(v.src=a,v.width=l,v.height=u,v.style.setProperty("position","absolute"),v.style.setProperty("left",c+"px"),v.style.setProperty("top",h+"px"),d.append(v),s.append(d),i){var p=document.createElement("audio");p.style.position="absolute",p.style.left="0",p.style.top="0",p.src=i,p.controls=!0,p.style.transform="translate(-50%)",s.append(p)}if(o){var y=document.createElement("video");y.style.position="absolute",y.style.left="0",y.style.top="0",y.width=e.w,y.height=e.h,y.src=o,y.controls=!0,s.append(y)}return s}function sot(r,e,t){var n,a=r.props,i=r.text,o=Dt(Dt({},e),a),s=document.createElement("span");s.innerHTML=typeof i=="string"?i:"";var l=18;o.size&&(!((n=t?.normAutofit)===null||n===void 0)&&n.fontScale?(l=o.size*t.normAutofit.fontScale,s.style.fontSize=l+"px"):(l=o.size,s.style.fontSize=l+"px"));var u=Le(o.color);u&&(s.style.color=u);var c=/^[^\u4e00-\u9fff]+$/;if(o.typeface)switch(s.style.fontFamily=o.typeface,o.typeface){case"DengXian":c.test(i)&&(s.style.letterSpacing=-.04*l+"px");break;case"DengXian Light":c.test(i)&&(s.style.letterSpacing=-.05*l+"px");break;case"STLiti":case"SimSun":case"NSimSun":case"SimHei":c.test(i)&&(s.style.fontSize=.85*parseInt(s.style.fontSize)+"px");break;case"华文中宋":case"Fira Sans Extra Condensed Medium":s.style.fontSize=.85*parseInt(s.style.fontSize)+"px";break;case"FangSong":s.style.letterSpacing=-.08*l+"px"}else c.test(i)&&(s.style.letterSpacing=-.04*l+"px");return o.bold&&(s.style.fontWeight="bold"),o.italic&&(s.style.fontStyle="italic"),o.underline&&o.underline!=="none"&&(s.style.textDecoration="underline"),o.background&&(s.style.backgroundColor=Le(o.background)),s.style.wordBreak="break-word",s}function lot(r,e,t){var n=document.createElement("span"),a=r.firstElementChild;switch(n.style.fontSize=a.style.fontSize,n.style.color=a.style.color,n.style.fontWeight=a.style.fontWeight,n.style.fontStyle=a.style.fontStyle,n.style.marginRight="10px",e.buAutoNum){case"arabicPeriod":default:n.textContent=t+".";break;case"circleNumDbPlain":n.textContent=["①","②","③","④","⑤","⑥","⑦","⑧","⑨","⑩","⑪","⑫","⑬","⑭","⑮","⑯","⑰","⑱","⑲","⑳"][t-1]||t+"";break;case"romanUcPeriod":n.textContent=function(i){var o=[{value:1e3,numeral:"M"},{value:900,numeral:"CM"},{value:500,numeral:"D"},{value:400,numeral:"CD"},{value:100,numeral:"C"},{value:90,numeral:"XC"},{value:50,numeral:"L"},{value:40,numeral:"XL"},{value:10,numeral:"X"},{value:9,numeral:"IX"},{value:5,numeral:"V"},{value:4,numeral:"IV"},{value:1,numeral:"I"}];if(typeof i!="number"||i<1||i>3999)throw new Error("Input must be a number between 1 and 3999.");for(var s="",l=0;l<o.length;l++)for(;i>=o[l].value;)s+=o[l].numeral,i-=o[l].value;return s}(t)+".";break;case"alphaUcPeriod":n.textContent=E0(t)+".";break;case"alphaLcPeriod":n.textContent=E0(t).toLowerCase()+".";break;case"alphaLcParenR":n.textContent=E0(t).toLowerCase()+")";break;case"ea1JpnChsDbPeriod":n.textContent=function(i){var o=["〇","一","二","三","四","五","六","七","八","九"];if(!Number.isInteger(i)||i<0)return"";for(var s="",l=i.toString(),u=0;u<l.length;u++)s+=o[parseInt(l[u],10)];return s}(t)+"."}r.prepend(n)}function up(r,e,t){var n,a,i,o;e===void 0&&(e=0),t===void 0&&(t={});var s=r.inheritProps,l=r.inheritRProps,u=r.props,c=r.rows,h=Dt(Dt({},s),u),d=function(){for(var A,T,L=0,M=0,I=c;M<I.length;M++){var R=I[M];R.props&&R.props.size&&(L=Math.max(L,R.props.size))}var P=((T=(A=t?.bodyProps)===null||A===void 0?void 0:A.normAutofit)===null||T===void 0?void 0:T.fontScale)||1;return(L||l.size||18)*P},v=document.createElement("div"),p=t.isFirst?0:h.spaceBefore||0,y=t.isLast?0:h.spaceAfter||0;v.style.margin="".concat(Math.floor(.2*d()),"px  0 0 0"),v.style.padding="".concat(Math.floor(p),"px 0px ").concat(Math.floor(y),"px 0px");var _=document.createElement("p");_.style.margin="0",_.style.padding="0px",_.style.wordBreak="break-word",_.style.textAlign=h.align&&{ctr:"center",l:"left",r:"right",dist:"justify"}[h.align]||"center",h.align==="dist"&&(_.style.textAlignLast="justify");var g=h.hasOwnProperty("lineHeight")?h.lineHeight:1;if(!((a=(n=t.bodyProps)===null||n===void 0?void 0:n.normAutofit)===null||a===void 0)&&a.lnSpcReduction&&(g*=1-((o=(i=t.bodyProps)===null||i===void 0?void 0:i.normAutofit)===null||o===void 0?void 0:o.lnSpcReduction)),_.style.lineHeight=g+"",_.style.fontSize=d()+"px",c.length){for(var f=0,w=c;f<w.length;f++){var x=w[f];x.isBr?_.appendChild(document.createElement("br")):_.appendChild(sot(x,Dt(Dt({},l),{marginTop:Math.floor(.2*d())}),t.bodyProps))}h.buAutoNum?lot(_,h,e):h.buChar&&function(A,T){var L=document.createElement("span"),M=A.firstElementChild;L.style.color=M.style.color,L.style.fontSize=M.style.fontSize,L.textContent={n:"■",l:"●",u:"◆",p:"□",ü:"✔",Ø:"➢","•":"•"}[T.buChar]||"■",L.style.marginRight="10px",A.prepend(L)}(_,h),_.style.paddingLeft=(h.marginLeft||0)+(h.indent||0)+"px"}else{var S=document.createElement("span");S.innerHTML="&nbsp;",S.style.fontSize=l.size+"px",_.appendChild(S)}return v.appendChild(_),v}var wB="http://www.w3.org/2000/svg";function _t(r){return document.createElementNS(wB,r)}function fi(r){var e=r.extend;return .16667*Math.min(e.w,e.h)}function $t(r,e,t){t===void 0&&(t=0);var n=e.prstGeom,a=(n?.gd||[]).find(function(i){return i.name===r});return a?a.fmla:t}function gt(r,e,t){t===void 0&&(t=0);var n=e.extend,a=e.prstGeom,i=(a?.gd||[]).find(function(o){return o.name===r});return i?Math.min(n.w,n.h)*i.fmla:t}function TI(r,e,t){t===void 0&&(t=0);var n=e.extend,a=e.prstGeom,i=(a?.gd||[]).find(function(o){return o.name===r});return i?Math.max(n.w,n.h)*i.fmla:t}function qa(r,e){var t=0;switch(r){case"sm":t=1*e;break;case"med":t=1.5*e;break;case"lg":t=2.5*e}return Math.max(t,2)}function CI(r,e,t,n){n===void 0&&(n=!1);var a=r.border,i=a===void 0?{}:a,o=r.uuid,s=i.headEnd,l=i.width,u=i.color,c=i.tailEnd,h=n?s:c,d=h.len,v=d===void 0?"med":d,p=h.w,y=p===void 0?"med":p,_=qa(v,l),g=qa(y,l),f=_t("defs"),w=_t("marker"),x="marker-".concat(o,"-").concat(n?"start":"end");w.setAttribute("id",x),w.setAttribute("viewBox","0 0 ".concat(2*_," ").concat(2*g)),w.setAttribute("refX",_+"px"),w.setAttribute("refY",g+"px"),w.setAttribute("markerWidth",2*_+"px"),w.setAttribute("markerHeight",2*g+"px"),w.setAttribute("orient","auto"),w.setAttribute("markerUnits","userSpaceOnUse");var S=_t("ellipse");S.setAttribute("cx",_+"px"),S.setAttribute("cy",g+"px"),S.setAttribute("rx",_+"px"),S.setAttribute("ry",g+"px"),S.setAttribute("fill",Le(u)||"transparent"),w.appendChild(S),f.appendChild(w),e.appendChild(f),t.setAttribute(n?"marker-start":"marker-end","url(#".concat(x,")"))}function LI(r,e,t,n){n===void 0&&(n=!1);var a=r.border,i=a===void 0?{}:a,o=r.uuid,s=i.headEnd,l=i.width,u=i.color,c=i.tailEnd,h=n?s:c,d=h.len,v=d===void 0?"med":d,p=h.w,y=p===void 0?"med":p,_=qa(v,l),g=qa(y,l),f=_t("defs"),w=_t("marker"),x="marker-".concat(o,"-").concat(n?"start":"end");w.setAttribute("id",x),w.setAttribute("viewBox","0 0 ".concat(2*_," ").concat(2*g)),w.setAttribute("refX",(n?.9*_:1.1*_)+"px"),w.setAttribute("refY",g+"px"),w.setAttribute("markerWidth",2*_+"px"),w.setAttribute("markerHeight",2*g+"px"),w.setAttribute("orient","auto"),w.setAttribute("markerUnits","userSpaceOnUse");var S=_t("path"),A=n?["M ".concat(2*_,",0"),"L 0,".concat(g),"L ".concat(2*_,",").concat(2*g),"Z"].join(" "):["M 0,0","L ".concat(2*_,",").concat(g),"L 0,".concat(2*g),"Z"].join(" ");S.setAttribute("d",A),S.setAttribute("fill",Le(u)||"transparent"),w.appendChild(S),f.appendChild(w),e.appendChild(f),t.setAttribute(n?"marker-start":"marker-end","url(#".concat(x,")"))}function MI(r,e,t,n){n===void 0&&(n=!1);var a=r.border,i=a===void 0?{}:a,o=r.uuid,s=i.headEnd,l=i.width,u=i.color,c=i.tailEnd,h=n?s:c,d=h.len,v=d===void 0?"med":d,p=h.w,y=p===void 0?"med":p,_=qa(v,l),g=qa(y,l),f=_t("defs"),w=_t("marker"),x="marker-".concat(o,"-").concat(n?"start":"end");w.setAttribute("id",x),w.setAttribute("viewBox","0 0 ".concat(2*_," ").concat(2*g)),w.setAttribute("refX",_+"px"),w.setAttribute("refY",g+"px"),w.setAttribute("markerWidth",2*_+"px"),w.setAttribute("markerHeight",2*g+"px"),w.setAttribute("orient","auto"),w.setAttribute("markerUnits","userSpaceOnUse");var S=_t("path"),A=["M 0,".concat(g),"L ".concat(_,",0"),"L ".concat(2*_,",").concat(g),"L ".concat(_,",").concat(2*g),"Z"].join(" ");S.setAttribute("d",A),S.setAttribute("fill",Le(u)||"transparent"),w.appendChild(S),f.appendChild(w),e.appendChild(f),t.setAttribute(n?"marker-start":"marker-end","url(#".concat(x,")"))}function DI(r,e,t,n){n===void 0&&(n=!1);var a=r.border,i=a===void 0?{}:a,o=r.uuid,s=i.headEnd,l=i.width,u=i.color,c=i.tailEnd,h=n?s:c,d=h.len,v=d===void 0?"med":d,p=h.w,y=p===void 0?"med":p,_=qa(v,l),g=qa(y,l),f=_t("defs"),w=_t("marker"),x="marker-".concat(o,"-").concat(n?"start":"end");w.setAttribute("id",x),w.setAttribute("viewBox","0 0 ".concat(2*_+2*l," ").concat(2*g+2*l));var S=n?y==="lg"?2*l:3*l:y==="lg"?2*_:2*_-l;w.setAttribute("refX",S+"px"),w.setAttribute("refY",g+l+"px"),w.setAttribute("markerWidth",2*_+"px"),w.setAttribute("markerHeight",2*g+"px"),w.setAttribute("orient","auto"),w.setAttribute("markerUnits","userSpaceOnUse");var A=_t("path"),T=n?["M ".concat(2*_+l,", ").concat(l),"L ".concat(l,",").concat(g+l),"L ".concat(2*_+l,",").concat(2*g+l)].join(" "):["M ".concat(l,", ").concat(l),"L ".concat(2*_+l,",").concat(g+l),"L ".concat(l,",").concat(2*g+l)].join(" ");A.setAttribute("d",T),A.setAttribute("stroke-width",l+"px"),A.setAttribute("stroke",Le(u)||"transparent"),A.setAttribute("fill","transparent"),A.setAttribute("stroke-linecap","round"),A.setAttribute("stroke-linejoin","miter"),A.style.overflow="visible",w.appendChild(A),f.appendChild(w),e.appendChild(f),t.setAttribute(n?"marker-start":"marker-end","url(#".concat(x,")"))}function II(r,e,t,n){n===void 0&&(n=!1);var a=r.border,i=a===void 0?{}:a,o=r.uuid,s=i.headEnd,l=i.width,u=i.color,c=i.tailEnd,h=n?s:c,d=h.len,v=d===void 0?"med":d,p=h.w,y=p===void 0?"med":p,_=qa(v,l),g=qa(y,l),f=_t("defs"),w=_t("marker"),x="marker-".concat(o,"-").concat(n?"start":"end");w.setAttribute("id",x),w.setAttribute("viewBox","0 0 ".concat(2*_," ").concat(2*g));var S=n?y==="sm"?1.5*l:2*l:y==="sm"?2*_-1.5*l:2*_-2*l;w.setAttribute("refX",S+"px"),w.setAttribute("refY",g+"px"),w.setAttribute("markerWidth",2*_+"px"),w.setAttribute("markerHeight",2*g+"px"),w.setAttribute("orient","auto"),w.setAttribute("markerUnits","userSpaceOnUse");var A=_t("path"),T=n?["M 0, ".concat(g),"L ".concat(2*_,",0"),"L ".concat(_,",").concat(g),"L ".concat(2*_,",").concat(2*g),"Z"].join(" "):["M 0,0","L ".concat(2*_,",").concat(g),"L 0,".concat(2*g),"L ".concat(_,",").concat(g),"Z"].join(" ");A.setAttribute("d",T),A.setAttribute("fill",Le(u)||"transparent"),A.style.overflow="visible",w.appendChild(A),f.appendChild(w),e.appendChild(f),t.setAttribute(n?"marker-start":"marker-end","url(#".concat(x,")"))}function pc(r,e,t){var n=r.border,a=n===void 0?{}:n;r.extend;var i=a.headEnd,o=a.tailEnd;if(i&&i.type!=="none")switch(i.type){case"triangle":LI(r,e,t,!0);break;case"oval":CI(r,e,t,!0);break;case"diamond":MI(r,e,t,!0);break;case"arrow":DI(r,e,t,!0);break;case"stealth":II(r,e,t,!0)}if(o&&o.type!=="none")switch(o.type){case"triangle":LI(r,e,t,!1);break;case"oval":CI(r,e,t,!1);break;case"diamond":MI(r,e,t,!1);break;case"arrow":DI(r,e,t,!1);break;case"stealth":II(r,e,t,!1)}}function PI(r){var e=r.extend,t=_t("rect");return t.setAttribute("x","0"),t.setAttribute("y","0"),t.setAttribute("width",e.w+"px"),t.setAttribute("height",e.h+"px"),t}function zr(r,e,t,n,a){var i=r*Math.PI/180;return[i===0||i===2*Math.PI?e+n:i===Math.PI?e-n:i===Math.PI/2||i===3*Math.PI/2?e:i>0&&i<Math.PI/2||i>3*Math.PI/2&&i<2*Math.PI?e+Math.sqrt(1/(1/Math.pow(n,2)+Math.pow(Math.tan(i),2)/Math.pow(a,2))):e-Math.sqrt(1/(1/Math.pow(n,2)+Math.pow(Math.tan(i),2)/Math.pow(a,2))),i===0||i===2*Math.PI||i===Math.PI?t:i===Math.PI/2?t+a:i===3*Math.PI/2?t-a:i>Math.PI&&i<2*Math.PI?t-Math.sqrt(1/(1/Math.pow(a,2)+Math.pow(1/Math.tan(i),2)/Math.pow(n,2))):t+Math.sqrt(1/(1/Math.pow(a,2)+Math.pow(1/Math.tan(i),2)/Math.pow(n,2)))]}function gc(r,e){var t=0;return(e>r&&e-r>180||e<r&&r-e<180)&&(t=1),t}function yc(r){var e=r.extend,t=.146*e.w,n=.146*e.h;return{top:n,bottom:n,left:t,right:t,w:e.w-2*t,h:e.h-2*n}}function k1(r){var e=r.extend,t=r.offset,n=r.border,a=r.background,i=r.rotate,o=r.flipH,s=r.flipV,l=document.createElement("div"),u=t.x,c=t.y;l.className="shape-wrapper shape-".concat(r.shape),l.style.setProperty("position","absolute"),l.style.setProperty("width",(e.w||1)+"px"),l.style.setProperty("height",(e.h||1)+"px"),l.style.setProperty("left",u+"px"),l.style.setProperty("top",c+"px");var h,d=document.createElementNS(wB,"svg");d.style.setProperty("position","absolute"),d.setAttribute("width","100%"),d.setAttribute("height","100%"),d.style.setProperty("left","0"),d.style.setProperty("top","0"),d.style.overflow="visible";var v={left:0,top:0,bottom:0,w:e.w,h:e.h},p=!0;switch(r.shape){case"customGeom":h=function(g){var f=g.prstGeom,w=f===void 0?{}:f,x=g.extend,S=w.pathList,A=w.w,T=w.h,L=_t("path"),M={moveTo:"M",lnTo:"L",cubicBezTo:"C",close:"Z"},I=x.w/A,R=x.h/T,P=S.map(function(E){var D=M[E.type],N=Array.isArray(E.points)?E.points.map(function(V){return"".concat(V[0]*I,",").concat(V[1]*R)}).join(" "):"";return N?"".concat(D," ").concat(N):"".concat(D)}).join(" ");return L.setAttribute("d",P),L.style.fillRule="evenodd",L}(r),pc(r,d,h);break;case"flowChartProcess":case"rect":h=PI(r);break;case"snip1Rect":h=function(g){var f=g.extend,w=_t("polygon"),x=gt("adj",g,fi(g)),S=["0,0","".concat(f.w-x,",0"),"".concat(f.w,",").concat(x),"".concat(f.w,",").concat(f.h),"0,".concat(f.h)].join(" ");return w.setAttribute("points",S),w}(r);break;case"snip2SameRect":h=function(g){var f=g.extend,w=_t("polygon"),x=gt("adj1",g,fi(g)),S=gt("adj2",g,0),A=[[x,0],[f.w-x,0],[f.w,x],[f.w,f.h-S],[f.w-S,f.h],[S,f.h],[0,f.h-S],[0,x]].map(function(T){return"".concat(T[0],",").concat(T[1])}).join(" ");return w.setAttribute("points",A),w}(r);break;case"snip2DiagRect":h=function(g){var f=g.extend,w=_t("polygon"),x=gt("adj1",g,0),S=gt("adj2",g,fi(g)),A=[[x,0],[f.w-S,0],[f.w,S],[f.w,f.h-x],[f.w-x,f.h],[S,f.h],[0,f.h-S],[0,x]].map(function(T){return"".concat(T[0],",").concat(T[1])}).join(" ");return w.setAttribute("points",A),w}(r);break;case"snipRoundRect":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj1",g,fi(g)),S=gt("adj2",g,fi(g)),A=["M ".concat(x,",0"),"L ".concat(f.w-S,",0"),"L ".concat(f.w,",").concat(S),"L ".concat(f.w,",").concat(f.h),"L 0,".concat(f.h),"L 0,".concat(x),"Q 0,0 ".concat(x,",0"),"Z"].join(" ");return w.setAttribute("d",A),w}(r);break;case"roundRect":h=function(g){var f=PI(g),w=gt("adj",g,fi(g));return f.setAttribute("rx",w+"px"),f.setAttribute("ry",w+"px"),f}(r);break;case"round1Rect":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,fi(g)),S=["M 0,0","L ".concat(f.w-x,",0"),"Q ".concat(f.w,",0 ").concat(f.w,",").concat(x),"L ".concat(f.w,",").concat(f.h),"L 0,".concat(f.h),"Z"].join(" ");return w.setAttribute("d",S),w}(r);break;case"round2SameRect":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj1",g,fi(g)),S=gt("adj2",g,0),A=["M ".concat(x,",0"),"L ".concat(f.w-x,",0"),"Q ".concat(f.w,",0 ").concat(f.w,",").concat(x),"L ".concat(f.w,",").concat(f.h-S),"Q ".concat(f.w,",").concat(f.h," ").concat(f.w-S,",").concat(f.h),"L ".concat(S,",").concat(f.h),"Q 0,".concat(f.h," 0,").concat(f.h-S),"L 0,".concat(x),"Q 0,0 ".concat(x,",0"),"Z"].join(" ");return w.setAttribute("d",A),w}(r);break;case"round2DiagRect":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj1",g,fi(g)),S=gt("adj2",g,0),A=["M ".concat(x,",0"),"L ".concat(f.w-S,",0"),"Q ".concat(f.w,",0 ").concat(f.w,",").concat(S),"L ".concat(f.w,",").concat(f.h-x),"Q ".concat(f.w,",").concat(f.h," ").concat(f.w-x,",").concat(f.h),"L ".concat(S,",").concat(f.h),"Q 0,".concat(f.h," 0,").concat(f.h-S),"L 0,".concat(x),"Q 0,0 ".concat(x,",0"),"Z"].join(" ");return w.setAttribute("d",A),w}(r);break;case"triangle":h=function(g){var f=g.extend,w=_t("polygon"),x=["".concat(f.w/2,",0"),"0,".concat(f.h),"".concat(f.w,",").concat(f.h)].join(" ");return w.setAttribute("points",x),w}(r);break;case"rtTriangle":h=function(g){var f=g.extend,w=_t("polygon"),x=["0,".concat(f.h),"0,0","".concat(f.w,",").concat(f.h)].join(" ");return w.setAttribute("points",x),w}(r);break;case"ellipse":h=function(g){var f=g.extend,w=_t("ellipse"),x=f.w/2,S=f.h/2,A=x,T=S;return w.setAttribute("cx",x+"px"),w.setAttribute("cy",S+"px"),w.setAttribute("rx",A+"px"),w.setAttribute("ry",T+"px"),w}(r);break;case"line":h=function(g){var f=g.extend,w=_t("path"),x=["M 0,0","L ".concat(f.w,",").concat(f.h)].join(" ");return w.setAttribute("d",x),w}(r),pc(r,d,h),p=!1;break;case"straightConnector1":h=function(g){var f=g.extend,w=_t("path"),x=["M 0,0","L ".concat(f.w,",").concat(f.h)].join(" ");return w.setAttribute("d",x),w}(r),pc(r,d,h),p=!1;break;case"bentConnector3":h=function(g){var f=g.extend,w=_t("path"),x=TI("adj1",g,.5*Math.max(f.w,f.h)),S=["M 0,0","L ".concat(x,",0"),"L ".concat(x,",").concat(f.h),"L ".concat(f.w,",").concat(f.h)].join(" ");return w.setAttribute("d",S),w}(r),pc(r,d,h),p=!1;break;case"curvedConnector3":h=function(g){var f=g.extend,w=_t("path"),x=TI("adj1",g,.5*Math.max(f.w,f.h)),S=["M0,0","Q".concat(x,",0 ").concat(x,",").concat(f.h/2),"T".concat(f.w,",").concat(f.h)].join(" ");return w.setAttribute("d",S),w}(r),pc(r,d,h),p=!1;break;case"parallelogram":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.5*Math.min(f.w,f.h)),S=["M".concat(x,",0"),"L".concat(f.w,",0"),"L".concat(f.w-x,",").concat(f.h),"L0,".concat(f.h),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj",g,.5*Math.min(f.w,f.h)),x=.84*(f.w-w),S=.08*f.h+w/f.w*f.h*.42;return{top:S,bottom:S,left:(f.w-x)/2,right:(f.w-x)/2,w:x,h:f.h-2*S}}(r);break;case"trapezoid":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.25*Math.min(f.w,f.h)),S=["M".concat(x,",0"),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(f.h),"L0,".concat(f.h),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj",g,.5*Math.min(f.w,f.h)),x=w/f.w*.66*f.h,S=.66*w;return{top:x,bottom:0,left:S,right:S,w:f.w-2*S,h:f.h-x}}(r);break;case"diamond":h=function(g){var f=g.extend,w=_t("path"),x=["M".concat(f.w/2,",0"),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w/2,",").concat(f.h),"L0,".concat(f.h/2),"Z"].join(" ");return w.setAttribute("d",x),w}(r),v=function(g){var f=g.extend,w=.25*f.h,x=.25*f.w;return{top:w,bottom:w,left:x,right:x,w:.5*f.w,h:.5*f.h}}(r);break;case"pentagon":h=function(g){var f=g.extend,w=_t("path"),x=["M".concat(f.w/2,",0"),"L".concat(f.w,",").concat(.3771*f.h),"L".concat(.808*f.w,",").concat(f.h),"L".concat(.192*f.w,",").concat(f.h),"L0,".concat(.3771*f.h),"Z"].join(" ");return w.setAttribute("d",x),w}(r),v=function(g){var f=g.extend,w=.227*f.h,x=.192*f.w;return{top:w,bottom:0,left:x,right:x,w:.616*f.w,h:.773*f.h}}(r);break;case"hexagon":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.25*Math.min(f.w,f.h)),S=["M".concat(x,",0"),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-x,",").concat(f.h),"L".concat(x,",").concat(f.h),"L0,".concat(f.h/2),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj",g,.25*Math.min(f.w,f.h)),x=.098*f.h+w/f.w*.38*f.h,S=.088*f.w+.422*w;return{top:x,bottom:x,left:S,right:S,w:f.w-2*S,h:f.h-2*x}}(r);break;case"heptagon":h=function(g){var f=g.extend,w=_t("path"),x=["M".concat(f.w/2,",0"),"L".concat(.9*f.w,",").concat(.2*f.h),"L".concat(f.w,",").concat(.642*f.h),"L".concat(.722*f.w,",").concat(f.h),"L".concat(.278*f.w,",").concat(f.h),"L0,".concat(.642*f.h),"L".concat(.1*f.w,",").concat(.2*f.h),"Z"].join(" ");return w.setAttribute("d",x),w}(r),v=function(g){var f=g.extend;return{top:.2*f.h,bottom:.2*f.h,left:.1*f.w,right:.1*f.w,w:.8*f.w,h:.6*f.h}}(r);break;case"octagon":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.29*Math.min(f.w,f.h)),S=["M".concat(x,",0"),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(x),"L".concat(f.w,",").concat(f.h-x),"L".concat(f.w-x,",").concat(f.h),"L".concat(x,",").concat(f.h),"L0,".concat(f.h-x),"L0,".concat(x),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj",g,.29*Math.min(f.w,f.h));return{top:.5*w,bottom:.5*w,left:.5*w,right:.5*w,w:f.w-w,h:f.h-w}}(r);break;case"decagon":h=function(g){var f=g.extend,w=_t("path"),x=.344,S=.117,A=.19,T=["M".concat(f.w*x,",0"),"L".concat(.656*f.w,",0"),"L".concat(.883*f.w,",").concat(f.h*A),"L".concat(f.w,",").concat(.5*f.h),"L".concat(.883*f.w,",").concat(.81*f.h),"L".concat(.656*f.w,",").concat(f.h),"L".concat(f.w*x,",").concat(f.h),"L".concat(f.w*S,",").concat(.81*f.h),"L0,".concat(.5*f.h),"L".concat(f.w*S,",").concat(f.h*A),"Z"].join(" ");return w.setAttribute("d",T),w}(r),v=function(g){var f=g.extend,w=.117,x=.19;return{top:f.h*x,bottom:f.h*x,left:f.w*w,right:f.w*w,w:.766*f.w,h:.62*f.h}}(r);break;case"dodecagon":h=function(g){var f=g.extend,w=_t("path"),x=.364,S=.133,A=.135,T=["M".concat(f.w*x,",0"),"L".concat(.636*f.w,",0"),"L".concat(.867*f.w,",").concat(f.h*A),"L".concat(f.w,",").concat(f.h*x),"L".concat(f.w,",").concat(.636*f.h),"L".concat(.867*f.w,",").concat(.865*f.h),"L".concat(.636*f.w,",").concat(f.h),"L".concat(f.w*x,",").concat(f.h),"L".concat(f.w*S,",").concat(.865*f.h),"L0,".concat(.636*f.h),"L0,".concat(f.h*x),"L".concat(f.w*S,",").concat(f.h*A),"Z"].join(" ");return w.setAttribute("d",T),w}(r),v=function(g){var f=g.extend,w=.133,x=.135;return{top:f.h*x,bottom:f.h*x,left:f.w*w,right:f.w*w,w:.734*f.w,h:.73*f.h}}(r);break;case"pie":h=function(g){var f=g.extend,w=_t("path"),x=$t("adj1",g,360),S=$t("adj2",g,270),A=f.w/2,T=f.h/2,L=f.w/2,M=f.h/2,I=zr(x,L,M,A,T),R=I[0],P=I[1],E=zr(S,L,M,A,T),D=E[0],N=E[1],V=gc(x,S),W="M".concat(L,",").concat(M,", L").concat(R," ").concat(P," A ").concat(A," ").concat(T," 0 ").concat(V," ").concat(1," ").concat(D," ").concat(N," Z");return w.setAttribute("d",W),w}(r),v=yc(r);break;case"arc":h=function(g){var f=g.extend,w=_t("path"),x=$t("adj1",g,270),S=$t("adj2",g,0),A=f.w/2,T=f.h/2,L=f.w/2,M=f.h/2,I=zr(x,L,M,A,T),R=I[0],P=I[1],E=zr(S,L,M,A,T),D=E[0],N=E[1],V=gc(x,S),W="M".concat(R,",").concat(P," A ").concat(A," ").concat(T," 0 ").concat(V," ").concat(1," ").concat(D," ").concat(N);return w.setAttribute("d",W),w}(r),p=!1;break;case"bracketPair":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.16667*Math.min(f.w,f.h)),S=["M".concat(x,",").concat(f.h),"Q".concat(0,",").concat(f.h," ").concat(0,",").concat(f.h-x),"L".concat(0,",").concat(x),"Q".concat(0,",").concat(0," ").concat(x,",").concat(0),"M".concat(f.w-x,",").concat(0),"Q".concat(f.w,",").concat(0," ").concat(f.w,",").concat(x),"L".concat(f.w,",").concat(f.h-x),"Q".concat(f.w,",").concat(f.h," ").concat(f.w-x,",").concat(f.h)].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=.285*gt("adj",g,.16667*Math.min(f.w,f.h));return{top:w,bottom:w,left:w,right:w,w:f.w-2*w,h:f.h-2*w}}(r),p=!1;break;case"bracePair":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.083335*Math.min(f.w,f.h)),S=["M".concat(2*x,",").concat(f.h),"Q".concat(x,",").concat(f.h," ").concat(x,",").concat(f.h-x),"L".concat(x,",").concat(f.h/2+x),"Q".concat(x,",").concat(f.h/2," ").concat(0,",").concat(f.h/2),"Q".concat(x,",").concat(f.h/2," ").concat(x,",").concat(f.h/2-x),"L".concat(x,",").concat(x),"Q".concat(x,",").concat(0," ").concat(2*x,",").concat(0),"M".concat(f.w-2*x,",").concat(0),"Q".concat(f.w-x,",").concat(0," ").concat(f.w-x,",").concat(x),"L".concat(f.w-x,",").concat(f.h/2-x),"Q".concat(f.w-x,",").concat(f.h/2," ").concat(f.w,",").concat(f.h/2),"Q".concat(f.w-x,",").concat(f.h/2," ").concat(f.w-x,",").concat(f.h/2+x),"L".concat(f.w-x,",").concat(f.h-x),"Q".concat(f.w-x,",").concat(f.h," ").concat(f.w-2*x,",").concat(f.h)].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=.285*gt("adj",g,.16667*Math.min(f.w,f.h));return{top:w,bottom:w,left:w,right:w,w:f.w-2*w,h:f.h-2*w}}(r),p=!1;break;case"chord":h=function(g){var f=g.extend,w=_t("path"),x=$t("adj1",g,45),S=$t("adj2",g,270),A=f.w/2,T=f.h/2,L=f.w/2,M=f.h/2,I=zr(x,L,M,A,T),R=I[0],P=I[1],E=zr(S,L,M,A,T),D=E[0],N=E[1],V=gc(x,S),W="M".concat(R," ").concat(P," A ").concat(A," ").concat(T," 0 ").concat(V," ").concat(1," ").concat(D," ").concat(N," Z");return w.setAttribute("d",W),w}(r),v=yc(r);break;case"teardrop":h=function(g){var f=g.extend,w=_t("path"),x=$t("adj",g,1),S=f.w/2,A=f.h/2,T=f.w/2,L=f.h/2,M=zr(0,T,L,S,A),I=M[0],R=M[1],P=zr(270,T,L,S,A),E=P[0],D=P[1],N=gc(0,270),V="M".concat(I," ").concat(R," A ").concat(S," ").concat(A," 0 ").concat(N," ").concat(1," ").concat(E," ").concat(D),W=S*x,$=T+W,H=L-A*W/(f.w/2),K=(f.w/2+$)/2,U=(f.h/2+H)/2;return V+=" Q".concat(K,",0 ").concat($,",").concat(H),V+=" Q".concat(f.w,",").concat(U," ").concat(T+S,",").concat(L),w.setAttribute("d",V),w}(r),v=yc(r);break;case"frame":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj1",g,.12*Math.min(f.w,f.h)),S=["M0,0","L".concat(f.w,",0"),"L".concat(f.w,",").concat(f.h),"L0,".concat(f.h),"Z","M".concat(x,",").concat(x),"L".concat(x,",").concat(f.h-x),"L".concat(f.w-x,",").concat(f.h-x),"L".concat(f.w-x,",").concat(x),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.12*Math.min(f.w,f.h));return{top:w,bottom:w,left:w,right:w,w:f.w-2*w,h:f.h-2*w}}(r);break;case"halfFrame":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj1",g,.333*Math.min(f.w,f.h)),S=Math.min(gt("adj2",g,.333*Math.min(f.w,f.h)),f.w*(1-x/f.h)),A=["M0,0","L".concat(f.w,",0"),"L".concat(f.w*(1-x/f.h),",").concat(x),"L".concat(S,",").concat(x),"L".concat(S,",").concat(f.h*(1-S/f.w)),"L0,".concat(f.h),"Z"].join(" ");return w.setAttribute("d",A),w}(r);break;case"corner":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj1",g,.5*Math.min(f.w,f.h)),S=gt("adj2",g,.5*Math.min(f.w,f.h)),A=["M0,0","L".concat(S,",0"),"L".concat(S,",").concat(f.h-x),"L".concat(f.w,",").concat(f.h-x),"L".concat(f.w,",").concat(f.h),"L0,".concat(f.h),"Z"].join(" ");return w.setAttribute("d",A),w}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h));return{top:f.h-w,bottom:0,left:0,right:0,w:f.w,h:w}}(r);break;case"diagStripe":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.5*Math.min(f.w,f.h)),S=f.w*x/f.h,A=["M".concat(S,",0"),"L".concat(f.w,",0"),"L0,".concat(f.h),"L0,".concat(x),"Z"].join(" ");return w.setAttribute("d",A),w}(r),v=function(g){var f=g.extend,w=$t("adj",g,.5),x=.5*(1-w)*f.h,S=.5*(1-w)*f.w;return{top:0,bottom:x,left:0,right:S,w:f.w-S,h:f.h-x}}(r);break;case"plus":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.25*Math.min(f.w,f.h)),S=["M".concat(x,",0"),"L".concat(f.w-x,",0"),"L".concat(f.w-x,",").concat(x),"L".concat(f.w,",").concat(x),"L".concat(f.w,",").concat(f.h-x),"L".concat(f.w-x,",").concat(f.h-x),"L".concat(f.w-x,",").concat(f.h),"L".concat(x,",").concat(f.h),"L".concat(x,",").concat(f.h-x),"L0,".concat(f.h-x),"L0,".concat(x),"L".concat(x,",").concat(x),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj",g,.25*Math.min(f.w,f.h));return{top:w,bottom:w,left:0,right:0,w:f.w,h:f.h-2*w}}(r);break;case"plaque":h=function(g){var f=g.extend,w=_t("path"),x=gt("adj",g,.16667*Math.min(f.w,f.h)),S=["M".concat(x,",0"),"L".concat(f.w-x,",0"),"Q".concat(f.w-x,",").concat(x," ").concat(f.w,",").concat(x),"L".concat(f.w,",").concat(f.h-x),"Q".concat(f.w-x,",").concat(f.h-x," ").concat(f.w-x,",").concat(f.h),"L".concat(x,",").concat(f.h),"Q".concat(x,",").concat(f.h-x," 0,").concat(f.h-x),"L0,".concat(x),"Q".concat(x,",").concat(x," ").concat(x,",0"),"Z"].join(" ");return w.setAttribute("d",S),w}(r),v=function(g){var f=g.extend,w=gt("adj",g,.16667*Math.min(f.w,f.h));return{top:.72*w,bottom:.72*w,left:.72*w,right:.72*w,w:f.w-1.44*w,h:f.w-1.44*w}}(r);break;case"can":h=function(g){var f=g.extend,w=g.background,x=_t("g"),S=_t("path"),A=gt("adj",g,.25*Math.min(f.w,f.h)),T=["M0,".concat(A/2),"L0,".concat(f.h-A/2),"A".concat(f.w/2,",").concat(A/2," 0 0 0 ").concat(f.w,",").concat(f.h-A/2),"L".concat(f.w,",").concat(A/2),"A".concat(f.w/2,",").concat(A/2," 0 0 1 0,").concat(A/2),"Z"].join(" ");S.setAttribute("d",T);var L=_t("ellipse"),M=f.w/2,I=A/2,R=f.w/2,P=A/2;return L.setAttribute("cx",M+"px"),L.setAttribute("cy",I+"px"),L.setAttribute("rx",R+"px"),L.setAttribute("ry",P+"px"),w?.type==="solidFill"&&L.setAttribute("fill",Le(w,{light:.5})||"transparent"),x.appendChild(S),x.appendChild(L),x}(r),v=function(g){var f=g.extend,w=gt("adj",g,.25*Math.min(f.w,f.h));return{top:w,bottom:0,left:0,right:0,w:f.w,h:f.h-w}}(r);break;case"cube":h=function(g){var f=g.extend,w=g.background,x=gt("adj",g,.25*Math.min(f.w,f.h)),S=_t("g"),A=_t("path"),T=["M0,".concat(x),"L".concat(f.w-x,",").concat(x),"L".concat(f.w-x,",").concat(f.h),"L0,".concat(f.h),"Z"].join(" ");A.setAttribute("d",T);var L=_t("path"),M=["M0,".concat(x),"L".concat(x,",0"),"L".concat(f.w,",0"),"L".concat(f.w-x,",").concat(x),"Z"].join(" ");L.setAttribute("d",M),w?.type==="solidFill"&&L.setAttribute("fill",Le(w,{light:.8})||"transparent");var I=_t("path"),R=["M".concat(f.w,",0"),"L".concat(f.w-x,",").concat(x),"L".concat(f.w-x,",").concat(f.h),"L".concat(f.w,",").concat(f.h-x),"Z"].join(" ");return I.setAttribute("d",R),w?.type==="solidFill"&&I.setAttribute("fill",Le(w,{dark:.6})||"transparent"),S.appendChild(A),S.appendChild(L),S.appendChild(I),S}(r),v=function(g){var f=g.extend,w=gt("adj",g,.25*Math.min(f.w,f.h));return{top:w,bottom:0,left:0,right:w,w:f.w-w,h:f.h-w}}(r);break;case"bevel":h=function(g){var f=g.extend,w=g.background,x=gt("adj",g,.125*Math.min(f.w,f.h)),S=_t("g"),A=_t("path"),T=["M".concat(x,",").concat(x),"L".concat(f.w-x,",").concat(x),"L".concat(f.w-x,",").concat(f.h-x),"L".concat(x,",").concat(f.h-x),"Z"].join(" ");A.setAttribute("d",T);var L=_t("path"),M=["M0,0","L".concat(x,",").concat(x),"L".concat(f.w-x,",").concat(x),"L".concat(f.w,",0"),"Z"].join(" ");L.setAttribute("d",M),w?.type==="solidFill"&&L.setAttribute("fill",Le(w,{light:.8})||"transparent");var I=_t("path"),R=["M".concat(f.w,",0"),"L".concat(f.w-x,",").concat(x),"L".concat(f.w-x,",").concat(f.h-x),"L".concat(f.w,",").concat(f.h),"Z"].join(" ");I.setAttribute("d",R),w?.type==="solidFill"&&I.setAttribute("fill",Le(w,{dark:.6})||"transparent");var P=_t("path"),E=["M".concat(f.w,",").concat(f.h),"L".concat(f.w-x,",").concat(f.h-x),"L".concat(x,",").concat(f.h-x),"L0,".concat(f.h),"Z"].join(" ");P.setAttribute("d",E),w?.type==="solidFill"&&P.setAttribute("fill",Le(w,{dark:.625})||"transparent");var D=_t("path"),N=["M0,".concat(f.h),"L".concat(x,",").concat(f.h-x),"L".concat(x,",").concat(x),"L0,0","Z"].join(" ");return D.setAttribute("d",N),w?.type==="solidFill"&&D.setAttribute("fill",Le(w,{light:.6})||"transparent"),S.appendChild(A),S.appendChild(L),S.appendChild(I),S.appendChild(P),S.appendChild(D),S}(r),v=function(g){var f=g.extend,w=gt("adj",g,.125*Math.min(f.w,f.h));return{top:w,bottom:w,left:w,right:w,w:f.w-2*w,h:f.h-2*w}}(r);break;case"donut":h=function(g){var f=g.extend,w=gt("adj",g,.25*Math.min(f.w,f.h)),x=_t("path"),S=["M0,".concat(f.h/2),"A".concat(f.w/2,",").concat(f.h/2," 0 1,1 0,").concat(f.h/2+1),"Z","M".concat(f.w-w,",").concat(f.h/2),"A".concat(f.w/2-w,",").concat(f.h/2-w," 0 1,0 ").concat(f.w-w,",").concat(f.h/2+1),"Z"].join(" ");return x.setAttribute("d",S),x}(r),v=yc(r);break;case"noSmoking":h=function(g){var f=g.extend,w=gt("adj",g,.25*Math.min(f.w,f.h)),x=_t("path"),S=Math.atan(f.h/f.w),A=w/2/Math.sin(S),T=f.w/2,L=f.h/2,M=-1*f.h/f.w,I=f.h*A/f.w,R=f.w/2-w,P=f.h/2-w,E=-2*R*R*M*I,D=Math.sqrt(Math.pow(2*R*R*M*I,2)-4*(P*P+R*R*M*M)*R*R*(I*I-P*P)),N=2*(P*P+R*R*M*M),V=(E-D)/N,W=M*V+I,$=(E+D)/N,H=M*$+I,K=-f.h*A/f.w,U=-2*R*R*M*K,j=Math.sqrt(Math.pow(2*R*R*M*K,2)-4*(P*P+R*R*M*M)*R*R*(K*K-P*P)),ut=2*(P*P+R*R*M*M),ot=(U-j)/ut,it=M*ot+K,Et=(U+j)/ut,jt=M*Et+K,bt=["M0,".concat(f.h/2),"A".concat(f.w/2,",").concat(f.h/2," 0 1,1 0,").concat(f.h/2+1),"Z","M".concat(T+$,",").concat(L-H),"A".concat(R,",").concat(P," 0 0 0 ").concat(T+V,",").concat(L-W),"Z","M".concat(T+ot,",").concat(L-it),"A".concat(R,",").concat(P," 0 0 0 ").concat(T+Et,",").concat(L-jt),"Z"].join(" ");return x.setAttribute("d",bt),x}(r),v=yc(r);break;case"rightArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=gt("adj2",g,.5*Math.min(f.w,f.h)),S=_t("path"),A=["M0,".concat(f.h/2-w/2),"L".concat(f.w-x,",").concat(f.h/2-w/2),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-x,",").concat(f.h),"L".concat(f.w-x,",").concat(f.h/2+w/2),"L0,".concat(f.h/2+w/2),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=w*gt("adj2",g,.5*Math.min(f.w,f.h))/f.h;return{top:f.h/2-w/2,bottom:f.h/2-w/2,left:0,right:x,w:f.w-x,h:w}}(r);break;case"leftArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=gt("adj2",g,.5*Math.min(f.w,f.h)),S=_t("path"),A=["M0,".concat(f.h/2),"L".concat(x,",0"),"L".concat(x,",").concat(f.h/2-w/2),"L".concat(f.w,",").concat(f.h/2-w/2),"L".concat(f.w,",").concat(f.h/2+w/2),"L".concat(x,",").concat(f.h/2+w/2),"L".concat(x,",").concat(f.h),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=w*gt("adj2",g,.5*Math.min(f.w,f.h))/f.h;return{top:f.h/2-w/2,bottom:f.h/2-w/2,left:x,right:0,w:f.w-x,h:w}}(r);break;case"upArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=gt("adj2",g,.5*Math.min(f.w,f.h)),S=_t("path"),A=["M".concat(f.w/2,",0"),"L".concat(f.w,",").concat(x),"L".concat(f.w/2+w/2,",").concat(x),"L".concat(f.w/2+w/2,",").concat(f.h),"L".concat(f.w/2-w/2,",").concat(f.h),"L".concat(f.w/2-w/2,",").concat(x),"L0,".concat(x),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=w*gt("adj2",g,.5*Math.min(f.w,f.h))/f.w;return{top:x,bottom:0,left:f.w/2-w/2,right:f.w/2-w/2,w,h:f.h-x}}(r);break;case"downArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=gt("adj2",g,.5*Math.min(f.w,f.h)),S=_t("path"),A=["M".concat(f.w/2,",").concat(f.h),"L0,".concat(f.h-x),"L".concat(f.w/2-w/2,",").concat(f.h-x),"L".concat(f.w/2-w/2,",0"),"L".concat(f.w/2+w/2,",0"),"L".concat(f.w/2+w/2,",").concat(f.h-x),"L".concat(f.w,",").concat(f.h-x),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=w*gt("adj2",g,.5*Math.min(f.w,f.h))/f.w;return{top:0,bottom:x,left:f.w/2-w/2,right:f.w/2-w/2,w,h:f.h-x}}(r);break;case"leftRightArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=gt("adj2",g,.5*Math.min(f.w,f.h)),S=_t("path"),A=["M0,".concat(f.h/2),"L".concat(x,",0"),"L".concat(x,",").concat(f.h/2-w/2),"L".concat(f.w-x,",").concat(f.h/2-w/2),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-x,",").concat(f.h),"L".concat(f.w-x,",").concat(f.h/2+w/2),"L".concat(x,",").concat(f.h/2+w/2),"L".concat(x,",").concat(f.h),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=w*gt("adj2",g,.5*Math.min(f.w,f.h))/f.h;return{top:f.h/2-w/2,bottom:f.h/2-w/2,left:x,right:x,w:f.w-2*x,h:w}}(r);break;case"upDownArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=gt("adj2",g,.5*Math.min(f.w,f.h)),S=_t("path"),A=["M".concat(f.w/2,",").concat(f.h),"L0,".concat(f.h-x),"L".concat(f.w/2-w/2,",").concat(f.h-x),"L".concat(f.w/2-w/2,",").concat(x),"L0,".concat(x),"L".concat(f.w/2,",0"),"L".concat(f.w,",").concat(x),"L".concat(f.w/2+w/2,",").concat(x),"L".concat(f.w/2+w/2,",").concat(f.h-x),"L".concat(f.w,",").concat(f.h-x),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.5*Math.min(f.w,f.h)),x=w*gt("adj2",g,.5*Math.min(f.w,f.h))/f.w;return{top:x,bottom:x,left:f.w/2-w/2,right:f.w/2-w/2,w,h:f.h-2*x}}(r);break;case"quadArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.225*Math.min(f.w,f.h)),x=gt("adj2",g,.225*Math.min(f.w,f.h)),S=gt("adj3",g,.225*Math.min(f.w,f.h)),A=_t("path"),T=["M0,".concat(f.h/2),"L".concat(S,",").concat(f.h/2-x),"L".concat(S,",").concat(f.h/2-w/2),"L".concat(f.w/2-w/2,",").concat(f.h/2-w/2),"L".concat(f.w/2-w/2,",").concat(S),"L".concat(f.w/2-x,",").concat(S),"L".concat(f.w/2,",0"),"L".concat(f.w/2+x,",").concat(S),"L".concat(f.w/2+w/2,",").concat(S),"L".concat(f.w/2+w/2,",").concat(f.h/2-w/2),"L".concat(f.w-S,",").concat(f.h/2-w/2),"L".concat(f.w-S,",").concat(f.h/2-x),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-S,",").concat(f.h/2+x),"L".concat(f.w-S,",").concat(f.h/2+w/2),"L".concat(f.w/2+w/2,",").concat(f.h/2+w/2),"L".concat(f.w/2+w/2,",").concat(f.h-S),"L".concat(f.w/2+x,",").concat(f.h-S),"L".concat(f.w/2,",").concat(f.h),"L".concat(f.w/2-x,",").concat(f.h-S),"L".concat(f.w/2-w/2,",").concat(f.h-S),"L".concat(f.w/2-w/2,",").concat(f.h/2+w/2),"L".concat(S,",").concat(f.h/2+w/2),"L".concat(S,",").concat(f.h/2+x),"Z"].join(" ");return A.setAttribute("d",T),A}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.225*Math.min(f.w,f.h)),x=gt("adj2",g,.225*Math.min(f.w,f.h)),S=gt("adj3",g,.225*Math.min(f.w,f.h)),A=x===0?0:w*S/x/2;return{top:f.h/2-w/2,bottom:f.h/2-w/2,left:A,right:A,w:f.w-2*A,h:w}}(r);break;case"leftRightUpArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.225*Math.min(f.w,f.h)),x=gt("adj2",g,.225*Math.min(f.w,f.h)),S=gt("adj3",g,.225*Math.min(f.w,f.h)),A=_t("path");w>2*x&&(w=2*x);var T=["M0,".concat(f.h-x),"L".concat(S,",").concat(f.h-2*x),"L".concat(S,",").concat(f.h-x-w/2),"L".concat(f.w/2-w/2,",").concat(f.h-x-w/2),"L".concat(f.w/2-w/2,",").concat(S),"L".concat(f.w/2-x,",").concat(S),"L".concat(f.w/2,",0"),"L".concat(f.w/2+x,",").concat(S),"L".concat(f.w/2+w/2,",").concat(S),"L".concat(f.w/2+w/2,",").concat(f.h-x-w/2),"L".concat(f.w-S,",").concat(f.h-x-w/2),"L".concat(f.w-S,",").concat(f.h-2*x),"L".concat(f.w,",").concat(f.h-x),"L".concat(f.w-S,",").concat(f.h),"L".concat(f.w-S,",").concat(f.h-x+w/2),"L".concat(S,",").concat(f.h-x+w/2),"L".concat(S,",").concat(f.h),"Z"].join(" ");return A.setAttribute("d",T),A}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.225*Math.min(f.w,f.h)),x=gt("adj2",g,.225*Math.min(f.w,f.h)),S=gt("adj3",g,.225*Math.min(f.w,f.h)),A=x===0?0:w*S/x/2;return{top:f.h-x-w/2,bottom:x-w/2,left:A,right:A,w:f.w-2*A,h:w}}(r);break;case"bentArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.25*Math.min(f.w,f.h)),x=gt("adj2",g,.25*Math.min(f.w,f.h)),S=gt("adj3",g,.25*Math.min(f.w,f.h)),A=gt("adj4",g,.4375*Math.min(f.w,f.h)),T=_t("path");w>2*x&&(w=2*x);var L=A-w;L<0&&(L=0);var M=["M0,".concat(f.h),"L0,".concat(x-w/2+A),"A".concat(A," ").concat(A," 0 0 1 ").concat(A," ").concat(x-w/2),"L".concat(f.w-S,",").concat(x-w/2),"L".concat(f.w-S,",0"),"L".concat(f.w,",").concat(x),"L".concat(f.w-S,",").concat(2*x),"L".concat(f.w-S,",").concat(x+w/2),"L".concat(w+L,",").concat(x+w/2),"A".concat(L," ").concat(L,"  0 0 0 ").concat(w," ").concat(x+w/2+L),"L".concat(w,",").concat(f.h),"Z"].join(" ");return T.setAttribute("d",M),T}(r);break;case"uturnArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.25*Math.min(f.w,f.h)),x=gt("adj2",g,.25*Math.min(f.w,f.h)),S=gt("adj3",g,.25*Math.min(f.w,f.h)),A=gt("adj4",g,.4375*Math.min(f.w,f.h)),T=gt("adj5",g,.75*Math.min(f.w,f.h)),L=_t("path");w>2*x&&(w=2*x),T<S&&(T=S+w),A>T-S&&(A=T-S);var M=A-w;M>T-S-w&&(M=T-S-w),M<0&&(M=0);var I=x-w/2,R=["M0,".concat(f.h),"L0,".concat(A),"A".concat(A," ").concat(A," 0 0 1 ").concat(A," 0"),"L".concat(f.w-A-I,",0"),"A".concat(A," ").concat(A," 0 0 1 ").concat(f.w-I," ").concat(A),"L".concat(f.w-I,",").concat(T-S),"L".concat(f.w,",").concat(T-S),"L".concat(f.w-x,",").concat(T),"L".concat(f.w-2*x,",").concat(T-S),"L".concat(f.w-x-w/2,",").concat(T-S),"L".concat(f.w-x-w/2,",").concat(w+M),"A".concat(M," ").concat(M,"  0 0 0 ").concat(f.w-M-x-w/2," ").concat(w),"L".concat(w+M,",").concat(w),"A".concat(M," ").concat(M,"  0 0 0 ").concat(w," ").concat(w+M),"L".concat(w,",").concat(f.h),"Z"].join(" ");return L.setAttribute("d",R),L}(r);break;case"leftUpArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.25*Math.min(f.w,f.h)),x=gt("adj2",g,.25*Math.min(f.w,f.h)),S=gt("adj3",g,.25*Math.min(f.w,f.h));w>2*x&&(w=2*x);var A=Math.min(f.w,f.h)-2*x;S>A&&(S=A),S<0&&(S=0);var T=x-w/2,L=_t("path"),M=["M0,".concat(f.h-x),"L".concat(S,",").concat(f.h-2*x),"L".concat(S,",").concat(f.h-x-w/2),"L".concat(f.w-x-w/2,",").concat(f.h-x-w/2),"L".concat(f.w-x-w/2,",").concat(S),"L".concat(f.w-2*x,",").concat(S),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(S),"L".concat(f.w-T,",").concat(S),"L".concat(f.w-T,",").concat(f.h-T),"L".concat(S,",").concat(f.h-T),"L".concat(S,",").concat(f.h),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.25*Math.min(f.w,f.h)),x=gt("adj2",g,.25*Math.min(f.w,f.h)),S=gt("adj3",g,.25*Math.min(f.w,f.h));w>2*x&&(w=2*x);var A=Math.min(f.w,f.h)-2*x;S>A&&(S=A),S<0&&(S=0);var T=x===0?0:w*S/x/2;return{top:f.h-x-w/2,bottom:x-w/2,left:T,right:x,w:f.w-T-x,h:w}}(r);break;case"bentUpArrow":h=function(g){var f=g.extend,w=gt("adj1",g,.25*Math.min(f.w,f.h)),x=gt("adj2",g,.25*Math.min(f.w,f.h)),S=gt("adj3",g,.25*Math.min(f.w,f.h));w>2*x&&(w=2*x);var A=Math.min(f.w,f.h)-2*x;S>A&&(S=A),S<0&&(S=0);var T=x-w/2,L=_t("path"),M=["M0,".concat(f.h),"L0,".concat(f.h-w),"L".concat(f.w-x-w/2,",").concat(f.h-w),"L".concat(f.w-x-w/2,",").concat(S),"L".concat(f.w-2*x,",").concat(S),"L".concat(f.w-x,",0"),"L".concat(f.w,",").concat(S),"L".concat(f.w-T,",").concat(S),"L".concat(f.w-T,",").concat(f.h),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=gt("adj1",g,.25*Math.min(f.w,f.h));return{top:f.h-w,bottom:0,left:0,right:0,w:f.w,h:w}}(r);break;case"curvedRightArrow":h=function(g){var f=g.extend,w=g.background,x=gt("adj1",g,.25*Math.min(f.w,f.h)),S=gt("adj2",g,.5*Math.min(f.w,f.h)),A=gt("adj3",g,.25*Math.min(f.w,f.h));x>S&&(x=S);var T=S/2-x/2,L=(f.h-S/2-x/2)/2,M=(f.h-T-x)/2,I=_t("g"),R=_t("path"),P=["M".concat(f.w,",0"),"A ".concat(f.w," ").concat(L," 0 0 0 ").concat(0," ").concat(L),"L0,".concat(M+x),"A ".concat(f.w," ").concat(M," 0 0 1 ").concat(f.w," ").concat(x),"Z"].join(" ");R.setAttribute("d",P),w?.type==="solidFill"&&R.setAttribute("fill",Le(w,{dark:.6})||"transparent");var E=_t("path"),D=["M0,".concat(L),"A ".concat(f.w," ").concat(L," 0 0 0 ").concat(f.w-A," ").concat(f.h-S/2-x/2),"L".concat(f.w-A,",").concat(f.h-S),"L".concat(f.w,",").concat(f.h-S/2),"L".concat(f.w-A,",").concat(f.h),"L".concat(f.w-A,",").concat(f.h-T),"A ".concat(f.w," ").concat(M," 0 0 1 0 ").concat(x+M),"Z"].join(" ");return E.setAttribute("d",D),I.appendChild(R),I.appendChild(E),I}(r);break;case"curvedLeftArrow":h=function(g){var f=g.extend,w=g.background,x=gt("adj1",g,.25*Math.min(f.w,f.h)),S=gt("adj2",g,.5*Math.min(f.w,f.h)),A=gt("adj3",g,.25*Math.min(f.w,f.h));x>S&&(x=S);var T=S/2-x/2,L=(f.h-S/2-x/2)/2,M=(f.h-T-x)/2,I=_t("g"),R=_t("path"),P=["M0,".concat(f.h-S/2),"L".concat(A,",").concat(f.h-S),"L".concat(A,",").concat(f.h-S/2-x/2),"A".concat(f.w," ").concat(L," 0 0 0 ").concat(f.w," ").concat(L),"L".concat(f.w,",").concat(M+x),"A ".concat(f.w," ").concat(M," 0 0 1 ").concat(A," ").concat(f.h-T),"L".concat(A,",").concat(f.h),"Z"].join(" ");R.setAttribute("d",P);var E=_t("path"),D=["M0,0","A ".concat(f.w," ").concat(L," 0 0 1 ").concat(f.w," ").concat(L),"L".concat(f.w,",").concat(M+x),"A ".concat(f.w," ").concat(M," 0 0 0 ").concat(0," ").concat(x),"Z"].join(" ");return E.setAttribute("d",D),w?.type==="solidFill"&&E.setAttribute("fill",Le(w,{dark:.6})||"transparent"),I.appendChild(R),I.appendChild(E),I}(r);break;case"curvedUpArrow":h=function(g){var f=g.extend,w=g.background,x=gt("adj1",g,.25*Math.min(f.w,f.h)),S=gt("adj2",g,.5*Math.min(f.w,f.h)),A=gt("adj3",g,.25*Math.min(f.w,f.h));x>S&&(x=S);var T=S/2-x/2,L=(f.w-S/2-x/2)/2,M=(f.w-T-x)/2,I=_t("g"),R=_t("path"),P=["M".concat(f.w-S/2,",").concat(0),"L".concat(f.w-S,",").concat(A),"L".concat(f.w-S/2-x/2,",").concat(A),"A".concat(L," ").concat(f.h," 0 0 1 ").concat(L," ").concat(f.h),"L".concat(L+x,",").concat(f.h),"A".concat(M," ").concat(f.h," 0 0 0 ").concat(f.w-T," ").concat(A),"L".concat(f.w,",").concat(A),"Z"].join(" ");R.setAttribute("d",P);var E=_t("path"),D=["M".concat(x,",0"),"L".concat(0,",").concat(0),"A ".concat(L," ").concat(f.h," 0 0 0 ").concat(L," ").concat(f.h),"L".concat(L+x,",").concat(f.h),"A ".concat(M," ").concat(f.h," 0 0 1 ").concat(x," ").concat(0),"Z"].join(" ");return E.setAttribute("d",D),w?.type==="solidFill"&&E.setAttribute("fill",Le(w,{dark:.6})||"transparent"),I.appendChild(R),I.appendChild(E),I}(r);break;case"curvedDownArrow":h=function(g){var f=g.extend,w=g.background,x=gt("adj1",g,.25*Math.min(f.w,f.h)),S=gt("adj2",g,.5*Math.min(f.w,f.h)),A=gt("adj3",g,.25*Math.min(f.w,f.h));x>S&&(x=S);var T=S/2-x/2,L=(f.w-S/2-x/2)/2,M=(f.w-T-x)/2,I=_t("g"),R=_t("path"),P=["M".concat(0,",").concat(f.h),"L".concat(x,",").concat(f.h),"A".concat(M," ").concat(f.h," 0 0 1 ").concat(M+x," ").concat(0),"L".concat(L,",").concat(0),"A".concat(L," ").concat(f.h," 0 0 0 ").concat(0," ").concat(f.h),"Z"].join(" ");R.setAttribute("d",P),w?.type==="solidFill"&&R.setAttribute("fill",Le(w,{dark:.6})||"transparent");var E=_t("path"),D=["M".concat(f.w-S/2,",").concat(f.h),"L".concat(f.w-S,",").concat(f.h-A),"L".concat(f.w-S/2-x/2,",").concat(f.h-A),"A ".concat(L," ").concat(f.h," 0 0 0 ").concat(L," ").concat(0),"L".concat(L+x,",").concat(0),"A ".concat(M," ").concat(f.h," 0 0 1 ").concat(f.w-T," ").concat(f.h-A),"L".concat(f.w,",").concat(f.h-A),"Z"].join(" ");return E.setAttribute("d",D),I.appendChild(R),I.appendChild(E),I}(r);break;case"stripedRightArrow":h=function(g){var f=g.extend,w=_t("g"),x=Math.min(f.w,f.h),S=$t("adj1",g,.5)*f.h,A=$t("adj2",g,.5)*x,T=x/8,L=x/16,M=x/32,I=5*x/32,R=f.h/2-S/2,P=f.h/2+S/2,E=_t("path");E.setAttribute("d",["M".concat(0,",").concat(R),"L".concat(M,",").concat(R),"L".concat(M,",").concat(P),"L".concat(0,",").concat(P),"Z"].join(" "));var D=_t("path");D.setAttribute("d",["M".concat(L,",").concat(R),"L".concat(T,",").concat(R),"L".concat(T,",").concat(P),"L".concat(L,",").concat(P),"Z"].join(" "));var N=_t("path"),V=["M".concat(I,",").concat(R),"L".concat(f.w-A,",").concat(R),"L".concat(f.w-A,",").concat(0),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-A,",").concat(f.h),"L".concat(f.w-A,",").concat(P),"L".concat(I,",").concat(P),"Z"].join(" ");return N.setAttribute("d",V),w.appendChild(N),w.appendChild(E),w.appendChild(D),w}(r),v=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.5)*f.h,S=x*($t("adj2",g,.5)*w)/f.h;return{top:f.h/2-x/2,bottom:f.h/2-x/2,left:0,right:S,w:f.w-S,h:x}}(r);break;case"notchedRightArrow":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.5)*f.h,S=$t("adj2",g,.5)*w,A=x*S/f.h,T=f.h/2-x/2,L=f.h/2+x/2,M=_t("path"),I=["M".concat(0,",").concat(T),"L".concat(f.w-S,",").concat(T),"L".concat(f.w-S,",").concat(0),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-S,",").concat(f.h),"L".concat(f.w-S,",").concat(L),"L".concat(0,",").concat(L),"L".concat(A,",").concat(f.h/2),"Z"].join(" ");return M.setAttribute("d",I),M}(r),v=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.5)*f.h,S=$t("adj2",g,.5)*w,A=x*S/f.h,T=x*S/f.h;return{top:f.h/2-x/2,bottom:f.h/2-x/2,left:A,right:T,w:f.w-A-T,h:x}}(r);break;case"homePlate":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj",g,.5)*w,S=_t("path"),A=["M".concat(0,",").concat(0),"L".concat(f.w-x,",").concat(0),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-x,",").concat(f.h),"L".concat(0,",").concat(f.h),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj",g,.5)*w;return{top:0,bottom:0,left:0,right:x/2,w:f.w-x/2,h:f.h}}(r);break;case"chevron":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj",g,.5)*w,S=_t("path"),A=["M".concat(0,",").concat(0),"L".concat(f.w-x,",").concat(0),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-x,",").concat(f.h),"L".concat(0,",").concat(f.h),"L".concat(x,",").concat(f.h/2),"Z"].join(" ");return S.setAttribute("d",A),S}(r),v=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj",g,.5)*w;return{top:0,bottom:0,left:x,right:x,w:f.w-2*x,h:f.h}}(r);break;case"blockArc":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=_t("path"),S=$t("adj1",g,180),A=$t("adj2",g,0),T=gt("adj3",g,.25*w),L=f.w/2,M=f.h/2,I=f.w/2,R=f.h/2,P=f.w/2-T,E=f.h/2-T,D=zr(S,L,M,I,R),N=D[0],V=D[1],W=zr(A,L,M,I,R),$=W[0],H=W[1],K=zr(S,L,M,P,E),U=K[0],j=K[1],ut=zr(A,L,M,P,E),ot=ut[0],it=ut[1],Et=gc(S,A),jt=["M".concat(N,",").concat(V),"A".concat(I," ").concat(R," 0 ").concat(Et," 1 ").concat($," ").concat(H),"L".concat(ot,",").concat(it),"A".concat(P," ").concat(E," 0 ").concat(Et," 0 ").concat(U," ").concat(j),"Z"].join(" ");return x.setAttribute("d",jt),x}(r),v=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,180),S=$t("adj2",g,0),A=gt("adj3",g,.25*w),T=f.w/2,L=f.h/2,M=f.w/2,I=f.h/2,R=f.w/2-A,P=f.h/2-A,E=zr(x,T,L,M,I),D=E[0],N=E[1],V=zr(S,T,L,M,I),W=V[0],$=V[1],H=zr(x,T,L,R,P),K=H[0],U=H[1],j=zr(S,T,L,R,P),ut=[[D,N],[W,$],[K,U],[j[0],j[1]]];ut.push(),x>S&&ut.push([f.w,f.h/2]),(S>180&&S<=360&&x<180||x>S&&S>=0&&S<180&&x<180)&&ut.push([0,f.h/2]),(x<S&&x<90&&S>90||x>S&&S>90||x>S&&x<90)&&ut.push([f.w/2,f.h]),(x<S&&x<270&&S>270||x>S&&S>270||x>S&&x<270)&&ut.push([f.w/2,0]);var ot=1/0,it=1/0,Et=-1/0,jt=-1/0;return ut.forEach(function(bt){ot=Math.min(bt[0],ot),it=Math.min(bt[1],it),Et=Math.max(bt[0],Et),jt=Math.max(bt[1],jt)}),{top:it,bottom:f.h-jt,left:ot,right:f.w-Et,w:Et-ot,h:jt-it}}(r);break;case"foldedCorner":h=function(g){var f=g.extend,w=g.background,x=_t("g"),S=_t("path"),A=gt("adj",g,.16667*Math.min(f.w,f.h)),T=["M0,0","L".concat(f.w,",0"),"L".concat(f.w,",").concat(f.h-A),"L".concat(f.w-A,",").concat(f.h),"L".concat(0,",").concat(f.h),"Z"].join(" ");S.setAttribute("d",T);var L=A*Math.cos(Math.PI/4)/Math.cos(Math.PI/6)*Math.cos(75/180*Math.PI),M=_t("path"),I=["M".concat(f.w-A+L,", ").concat(f.h-A+L),"L".concat(f.w,",").concat(f.h-A),"L".concat(f.w-A,",").concat(f.h),"Z"].join(" ");return M.setAttribute("d",I),w?.type==="solidFill"&&M.setAttribute("fill",Le(w,{dark:.6})||"transparent"),x.appendChild(S),x.appendChild(M),x}(r),v=function(g){var f=g.extend,w=gt("adj",g,.16667*Math.min(f.w,f.h));return{top:0,bottom:w,left:0,right:0,w:f.w,h:f.h-w}}(r);break;case"rightArrowCallout":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.25)*w,S=$t("adj2",g,.25)*w,A=$t("adj3",g,.25)*w,T=$t("adj4",g,.64977)*f.w,L=_t("path"),M=["M".concat(0,",").concat(0),"L".concat(T,",").concat(0),"L".concat(T,",").concat(f.h/2-x/2),"L".concat(f.w-A,",").concat(f.h/2-x/2),"L".concat(f.w-A,",").concat(f.h/2-S),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-A,",").concat(f.h/2+S),"L".concat(f.w-A,",").concat(f.h/2+x/2),"L".concat(T,",").concat(f.h/2+x/2),"L".concat(T,",").concat(f.h),"L".concat(0,",").concat(f.h),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=$t("adj4",g,.64977)*f.w;return{top:0,bottom:0,left:0,right:f.w-w,w,h:f.h}}(r);break;case"leftArrowCallout":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.25)*w,S=$t("adj2",g,.25)*w,A=$t("adj3",g,.25)*w,T=$t("adj4",g,.64977)*f.w,L=_t("path"),M=["M".concat(0,",").concat(f.h/2),"L".concat(A,",").concat(f.h/2-S),"L".concat(A,",").concat(f.h/2-x/2),"L".concat(f.w-T,",").concat(f.h/2-x/2),"L".concat(f.w-T,",").concat(0),"L".concat(f.w,",").concat(0),"L".concat(f.w,",").concat(f.h),"L".concat(f.w-T,",").concat(f.h),"L".concat(f.w-T,",").concat(f.h/2+x/2),"L".concat(A,",").concat(f.h/2+x/2),"L".concat(A,",").concat(f.h/2+S),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=$t("adj4",g,.64977)*f.w;return{top:0,bottom:0,left:f.w-w,right:0,w,h:f.h}}(r);break;case"upArrowCallout":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.25)*w,S=$t("adj2",g,.25)*w,A=$t("adj3",g,.25)*w,T=$t("adj4",g,.64977)*f.h,L=_t("path"),M=["M".concat(0,",").concat(f.h-T),"L".concat(f.w/2-x/2,",").concat(f.h-T),"L".concat(f.w/2-x/2,",").concat(A),"L".concat(f.w/2-S,",").concat(A),"L".concat(f.w/2,",").concat(0),"L".concat(f.w/2+S,",").concat(A),"L".concat(f.w/2+x/2,",").concat(A),"L".concat(f.w/2+x/2,",").concat(f.h-T),"L".concat(f.w,",").concat(f.h-T),"L".concat(f.w,",").concat(f.h),"L".concat(0,",").concat(f.h),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=$t("adj4",g,.64977)*f.h;return{top:f.h-w,bottom:0,left:0,right:0,w:f.w,h:w}}(r);break;case"downArrowCallout":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.25)*w,S=$t("adj2",g,.25)*w,A=$t("adj3",g,.25)*w,T=$t("adj4",g,.64977)*f.h,L=_t("path"),M=["M".concat(0,",").concat(0),"L".concat(f.w,",").concat(0),"L".concat(f.w,",").concat(T),"L".concat(f.w/2+x/2,",").concat(T),"L".concat(f.w/2+x/2,",").concat(f.h-A),"L".concat(f.w/2+S,",").concat(f.h-A),"L".concat(f.w/2,",").concat(f.h),"L".concat(f.w/2-S,",").concat(f.h-A),"L".concat(f.w/2-x/2,",").concat(f.h-A),"L".concat(f.w/2-x/2,",").concat(T),"L".concat(0,",").concat(T),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=$t("adj4",g,.64977)*f.h;return{top:0,bottom:f.h-w,left:0,right:0,w:f.w,h:w}}(r);break;case"leftRightArrowCallout":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.25)*w,S=$t("adj2",g,.25)*w,A=$t("adj3",g,.25)*w,T=$t("adj4",g,.48123)*f.w,L=_t("path"),M=["M".concat(0,",").concat(f.h/2),"L".concat(A,",").concat(f.h/2-S),"L".concat(A,",").concat(f.h/2-x/2),"L".concat(f.w/2-T/2,",").concat(f.h/2-x/2),"L".concat(f.w/2-T/2,",").concat(0),"L".concat(f.w/2+T/2,",").concat(0),"L".concat(f.w/2+T/2,",").concat(f.h/2-x/2),"L".concat(f.w-A,",").concat(f.h/2-x/2),"L".concat(f.w-A,",").concat(f.h/2-S),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-A,",").concat(f.h/2+S),"L".concat(f.w-A,",").concat(f.h/2+x/2),"L".concat(f.w/2+T/2,",").concat(f.h/2+x/2),"L".concat(f.w/2+T/2,",").concat(f.h),"L".concat(f.w/2-T/2,",").concat(f.h),"L".concat(f.w/2-T/2,",").concat(f.h/2+x/2),"L".concat(A,",").concat(f.h/2+x/2),"L".concat(A,",").concat(f.h/2+S),"Z"].join(" ");return L.setAttribute("d",M),L}(r),v=function(g){var f=g.extend,w=$t("adj4",g,.48123)*f.w;return{top:0,bottom:0,left:f.w/2-w/2,right:f.w/2-w/2,w,h:f.h}}(r);break;case"quadArrowCallout":h=function(g){var f=g.extend,w=Math.min(f.w,f.h),x=$t("adj1",g,.18515)*w,S=$t("adj2",g,.18515)*w,A=$t("adj3",g,.18515)*w,T=$t("adj4",g,.48123)*f.w,L=$t("adj4",g,.48123)*f.h,M=_t("path"),I=["M".concat(0,",").concat(f.h/2),"L".concat(A,",").concat(f.h/2-S),"L".concat(A,",").concat(f.h/2-x/2),"L".concat(f.w/2-T/2,",").concat(f.h/2-x/2),"L".concat(f.w/2-T/2,",").concat(f.h/2-L/2),"L".concat(f.w/2-x/2,",").concat(f.h/2-L/2),"L".concat(f.w/2-x/2,",").concat(A),"L".concat(f.w/2-S,",").concat(A),"L".concat(f.w/2,",").concat(0),"L".concat(f.w/2+S,",").concat(A),"L".concat(f.w/2+x/2,",").concat(A),"L".concat(f.w/2+x/2,",").concat(f.h/2-L/2),"L".concat(f.w/2+T/2,",").concat(f.h/2-L/2),"L".concat(f.w/2+T/2,",").concat(f.h/2-x/2),"L".concat(f.w-A,",").concat(f.h/2-x/2),"L".concat(f.w-A,",").concat(f.h/2-S),"L".concat(f.w,",").concat(f.h/2),"L".concat(f.w-A,",").concat(f.h/2+S),"L".concat(f.w-A,",").concat(f.h/2+x/2),"L".concat(f.w/2+T/2,",").concat(f.h/2+x/2),"L".concat(f.w/2+T/2,",").concat(f.h/2+L/2),"L".concat(f.w/2+x/2,",").concat(f.h/2+L/2),"L".concat(f.w/2+x/2,",").concat(f.h-A),"L".concat(f.w/2+S,",").concat(f.h-A),"L".concat(f.w/2,",").concat(f.h),"L".concat(f.w/2-S,",").concat(f.h-A),"L".concat(f.w/2-x/2,",").concat(f.h-A),"L".concat(f.w/2-x/2,",").concat(f.h/2+L/2),"L".concat(f.w/2-T/2,",").concat(f.h/2+L/2),"L".concat(f.w/2-T/2,",").concat(f.h/2+x/2),"L".concat(A,",").concat(f.h/2+x/2),"L".concat(A,",").concat(f.h/2+S),"Z"].join(" ");return M.setAttribute("d",I),M}(r),v=function(g){var f=g.extend,w=$t("adj4",g,.48123)*f.w,x=$t("adj4",g,.48123)*f.h;return{top:f.h/2-x/2,bottom:f.h/2-x/2,left:f.w/2-w/2,right:f.w/2-w/2,w,h:x}}(r)}h&&(p?a?.type==="blipFill"?function(g,f,w){var x=g.background,S=x===void 0?{}:x,A=g.extend,T=S.base64,L=S.alpha,M=S.fillRect,I=M===void 0?{}:M,R=I.b,P=R===void 0?0:R,E=I.t,D=E===void 0?0:E,N=I.l,V=N===void 0?0:N,W=I.r,$=W===void 0?0:W,H=_t("defs"),K=_t("pattern");K.setAttribute("id","background_"+g.uuid),K.setAttribute("patternUnits","userSpaceOnUse"),K.setAttribute("width",A.w+""),K.setAttribute("height",A.h+"");var U=_t("image");U.setAttribute("href",T),U.setAttribute("preserveAspectRatio","none");var j=A.w*V,ut=A.h*D,ot=A.w*(1-V-$),it=A.h*(1-D-P);U.setAttribute("width",ot+""),U.setAttribute("height",it+""),U.setAttribute("x",j+""),U.setAttribute("y",ut+""),typeof L=="number"&&U.setAttribute("opacity",L+""),K.appendChild(U),H.appendChild(K),f.appendChild(H),w.setAttribute("fill","url(#background_".concat(g.uuid,")"))}(r,d,h):a?.type==="gradFill"?function(g,f,w){var x=g.background,S=x===void 0?{}:x;g.extend;var A=S.gsList,T=S.lin,L=S.path,M=S.tileRect,I=M===void 0?{}:M,R=_t("defs"),P=_t(L==="circle"?"radialGradient":"linearGradient");P.setAttribute("id","background_grad_fill_"+g.uuid);var E=A||[];if(E.sort(function($,H){return $.pos-H.pos}),E.forEach(function($){var H=_t("stop");H.setAttribute("offset","".concat(100*$.pos,"%")),H.setAttribute("stop-color",Le($.color)),P.appendChild(H)}),L==="circle"){var D=I.r,N=I.l,V=I.t,W=I.b;D===-1?P.setAttribute("cx","100%"):N===-1&&P.setAttribute("cx","0%"),V===-1?P.setAttribute("cy","0%"):W===-1&&P.setAttribute("cy","100%")}else T?.ang&&P.setAttribute("gradientTransform","rotate(".concat(T.ang,")"));R.appendChild(P),f.appendChild(R),w.setAttribute("fill","url(#background_grad_fill_".concat(g.uuid,")"))}(r,d,h):h.setAttribute("fill",Le(a)||"transparent"):h.setAttribute("fill","transparent"),n.width?(h.setAttribute("stroke-width",n.width+"px"),h.setAttribute("stroke",Le(n.color)||"transparent")):h.setAttribute("stroke-width","0"),h.setAttribute("stroke-dasharray",function(g){return g&&g.type!=="solid"?({sysDot:[1,1],sysDash:[3,1],dash:[4,3],dashDot:[4,3,1,3],lgDash:[8,3],lgDashDot:[8,3,1,3],lgDashDotDot:[8,3,1,3,1,3]}[g.type]||[]).map(function(f){return f*g.width}).join(","):""}(n)),h.setAttribute("stroke-linecap",n.cap&&{sq:"square",rnd:"round",flat:"butt"}[n.cap]||"square"),h.setAttribute("stroke-linejoin",n.lineJoin||"round"),n.lineJoin==="miter"&&h.setAttribute("stroke-miterlimit",n.miterLim+""),d.appendChild(h));var y=[];o&&y.push("scaleX(-1)"),s&&y.push("scaleY(-1)"),d.style.setProperty("transform",y.join(" ")),l.appendChild(d);var _=function(g,f,w){var x;w===void 0&&(w=!1);var S=g.inheritProps,A=g.props,T=g.paragraphs;if(!T||T.length===0)return null;var L=Dt(Dt({},S),A),M=document.createElement("div");switch(M.className="text-wrapper",M.style.boxSizing="border-box",M.style.position="absolute",M.style.left=f.left+"px",L.vert==="eaVert"?(M.style.writingMode="vertical-rl",M.style.height=f.h+"px"):M.style.width=f.w+"px",L.anchor){case"b":M.style.bottom=f.bottom+"px";break;case"t":M.style.top=f.top+"px";break;case"ctr":M.style.top=f.top+f.h/2+"px",M.style.transform="translateY(-50%)";break;default:w?M.style.top=f.top+"px":(M.style.top=f.top+f.h/2+"px",M.style.transform="translateY(-50%)")}var I=[L.hasOwnProperty("tIns")?Math.floor(L.tIns)+"px":"3px",L.hasOwnProperty("rIns")?Math.floor(L.rIns)+"px":"5px",L.hasOwnProperty("bIns")?Math.floor(L.bIns)+"px":"3px",L.hasOwnProperty("lIns")?Math.floor(L.lIns)+"px":"5px"];M.style.padding=I.join(" ");for(var R={},P=0,E=function(V){var W=Dt(Dt({},V.inheritProps),V.props),$=void 0;if(W.buAutoNum){var H=W.level?+W.level:0;R[H]||(R[H]=0),!((x=V.rows)===null||x===void 0)&&x.length&&R[H]++,Object.keys(R).forEach(function(K){+K>H&&(R[K]=0)}),$=up(V,R[H],{isFirst:P===0,isLast:T.length-1===P,bodyProps:L})}else $=up(V,0,{isFirst:P===0,isLast:T.length-1===P,bodyProps:L});M.appendChild($),P++},D=0,N=T;D<N.length;D++)E(N[D]);return M}(r.textBody,v,r.isTextBox);return _&&l.appendChild(_),i&&l.style.setProperty("transform","rotate(".concat(i,"deg)")),l}function xB(r){var e=document.createElement("div"),t=r.extend;r.chExtend;var n=r.offset;r.chOffset;var a=r.flipV,i=r.flipH,o=r.rotate,s=n.x,l=n.y,u=t.w,c=t.h;e.className="group",e.style.position="absolute",e.style.left=s+"px",e.style.top=l+"px",e.style.width=u+"px",e.style.height=c+"px";var h=[];i&&h.push("scaleX(-1)"),a&&h.push("scaleY(-1)"),o&&h.push("rotate(".concat(o,"deg)")),e.style.transformOrigin="center center",e.style.transform=h.join(" ");for(var d=0;d<r.nodes.length;d++){var v=r.nodes[d],p=void 0;v instanceof lp?p=P1(v):v instanceof bh?p=k1(v):v instanceof Hx&&(p=xB(v)),p&&e.appendChild(p)}return e}var pa={};function kI(r,e){pa[r]||(pa[r]=[]),pa[r].push(e)}function Hv(r,e){if(pa[r])for(var t=0;t<pa[r].length;t++)pa[r][t](e)}function F0(r,e){pa?pa[r]&&(pa[r]=pa[r].filter(function(t){return t!==e})):pa[r]=[]}var RI=function(){function r(e,t,n){this.scale=1,this.wrapper=e,this.pptx=t,this.options=n,this._calcScaleAndRenderPort()}return r.prototype._calcScaleAndRenderPort=function(){var e=this.options.viewPort.width/this.pptx.width;this.scale=e;var t=this.options.viewPort.width,n=this.pptx.height*this.scale;this.renderPort={width:t,height:n,left:0,top:0}},r.prototype.renderSlide=function(e){var t=this.pptx.slides[e],n=document.createElement("div");n.classList.add("pptx-preview-slide-wrapper"),n.classList.add("pptx-preview-slide-wrapper-".concat(e)),n.style.setProperty("width",this.renderPort.width+"px"),n.style.setProperty("height",this.renderPort.height+"px"),n.style.setProperty("position",this.options.mode==="slide"?"absolute":"relative"),this.options.mode==="slide"&&n.style.setProperty("top",(this.options.viewPort.height-this.renderPort.height)/2+"px"),n.style.margin="0 auto 10px",n.style.setProperty("background","#fff"),n.style.setProperty("overflow","hidden"),this._renderBackground(t,n),this._renderSlideMaster(t.slideMaster,n),this._renderSlideLayout(t.slideLayout,n),this._renderSlide(t,n),this.wrapper.append(n)},r.prototype._renderSlideMaster=function(e,t){var n=document.createElement("div");n.classList.add("slide-master-wrapper"),n.style.setProperty("position","absolute"),n.style.setProperty("left","0"),n.style.setProperty("top","0"),n.style.setProperty("width",this.pptx.width+"px"),n.style.setProperty("height",this.pptx.height+"px"),n.style.setProperty("transform","scale(".concat(this.scale,")")),n.style.setProperty("transform-origin","0 0");var a=Ic([],e.nodes,!0).filter(function(s){return s.userDrawn});a.sort(function(s,l){return s.order>l.order?1:-1});for(var i=0;i<a.length;i++){var o=this._renderNode(a[i]);o&&n.append(o)}t.append(n)},r.prototype._renderSlideLayout=function(e,t){var n=document.createElement("div");n.classList.add("slide-layout-wrapper"),n.style.setProperty("position","absolute"),n.style.setProperty("left","0"),n.style.setProperty("top","0"),n.style.setProperty("width",this.pptx.width+"px"),n.style.setProperty("height",this.pptx.height+"px"),n.style.setProperty("transform","scale(".concat(this.scale,")")),n.style.setProperty("transform-origin","0 0");var a=Ic([],e.nodes,!0).filter(function(s){return s.userDrawn});a.sort(function(s,l){return s.order>l.order?1:-1});for(var i=0;i<a.length;i++){var o=this._renderNode(a[i]);o&&n.append(o)}t.append(n)},r.prototype._renderSlide=function(e,t){var n=document.createElement("div");n.classList.add("slide-wrapper"),n.style.setProperty("position","absolute"),n.style.setProperty("left","0"),n.style.setProperty("top","0"),n.style.setProperty("width",this.pptx.width+"px"),n.style.setProperty("height",this.pptx.height+"px"),n.style.setProperty("transform","scale(".concat(this.scale,")")),n.style.setProperty("transform-origin","0 0");var a=Ic([],e.nodes,!0);a.sort(function(s,l){return s.order>l.order?1:-1});for(var i=0;i<a.length;i++){var o=this._renderNode(a[i]);o&&n.append(o)}t.append(n)},r.prototype._renderNode=function(e){return e instanceof lp?P1(e):e instanceof bh?k1(e):e instanceof Hx?xB(e):e instanceof mB?function(t){var n=document.createElement("div"),a=t.extend,i=t.offset,o=t.flipV,s=t.flipH,l=t.rotate,u=i.x,c=i.y,h=a.w,d=a.h;n.className="smart-chart-diagram",n.style.position="absolute",n.style.left=u+"px",n.style.top=c+"px",n.style.width=h+"px",n.style.height=d+"px";var v=[];s&&v.push("scaleX(-1)"),o&&v.push("scaleY(-1)"),l&&v.push("rotate(".concat(l,"deg)")),n.style.transformOrigin="center center",n.style.transform=v.join(" ");for(var p=0;p<t.nodes.length;p++){var y=t.nodes[p],_=void 0;y instanceof lp?_=P1(y):y instanceof bh&&(_=k1(y)),_&&n.appendChild(_)}return n}(e):e instanceof yB?function(t){var n=t.extend,a=t.offset,i=t.tr,o=t.tableGrid.gridCol,s=document.createElement("div");s.style.position="absolute",s.style.left=a.x+"px",s.style.top=a.y+"px",s.style.width=n.w+"px",s.style.height=n.h+"px";var l=document.createElement("table");return l.style.borderCollapse="collapse",i.forEach(function(u){var c=u.props,h=u.td,d=c.height,v=document.createElement("tr");v.style.height=d+"px",h.forEach(function(p,y){var _,g,f=p.props,w=p.inheritTcStyle,x=p.inheritTcTxStyle,S=p.paragraphs;if(!f.vMerge&&!f.hMerge){var A=document.createElement("td");A.style.width=(((_=o[y])===null||_===void 0?void 0:_.width)||30)+"px",f.rowSpan&&A.setAttribute("rowspan",f.rowSpan+""),f.gridSpan&&A.setAttribute("colspan",f.gridSpan+"");var T=f.background||w.background;T&&(A.style.background=Le(T));var L=Dt(Dt({},w.border),f.border),M=function(H){return H?H.toLowerCase().includes("dash")?"dashed":H.toLowerCase().includes("dot")?"dotted":"solid":"solid"};L.bottom&&(A.style.borderBottom="".concat(L.bottom.width,"px ").concat(M(L.bottom.type)," ").concat(Le(L.bottom.color))),L.top&&(A.style.borderTop="".concat(L.top.width,"px ").concat(M(L.top.type)," ").concat(Le(L.top.color))),L.left&&(A.style.borderLeft="".concat(L.left.width,"px ").concat(M(L.left.type)," ").concat(Le(L.left.color))),L.right&&(A.style.borderRight="".concat(L.right.width,"px ").concat(M(L.right.type)," ").concat(Le(L.right.color)));var I=document.createElement("div");switch(I.className="text-wrapper",I.style.boxSizing="border-box",I.style.width="100%",I.style.height="100%",I.style.overflow="hidden",I.style.display="flex",I.style.flexDirection="column",f.anchor){case"b":I.style.justifyContent="flex-end";break;case"t":I.style.justifyContent="flex-start";break;case"ctr":I.style.justifyContent="center"}var R=[f.hasOwnProperty("marT")?Math.floor(f.marT)+"px":"3px",f.hasOwnProperty("marR")?Math.floor(f.marR-1)+"px":"5px",f.hasOwnProperty("marB")?Math.floor(f.marB)+"px":"3px",f.hasOwnProperty("marL")?Math.floor(f.marL-1)+"px":"5px"];I.style.padding=R.join(" ");for(var P=Dt({},f),E={},D=S.map(function(H){return Dt(Dt({},H),{props:Dt({align:"l"},H.props),inheritRProps:Dt(Dt({},H.inheritRProps),x)})}),N=0,V=function(H){var K=Dt(Dt({},H.inheritProps),H.props),U=void 0;if(K.buAutoNum){var j=K.level?+K.level:0;E[j]||(E[j]=0),!((g=H.rows)===null||g===void 0)&&g.length&&E[j]++,Object.keys(E).forEach(function(ut){+ut>j&&(E[ut]=0)}),U=up(H,E[j],{isFirst:N===0,isLast:S.length-1===N,bodyProps:P})}else U=up(H,0,{isFirst:N===0,isLast:S.length-1===N,bodyProps:P});I.appendChild(U),N++},W=0,$=D;W<$.length;W++)V($[W]);A.append(I),v.append(A)}}),l.append(v)}),s.append(l),s}(e):e instanceof _B?function(t){var n=document.createElement("div"),a=t.extend,i=t.offset,o=t.flipV,s=t.flipH,l=t.rotate,u=t.options,c=i.x,h=i.y,d=a.w,v=a.h;n.className="chart-node",n.style.position="absolute",n.style.left=c+"px",n.style.top=h+"px",n.style.width=d+"px",n.style.height=v+"px";var p=[];return s&&p.push("scaleX(-1)"),o&&p.push("scaleY(-1)"),l&&p.push("rotate(".concat(l,"deg)")),n.style.transformOrigin="center center",n.style.transform=p.join(" "),setTimeout(function(){var y=$9(n,null,{renderer:"svg"});y.setOption(u),kI("destroy",function(){y&&y.dispose(),y&&(y=null)}),kI("removeSlide",function(){y&&y.dispose(),y&&(y=null)})},0),n}(e):void 0},r.prototype._renderBackground=function(e,t){var n,a=document.createElement("div");a.classList.add("slide-background"),a.style.setProperty("position","absolute"),a.style.setProperty("left","0"),a.style.setProperty("top","0"),a.style.setProperty("width","100%"),a.style.setProperty("height","100%");var i=e.background;if(i.type==="none"&&(i=e.slideLayout.background),i.type==="none"&&(i=e.slideMaster.background),i.type==="blipFill"){var o=i,s=o.base64,l=o.alpha,u=o.fillRect,c=u===void 0?{}:u,h=c.b,d=h===void 0?0:h,v=c.t,p=v===void 0?0:v,y=c.l,_=y===void 0?0:y,g=c.r,f=g===void 0?0:g,w=this.renderPort.width*_,x=this.renderPort.height*p,S=this.renderPort.width*(1-_-f),A=this.renderPort.height*(1-p-d);a.style.backgroundImage="url(".concat(s,")"),a.style.backgroundSize="".concat(S," ").concat(A),a.style.backgroundPosition="".concat(w,"px ").concat(x,"px"),l&&(a.style.opacity=l+""),a.style.backgroundRepeat="no-repeat"}else if(i.type==="solidFill"){var T=Le(e.background)||Le(e.slideLayout.background)||Le(e.slideMaster.background);T?a.style.setProperty("background",T):a.style.setProperty("background","#fff")}else if(i.type==="gradFill")if(i.path==="circle"){var L=i.tileRect||{},M=(d=L.b,p=L.t,_=L.l,"radial-gradient(circle at ");(f=L.r)===-1?M+=" right":_===-1&&(M+=" left"),p===-1?M+=" top":d===-1&&(M+=" bottom"),d||p||_||f||(M+=" center"),M+=",",M+=i.gsList.map(function(R){return"".concat(Le(R.color)," ").concat(100*R.pos+"%")}).join(","),a.style.setProperty("background",M)}else{var I=((n=i?.lin)===null||n===void 0?void 0:n.ang)||0;M="linear-gradient(".concat(I+90,"deg,"),M+=i.gsList.map(function(R){return"".concat(Le(R.color)," ").concat(100*R.pos+"%")}).join(","),a.style.setProperty("background",M)}t.append(a)},r}(),uot=function(){function r(e,t){this.currentIndex=-1,this.dom=e,this.options=t,this._renderWrapper()}return Object.defineProperty(r.prototype,"slideCount",{get:function(){var e,t;return(t=(e=this.pptx)===null||e===void 0?void 0:e.slides)===null||t===void 0?void 0:t.length},enumerable:!1,configurable:!0}),r.prototype._renderWrapper=function(){var e=document.createElement("div");e.classList.add("pptx-preview-wrapper"),e.setAttribute("position","relative"),e.style.setProperty("background","#000"),e.style.setProperty("width",this.options.width+"px"),this.options.height&&e.style.setProperty("height",this.options.height+"px"),e.style.setProperty("position","relative"),e.style.setProperty("margin","0 auto"),this.options.height&&e.style.setProperty("overflow-y","auto"),this.dom.append(e),this.wrapper=e},r.prototype.renderNextButton=function(){var e=document.createElement("div");e.classList.add("pptx-preview-wrapper-next"),e.style.setProperty("position","absolute"),e.style.setProperty("bottom","20px"),e.style.setProperty("right","80px"),e.style.setProperty("z-index","100"),e.style.setProperty("cursor","pointer"),e.style.setProperty("width","40px"),e.style.setProperty("height","40px"),e.style.setProperty("background","#666666"),e.style.setProperty("border-radius","100%");var t=document.createElement("div");return t.style.setProperty("width","10px"),t.style.setProperty("height","10px"),t.style.setProperty("border-left","2px solid #fff"),t.style.setProperty("border-bottom","2px solid #fff"),t.style.setProperty("transform","rotate(225deg)"),t.style.setProperty("position","absolute"),t.style.setProperty("top","15px"),t.style.setProperty("left","15px"),e.append(t),e},r.prototype.renderPreButton=function(){var e=document.createElement("div");e.classList.add("pptx-preview-wrapper-next"),e.style.setProperty("position","absolute"),e.style.setProperty("bottom","20px"),e.style.setProperty("right","140px"),e.style.setProperty("z-index","100"),e.style.setProperty("cursor","pointer"),e.style.setProperty("width","40px"),e.style.setProperty("height","40px"),e.style.setProperty("background","#666666"),e.style.setProperty("border-radius","100%");var t=document.createElement("div");return t.style.setProperty("width","10px"),t.style.setProperty("height","10px"),t.style.setProperty("border-left","2px solid #fff"),t.style.setProperty("border-bottom","2px solid #fff"),t.style.setProperty("transform","rotate(45deg)"),t.style.setProperty("position","absolute"),t.style.setProperty("top","15px"),t.style.setProperty("left","15px"),e.append(t),e},r.prototype.updatePagination=function(){var e=this.wrapper.querySelector(".pptx-preview-wrapper-pagination");e&&(e.innerText="".concat(this.currentIndex+1,"/").concat(this.slideCount))},r.prototype.renderPagination=function(e){var t=document.createElement("div");t.classList.add("pptx-preview-wrapper-pagination"),t.innerText="".concat(this.currentIndex+1,"/").concat(this.slideCount),t.style.setProperty("position","absolute"),t.style.setProperty("bottom","33px"),t.style.setProperty("right","20px"),t.style.setProperty("color","#666666"),t.style.setProperty("font-size","14px"),t.style.setProperty("z-index","100"),e.append(t)},r.prototype.removeCurrentSlide=function(){var e=this.wrapper.querySelector(".pptx-preview-slide-wrapper-".concat(this.currentIndex));e&&this.wrapper.removeChild(e),Hv("removeSlide")},r.prototype.renderNextSlide=function(){this.removeCurrentSlide(),this.currentIndex=this.currentIndex<this.slideCount-1?this.currentIndex+1:0,this.htmlRender.renderSlide(this.currentIndex),this.updatePagination()},r.prototype.renderPreSlide=function(){this.removeCurrentSlide(),this.currentIndex=this.currentIndex>0?this.currentIndex-1:this.slideCount-1,this.htmlRender.renderSlide(this.currentIndex),this.updatePagination()},r.prototype._addPre=function(e){},r.prototype.preview=function(e){var t=this;return Hv("destroy"),F0("destroy"),new Promise(function(n,a){t.wrapper.innerHTML="";var i=t.pptx=new AI;i.load(e).then(function(){try{var o=t.htmlRender=new RI(t.wrapper,i,{viewPort:{width:t.options.width,height:t.options.height},mode:t.options.mode});if(t.options.mode==="slide"){var s=t.renderNextButton();s.onclick=function(){t.renderNextSlide()},t.wrapper.append(s);var l=t.renderPreButton();l.onclick=function(){t.renderPreSlide()},t.wrapper.append(l),t.renderPagination(t.wrapper),t._addPre(t.wrapper),t.currentIndex=0,o.renderSlide(0)}else for(var u=0;u<i.slides.length;u++)o.renderSlide(u);n(i)}catch(c){a(c)}}).catch(function(o){a(o)})})},r.prototype.load=function(e){var t=this;return Hv("destroy"),F0("destroy"),new Promise(function(n,a){t.wrapper.innerHTML="";var i=t.pptx=new AI;i.load(e).then(function(){try{t.htmlRender=new RI(t.wrapper,i,{viewPort:{width:t.options.width,height:t.options.height},mode:t.options.mode}),n(i)}catch(o){a(o)}}).catch(function(o){a(o)})})},r.prototype.renderSingleSlide=function(e){this.removeCurrentSlide(),this.currentIndex=e,this.htmlRender.renderSlide(this.currentIndex)},r.prototype.destroy=function(){Hv("destroy"),F0("destroy")},r}();function cot(r,e){return new uot(r,e)}const bB="FILE_BASE64_PLACEHOLDER",hot=1;let R1=globalThis.fileBase64||bB,fot=globalThis.pageNumber||hot;function vot(){if(!document.getElementById("container"))return;const e=document.createElement("div");e.style.cssText=`
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: white;
    display: flex;
    justify-content: center;
    align-items: center;
    z-index: 1000;
  `,e.innerHTML=`
    <div style="padding: 2rem; text-align: center;">
      <h2>Local Testing Mode</h2>
      <p>Select a PPTX file to render:</p>
      <input type="file" accept=".pptx" id="file-input" style="margin: 1rem 0;">
    </div>
  `,document.body.appendChild(e),document.getElementById("file-input").addEventListener("change",async n=>{const a=n.target.files?.[0];if(!a)return;const i=new FileReader;i.onload=async o=>{R1=(o.target?.result).split(",")[1],e.remove(),await SB()},i.readAsDataURL(a)})}async function SB(){try{const r=document.getElementById("pptx-container");if(!r)throw new Error("PPTX container element not found");if(R1===bB)return vot(),{width:1280,height:960,pageCount:1,pageNumber:1,scale:1};const e=atob(R1),t=new Uint8Array(e.length);for(let v=0;v<e.length;v++)t[v]=e.charCodeAt(v);const n=t.buffer,a=960,i=540,o=2;await cot(r,{width:a,height:i}).preview(n),await new Promise(v=>setTimeout(v,500));const l=r.querySelectorAll('.pptx-preview-slide, [class*="slide"]'),u=Math.max(l.length,1),c=Math.max(1,Math.min(fot,u));l.length>1&&c<=l.length&&l.forEach((v,p)=>{v.style.display=p===c-1?"block":"none"});const h=Math.ceil(a*o),d=Math.ceil(i*o);return{width:h,height:d,pageCount:u,pageNumber:c,scale:o}}catch(r){throw console.error("Error rendering PPTX:",r),r}}window.renderComplete=SB();</script>
</head>
<body>
  <div id="container">
    <div id="pptx-container"></div>
  </div>
</body>
</html>
